// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
try {
  this['Module'] = Module;
} catch(e) {
  this['Module'] = Module = {};
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function(filename) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename).toString();
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename).toString();
    }
    return ret;
  };

  Module['load'] = function(f) {
    globalEval(read(f));
  };

  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
}

if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  // Polyfill over SpiderMonkey/V8 differences
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function(f) { snarf(f) };
  }

  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}

if (ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }

  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }
}

if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}

if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...
  var TRY_USE_DUMP = false;
  if (!Module['print']) {
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  Module['load'] = importScripts;
}

if (!ENVIRONMENT_IS_WORKER && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_SHELL) {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];

  
// === Auto-generated preamble library stuff ===

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (/^\[\d+\ x\ (.*)\]/.test(type)) return true; // [15 x ?] blocks. Like structs
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  BITSHIFT64_SHL: 0,
  BITSHIFT64_ASHR: 1,
  BITSHIFT64_LSHR: 2,
  bitshift64: function (low, high, op, bits) {
    var ret;
    var ander = Math.pow(2, bits)-1;
    if (bits < 32) {
      switch (op) {
        case Runtime.BITSHIFT64_SHL:
          ret = [low << bits, (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits))];
          break;
        case Runtime.BITSHIFT64_ASHR:
          ret = [(((low >>> bits ) | ((high&ander) << (32 - bits))) >> 0) >>> 0, (high >> bits) >>> 0];
          break;
        case Runtime.BITSHIFT64_LSHR:
          ret = [((low >>> bits) | ((high&ander) << (32 - bits))) >>> 0, high >>> bits];
          break;
      }
    } else if (bits == 32) {
      switch (op) {
        case Runtime.BITSHIFT64_SHL:
          ret = [0, low];
          break;
        case Runtime.BITSHIFT64_ASHR:
          ret = [high, (high|0) < 0 ? ander : 0];
          break;
        case Runtime.BITSHIFT64_LSHR:
          ret = [high, 0];
          break;
      }
    } else { // bits > 32
      switch (op) {
        case Runtime.BITSHIFT64_SHL:
          ret = [0, low << (bits - 32)];
          break;
        case Runtime.BITSHIFT64_ASHR:
          ret = [(high >> (bits - 32)) >>> 0, (high|0) < 0 ? ander : 0];
          break;
        case Runtime.BITSHIFT64_LSHR:
          ret = [high >>>  (bits - 32) , 0];
          break;
      }
    }
    HEAP32[tempDoublePtr>>2] = ret[0]; // cannot use utility functions since we are in runtime itself
    HEAP32[tempDoublePtr+4>>2] = ret[1];
  },
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = size;
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Types.types[field].alignSize;
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      alignSize = type.packed ? 1 : Math.min(alignSize, Runtime.QUANTUM_SIZE);
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  addFunction: function (func, sig) {
    //assert(sig); // TODO: support asm
    var table = FUNCTION_TABLE; // TODO: support asm
    var ret = table.length;
    table.push(func);
    table.push(0);
    return ret;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function stackAlloc(size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+3)>>2)<<2); return ret; },
  staticAlloc: function staticAlloc(size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+3)>>2)<<2); if (STATICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function alignMemory(size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 4))*(quantum ? quantum : 4); return ret; },
  makeBigInt: function makeBigInt(low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>0)))+((+(((high)>>>0)))*(+(4294967296)))) : ((+(((low)>>>0)))+((+(((high)|0)))*(+(4294967296))))); return ret; },
  QUANTUM_SIZE: 4,
  __dummy__: 0
}







//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.
var setjmpId = 1; // Used in setjmp/longjmp
var setjmpLabels = {};

var ABORT = false;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = eval('_' + ident);
  } catch(e) {
    try {
      func = globalScope['Module']['_' + ident]; // closure exported function
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;

// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,Math.min(Math.floor((value)/(+(4294967296))), (+(4294967295)))>>>0],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF32[((ptr)>>2)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;

// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF32[((ptr)>>2)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_NONE = 3; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// Simple unoptimized memset - necessary during startup
var _memset = function(ptr, value, num) {
  var stop = ptr + num;
  while (ptr < stop) {
    HEAP8[(ptr++)]=value;
  }
}

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    _memset(ret, 0, size);
    return ret;
  }

  if (singleType === 'i8') {
    HEAPU8.set(new Uint8Array(slab), ret);
    return ret;
  }

  var i = 0, type;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);
    i += Runtime.getNativeTypeSize(type);
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  var utf8 = new Runtime.UTF8Processor();
  var nullTerminated = typeof(length) == "undefined";
  var ret = "";
  var i = 0;
  var t;
  while (1) {
    t = HEAPU8[((ptr)+(i))];
    if (nullTerminated && t == 0) break;
    ret += utf8.processCChar(t);
    i += 1;
    if (!nullTerminated && i == length) break;
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

function Array_stringify(array) {
  var ret = "";
  for (var i = 0; i < array.length; i++) {
    ret += String.fromCharCode(array[i]);
  }
  return ret;
}
Module['Array_stringify'] = Array_stringify;

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STACK_ROOT, STACKTOP, STACK_MAX;
var STATICTOP;
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Compile with -s TOTAL_MEMORY=X with X higher than the current value.');
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 134217728;
var FAST_MEMORY = Module['FAST_MEMORY'] || 10485760;

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

STACK_ROOT = STACKTOP = Runtime.alignMemory(1);
STACK_MAX = TOTAL_STACK; // we lose a little stack here, but TOTAL_STACK is nice and round so use that as the max

var tempDoublePtr = Runtime.alignMemory(allocate(12, 'i8', ALLOC_STACK), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}

STATICTOP = STACK_MAX;
assert(STATICTOP < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY

var nullString = allocate(intArrayFromString('(null)'), 'i8', ALLOC_STACK);

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown

function initRuntime() {
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}

// Tools

// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[((buffer)+(i))]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[((buffer)+(i))]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 6000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data

// === Body ===



assert(STATICTOP == STACK_MAX); assert(STACK_MAX == TOTAL_STACK);

STATICTOP += 580;

assert(STATICTOP < TOTAL_MEMORY);







allocate([47,116,109,112,47,101,109,115,99,114,105,112,116,101,110,95,116,101,109,112,47,100,108,109,97,108,108,111,99,46,99,112,112,0] /* /tmp/emscripten_temp */, "i8", ALLOC_NONE, 5242880);
allocate([42,37,100,44,37,100,42,10,0] /* _%d,%d_\0A\00 */, "i8", ALLOC_NONE, 5242916);
allocate([97,108,108,111,99,97,116,105,111,110,115,91,105,93,0] /* allocations[i]\00 */, "i8", ALLOC_NONE, 5242928);
allocate([105,110,116,32,109,97,105,110,40,105,110,116,44,32,99,104,97,114,32,42,42,41,0] /* int main(int, char _ */, "i8", ALLOC_NONE, 5242944);
allocate(24, "i8", ALLOC_NONE, 5242968);
allocate(468, "i8", ALLOC_NONE, 5242992);

  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }

  
  
  
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }
  
  function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      if (!___setErrNo.ret) ___setErrNo.ret = allocate([0], 'i32', ALLOC_STATIC);
      HEAP32[((___setErrNo.ret)>>2)]=value
      return value;
    }
  
  var ERRNO_CODES={E2BIG:7,EACCES:13,EADDRINUSE:98,EADDRNOTAVAIL:99,EAFNOSUPPORT:97,EAGAIN:11,EALREADY:114,EBADF:9,EBADMSG:74,EBUSY:16,ECANCELED:125,ECHILD:10,ECONNABORTED:103,ECONNREFUSED:111,ECONNRESET:104,EDEADLK:35,EDESTADDRREQ:89,EDOM:33,EDQUOT:122,EEXIST:17,EFAULT:14,EFBIG:27,EHOSTUNREACH:113,EIDRM:43,EILSEQ:84,EINPROGRESS:115,EINTR:4,EINVAL:22,EIO:5,EISCONN:106,EISDIR:21,ELOOP:40,EMFILE:24,EMLINK:31,EMSGSIZE:90,EMULTIHOP:72,ENAMETOOLONG:36,ENETDOWN:100,ENETRESET:102,ENETUNREACH:101,ENFILE:23,ENOBUFS:105,ENODATA:61,ENODEV:19,ENOENT:2,ENOEXEC:8,ENOLCK:37,ENOLINK:67,ENOMEM:12,ENOMSG:42,ENOPROTOOPT:92,ENOSPC:28,ENOSR:63,ENOSTR:60,ENOSYS:38,ENOTCONN:107,ENOTDIR:20,ENOTEMPTY:39,ENOTRECOVERABLE:131,ENOTSOCK:88,ENOTSUP:95,ENOTTY:25,ENXIO:6,EOVERFLOW:75,EOWNERDEAD:130,EPERM:1,EPIPE:32,EPROTO:71,EPROTONOSUPPORT:93,EPROTOTYPE:91,ERANGE:34,EROFS:30,ESPIPE:29,ESRCH:3,ESTALE:116,ETIME:62,ETIMEDOUT:110,ETXTBSY:26,EWOULDBLOCK:11,EXDEV:18};function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == '-'.charCodeAt(0)) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == '+'.charCodeAt(0)) {
        str++;
      }
  
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == '0'.charCodeAt(0)) {
          if (HEAP8[(str+1)] == 'x'.charCodeAt(0) ||
              HEAP8[(str+1)] == 'X'.charCodeAt(0)) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      }
      if (!finalBase) finalBase = 10;
  
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
  
      // Apply sign.
      ret *= multiplier;
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
  
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
  
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
  
      if (bits == 64) {
        return (asm.setTempRet0(Math.min(Math.floor((ret)/(+(4294967296))), (+(4294967295)))>>>0),ret>>>0);
      }
  
      return ret;
    }function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }

  function _llvm_stacksave() {
      var self = _llvm_stacksave;
      if (!self.LLVM_SAVEDSTACKS) {
        self.LLVM_SAVEDSTACKS = [];
      }
      self.LLVM_SAVEDSTACKS.push(Runtime.stackSave());
      return self.LLVM_SAVEDSTACKS.length-1;
    }

  function ___assert_func(filename, line, func, condition) {
      throw 'Assertion failed: ' + (condition ? Pointer_stringify(condition) : 'unknown condition') + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + new Error().stack;
    }

  function _llvm_stackrestore(p) {
      var self = _llvm_stacksave;
      var ret = self.LLVM_SAVEDSTACKS[p];
      self.LLVM_SAVEDSTACKS.splice(p, 1);
      Runtime.stackRestore(ret);
    }

  
  
  
  
  var _stdin=allocate(1, "i32*", ALLOC_STACK);
  
  var _stdout=allocate(1, "i32*", ALLOC_STACK);
  
  var _stderr=allocate(1, "i32*", ALLOC_STACK);
  
  var __impure_ptr=allocate(1, "i32*", ALLOC_STACK);var FS={currentPath:"/",nextInode:2,streams:[null],ignorePermissions:true,joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
  
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
  
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
  
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
  
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function(chunkSize, length) {
            this.length = length;
            this.chunkSize = chunkSize;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % chunkSize;
            var chunkNum = Math.floor(idx / chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
    
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
          if (!hasByteServing) chunkSize = datalength;
    
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
    
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
    
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
    
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
    
          var lazyArray = new LazyUint8Array(chunkSize, datalength);
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * lazyArray.chunkSize;
            var end = (chunkNum+1) * lazyArray.chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile) {
        Browser.ensureObjects();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureRoot();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
  
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === '\n'.charCodeAt(0)) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
  
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
  
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        FS.createDevice(devFolder, 'tty', input, output);
  
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          isTerminal: !stdinOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stdoutOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stderrOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        assert(Math.max(_stdin, _stdout, _stderr) < 128); // make sure these are low, we flatten arrays with these
        HEAP32[((_stdin)>>2)]=1;
        HEAP32[((_stdout)>>2)]=2;
        HEAP32[((_stderr)>>2)]=3;
  
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
  
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_STATIC) ], 'void*', ALLOC_NONE, __impure_ptr);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output('\n'.charCodeAt(0));
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output('\n'.charCodeAt(0));
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};
  
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[((buf)+(i))];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[((buf)+(i))]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  
  
   function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF32[(((varargs)+(argIndex))>>2)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[(textIndex+1)];
        if (curr == '%'.charCodeAt(0)) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case '+'.charCodeAt(0):
                flagAlwaysSigned = true;
                break;
              case '-'.charCodeAt(0):
                flagLeftAlign = true;
                break;
              case '#'.charCodeAt(0):
                flagAlternative = true;
                break;
              case '0'.charCodeAt(0):
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[(textIndex+1)];
          }
  
          // Handle width.
          var width = 0;
          if (next == '*'.charCodeAt(0)) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[(textIndex+1)];
          } else {
            while (next >= '0'.charCodeAt(0) && next <= '9'.charCodeAt(0)) {
              width = width * 10 + (next - '0'.charCodeAt(0));
              textIndex++;
              next = HEAP8[(textIndex+1)];
            }
          }
  
          // Handle precision.
          var precisionSet = false;
          if (next == '.'.charCodeAt(0)) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[(textIndex+1)];
            if (next == '*'.charCodeAt(0)) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[(textIndex+1)];
                if (precisionChr < '0'.charCodeAt(0) ||
                    precisionChr > '9'.charCodeAt(0)) break;
                precision = precision * 10 + (precisionChr - '0'.charCodeAt(0));
                textIndex++;
              }
            }
            next = HEAP8[(textIndex+1)];
          } else {
            var precision = 6; // Standard default.
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[(textIndex+2)];
              if (nextNext == 'h'.charCodeAt(0)) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[(textIndex+2)];
              if (nextNext == 'l'.charCodeAt(0)) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[(textIndex+1)];
  
          // Handle type specifier.
          if (['d', 'i', 'u', 'o', 'x', 'X', 'p'].indexOf(String.fromCharCode(next)) != -1) {
            // Integer.
            var signed = next == 'd'.charCodeAt(0) || next == 'i'.charCodeAt(0);
            argSize = argSize || 4;
            var currArg = getNextArg('i' + (argSize * 8));
            var argText;
            // Flatten i64-1 [low, high] into a (slightly rounded) double
            if (argSize == 8) {
              currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 'u'.charCodeAt(0));
            }
            // Truncate to requested size.
            if (argSize <= 4) {
              var limit = Math.pow(256, argSize) - 1;
              currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
            }
            // Format the number.
            var currAbsArg = Math.abs(currArg);
            var prefix = '';
            if (next == 'd'.charCodeAt(0) || next == 'i'.charCodeAt(0)) {
              argText = reSign(currArg, 8 * argSize, 1).toString(10);
            } else if (next == 'u'.charCodeAt(0)) {
              argText = unSign(currArg, 8 * argSize, 1).toString(10);
              currArg = Math.abs(currArg);
            } else if (next == 'o'.charCodeAt(0)) {
              argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
            } else if (next == 'x'.charCodeAt(0) || next == 'X'.charCodeAt(0)) {
              prefix = flagAlternative ? '0x' : '';
              if (currArg < 0) {
                // Represent negative numbers in hex as 2's complement.
                currArg = -currArg;
                argText = (currAbsArg - 1).toString(16);
                var buffer = [];
                for (var i = 0; i < argText.length; i++) {
                  buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                }
                argText = buffer.join('');
                while (argText.length < argSize * 2) argText = 'f' + argText;
              } else {
                argText = currAbsArg.toString(16);
              }
              if (next == 'X'.charCodeAt(0)) {
                prefix = prefix.toUpperCase();
                argText = argText.toUpperCase();
              }
            } else if (next == 'p'.charCodeAt(0)) {
              if (currAbsArg === 0) {
                argText = '(nil)';
              } else {
                prefix = '0x';
                argText = currAbsArg.toString(16);
              }
            }
            if (precisionSet) {
              while (argText.length < precision) {
                argText = '0' + argText;
              }
            }
  
            // Add sign if needed
            if (flagAlwaysSigned) {
              if (currArg < 0) {
                prefix = '-' + prefix;
              } else {
                prefix = '+' + prefix;
              }
            }
  
            // Add padding.
            while (prefix.length + argText.length < width) {
              if (flagLeftAlign) {
                argText += ' ';
              } else {
                if (flagZeroPad) {
                  argText = '0' + argText;
                } else {
                  prefix = ' ' + prefix;
                }
              }
            }
  
            // Insert the result into the buffer.
            argText = prefix + argText;
            argText.split('').forEach(function(chr) {
              ret.push(chr.charCodeAt(0));
            });
          } else if (['f', 'F', 'e', 'E', 'g', 'G'].indexOf(String.fromCharCode(next)) != -1) {
            // Float.
            var currArg = getNextArg('double');
            var argText;
  
            if (isNaN(currArg)) {
              argText = 'nan';
              flagZeroPad = false;
            } else if (!isFinite(currArg)) {
              argText = (currArg < 0 ? '-' : '') + 'inf';
              flagZeroPad = false;
            } else {
              var isGeneral = false;
              var effectivePrecision = Math.min(precision, 20);
  
              // Convert g/G to f/F or e/E, as per:
              // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
              if (next == 'g'.charCodeAt(0) || next == 'G'.charCodeAt(0)) {
                isGeneral = true;
                precision = precision || 1;
                var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                if (precision > exponent && exponent >= -4) {
                  next = ((next == 'g'.charCodeAt(0)) ? 'f' : 'F').charCodeAt(0);
                  precision -= exponent + 1;
                } else {
                  next = ((next == 'g'.charCodeAt(0)) ? 'e' : 'E').charCodeAt(0);
                  precision--;
                }
                effectivePrecision = Math.min(precision, 20);
              }
  
              if (next == 'e'.charCodeAt(0) || next == 'E'.charCodeAt(0)) {
                argText = currArg.toExponential(effectivePrecision);
                // Make sure the exponent has at least 2 digits.
                if (/[eE][-+]\d$/.test(argText)) {
                  argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                }
              } else if (next == 'f'.charCodeAt(0) || next == 'F'.charCodeAt(0)) {
                argText = currArg.toFixed(effectivePrecision);
              }
  
              var parts = argText.split('e');
              if (isGeneral && !flagAlternative) {
                // Discard trailing zeros and periods.
                while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                       (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                  parts[0] = parts[0].slice(0, -1);
                }
              } else {
                // Make sure we have a period in alternative mode.
                if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                // Zero pad until required precision.
                while (precision > effectivePrecision++) parts[0] += '0';
              }
              argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
              // Capitalize 'E' if needed.
              if (next == 'E'.charCodeAt(0)) argText = argText.toUpperCase();
  
              // Add sign.
              if (flagAlwaysSigned && currArg >= 0) {
                argText = '+' + argText;
              }
            }
  
            // Add padding.
            while (argText.length < width) {
              if (flagLeftAlign) {
                argText += ' ';
              } else {
                if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                  argText = argText[0] + '0' + argText.slice(1);
                } else {
                  argText = (flagZeroPad ? '0' : ' ') + argText;
                }
              }
            }
  
            // Adjust case.
            if (next < 'a'.charCodeAt(0)) argText = argText.toUpperCase();
  
            // Insert the result into the buffer.
            argText.split('').forEach(function(chr) {
              ret.push(chr.charCodeAt(0));
            });
          } else if (next == 's'.charCodeAt(0)) {
            // String.
            var arg = getNextArg('i8*') || nullString;
            var argLength = _strlen(arg);
            if (precisionSet) argLength = Math.min(argLength, precision);
            if (!flagLeftAlign) {
              while (argLength < width--) {
                ret.push(' '.charCodeAt(0));
              }
            }
            for (var i = 0; i < argLength; i++) {
              ret.push(HEAPU8[(arg++)]);
            }
            if (flagLeftAlign) {
              while (argLength < width--) {
                ret.push(' '.charCodeAt(0));
              }
            }
          } else if (next == 'c'.charCodeAt(0)) {
            // Character.
            if (flagLeftAlign) ret.push(getNextArg('i8'));
            while (--width > 0) {
              ret.push(' '.charCodeAt(0));
            }
            if (!flagLeftAlign) ret.push(getNextArg('i8'));
          } else if (next == 'n'.charCodeAt(0)) {
            // Write the length written so far to the next parameter.
            var ptr = getNextArg('i32*');
            HEAP32[((ptr)>>2)]=ret.length
          } else if (next == '%'.charCodeAt(0)) {
            // Literal percent sign.
            ret.push(curr);
          } else {
            // Unknown specifiers remain untouched.
            for (var i = startTextIndex; i < textIndex + 2; i++) {
              ret.push(HEAP8[(i)]);
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }

  
  function ___errno_location() {
      return ___setErrNo.ret;
    }var ___errno;

  
   var _llvm_memcpy_p0i8_p0i8_i32;

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
  
      // We need to make sure no one else allocates unfreeable memory!
      // We must control this entirely. So we don't even need to do
      // unfreeable allocations - the HEAP is ours, from STATICTOP up.
      // TODO: We could in theory slice off the top of the HEAP when
      //       sbrk gets a negative increment in |bytes|...
      var self = _sbrk;
      if (!self.called) {
        STATICTOP = alignMemoryPage(STATICTOP); // make sure we start out aligned
        self.called = true;
        _sbrk.DYNAMIC_START = STATICTOP;
      }
      var ret = STATICTOP;
      if (bytes != 0) Runtime.staticAlloc(bytes);
      return ret;  // Previous break location.
    }


   



  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],ensureObjects:function () {
        if (Browser.ensured) return;
        Browser.ensured = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'jpeg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(-3)];
          return ret;
        }
  
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = [];
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/.exec(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            setTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', { alpha: false });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
  
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},requestFullScreen:function () {
        var canvas = Module['canvas'];
        function fullScreenChange() {
          var isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                        canvas['mozRequestPointerLock'] ||
                                        canvas['webkitRequestPointerLock'];
            canvas.requestPointerLock();
            isFullScreen = true;
          }
          if (Module['onFullScreen']) Module['onFullScreen'](isFullScreen);
        }
  
        document.addEventListener('fullscreenchange', fullScreenChange, false);
        document.addEventListener('mozfullscreenchange', fullScreenChange, false);
        document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
  
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
  
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen(); 
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200) {
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      }};
___setErrNo(0);
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
Module["requestFullScreen"] = function() { Browser.requestFullScreen() };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  

if (!Math.imul) Math.imul = function(x, y) { return (x*y)|0 }; // # not a real polyfill since semantics not identical, but close and fairly fast
var Runtime_bitshift64 = Runtime.bitshift64;
var Math_min = Math.min;
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
var asm = (function(global, env, buffer) {
  'use asm';
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);

  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var NaN=+env.NaN;
  var Infinity=+env.Infinity;

  var __THREW__ = 0;
  var undef = 0;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;

  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var abort=env.abort;
  var assert=env.assert;
  var asmPrintInt=env.asmPrintInt;
  var asmPrintFloat=env.asmPrintFloat;
  var copyTempDouble=env.copyTempDouble;
  var copyTempFloat=env.copyTempFloat;
  var Runtime_bitshift64=env.Runtime_bitshift64;
  var Math_min=env.min;
  var _strtol=env._strtol;
  var _pwrite=env._pwrite;
  var _llvm_stackrestore=env._llvm_stackrestore;
  var _sysconf=env._sysconf;
  var _llvm_stacksave=env._llvm_stacksave;
  var ___setErrNo=env.___setErrNo;
  var _fwrite=env._fwrite;
  var _time=env._time;
  var _abort=env._abort;
  var _write=env._write;
  var _atoi=env._atoi;
  var _fprintf=env._fprintf;
  var _sbrk=env._sbrk;
  var __parseInt=env.__parseInt;
  var _printf=env._printf;
  var __formatString=env.__formatString;
  var ___errno_location=env.___errno_location;
  var ___assert_func=env.___assert_func;
  var _isspace=env._isspace;

  function stackAlloc(size) {
    size = size|0;
    var ret = 0;
    ret = STACKTOP;
    STACKTOP = (STACKTOP + size)|0;
    STACKTOP = ((STACKTOP + 3)>>2)<<2;
    return ret|0;
  }
  function stackSave() {
    return STACKTOP|0;
  }
  function stackRestore(top) {
    top = top|0;
    STACKTOP = top;
  }
  function setThrew(threw) {
    threw = threw|0;
    __THREW__ = threw;
  }

  function setTempRet0(value) {
    value = value|0;
    tempRet0 = value;
  }

  function setTempRet1(value) {
    value = value|0;
    tempRet1 = value;
  }

  function setTempRet2(value) {
    value = value|0;
    tempRet2 = value;
  }

  function setTempRet3(value) {
    value = value|0;
    tempRet3 = value;
  }

  function setTempRet4(value) {
    value = value|0;
    tempRet4 = value;
  }

  function setTempRet5(value) {
    value = value|0;
    tempRet5 = value;
  }

  function setTempRet6(value) {
    value = value|0;
    tempRet6 = value;
  }

  function setTempRet7(value) {
    value = value|0;
    tempRet7 = value;
  }

  function setTempRet8(value) {
    value = value|0;
    tempRet8 = value;
  }

  function setTempRet9(value) {
    value = value|0;
    tempRet9 = value;
  }

function _malloc(i1) {
  i1 = i1 | 0;
  var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i72 = 0, i73 = 0, i74 = 0, i75 = 0, i76 = 0, i77 = 0, i78 = 0, i79 = 0, i80 = 0, i81 = 0, i82 = 0, i83 = 0, i84 = 0, i85 = 0, i86 = 0;
  L1 : do {
    if (i1 >>> 0 < 245) {
      if (i1 >>> 0 < 11) {
        i2 = 16;
      } else {
        i2 = i1 + 11 & -8;
      }
      i3 = i2 >>> 3;
      i4 = HEAP32[1310748] | 0;
      i5 = i4 >>> (i3 >>> 0);
      if ((i5 & 3 | 0) != 0) {
        i6 = (i5 & 1 ^ 1) + i3 | 0;
        i7 = i6 << 1;
        i8 = 5243032 + (i7 << 2) | 0;
        i9 = 5243032 + (i7 + 2 << 2) | 0;
        i7 = HEAP32[i9 >> 2] | 0;
        i10 = i7 + 8 | 0;
        i11 = HEAP32[i10 >> 2] | 0;
        do {
          if ((i8 | 0) == (i11 | 0)) {
            HEAP32[1310748] = i4 & (1 << i6 ^ -1);
          } else {
            if (i11 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
              _abort();
              return 0;
              break;
            } else {
              HEAP32[i9 >> 2] = i11;
              HEAP32[i11 + 12 >> 2] = i8;
              break;
            }
          }
        } while (0);
        i8 = i6 << 3;
        HEAP32[i7 + 4 >> 2] = i8 | 3;
        i11 = i7 + (i8 | 4) | 0;
        HEAP32[i11 >> 2] = HEAP32[i11 >> 2] | 1;
        i12 = i10;
        return i12 | 0;
      }
      if (i2 >>> 0 <= (HEAP32[1310750] | 0) >>> 0) {
        i13 = i2;
        break;
      }
      if ((i5 | 0) != 0) {
        i11 = 2 << i3;
        i8 = i5 << i3 & (i11 | -i11);
        i11 = (i8 & -i8) - 1 | 0;
        i8 = i11 >>> 12 & 16;
        i9 = i11 >>> (i8 >>> 0);
        i11 = i9 >>> 5 & 8;
        i14 = i9 >>> (i11 >>> 0);
        i9 = i14 >>> 2 & 4;
        i15 = i14 >>> (i9 >>> 0);
        i14 = i15 >>> 1 & 2;
        i16 = i15 >>> (i14 >>> 0);
        i15 = i16 >>> 1 & 1;
        i17 = (i11 | i8 | i9 | i14 | i15) + (i16 >>> (i15 >>> 0)) | 0;
        i15 = i17 << 1;
        i16 = 5243032 + (i15 << 2) | 0;
        i14 = 5243032 + (i15 + 2 << 2) | 0;
        i15 = HEAP32[i14 >> 2] | 0;
        i9 = i15 + 8 | 0;
        i8 = HEAP32[i9 >> 2] | 0;
        do {
          if ((i16 | 0) == (i8 | 0)) {
            HEAP32[1310748] = i4 & (1 << i17 ^ -1);
          } else {
            if (i8 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
              _abort();
              return 0;
              break;
            } else {
              HEAP32[i14 >> 2] = i8;
              HEAP32[i8 + 12 >> 2] = i16;
              break;
            }
          }
        } while (0);
        i16 = i17 << 3;
        i8 = i16 - i2 | 0;
        HEAP32[i15 + 4 >> 2] = i2 | 3;
        i14 = i15;
        i4 = i14 + i2 | 0;
        HEAP32[i14 + (i2 | 4) >> 2] = i8 | 1;
        HEAP32[i14 + i16 >> 2] = i8;
        i16 = HEAP32[1310750] | 0;
        if ((i16 | 0) != 0) {
          i14 = HEAP32[1310753] | 0;
          i3 = i16 >>> 3;
          i16 = i3 << 1;
          i5 = 5243032 + (i16 << 2) | 0;
          i10 = HEAP32[1310748] | 0;
          i7 = 1 << i3;
          do {
            if ((i10 & i7 | 0) == 0) {
              HEAP32[1310748] = i10 | i7;
              i18 = i5;
              i19 = 5243032 + (i16 + 2 << 2) | 0;
            } else {
              i3 = 5243032 + (i16 + 2 << 2) | 0;
              i6 = HEAP32[i3 >> 2] | 0;
              if (i6 >>> 0 >= (HEAP32[1310752] | 0) >>> 0) {
                i18 = i6;
                i19 = i3;
                break;
              }
              _abort();
              return 0;
              i18 = i5;
              i19 = i3;
            }
          } while (0);
          HEAP32[i19 >> 2] = i14;
          HEAP32[i18 + 12 >> 2] = i14;
          HEAP32[i14 + 8 >> 2] = i18;
          HEAP32[i14 + 12 >> 2] = i5;
        }
        HEAP32[1310750] = i8;
        HEAP32[1310753] = i4;
        i12 = i9;
        return i12 | 0;
      }
      i16 = HEAP32[1310749] | 0;
      if ((i16 | 0) == 0) {
        i13 = i2;
        break;
      }
      i7 = (i16 & -i16) - 1 | 0;
      i16 = i7 >>> 12 & 16;
      i10 = i7 >>> (i16 >>> 0);
      i7 = i10 >>> 5 & 8;
      i15 = i10 >>> (i7 >>> 0);
      i10 = i15 >>> 2 & 4;
      i17 = i15 >>> (i10 >>> 0);
      i15 = i17 >>> 1 & 2;
      i3 = i17 >>> (i15 >>> 0);
      i17 = i3 >>> 1 & 1;
      i6 = HEAP32[5243296 + ((i7 | i16 | i10 | i15 | i17) + (i3 >>> (i17 >>> 0)) << 2) >> 2] | 0;
      i17 = i6;
      i3 = i6;
      i15 = (HEAP32[i6 + 4 >> 2] & -8) - i2 | 0;
      while (1) {
        i6 = HEAP32[i17 + 16 >> 2] | 0;
        if ((i6 | 0) == 0) {
          i10 = HEAP32[i17 + 20 >> 2] | 0;
          if ((i10 | 0) == 0) {
            break;
          } else {
            i20 = i10;
          }
        } else {
          i20 = i6;
        }
        i6 = (HEAP32[i20 + 4 >> 2] & -8) - i2 | 0;
        i10 = i6 >>> 0 < i15 >>> 0;
        i17 = i20;
        i3 = i10 ? i20 : i3;
        i15 = i10 ? i6 : i15;
      }
      i17 = i3;
      i9 = HEAP32[1310752] | 0;
      do {
        if (i17 >>> 0 >= i9 >>> 0) {
          i4 = i17 + i2 | 0;
          i8 = i4;
          if (i17 >>> 0 >= i4 >>> 0) {
            break;
          }
          i4 = HEAP32[i3 + 24 >> 2] | 0;
          i5 = HEAP32[i3 + 12 >> 2] | 0;
          L47 : do {
            if ((i5 | 0) == (i3 | 0)) {
              i14 = i3 + 20 | 0;
              i6 = HEAP32[i14 >> 2] | 0;
              do {
                if ((i6 | 0) == 0) {
                  i10 = i3 + 16 | 0;
                  i16 = HEAP32[i10 >> 2] | 0;
                  if ((i16 | 0) == 0) {
                    i21 = 0;
                    break L47;
                  } else {
                    i22 = i16;
                    i23 = i10;
                    break;
                  }
                } else {
                  i22 = i6;
                  i23 = i14;
                }
              } while (0);
              while (1) {
                i14 = i22 + 20 | 0;
                i6 = HEAP32[i14 >> 2] | 0;
                if ((i6 | 0) != 0) {
                  i22 = i6;
                  i23 = i14;
                  continue;
                }
                i14 = i22 + 16 | 0;
                i6 = HEAP32[i14 >> 2] | 0;
                if ((i6 | 0) == 0) {
                  break;
                } else {
                  i22 = i6;
                  i23 = i14;
                }
              }
              if (i23 >>> 0 < i9 >>> 0) {
                _abort();
                return 0;
                i21 = i22;
                break;
              } else {
                HEAP32[i23 >> 2] = 0;
                i21 = i22;
                break;
              }
            } else {
              i14 = HEAP32[i3 + 8 >> 2] | 0;
              if (i14 >>> 0 < i9 >>> 0) {
                _abort();
                return 0;
                i21 = i5;
                break;
              } else {
                HEAP32[i14 + 12 >> 2] = i5;
                HEAP32[i5 + 8 >> 2] = i14;
                i21 = i5;
                break;
              }
            }
          } while (0);
          L63 : do {
            if ((i4 | 0) != 0) {
              i5 = i3 + 28 | 0;
              i14 = 5243296 + (HEAP32[i5 >> 2] << 2) | 0;
              do {
                if ((i3 | 0) == (HEAP32[i14 >> 2] | 0)) {
                  HEAP32[i14 >> 2] = i21;
                  if ((i21 | 0) != 0) {
                    break;
                  }
                  HEAP32[1310749] = HEAP32[1310749] & (1 << HEAP32[i5 >> 2] ^ -1);
                  break L63;
                } else {
                  do {
                    if (i4 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                      _abort();
                      return 0;
                    } else {
                      i6 = i4 + 16 | 0;
                      if ((HEAP32[i6 >> 2] | 0) == (i3 | 0)) {
                        HEAP32[i6 >> 2] = i21;
                        break;
                      } else {
                        HEAP32[i4 + 20 >> 2] = i21;
                        break;
                      }
                    }
                  } while (0);
                  if ((i21 | 0) == 0) {
                    break L63;
                  }
                }
              } while (0);
              if (i21 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                return 0;
                break;
              }
              HEAP32[i21 + 24 >> 2] = i4;
              i5 = HEAP32[i3 + 16 >> 2] | 0;
              do {
                if ((i5 | 0) != 0) {
                  if (i5 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                    _abort();
                    return 0;
                    break;
                  } else {
                    HEAP32[i21 + 16 >> 2] = i5;
                    HEAP32[i5 + 24 >> 2] = i21;
                    break;
                  }
                }
              } while (0);
              i5 = HEAP32[i3 + 20 >> 2] | 0;
              if ((i5 | 0) == 0) {
                break;
              }
              if (i5 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                return 0;
                break;
              } else {
                HEAP32[i21 + 20 >> 2] = i5;
                HEAP32[i5 + 24 >> 2] = i21;
                break;
              }
            }
          } while (0);
          if (i15 >>> 0 < 16) {
            i4 = i15 + i2 | 0;
            HEAP32[i3 + 4 >> 2] = i4 | 3;
            i5 = i17 + (i4 + 4 | 0) | 0;
            HEAP32[i5 >> 2] = HEAP32[i5 >> 2] | 1;
          } else {
            HEAP32[i3 + 4 >> 2] = i2 | 3;
            HEAP32[i17 + (i2 | 4) >> 2] = i15 | 1;
            HEAP32[i17 + (i15 + i2 | 0) >> 2] = i15;
            i5 = HEAP32[1310750] | 0;
            if ((i5 | 0) != 0) {
              i4 = HEAP32[1310753] | 0;
              i14 = i5 >>> 3;
              i5 = i14 << 1;
              i6 = 5243032 + (i5 << 2) | 0;
              i10 = HEAP32[1310748] | 0;
              i16 = 1 << i14;
              do {
                if ((i10 & i16 | 0) == 0) {
                  HEAP32[1310748] = i10 | i16;
                  i24 = i6;
                  i25 = 5243032 + (i5 + 2 << 2) | 0;
                } else {
                  i14 = 5243032 + (i5 + 2 << 2) | 0;
                  i7 = HEAP32[i14 >> 2] | 0;
                  if (i7 >>> 0 >= (HEAP32[1310752] | 0) >>> 0) {
                    i24 = i7;
                    i25 = i14;
                    break;
                  }
                  _abort();
                  return 0;
                  i24 = i6;
                  i25 = i14;
                }
              } while (0);
              HEAP32[i25 >> 2] = i4;
              HEAP32[i24 + 12 >> 2] = i4;
              HEAP32[i4 + 8 >> 2] = i24;
              HEAP32[i4 + 12 >> 2] = i6;
            }
            HEAP32[1310750] = i15;
            HEAP32[1310753] = i8;
          }
          i5 = i3 + 8 | 0;
          if ((i5 | 0) == 0) {
            i13 = i2;
            break L1;
          } else {
            i12 = i5;
          }
          return i12 | 0;
        }
      } while (0);
      _abort();
      return 0;
      i13 = i2;
    } else {
      if (i1 >>> 0 > 4294967231) {
        i13 = -1;
        break;
      }
      i3 = i1 + 11 | 0;
      i15 = i3 & -8;
      i17 = HEAP32[1310749] | 0;
      if ((i17 | 0) == 0) {
        i13 = i15;
        break;
      }
      i9 = -i15 | 0;
      i5 = i3 >>> 8;
      do {
        if ((i5 | 0) == 0) {
          i26 = 0;
        } else {
          if (i15 >>> 0 > 16777215) {
            i26 = 31;
            break;
          }
          i3 = (i5 + 1048320 | 0) >>> 16 & 8;
          i16 = i5 << i3;
          i10 = (i16 + 520192 | 0) >>> 16 & 4;
          i14 = i16 << i10;
          i16 = (i14 + 245760 | 0) >>> 16 & 2;
          i7 = (14 - (i10 | i3 | i16) | 0) + (i14 << i16 >>> 15) | 0;
          i26 = i15 >>> ((i7 + 7 | 0) >>> 0) & 1 | i7 << 1;
        }
      } while (0);
      i5 = HEAP32[5243296 + (i26 << 2) >> 2] | 0;
      L112 : do {
        if ((i5 | 0) == 0) {
          i27 = 0;
          i28 = i9;
          i29 = 0;
        } else {
          if ((i26 | 0) == 31) {
            i30 = 0;
          } else {
            i30 = 25 - (i26 >>> 1) | 0;
          }
          i7 = 0;
          i16 = i9;
          i14 = i5;
          i3 = i15 << i30;
          i10 = 0;
          while (1) {
            i11 = HEAP32[i14 + 4 >> 2] & -8;
            i31 = i11 - i15 | 0;
            if (i31 >>> 0 < i16 >>> 0) {
              if ((i11 | 0) == (i15 | 0)) {
                i27 = i14;
                i28 = i31;
                i29 = i14;
                break L112;
              } else {
                i32 = i14;
                i33 = i31;
              }
            } else {
              i32 = i7;
              i33 = i16;
            }
            i31 = HEAP32[i14 + 20 >> 2] | 0;
            i11 = HEAP32[i14 + 16 + (i3 >>> 31 << 2) >> 2] | 0;
            i34 = (i31 | 0) == 0 | (i31 | 0) == (i11 | 0) ? i10 : i31;
            if ((i11 | 0) == 0) {
              i27 = i32;
              i28 = i33;
              i29 = i34;
              break L112;
            } else {
              i7 = i32;
              i16 = i33;
              i14 = i11;
              i3 = i3 << 1;
              i10 = i34;
            }
          }
        }
      } while (0);
      if ((i29 | 0) == 0 & (i27 | 0) == 0) {
        i5 = 2 << i26;
        i9 = i17 & (i5 | -i5);
        if ((i9 | 0) == 0) {
          i13 = i15;
          break;
        }
        i5 = (i9 & -i9) - 1 | 0;
        i9 = i5 >>> 12 & 16;
        i10 = i5 >>> (i9 >>> 0);
        i5 = i10 >>> 5 & 8;
        i3 = i10 >>> (i5 >>> 0);
        i10 = i3 >>> 2 & 4;
        i14 = i3 >>> (i10 >>> 0);
        i3 = i14 >>> 1 & 2;
        i16 = i14 >>> (i3 >>> 0);
        i14 = i16 >>> 1 & 1;
        i35 = HEAP32[5243296 + ((i5 | i9 | i10 | i3 | i14) + (i16 >>> (i14 >>> 0)) << 2) >> 2] | 0;
      } else {
        i35 = i29;
      }
      L127 : do {
        if ((i35 | 0) == 0) {
          i36 = i28;
          i37 = i27;
        } else {
          i14 = i35;
          i16 = i28;
          i3 = i27;
          while (1) {
            i10 = (HEAP32[i14 + 4 >> 2] & -8) - i15 | 0;
            i9 = i10 >>> 0 < i16 >>> 0;
            i5 = i9 ? i10 : i16;
            i10 = i9 ? i14 : i3;
            i9 = HEAP32[i14 + 16 >> 2] | 0;
            if ((i9 | 0) != 0) {
              i14 = i9;
              i16 = i5;
              i3 = i10;
              continue;
            }
            i9 = HEAP32[i14 + 20 >> 2] | 0;
            if ((i9 | 0) == 0) {
              i36 = i5;
              i37 = i10;
              break L127;
            } else {
              i14 = i9;
              i16 = i5;
              i3 = i10;
            }
          }
        }
      } while (0);
      if ((i37 | 0) == 0) {
        i13 = i15;
        break;
      }
      if (i36 >>> 0 >= ((HEAP32[1310750] | 0) - i15 | 0) >>> 0) {
        i13 = i15;
        break;
      }
      i17 = i37;
      i3 = HEAP32[1310752] | 0;
      do {
        if (i17 >>> 0 >= i3 >>> 0) {
          i16 = i17 + i15 | 0;
          i14 = i16;
          if (i17 >>> 0 >= i16 >>> 0) {
            break;
          }
          i10 = HEAP32[i37 + 24 >> 2] | 0;
          i5 = HEAP32[i37 + 12 >> 2] | 0;
          L137 : do {
            if ((i5 | 0) == (i37 | 0)) {
              i9 = i37 + 20 | 0;
              i7 = HEAP32[i9 >> 2] | 0;
              do {
                if ((i7 | 0) == 0) {
                  i8 = i37 + 16 | 0;
                  i6 = HEAP32[i8 >> 2] | 0;
                  if ((i6 | 0) == 0) {
                    i38 = 0;
                    break L137;
                  } else {
                    i39 = i6;
                    i40 = i8;
                    break;
                  }
                } else {
                  i39 = i7;
                  i40 = i9;
                }
              } while (0);
              while (1) {
                i9 = i39 + 20 | 0;
                i7 = HEAP32[i9 >> 2] | 0;
                if ((i7 | 0) != 0) {
                  i39 = i7;
                  i40 = i9;
                  continue;
                }
                i9 = i39 + 16 | 0;
                i7 = HEAP32[i9 >> 2] | 0;
                if ((i7 | 0) == 0) {
                  break;
                } else {
                  i39 = i7;
                  i40 = i9;
                }
              }
              if (i40 >>> 0 < i3 >>> 0) {
                _abort();
                return 0;
                i38 = i39;
                break;
              } else {
                HEAP32[i40 >> 2] = 0;
                i38 = i39;
                break;
              }
            } else {
              i9 = HEAP32[i37 + 8 >> 2] | 0;
              if (i9 >>> 0 < i3 >>> 0) {
                _abort();
                return 0;
                i38 = i5;
                break;
              } else {
                HEAP32[i9 + 12 >> 2] = i5;
                HEAP32[i5 + 8 >> 2] = i9;
                i38 = i5;
                break;
              }
            }
          } while (0);
          L153 : do {
            if ((i10 | 0) != 0) {
              i5 = i37 + 28 | 0;
              i9 = 5243296 + (HEAP32[i5 >> 2] << 2) | 0;
              do {
                if ((i37 | 0) == (HEAP32[i9 >> 2] | 0)) {
                  HEAP32[i9 >> 2] = i38;
                  if ((i38 | 0) != 0) {
                    break;
                  }
                  HEAP32[1310749] = HEAP32[1310749] & (1 << HEAP32[i5 >> 2] ^ -1);
                  break L153;
                } else {
                  do {
                    if (i10 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                      _abort();
                      return 0;
                    } else {
                      i7 = i10 + 16 | 0;
                      if ((HEAP32[i7 >> 2] | 0) == (i37 | 0)) {
                        HEAP32[i7 >> 2] = i38;
                        break;
                      } else {
                        HEAP32[i10 + 20 >> 2] = i38;
                        break;
                      }
                    }
                  } while (0);
                  if ((i38 | 0) == 0) {
                    break L153;
                  }
                }
              } while (0);
              if (i38 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                return 0;
                break;
              }
              HEAP32[i38 + 24 >> 2] = i10;
              i5 = HEAP32[i37 + 16 >> 2] | 0;
              do {
                if ((i5 | 0) != 0) {
                  if (i5 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                    _abort();
                    return 0;
                    break;
                  } else {
                    HEAP32[i38 + 16 >> 2] = i5;
                    HEAP32[i5 + 24 >> 2] = i38;
                    break;
                  }
                }
              } while (0);
              i5 = HEAP32[i37 + 20 >> 2] | 0;
              if ((i5 | 0) == 0) {
                break;
              }
              if (i5 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                return 0;
                break;
              } else {
                HEAP32[i38 + 20 >> 2] = i5;
                HEAP32[i5 + 24 >> 2] = i38;
                break;
              }
            }
          } while (0);
          L181 : do {
            if (i36 >>> 0 < 16) {
              i10 = i36 + i15 | 0;
              HEAP32[i37 + 4 >> 2] = i10 | 3;
              i5 = i17 + (i10 + 4 | 0) | 0;
              HEAP32[i5 >> 2] = HEAP32[i5 >> 2] | 1;
            } else {
              HEAP32[i37 + 4 >> 2] = i15 | 3;
              HEAP32[i17 + (i15 | 4) >> 2] = i36 | 1;
              HEAP32[i17 + (i36 + i15 | 0) >> 2] = i36;
              i5 = i36 >>> 3;
              if (i36 >>> 0 < 256) {
                i10 = i5 << 1;
                i9 = 5243032 + (i10 << 2) | 0;
                i7 = HEAP32[1310748] | 0;
                i8 = 1 << i5;
                do {
                  if ((i7 & i8 | 0) == 0) {
                    HEAP32[1310748] = i7 | i8;
                    i41 = i9;
                    i42 = 5243032 + (i10 + 2 << 2) | 0;
                  } else {
                    i5 = 5243032 + (i10 + 2 << 2) | 0;
                    i6 = HEAP32[i5 >> 2] | 0;
                    if (i6 >>> 0 >= (HEAP32[1310752] | 0) >>> 0) {
                      i41 = i6;
                      i42 = i5;
                      break;
                    }
                    _abort();
                    return 0;
                    i41 = i9;
                    i42 = i5;
                  }
                } while (0);
                HEAP32[i42 >> 2] = i14;
                HEAP32[i41 + 12 >> 2] = i14;
                HEAP32[i17 + (i15 + 8 | 0) >> 2] = i41;
                HEAP32[i17 + (i15 + 12 | 0) >> 2] = i9;
                break;
              }
              i10 = i16;
              i8 = i36 >>> 8;
              do {
                if ((i8 | 0) == 0) {
                  i43 = 0;
                } else {
                  if (i36 >>> 0 > 16777215) {
                    i43 = 31;
                    break;
                  }
                  i7 = (i8 + 1048320 | 0) >>> 16 & 8;
                  i5 = i8 << i7;
                  i6 = (i5 + 520192 | 0) >>> 16 & 4;
                  i4 = i5 << i6;
                  i5 = (i4 + 245760 | 0) >>> 16 & 2;
                  i34 = (14 - (i6 | i7 | i5) | 0) + (i4 << i5 >>> 15) | 0;
                  i43 = i36 >>> ((i34 + 7 | 0) >>> 0) & 1 | i34 << 1;
                }
              } while (0);
              i8 = 5243296 + (i43 << 2) | 0;
              HEAP32[i17 + (i15 + 28 | 0) >> 2] = i43;
              HEAP32[i17 + (i15 + 20 | 0) >> 2] = 0;
              HEAP32[i17 + (i15 + 16 | 0) >> 2] = 0;
              i9 = HEAP32[1310749] | 0;
              i34 = 1 << i43;
              if ((i9 & i34 | 0) == 0) {
                HEAP32[1310749] = i9 | i34;
                HEAP32[i8 >> 2] = i10;
                HEAP32[i17 + (i15 + 24 | 0) >> 2] = i8;
                HEAP32[i17 + (i15 + 12 | 0) >> 2] = i10;
                HEAP32[i17 + (i15 + 8 | 0) >> 2] = i10;
                break;
              }
              if ((i43 | 0) == 31) {
                i44 = 0;
              } else {
                i44 = 25 - (i43 >>> 1) | 0;
              }
              i34 = i36 << i44;
              i9 = HEAP32[i8 >> 2] | 0;
              while (1) {
                if ((HEAP32[i9 + 4 >> 2] & -8 | 0) == (i36 | 0)) {
                  break;
                }
                i45 = i9 + 16 + (i34 >>> 31 << 2) | 0;
                i8 = HEAP32[i45 >> 2] | 0;
                if ((i8 | 0) == 0) {
                  i46 = 145;
                  break;
                } else {
                  i34 = i34 << 1;
                  i9 = i8;
                }
              }
              if ((i46 | 0) == 145) {
                if (i45 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                  _abort();
                  return 0;
                  break;
                } else {
                  HEAP32[i45 >> 2] = i10;
                  HEAP32[i17 + (i15 + 24 | 0) >> 2] = i9;
                  HEAP32[i17 + (i15 + 12 | 0) >> 2] = i10;
                  HEAP32[i17 + (i15 + 8 | 0) >> 2] = i10;
                  break;
                }
              }
              i34 = i9 + 8 | 0;
              i8 = HEAP32[i34 >> 2] | 0;
              i5 = HEAP32[1310752] | 0;
              do {
                if (i9 >>> 0 >= i5 >>> 0) {
                  if (i8 >>> 0 < i5 >>> 0) {
                    break;
                  }
                  HEAP32[i8 + 12 >> 2] = i10;
                  HEAP32[i34 >> 2] = i10;
                  HEAP32[i17 + (i15 + 8 | 0) >> 2] = i8;
                  HEAP32[i17 + (i15 + 12 | 0) >> 2] = i9;
                  HEAP32[i17 + (i15 + 24 | 0) >> 2] = 0;
                  break L181;
                }
              } while (0);
              _abort();
              return 0;
            }
          } while (0);
          i16 = i37 + 8 | 0;
          if ((i16 | 0) == 0) {
            i13 = i15;
            break L1;
          } else {
            i12 = i16;
          }
          return i12 | 0;
        }
      } while (0);
      _abort();
      return 0;
      i13 = i15;
    }
  } while (0);
  i37 = HEAP32[1310750] | 0;
  if (i13 >>> 0 <= i37 >>> 0) {
    i45 = i37 - i13 | 0;
    i36 = HEAP32[1310753] | 0;
    if (i45 >>> 0 > 15) {
      i44 = i36;
      HEAP32[1310753] = i44 + i13 | 0;
      HEAP32[1310750] = i45;
      HEAP32[i44 + (i13 + 4 | 0) >> 2] = i45 | 1;
      HEAP32[i44 + i37 >> 2] = i45;
      HEAP32[i36 + 4 >> 2] = i13 | 3;
    } else {
      HEAP32[1310750] = 0;
      HEAP32[1310753] = 0;
      HEAP32[i36 + 4 >> 2] = i37 | 3;
      i45 = i36 + (i37 + 4 | 0) | 0;
      HEAP32[i45 >> 2] = HEAP32[i45 >> 2] | 1;
    }
    i12 = i36 + 8 | 0;
    return i12 | 0;
  }
  i36 = HEAP32[1310751] | 0;
  if (i13 >>> 0 < i36 >>> 0) {
    i45 = i36 - i13 | 0;
    HEAP32[1310751] = i45;
    i36 = HEAP32[1310754] | 0;
    i37 = i36;
    HEAP32[1310754] = i37 + i13 | 0;
    HEAP32[i37 + (i13 + 4 | 0) >> 2] = i45 | 1;
    HEAP32[i36 + 4 >> 2] = i13 | 3;
    i12 = i36 + 8 | 0;
    return i12 | 0;
  }
  do {
    if ((HEAP32[1310742] | 0) == 0) {
      if ((HEAP32[1310742] | 0) != 0) {
        break;
      }
      i36 = _sysconf(8) | 0;
      if ((i36 - 1 & i36 | 0) != 0) {
        _abort();
        return 0;
      }
      HEAP32[1310744] = i36;
      HEAP32[1310743] = i36;
      HEAP32[1310745] = -1;
      HEAP32[1310746] = 2097152;
      HEAP32[1310747] = 0;
      HEAP32[1310858] = 0;
      HEAP32[1310742] = _time(0) & -16 ^ 1431655768;
    }
  } while (0);
  L238 : do {
    if ((HEAP32[1310858] & 4 | 0) == 0) {
      i36 = HEAP32[1310754] | 0;
      L240 : do {
        if ((i36 | 0) == 0) {
          i46 = 173;
        } else {
          i45 = i36;
          i37 = 5243436;
          while (1) {
            i47 = i37 | 0;
            i44 = HEAP32[i47 >> 2] | 0;
            if (i44 >>> 0 <= i45 >>> 0) {
              i48 = i37 + 4 | 0;
              if ((i44 + (HEAP32[i48 >> 2] | 0) | 0) >>> 0 > i45 >>> 0) {
                break;
              }
            }
            i44 = HEAP32[i37 + 8 >> 2] | 0;
            if ((i44 | 0) == 0) {
              i46 = 173;
              break L240;
            } else {
              i37 = i44;
            }
          }
          if ((i37 | 0) == 0) {
            i46 = 173;
            break;
          }
          i45 = HEAP32[1310744] | 0;
          i44 = ((i13 + 47 | 0) - (HEAP32[1310751] | 0) | 0) + i45 & -i45;
          if (i44 >>> 0 >= 2147483647) {
            i49 = 0;
            break;
          }
          i45 = _sbrk(i44 | 0) | 0;
          i43 = (i45 | 0) == ((HEAP32[i47 >> 2] | 0) + (HEAP32[i48 >> 2] | 0) | 0);
          i50 = i43 ? i45 : -1;
          i51 = i43 ? i44 : 0;
          i52 = i45;
          i53 = i44;
          i46 = 180;
          break;
        }
      } while (0);
      do {
        if ((i46 | 0) == 173) {
          i36 = _sbrk(0) | 0;
          if ((i36 | 0) == -1) {
            i49 = 0;
            break;
          }
          i15 = HEAP32[1310744] | 0;
          i44 = (i13 + 47 | 0) + i15 & -i15;
          i15 = i36;
          i45 = HEAP32[1310743] | 0;
          i43 = i45 - 1 | 0;
          if ((i43 & i15 | 0) == 0) {
            i54 = i44;
          } else {
            i54 = (i44 - i15 | 0) + (i43 + i15 & -i45) | 0;
          }
          if (i54 >>> 0 >= 2147483647) {
            i49 = 0;
            break;
          }
          i45 = _sbrk(i54 | 0) | 0;
          i15 = (i45 | 0) == (i36 | 0);
          i50 = i15 ? i36 : -1;
          i51 = i15 ? i54 : 0;
          i52 = i45;
          i53 = i54;
          i46 = 180;
          break;
        }
      } while (0);
      L257 : do {
        if ((i46 | 0) == 180) {
          i45 = -i53 | 0;
          if ((i50 | 0) != -1) {
            i55 = i51;
            i56 = i50;
            i46 = 193;
            break L238;
          }
          do {
            if ((i52 | 0) != -1 & i53 >>> 0 < 2147483647) {
              if (i53 >>> 0 >= (i13 + 48 | 0) >>> 0) {
                i57 = i53;
                break;
              }
              i15 = HEAP32[1310744] | 0;
              i36 = ((i13 + 47 | 0) - i53 | 0) + i15 & -i15;
              if (i36 >>> 0 >= 2147483647) {
                i57 = i53;
                break;
              }
              if ((_sbrk(i36 | 0) | 0) == -1) {
                _sbrk(i45 | 0) | 0;
                i49 = i51;
                break L257;
              } else {
                i57 = i36 + i53 | 0;
                break;
              }
            } else {
              i57 = i53;
            }
          } while (0);
          if ((i52 | 0) != -1) {
            i55 = i57;
            i56 = i52;
            i46 = 193;
            break L238;
          }
          HEAP32[1310858] = HEAP32[1310858] | 4;
          i58 = i51;
          i46 = 190;
          break L238;
        }
      } while (0);
      HEAP32[1310858] = HEAP32[1310858] | 4;
      i58 = i49;
      i46 = 190;
      break;
    } else {
      i58 = 0;
      i46 = 190;
    }
  } while (0);
  do {
    if ((i46 | 0) == 190) {
      i49 = HEAP32[1310744] | 0;
      i51 = (i13 + 47 | 0) + i49 & -i49;
      if (i51 >>> 0 >= 2147483647) {
        break;
      }
      i49 = _sbrk(i51 | 0) | 0;
      i51 = _sbrk(0) | 0;
      if (!((i51 | 0) != -1 & (i49 | 0) != -1 & i49 >>> 0 < i51 >>> 0)) {
        break;
      }
      i52 = i51 - i49 | 0;
      i51 = i52 >>> 0 > (i13 + 40 | 0) >>> 0;
      i57 = i51 ? i49 : -1;
      if ((i57 | 0) == -1) {
        break;
      } else {
        i55 = i51 ? i52 : i58;
        i56 = i57;
        i46 = 193;
        break;
      }
    }
  } while (0);
  do {
    if ((i46 | 0) == 193) {
      i58 = (HEAP32[1310856] | 0) + i55 | 0;
      HEAP32[1310856] = i58;
      if (i58 >>> 0 > (HEAP32[1310857] | 0) >>> 0) {
        HEAP32[1310857] = i58;
      }
      i58 = HEAP32[1310754] | 0;
      L279 : do {
        if ((i58 | 0) == 0) {
          i57 = HEAP32[1310752] | 0;
          if ((i57 | 0) == 0 | i56 >>> 0 < i57 >>> 0) {
            HEAP32[1310752] = i56;
          }
          HEAP32[1310859] = i56;
          HEAP32[1310860] = i55;
          HEAP32[1310862] = 0;
          HEAP32[1310757] = HEAP32[1310742] | 0;
          HEAP32[1310756] = -1;
          i57 = 0;
          while (1) {
            i52 = i57 << 1;
            i51 = 5243032 + (i52 << 2) | 0;
            HEAP32[5243032 + (i52 + 3 << 2) >> 2] = i51;
            HEAP32[5243032 + (i52 + 2 << 2) >> 2] = i51;
            i51 = i57 + 1 | 0;
            if ((i51 | 0) == 32) {
              break;
            } else {
              i57 = i51;
            }
          }
          i57 = i56 + 8 | 0;
          if ((i57 & 7 | 0) == 0) {
            i59 = 0;
          } else {
            i59 = -i57 & 7;
          }
          i57 = (i55 - 40 | 0) - i59 | 0;
          HEAP32[1310754] = i56 + i59 | 0;
          HEAP32[1310751] = i57;
          HEAP32[i56 + (i59 + 4 | 0) >> 2] = i57 | 1;
          HEAP32[i56 + (i55 - 36 | 0) >> 2] = 40;
          HEAP32[1310755] = HEAP32[1310746] | 0;
        } else {
          i57 = 5243436;
          while (1) {
            i60 = HEAP32[i57 >> 2] | 0;
            i61 = i57 + 4 | 0;
            i62 = HEAP32[i61 >> 2] | 0;
            if ((i56 | 0) == (i60 + i62 | 0)) {
              i46 = 205;
              break;
            }
            i51 = HEAP32[i57 + 8 >> 2] | 0;
            if ((i51 | 0) == 0) {
              break;
            } else {
              i57 = i51;
            }
          }
          do {
            if ((i46 | 0) == 205) {
              if ((HEAP32[i57 + 12 >> 2] & 8 | 0) != 0) {
                break;
              }
              i51 = i58;
              if (!(i51 >>> 0 >= i60 >>> 0 & i51 >>> 0 < i56 >>> 0)) {
                break;
              }
              HEAP32[i61 >> 2] = i62 + i55 | 0;
              i51 = HEAP32[1310754] | 0;
              i52 = (HEAP32[1310751] | 0) + i55 | 0;
              i49 = i51;
              i53 = i51 + 8 | 0;
              if ((i53 & 7 | 0) == 0) {
                i63 = 0;
              } else {
                i63 = -i53 & 7;
              }
              i53 = i52 - i63 | 0;
              HEAP32[1310754] = i49 + i63 | 0;
              HEAP32[1310751] = i53;
              HEAP32[i49 + (i63 + 4 | 0) >> 2] = i53 | 1;
              HEAP32[i49 + (i52 + 4 | 0) >> 2] = 40;
              HEAP32[1310755] = HEAP32[1310746] | 0;
              break L279;
            }
          } while (0);
          if (i56 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
            HEAP32[1310752] = i56;
          }
          i57 = i56 + i55 | 0;
          i52 = 5243436;
          while (1) {
            i64 = i52 | 0;
            if ((HEAP32[i64 >> 2] | 0) == (i57 | 0)) {
              i46 = 215;
              break;
            }
            i49 = HEAP32[i52 + 8 >> 2] | 0;
            if ((i49 | 0) == 0) {
              break;
            } else {
              i52 = i49;
            }
          }
          do {
            if ((i46 | 0) == 215) {
              if ((HEAP32[i52 + 12 >> 2] & 8 | 0) != 0) {
                break;
              }
              HEAP32[i64 >> 2] = i56;
              i57 = i52 + 4 | 0;
              HEAP32[i57 >> 2] = (HEAP32[i57 >> 2] | 0) + i55 | 0;
              i57 = i56 + 8 | 0;
              if ((i57 & 7 | 0) == 0) {
                i65 = 0;
              } else {
                i65 = -i57 & 7;
              }
              i57 = i56 + (i55 + 8 | 0) | 0;
              if ((i57 & 7 | 0) == 0) {
                i66 = 0;
              } else {
                i66 = -i57 & 7;
              }
              i57 = i56 + (i66 + i55 | 0) | 0;
              i49 = i57;
              i53 = i65 + i13 | 0;
              i51 = i56 + i53 | 0;
              i50 = i51;
              i54 = (i57 - (i56 + i65 | 0) | 0) - i13 | 0;
              HEAP32[i56 + (i65 + 4 | 0) >> 2] = i13 | 3;
              L316 : do {
                if ((i49 | 0) == (HEAP32[1310754] | 0)) {
                  i48 = (HEAP32[1310751] | 0) + i54 | 0;
                  HEAP32[1310751] = i48;
                  HEAP32[1310754] = i50;
                  HEAP32[i56 + (i53 + 4 | 0) >> 2] = i48 | 1;
                } else {
                  if ((i49 | 0) == (HEAP32[1310753] | 0)) {
                    i48 = (HEAP32[1310750] | 0) + i54 | 0;
                    HEAP32[1310750] = i48;
                    HEAP32[1310753] = i50;
                    HEAP32[i56 + (i53 + 4 | 0) >> 2] = i48 | 1;
                    HEAP32[i56 + (i48 + i53 | 0) >> 2] = i48;
                    break;
                  }
                  i48 = i55 + 4 | 0;
                  i47 = HEAP32[i56 + (i48 + i66 | 0) >> 2] | 0;
                  if ((i47 & 3 | 0) == 1) {
                    i45 = i47 & -8;
                    i37 = i47 >>> 3;
                    L324 : do {
                      if (i47 >>> 0 < 256) {
                        i36 = HEAP32[i56 + ((i66 | 8) + i55 | 0) >> 2] | 0;
                        i15 = HEAP32[i56 + ((i55 + 12 | 0) + i66 | 0) >> 2] | 0;
                        if ((i36 | 0) == (i15 | 0)) {
                          HEAP32[1310748] = HEAP32[1310748] & (1 << i37 ^ -1);
                          break;
                        }
                        i43 = 5243032 + (i37 << 1 << 2) | 0;
                        do {
                          if ((i36 | 0) == (i43 | 0)) {
                            i46 = 230;
                          } else {
                            if (i36 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                              break;
                            } else {
                              i46 = 230;
                              break;
                            }
                          }
                        } while (0);
                        do {
                          if ((i46 | 0) == 230) {
                            if ((i15 | 0) != (i43 | 0)) {
                              if (i15 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                                break;
                              }
                            }
                            HEAP32[i36 + 12 >> 2] = i15;
                            HEAP32[i15 + 8 >> 2] = i36;
                            break L324;
                          }
                        } while (0);
                        _abort();
                        return 0;
                      } else {
                        i36 = i57;
                        i15 = HEAP32[i56 + ((i66 | 24) + i55 | 0) >> 2] | 0;
                        i43 = HEAP32[i56 + ((i55 + 12 | 0) + i66 | 0) >> 2] | 0;
                        L338 : do {
                          if ((i43 | 0) == (i36 | 0)) {
                            i44 = i66 | 16;
                            i41 = i56 + (i48 + i44 | 0) | 0;
                            i42 = HEAP32[i41 >> 2] | 0;
                            do {
                              if ((i42 | 0) == 0) {
                                i38 = i56 + (i44 + i55 | 0) | 0;
                                i39 = HEAP32[i38 >> 2] | 0;
                                if ((i39 | 0) == 0) {
                                  i67 = 0;
                                  break L338;
                                } else {
                                  i68 = i39;
                                  i69 = i38;
                                  break;
                                }
                              } else {
                                i68 = i42;
                                i69 = i41;
                              }
                            } while (0);
                            while (1) {
                              i41 = i68 + 20 | 0;
                              i42 = HEAP32[i41 >> 2] | 0;
                              if ((i42 | 0) != 0) {
                                i68 = i42;
                                i69 = i41;
                                continue;
                              }
                              i41 = i68 + 16 | 0;
                              i42 = HEAP32[i41 >> 2] | 0;
                              if ((i42 | 0) == 0) {
                                break;
                              } else {
                                i68 = i42;
                                i69 = i41;
                              }
                            }
                            if (i69 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                              _abort();
                              return 0;
                              i67 = i68;
                              break;
                            } else {
                              HEAP32[i69 >> 2] = 0;
                              i67 = i68;
                              break;
                            }
                          } else {
                            i41 = HEAP32[i56 + ((i66 | 8) + i55 | 0) >> 2] | 0;
                            if (i41 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                              _abort();
                              return 0;
                              i67 = i43;
                              break;
                            } else {
                              HEAP32[i41 + 12 >> 2] = i43;
                              HEAP32[i43 + 8 >> 2] = i41;
                              i67 = i43;
                              break;
                            }
                          }
                        } while (0);
                        if ((i15 | 0) == 0) {
                          break;
                        }
                        i43 = i56 + ((i55 + 28 | 0) + i66 | 0) | 0;
                        i41 = 5243296 + (HEAP32[i43 >> 2] << 2) | 0;
                        do {
                          if ((i36 | 0) == (HEAP32[i41 >> 2] | 0)) {
                            HEAP32[i41 >> 2] = i67;
                            if ((i67 | 0) != 0) {
                              break;
                            }
                            HEAP32[1310749] = HEAP32[1310749] & (1 << HEAP32[i43 >> 2] ^ -1);
                            break L324;
                          } else {
                            do {
                              if (i15 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                                _abort();
                                return 0;
                              } else {
                                i42 = i15 + 16 | 0;
                                if ((HEAP32[i42 >> 2] | 0) == (i36 | 0)) {
                                  HEAP32[i42 >> 2] = i67;
                                  break;
                                } else {
                                  HEAP32[i15 + 20 >> 2] = i67;
                                  break;
                                }
                              }
                            } while (0);
                            if ((i67 | 0) == 0) {
                              break L324;
                            }
                          }
                        } while (0);
                        if (i67 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                          _abort();
                          return 0;
                          break;
                        }
                        HEAP32[i67 + 24 >> 2] = i15;
                        i36 = i66 | 16;
                        i43 = HEAP32[i56 + (i36 + i55 | 0) >> 2] | 0;
                        do {
                          if ((i43 | 0) != 0) {
                            if (i43 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                              _abort();
                              return 0;
                              break;
                            } else {
                              HEAP32[i67 + 16 >> 2] = i43;
                              HEAP32[i43 + 24 >> 2] = i67;
                              break;
                            }
                          }
                        } while (0);
                        i43 = HEAP32[i56 + (i48 + i36 | 0) >> 2] | 0;
                        if ((i43 | 0) == 0) {
                          break;
                        }
                        if (i43 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                          _abort();
                          return 0;
                          break;
                        } else {
                          HEAP32[i67 + 20 >> 2] = i43;
                          HEAP32[i43 + 24 >> 2] = i67;
                          break;
                        }
                      }
                    } while (0);
                    i70 = i56 + ((i45 | i66) + i55 | 0) | 0;
                    i71 = i45 + i54 | 0;
                  } else {
                    i70 = i49;
                    i71 = i54;
                  }
                  i48 = i70 + 4 | 0;
                  HEAP32[i48 >> 2] = HEAP32[i48 >> 2] & -2;
                  HEAP32[i56 + (i53 + 4 | 0) >> 2] = i71 | 1;
                  HEAP32[i56 + (i71 + i53 | 0) >> 2] = i71;
                  i48 = i71 >>> 3;
                  if (i71 >>> 0 < 256) {
                    i37 = i48 << 1;
                    i47 = 5243032 + (i37 << 2) | 0;
                    i43 = HEAP32[1310748] | 0;
                    i15 = 1 << i48;
                    do {
                      if ((i43 & i15 | 0) == 0) {
                        HEAP32[1310748] = i43 | i15;
                        i72 = i47;
                        i73 = 5243032 + (i37 + 2 << 2) | 0;
                      } else {
                        i48 = 5243032 + (i37 + 2 << 2) | 0;
                        i41 = HEAP32[i48 >> 2] | 0;
                        if (i41 >>> 0 >= (HEAP32[1310752] | 0) >>> 0) {
                          i72 = i41;
                          i73 = i48;
                          break;
                        }
                        _abort();
                        return 0;
                        i72 = i47;
                        i73 = i48;
                      }
                    } while (0);
                    HEAP32[i73 >> 2] = i50;
                    HEAP32[i72 + 12 >> 2] = i50;
                    HEAP32[i56 + (i53 + 8 | 0) >> 2] = i72;
                    HEAP32[i56 + (i53 + 12 | 0) >> 2] = i47;
                    break;
                  }
                  i37 = i51;
                  i15 = i71 >>> 8;
                  do {
                    if ((i15 | 0) == 0) {
                      i74 = 0;
                    } else {
                      if (i71 >>> 0 > 16777215) {
                        i74 = 31;
                        break;
                      }
                      i43 = (i15 + 1048320 | 0) >>> 16 & 8;
                      i45 = i15 << i43;
                      i48 = (i45 + 520192 | 0) >>> 16 & 4;
                      i41 = i45 << i48;
                      i45 = (i41 + 245760 | 0) >>> 16 & 2;
                      i42 = (14 - (i48 | i43 | i45) | 0) + (i41 << i45 >>> 15) | 0;
                      i74 = i71 >>> ((i42 + 7 | 0) >>> 0) & 1 | i42 << 1;
                    }
                  } while (0);
                  i15 = 5243296 + (i74 << 2) | 0;
                  HEAP32[i56 + (i53 + 28 | 0) >> 2] = i74;
                  HEAP32[i56 + (i53 + 20 | 0) >> 2] = 0;
                  HEAP32[i56 + (i53 + 16 | 0) >> 2] = 0;
                  i47 = HEAP32[1310749] | 0;
                  i42 = 1 << i74;
                  if ((i47 & i42 | 0) == 0) {
                    HEAP32[1310749] = i47 | i42;
                    HEAP32[i15 >> 2] = i37;
                    HEAP32[i56 + (i53 + 24 | 0) >> 2] = i15;
                    HEAP32[i56 + (i53 + 12 | 0) >> 2] = i37;
                    HEAP32[i56 + (i53 + 8 | 0) >> 2] = i37;
                    break;
                  }
                  if ((i74 | 0) == 31) {
                    i75 = 0;
                  } else {
                    i75 = 25 - (i74 >>> 1) | 0;
                  }
                  i42 = i71 << i75;
                  i47 = HEAP32[i15 >> 2] | 0;
                  while (1) {
                    if ((HEAP32[i47 + 4 >> 2] & -8 | 0) == (i71 | 0)) {
                      break;
                    }
                    i76 = i47 + 16 + (i42 >>> 31 << 2) | 0;
                    i15 = HEAP32[i76 >> 2] | 0;
                    if ((i15 | 0) == 0) {
                      i46 = 282;
                      break;
                    } else {
                      i42 = i42 << 1;
                      i47 = i15;
                    }
                  }
                  if ((i46 | 0) == 282) {
                    if (i76 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                      _abort();
                      return 0;
                      break;
                    } else {
                      HEAP32[i76 >> 2] = i37;
                      HEAP32[i56 + (i53 + 24 | 0) >> 2] = i47;
                      HEAP32[i56 + (i53 + 12 | 0) >> 2] = i37;
                      HEAP32[i56 + (i53 + 8 | 0) >> 2] = i37;
                      break;
                    }
                  }
                  i42 = i47 + 8 | 0;
                  i15 = HEAP32[i42 >> 2] | 0;
                  i45 = HEAP32[1310752] | 0;
                  do {
                    if (i47 >>> 0 >= i45 >>> 0) {
                      if (i15 >>> 0 < i45 >>> 0) {
                        break;
                      }
                      HEAP32[i15 + 12 >> 2] = i37;
                      HEAP32[i42 >> 2] = i37;
                      HEAP32[i56 + (i53 + 8 | 0) >> 2] = i15;
                      HEAP32[i56 + (i53 + 12 | 0) >> 2] = i47;
                      HEAP32[i56 + (i53 + 24 | 0) >> 2] = 0;
                      break L316;
                    }
                  } while (0);
                  _abort();
                  return 0;
                }
              } while (0);
              i12 = i56 + (i65 | 8) | 0;
              return i12 | 0;
            }
          } while (0);
          i52 = i58;
          i53 = 5243436;
          while (1) {
            i77 = HEAP32[i53 >> 2] | 0;
            if (i77 >>> 0 <= i52 >>> 0) {
              i78 = HEAP32[i53 + 4 >> 2] | 0;
              i79 = i77 + i78 | 0;
              if (i79 >>> 0 > i52 >>> 0) {
                break;
              }
            }
            i53 = HEAP32[i53 + 8 >> 2] | 0;
          }
          i53 = i77 + (i78 - 39 | 0) | 0;
          if ((i53 & 7 | 0) == 0) {
            i80 = 0;
          } else {
            i80 = -i53 & 7;
          }
          i53 = i77 + ((i78 - 47 | 0) + i80 | 0) | 0;
          i51 = i53 >>> 0 < (i58 + 16 | 0) >>> 0 ? i52 : i53;
          i53 = i51 + 8 | 0;
          i50 = i56 + 8 | 0;
          if ((i50 & 7 | 0) == 0) {
            i81 = 0;
          } else {
            i81 = -i50 & 7;
          }
          i50 = (i55 - 40 | 0) - i81 | 0;
          HEAP32[1310754] = i56 + i81 | 0;
          HEAP32[1310751] = i50;
          HEAP32[i56 + (i81 + 4 | 0) >> 2] = i50 | 1;
          HEAP32[i56 + (i55 - 36 | 0) >> 2] = 40;
          HEAP32[1310755] = HEAP32[1310746] | 0;
          HEAP32[i51 + 4 >> 2] = 27;
          HEAP32[i53 >> 2] = HEAP32[1310859] | 0;
          HEAP32[i53 + 4 >> 2] = HEAP32[5243440 >> 2] | 0;
          HEAP32[i53 + 8 >> 2] = HEAP32[5243444 >> 2] | 0;
          HEAP32[i53 + 12 >> 2] = HEAP32[5243448 >> 2] | 0;
          HEAP32[1310859] = i56;
          HEAP32[1310860] = i55;
          HEAP32[1310862] = 0;
          HEAP32[1310861] = i53;
          i53 = i51 + 28 | 0;
          HEAP32[i53 >> 2] = 7;
          L428 : do {
            if ((i51 + 32 | 0) >>> 0 < i79 >>> 0) {
              i50 = i53;
              while (1) {
                i54 = i50 + 4 | 0;
                HEAP32[i54 >> 2] = 7;
                if ((i50 + 8 | 0) >>> 0 < i79 >>> 0) {
                  i50 = i54;
                } else {
                  break L428;
                }
              }
            }
          } while (0);
          if ((i51 | 0) == (i52 | 0)) {
            break;
          }
          i53 = i51 - i58 | 0;
          i50 = i52 + (i53 + 4 | 0) | 0;
          HEAP32[i50 >> 2] = HEAP32[i50 >> 2] & -2;
          HEAP32[i58 + 4 >> 2] = i53 | 1;
          HEAP32[i52 + i53 >> 2] = i53;
          i50 = i53 >>> 3;
          if (i53 >>> 0 < 256) {
            i54 = i50 << 1;
            i49 = 5243032 + (i54 << 2) | 0;
            i57 = HEAP32[1310748] | 0;
            i47 = 1 << i50;
            do {
              if ((i57 & i47 | 0) == 0) {
                HEAP32[1310748] = i57 | i47;
                i82 = i49;
                i83 = 5243032 + (i54 + 2 << 2) | 0;
              } else {
                i50 = 5243032 + (i54 + 2 << 2) | 0;
                i15 = HEAP32[i50 >> 2] | 0;
                if (i15 >>> 0 >= (HEAP32[1310752] | 0) >>> 0) {
                  i82 = i15;
                  i83 = i50;
                  break;
                }
                _abort();
                return 0;
                i82 = i49;
                i83 = i50;
              }
            } while (0);
            HEAP32[i83 >> 2] = i58;
            HEAP32[i82 + 12 >> 2] = i58;
            HEAP32[i58 + 8 >> 2] = i82;
            HEAP32[i58 + 12 >> 2] = i49;
            break;
          }
          i54 = i58;
          i47 = i53 >>> 8;
          do {
            if ((i47 | 0) == 0) {
              i84 = 0;
            } else {
              if (i53 >>> 0 > 16777215) {
                i84 = 31;
                break;
              }
              i57 = (i47 + 1048320 | 0) >>> 16 & 8;
              i52 = i47 << i57;
              i51 = (i52 + 520192 | 0) >>> 16 & 4;
              i50 = i52 << i51;
              i52 = (i50 + 245760 | 0) >>> 16 & 2;
              i15 = (14 - (i51 | i57 | i52) | 0) + (i50 << i52 >>> 15) | 0;
              i84 = i53 >>> ((i15 + 7 | 0) >>> 0) & 1 | i15 << 1;
            }
          } while (0);
          i47 = 5243296 + (i84 << 2) | 0;
          HEAP32[i58 + 28 >> 2] = i84;
          HEAP32[i58 + 20 >> 2] = 0;
          HEAP32[i58 + 16 >> 2] = 0;
          i49 = HEAP32[1310749] | 0;
          i15 = 1 << i84;
          if ((i49 & i15 | 0) == 0) {
            HEAP32[1310749] = i49 | i15;
            HEAP32[i47 >> 2] = i54;
            HEAP32[i58 + 24 >> 2] = i47;
            HEAP32[i58 + 12 >> 2] = i58;
            HEAP32[i58 + 8 >> 2] = i58;
            break;
          }
          if ((i84 | 0) == 31) {
            i85 = 0;
          } else {
            i85 = 25 - (i84 >>> 1) | 0;
          }
          i15 = i53 << i85;
          i49 = HEAP32[i47 >> 2] | 0;
          while (1) {
            if ((HEAP32[i49 + 4 >> 2] & -8 | 0) == (i53 | 0)) {
              break;
            }
            i86 = i49 + 16 + (i15 >>> 31 << 2) | 0;
            i47 = HEAP32[i86 >> 2] | 0;
            if ((i47 | 0) == 0) {
              i46 = 317;
              break;
            } else {
              i15 = i15 << 1;
              i49 = i47;
            }
          }
          if ((i46 | 0) == 317) {
            if (i86 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
              _abort();
              return 0;
              break;
            } else {
              HEAP32[i86 >> 2] = i54;
              HEAP32[i58 + 24 >> 2] = i49;
              HEAP32[i58 + 12 >> 2] = i58;
              HEAP32[i58 + 8 >> 2] = i58;
              break;
            }
          }
          i15 = i49 + 8 | 0;
          i53 = HEAP32[i15 >> 2] | 0;
          i47 = HEAP32[1310752] | 0;
          do {
            if (i49 >>> 0 >= i47 >>> 0) {
              if (i53 >>> 0 < i47 >>> 0) {
                break;
              }
              HEAP32[i53 + 12 >> 2] = i54;
              HEAP32[i15 >> 2] = i54;
              HEAP32[i58 + 8 >> 2] = i53;
              HEAP32[i58 + 12 >> 2] = i49;
              HEAP32[i58 + 24 >> 2] = 0;
              break L279;
            }
          } while (0);
          _abort();
          return 0;
        }
      } while (0);
      i58 = HEAP32[1310751] | 0;
      if (i58 >>> 0 <= i13 >>> 0) {
        break;
      }
      i49 = i58 - i13 | 0;
      HEAP32[1310751] = i49;
      i58 = HEAP32[1310754] | 0;
      i53 = i58;
      HEAP32[1310754] = i53 + i13 | 0;
      HEAP32[i53 + (i13 + 4 | 0) >> 2] = i49 | 1;
      HEAP32[i58 + 4 >> 2] = i13 | 3;
      i12 = i58 + 8 | 0;
      return i12 | 0;
    }
  } while (0);
  HEAP32[___errno_location() >> 2] = 12;
  i12 = 0;
  return i12 | 0;
}
function _free(i1) {
  i1 = i1 | 0;
  var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0;
  if ((i1 | 0) == 0) {
    return;
  }
  i2 = i1 - 8 | 0;
  i3 = i2;
  i4 = HEAP32[1310752] | 0;
  L473 : do {
    if (i2 >>> 0 >= i4 >>> 0) {
      i5 = HEAP32[i1 - 4 >> 2] | 0;
      i6 = i5 & 3;
      if ((i6 | 0) == 1) {
        break;
      }
      i7 = i5 & -8;
      i8 = i1 + (i7 - 8 | 0) | 0;
      i9 = i8;
      L476 : do {
        if ((i5 & 1 | 0) == 0) {
          i10 = HEAP32[i2 >> 2] | 0;
          if ((i6 | 0) == 0) {
            return;
          }
          i11 = -8 - i10 | 0;
          i12 = i1 + i11 | 0;
          i13 = i12;
          i14 = i10 + i7 | 0;
          if (i12 >>> 0 < i4 >>> 0) {
            break L473;
          }
          if ((i13 | 0) == (HEAP32[1310753] | 0)) {
            i15 = i1 + (i7 - 4 | 0) | 0;
            if ((HEAP32[i15 >> 2] & 3 | 0) != 3) {
              i16 = i13;
              i17 = i14;
              break;
            }
            HEAP32[1310750] = i14;
            HEAP32[i15 >> 2] = HEAP32[i15 >> 2] & -2;
            HEAP32[i1 + (i11 + 4 | 0) >> 2] = i14 | 1;
            HEAP32[i8 >> 2] = i14;
            return;
          }
          i15 = i10 >>> 3;
          if (i10 >>> 0 < 256) {
            i10 = HEAP32[i1 + (i11 + 8 | 0) >> 2] | 0;
            i18 = HEAP32[i1 + (i11 + 12 | 0) >> 2] | 0;
            if ((i10 | 0) == (i18 | 0)) {
              HEAP32[1310748] = HEAP32[1310748] & (1 << i15 ^ -1);
              i16 = i13;
              i17 = i14;
              break;
            }
            i19 = 5243032 + (i15 << 1 << 2) | 0;
            do {
              if (!((i10 | 0) != (i19 | 0) & i10 >>> 0 < i4 >>> 0)) {
                if (!((i18 | 0) == (i19 | 0) | i18 >>> 0 >= i4 >>> 0)) {
                  break;
                }
                HEAP32[i10 + 12 >> 2] = i18;
                HEAP32[i18 + 8 >> 2] = i10;
                i16 = i13;
                i17 = i14;
                break L476;
              }
            } while (0);
            _abort();
            i16 = i13;
            i17 = i14;
            break;
          }
          i10 = i12;
          i18 = HEAP32[i1 + (i11 + 24 | 0) >> 2] | 0;
          i19 = HEAP32[i1 + (i11 + 12 | 0) >> 2] | 0;
          L497 : do {
            if ((i19 | 0) == (i10 | 0)) {
              i15 = i1 + (i11 + 20 | 0) | 0;
              i20 = HEAP32[i15 >> 2] | 0;
              do {
                if ((i20 | 0) == 0) {
                  i21 = i1 + (i11 + 16 | 0) | 0;
                  i22 = HEAP32[i21 >> 2] | 0;
                  if ((i22 | 0) == 0) {
                    i23 = 0;
                    break L497;
                  } else {
                    i24 = i22;
                    i25 = i21;
                    break;
                  }
                } else {
                  i24 = i20;
                  i25 = i15;
                }
              } while (0);
              while (1) {
                i15 = i24 + 20 | 0;
                i20 = HEAP32[i15 >> 2] | 0;
                if ((i20 | 0) != 0) {
                  i24 = i20;
                  i25 = i15;
                  continue;
                }
                i15 = i24 + 16 | 0;
                i20 = HEAP32[i15 >> 2] | 0;
                if ((i20 | 0) == 0) {
                  break;
                } else {
                  i24 = i20;
                  i25 = i15;
                }
              }
              if (i25 >>> 0 < i4 >>> 0) {
                _abort();
                i23 = i24;
                break;
              } else {
                HEAP32[i25 >> 2] = 0;
                i23 = i24;
                break;
              }
            } else {
              i15 = HEAP32[i1 + (i11 + 8 | 0) >> 2] | 0;
              if (i15 >>> 0 < i4 >>> 0) {
                _abort();
                i23 = i19;
                break;
              } else {
                HEAP32[i15 + 12 >> 2] = i19;
                HEAP32[i19 + 8 >> 2] = i15;
                i23 = i19;
                break;
              }
            }
          } while (0);
          if ((i18 | 0) == 0) {
            i16 = i13;
            i17 = i14;
            break;
          }
          i19 = i1 + (i11 + 28 | 0) | 0;
          i12 = 5243296 + (HEAP32[i19 >> 2] << 2) | 0;
          do {
            if ((i10 | 0) == (HEAP32[i12 >> 2] | 0)) {
              HEAP32[i12 >> 2] = i23;
              if ((i23 | 0) != 0) {
                break;
              }
              HEAP32[1310749] = HEAP32[1310749] & (1 << HEAP32[i19 >> 2] ^ -1);
              i16 = i13;
              i17 = i14;
              break L476;
            } else {
              do {
                if (i18 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                  _abort();
                } else {
                  i15 = i18 + 16 | 0;
                  if ((HEAP32[i15 >> 2] | 0) == (i10 | 0)) {
                    HEAP32[i15 >> 2] = i23;
                    break;
                  } else {
                    HEAP32[i18 + 20 >> 2] = i23;
                    break;
                  }
                }
              } while (0);
              if ((i23 | 0) == 0) {
                i16 = i13;
                i17 = i14;
                break L476;
              }
            }
          } while (0);
          if (i23 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
            _abort();
            i16 = i13;
            i17 = i14;
            break;
          }
          HEAP32[i23 + 24 >> 2] = i18;
          i10 = HEAP32[i1 + (i11 + 16 | 0) >> 2] | 0;
          do {
            if ((i10 | 0) != 0) {
              if (i10 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                break;
              } else {
                HEAP32[i23 + 16 >> 2] = i10;
                HEAP32[i10 + 24 >> 2] = i23;
                break;
              }
            }
          } while (0);
          i10 = HEAP32[i1 + (i11 + 20 | 0) >> 2] | 0;
          if ((i10 | 0) == 0) {
            i16 = i13;
            i17 = i14;
            break;
          }
          if (i10 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
            _abort();
            i16 = i13;
            i17 = i14;
            break;
          } else {
            HEAP32[i23 + 20 >> 2] = i10;
            HEAP32[i10 + 24 >> 2] = i23;
            i16 = i13;
            i17 = i14;
            break;
          }
        } else {
          i16 = i3;
          i17 = i7;
        }
      } while (0);
      i6 = i16;
      if (i6 >>> 0 >= i8 >>> 0) {
        break;
      }
      i5 = i1 + (i7 - 4 | 0) | 0;
      i10 = HEAP32[i5 >> 2] | 0;
      if ((i10 & 1 | 0) == 0) {
        break;
      }
      do {
        if ((i10 & 2 | 0) == 0) {
          if ((i9 | 0) == (HEAP32[1310754] | 0)) {
            i18 = (HEAP32[1310751] | 0) + i17 | 0;
            HEAP32[1310751] = i18;
            HEAP32[1310754] = i16;
            HEAP32[i16 + 4 >> 2] = i18 | 1;
            if ((i16 | 0) == (HEAP32[1310753] | 0)) {
              HEAP32[1310753] = 0;
              HEAP32[1310750] = 0;
            }
            if (i18 >>> 0 <= (HEAP32[1310755] | 0) >>> 0) {
              return;
            }
            do {
              if ((HEAP32[1310742] | 0) == 0) {
                if ((HEAP32[1310742] | 0) != 0) {
                  break;
                }
                i18 = _sysconf(8) | 0;
                if ((i18 - 1 & i18 | 0) != 0) {
                  _abort();
                }
                HEAP32[1310744] = i18;
                HEAP32[1310743] = i18;
                HEAP32[1310745] = -1;
                HEAP32[1310746] = 2097152;
                HEAP32[1310747] = 0;
                HEAP32[1310858] = 0;
                HEAP32[1310742] = _time(0) & -16 ^ 1431655768;
              }
            } while (0);
            i14 = HEAP32[1310754] | 0;
            if ((i14 | 0) == 0) {
              return;
            }
            i13 = HEAP32[1310751] | 0;
            do {
              if (i13 >>> 0 > 40) {
                i11 = HEAP32[1310744] | 0;
                i18 = Math_imul(((((i13 - 41 | 0) + i11 | 0) >>> 0) / (i11 >>> 0) >>> 0) - 1 | 0, i11) & -1;
                i19 = i14;
                i12 = 5243436;
                while (1) {
                  i15 = HEAP32[i12 >> 2] | 0;
                  if (i15 >>> 0 <= i19 >>> 0) {
                    if ((i15 + (HEAP32[i12 + 4 >> 2] | 0) | 0) >>> 0 > i19 >>> 0) {
                      i26 = i12;
                      break;
                    }
                  }
                  i15 = HEAP32[i12 + 8 >> 2] | 0;
                  if ((i15 | 0) == 0) {
                    i26 = 0;
                    break;
                  } else {
                    i12 = i15;
                  }
                }
                if ((HEAP32[i26 + 12 >> 2] & 8 | 0) != 0) {
                  break;
                }
                i12 = _sbrk(0) | 0;
                i19 = i26 + 4 | 0;
                if ((i12 | 0) != ((HEAP32[i26 >> 2] | 0) + (HEAP32[i19 >> 2] | 0) | 0)) {
                  break;
                }
                i15 = _sbrk(-(i18 >>> 0 > 2147483646 ? -2147483648 - i11 | 0 : i18) | 0) | 0;
                i20 = _sbrk(0) | 0;
                if (!((i15 | 0) != -1 & i20 >>> 0 < i12 >>> 0)) {
                  break;
                }
                i15 = i12 - i20 | 0;
                if ((i12 | 0) == (i20 | 0)) {
                  break;
                }
                HEAP32[i19 >> 2] = (HEAP32[i19 >> 2] | 0) - i15 | 0;
                HEAP32[1310856] = (HEAP32[1310856] | 0) - i15 | 0;
                i19 = HEAP32[1310754] | 0;
                i20 = (HEAP32[1310751] | 0) - i15 | 0;
                i15 = i19;
                i12 = i19 + 8 | 0;
                if ((i12 & 7 | 0) == 0) {
                  i27 = 0;
                } else {
                  i27 = -i12 & 7;
                }
                i12 = i20 - i27 | 0;
                HEAP32[1310754] = i15 + i27 | 0;
                HEAP32[1310751] = i12;
                HEAP32[i15 + (i27 + 4 | 0) >> 2] = i12 | 1;
                HEAP32[i15 + (i20 + 4 | 0) >> 2] = 40;
                HEAP32[1310755] = HEAP32[1310746] | 0;
                return;
              }
            } while (0);
            if ((HEAP32[1310751] | 0) >>> 0 <= (HEAP32[1310755] | 0) >>> 0) {
              return;
            }
            HEAP32[1310755] = -1;
            return;
          }
          if ((i9 | 0) == (HEAP32[1310753] | 0)) {
            i14 = (HEAP32[1310750] | 0) + i17 | 0;
            HEAP32[1310750] = i14;
            HEAP32[1310753] = i16;
            HEAP32[i16 + 4 >> 2] = i14 | 1;
            HEAP32[i6 + i14 >> 2] = i14;
            return;
          }
          i14 = (i10 & -8) + i17 | 0;
          i13 = i10 >>> 3;
          L588 : do {
            if (i10 >>> 0 < 256) {
              i20 = HEAP32[i1 + i7 >> 2] | 0;
              i15 = HEAP32[i1 + (i7 | 4) >> 2] | 0;
              if ((i20 | 0) == (i15 | 0)) {
                HEAP32[1310748] = HEAP32[1310748] & (1 << i13 ^ -1);
                break;
              }
              i12 = 5243032 + (i13 << 1 << 2) | 0;
              do {
                if ((i20 | 0) == (i12 | 0)) {
                  i28 = 418;
                } else {
                  if (i20 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                    break;
                  } else {
                    i28 = 418;
                    break;
                  }
                }
              } while (0);
              do {
                if ((i28 | 0) == 418) {
                  if ((i15 | 0) != (i12 | 0)) {
                    if (i15 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                      break;
                    }
                  }
                  HEAP32[i20 + 12 >> 2] = i15;
                  HEAP32[i15 + 8 >> 2] = i20;
                  break L588;
                }
              } while (0);
              _abort();
            } else {
              i20 = i8;
              i15 = HEAP32[i1 + (i7 + 16 | 0) >> 2] | 0;
              i12 = HEAP32[i1 + (i7 | 4) >> 2] | 0;
              L602 : do {
                if ((i12 | 0) == (i20 | 0)) {
                  i18 = i1 + (i7 + 12 | 0) | 0;
                  i11 = HEAP32[i18 >> 2] | 0;
                  do {
                    if ((i11 | 0) == 0) {
                      i19 = i1 + (i7 + 8 | 0) | 0;
                      i21 = HEAP32[i19 >> 2] | 0;
                      if ((i21 | 0) == 0) {
                        i29 = 0;
                        break L602;
                      } else {
                        i30 = i21;
                        i31 = i19;
                        break;
                      }
                    } else {
                      i30 = i11;
                      i31 = i18;
                    }
                  } while (0);
                  while (1) {
                    i18 = i30 + 20 | 0;
                    i11 = HEAP32[i18 >> 2] | 0;
                    if ((i11 | 0) != 0) {
                      i30 = i11;
                      i31 = i18;
                      continue;
                    }
                    i18 = i30 + 16 | 0;
                    i11 = HEAP32[i18 >> 2] | 0;
                    if ((i11 | 0) == 0) {
                      break;
                    } else {
                      i30 = i11;
                      i31 = i18;
                    }
                  }
                  if (i31 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                    _abort();
                    i29 = i30;
                    break;
                  } else {
                    HEAP32[i31 >> 2] = 0;
                    i29 = i30;
                    break;
                  }
                } else {
                  i18 = HEAP32[i1 + i7 >> 2] | 0;
                  if (i18 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                    _abort();
                    i29 = i12;
                    break;
                  } else {
                    HEAP32[i18 + 12 >> 2] = i12;
                    HEAP32[i12 + 8 >> 2] = i18;
                    i29 = i12;
                    break;
                  }
                }
              } while (0);
              if ((i15 | 0) == 0) {
                break;
              }
              i12 = i1 + (i7 + 20 | 0) | 0;
              i18 = 5243296 + (HEAP32[i12 >> 2] << 2) | 0;
              do {
                if ((i20 | 0) == (HEAP32[i18 >> 2] | 0)) {
                  HEAP32[i18 >> 2] = i29;
                  if ((i29 | 0) != 0) {
                    break;
                  }
                  HEAP32[1310749] = HEAP32[1310749] & (1 << HEAP32[i12 >> 2] ^ -1);
                  break L588;
                } else {
                  do {
                    if (i15 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                      _abort();
                    } else {
                      i11 = i15 + 16 | 0;
                      if ((HEAP32[i11 >> 2] | 0) == (i20 | 0)) {
                        HEAP32[i11 >> 2] = i29;
                        break;
                      } else {
                        HEAP32[i15 + 20 >> 2] = i29;
                        break;
                      }
                    }
                  } while (0);
                  if ((i29 | 0) == 0) {
                    break L588;
                  }
                }
              } while (0);
              if (i29 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                break;
              }
              HEAP32[i29 + 24 >> 2] = i15;
              i20 = HEAP32[i1 + (i7 + 8 | 0) >> 2] | 0;
              do {
                if ((i20 | 0) != 0) {
                  if (i20 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                    _abort();
                    break;
                  } else {
                    HEAP32[i29 + 16 >> 2] = i20;
                    HEAP32[i20 + 24 >> 2] = i29;
                    break;
                  }
                }
              } while (0);
              i20 = HEAP32[i1 + (i7 + 12 | 0) >> 2] | 0;
              if ((i20 | 0) == 0) {
                break;
              }
              if (i20 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
                _abort();
                break;
              } else {
                HEAP32[i29 + 20 >> 2] = i20;
                HEAP32[i20 + 24 >> 2] = i29;
                break;
              }
            }
          } while (0);
          HEAP32[i16 + 4 >> 2] = i14 | 1;
          HEAP32[i6 + i14 >> 2] = i14;
          if ((i16 | 0) != (HEAP32[1310753] | 0)) {
            i32 = i14;
            break;
          }
          HEAP32[1310750] = i14;
          return;
        } else {
          HEAP32[i5 >> 2] = i10 & -2;
          HEAP32[i16 + 4 >> 2] = i17 | 1;
          HEAP32[i6 + i17 >> 2] = i17;
          i32 = i17;
        }
      } while (0);
      i6 = i32 >>> 3;
      if (i32 >>> 0 < 256) {
        i10 = i6 << 1;
        i5 = 5243032 + (i10 << 2) | 0;
        i7 = HEAP32[1310748] | 0;
        i8 = 1 << i6;
        do {
          if ((i7 & i8 | 0) == 0) {
            HEAP32[1310748] = i7 | i8;
            i33 = i5;
            i34 = 5243032 + (i10 + 2 << 2) | 0;
          } else {
            i6 = 5243032 + (i10 + 2 << 2) | 0;
            i9 = HEAP32[i6 >> 2] | 0;
            if (i9 >>> 0 >= (HEAP32[1310752] | 0) >>> 0) {
              i33 = i9;
              i34 = i6;
              break;
            }
            _abort();
            i33 = i5;
            i34 = i6;
          }
        } while (0);
        HEAP32[i34 >> 2] = i16;
        HEAP32[i33 + 12 >> 2] = i16;
        HEAP32[i16 + 8 >> 2] = i33;
        HEAP32[i16 + 12 >> 2] = i5;
        return;
      }
      i10 = i16;
      i8 = i32 >>> 8;
      do {
        if ((i8 | 0) == 0) {
          i35 = 0;
        } else {
          if (i32 >>> 0 > 16777215) {
            i35 = 31;
            break;
          }
          i7 = (i8 + 1048320 | 0) >>> 16 & 8;
          i6 = i8 << i7;
          i9 = (i6 + 520192 | 0) >>> 16 & 4;
          i13 = i6 << i9;
          i6 = (i13 + 245760 | 0) >>> 16 & 2;
          i20 = (14 - (i9 | i7 | i6) | 0) + (i13 << i6 >>> 15) | 0;
          i35 = i32 >>> ((i20 + 7 | 0) >>> 0) & 1 | i20 << 1;
        }
      } while (0);
      i8 = 5243296 + (i35 << 2) | 0;
      HEAP32[i16 + 28 >> 2] = i35;
      HEAP32[i16 + 20 >> 2] = 0;
      HEAP32[i16 + 16 >> 2] = 0;
      i5 = HEAP32[1310749] | 0;
      i20 = 1 << i35;
      L662 : do {
        if ((i5 & i20 | 0) == 0) {
          HEAP32[1310749] = i5 | i20;
          HEAP32[i8 >> 2] = i10;
          HEAP32[i16 + 24 >> 2] = i8;
          HEAP32[i16 + 12 >> 2] = i16;
          HEAP32[i16 + 8 >> 2] = i16;
        } else {
          if ((i35 | 0) == 31) {
            i36 = 0;
          } else {
            i36 = 25 - (i35 >>> 1) | 0;
          }
          i6 = i32 << i36;
          i13 = HEAP32[i8 >> 2] | 0;
          while (1) {
            if ((HEAP32[i13 + 4 >> 2] & -8 | 0) == (i32 | 0)) {
              break;
            }
            i37 = i13 + 16 + (i6 >>> 31 << 2) | 0;
            i7 = HEAP32[i37 >> 2] | 0;
            if ((i7 | 0) == 0) {
              i28 = 472;
              break;
            } else {
              i6 = i6 << 1;
              i13 = i7;
            }
          }
          if ((i28 | 0) == 472) {
            if (i37 >>> 0 < (HEAP32[1310752] | 0) >>> 0) {
              _abort();
              break;
            } else {
              HEAP32[i37 >> 2] = i10;
              HEAP32[i16 + 24 >> 2] = i13;
              HEAP32[i16 + 12 >> 2] = i16;
              HEAP32[i16 + 8 >> 2] = i16;
              break;
            }
          }
          i6 = i13 + 8 | 0;
          i14 = HEAP32[i6 >> 2] | 0;
          i7 = HEAP32[1310752] | 0;
          do {
            if (i13 >>> 0 >= i7 >>> 0) {
              if (i14 >>> 0 < i7 >>> 0) {
                break;
              }
              HEAP32[i14 + 12 >> 2] = i10;
              HEAP32[i6 >> 2] = i10;
              HEAP32[i16 + 8 >> 2] = i14;
              HEAP32[i16 + 12 >> 2] = i13;
              HEAP32[i16 + 24 >> 2] = 0;
              break L662;
            }
          } while (0);
          _abort();
        }
      } while (0);
      i10 = (HEAP32[1310756] | 0) - 1 | 0;
      HEAP32[1310756] = i10;
      if ((i10 | 0) == 0) {
        i38 = 5243444;
      } else {
        return;
      }
      while (1) {
        i10 = HEAP32[i38 >> 2] | 0;
        if ((i10 | 0) == 0) {
          break;
        } else {
          i38 = i10 + 8 | 0;
        }
      }
      HEAP32[1310756] = -1;
      return;
    }
  } while (0);
  _abort();
  return;
}
function _main(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0;
  i3 = STACKTOP;
  L691 : do {
    if ((i1 | 0) > 1) {
      i4 = _atoi(HEAP32[i2 + 4 >> 2] | 0) | 0;
      if ((i1 | 0) <= 2) {
        i5 = 0;
        i6 = 0;
        break;
      }
      i7 = _atoi(HEAP32[i2 + 8 >> 2] | 0) | 0;
      if ((i7 | 0) <= 0) {
        i5 = 0;
        i6 = 0;
        break;
      }
      i8 = (i4 | 0) / 2 & -1;
      i9 = (i4 | 0) > 1;
      i10 = (i4 | 0) > 0;
      i11 = (i8 | 0) < (i4 | 0);
      i12 = 0;
      i13 = 0;
      i14 = 0;
      while (1) {
        i15 = _llvm_stacksave() | 0;
        i16 = STACKTOP;
        STACKTOP = STACKTOP + (i4 * 4 & -1) | 0;
        STACKTOP = STACKTOP + 3 >> 2 << 2;
        L697 : do {
          if (i9) {
            i17 = 0;
            while (1) {
              i18 = _malloc((i17 * 11 & -1 & -1 | 0) % 1024 + i12 | 0) | 0;
              HEAP32[i16 + (i17 << 2) >> 2] = i18;
              if ((i18 | 0) == 0) {
                ___assert_func(5242880, 5727, 5242944, 5242928);
              }
              do {
                if ((i17 | 0) > 10 & ((i17 | 0) % 4 | 0) == 1) {
                  i18 = i16 + (i17 - 10 << 2) | 0;
                  i19 = HEAP32[i18 >> 2] | 0;
                  if ((i19 | 0) == 0) {
                    break;
                  }
                  _free(i19);
                  HEAP32[i18 >> 2] = 0;
                }
              } while (0);
              i18 = i17 + 1 | 0;
              if ((i18 | 0) < (i8 | 0)) {
                i17 = i18;
              } else {
                break L697;
              }
            }
          }
        } while (0);
        L708 : do {
          if (i11) {
            i17 = i8;
            while (1) {
              i18 = i17 + 1 | 0;
              i19 = _malloc(i18 << 10) | 0;
              HEAP32[i16 + (i17 << 2) >> 2] = i19;
              if ((i19 | 0) == 0) {
                ___assert_func(5242880, 5737, 5242944, 5242928);
              }
              do {
                if (!((i17 | 0) < 11 | ((i17 | 0) % 4 | 0) == 1)) {
                  i19 = i16 + (i17 - 10 << 2) | 0;
                  i20 = HEAP32[i19 >> 2] | 0;
                  if ((i20 | 0) == 0) {
                    break;
                  }
                  _free(i20);
                  HEAP32[i19 >> 2] = 0;
                }
              } while (0);
              if ((i18 | 0) == (i4 | 0)) {
                break L708;
              } else {
                i17 = i18;
              }
            }
          }
        } while (0);
        i17 = HEAP32[i16 >> 2] | 0;
        L719 : do {
          if (i10) {
            i19 = 1;
            i20 = i17;
            while (1) {
              if ((i20 | 0) != 0) {
                _free(i20);
              }
              if ((i19 | 0) == (i4 | 0)) {
                break L719;
              }
              i21 = HEAP32[i16 + (i19 << 2) >> 2] | 0;
              i19 = i19 + 1 | 0;
              i20 = i21;
            }
          }
        } while (0);
        i16 = _malloc(512) | 0;
        i20 = ((i17 | 0) == (i16 | 0) & 1) + i14 | 0;
        i16 = ((i17 | 0) == (_malloc(512) | 0) & 1) + i13 | 0;
        _llvm_stackrestore(i15 | 0);
        i19 = i12 + 1 | 0;
        if ((i19 | 0) == (i7 | 0)) {
          i5 = i16;
          i6 = i20;
          break L691;
        } else {
          i12 = i19;
          i13 = i16;
          i14 = i20;
        }
      }
    } else {
      i5 = 0;
      i6 = 0;
    }
  } while (0);
  _printf(5242916, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = i6, HEAP32[tempInt + 4 >> 2] = i5, tempInt) | 0) | 0;
  STACKTOP = i3;
  return 0;
}
function _strlen(i1) {
  i1 = i1 | 0;
  var i2 = 0;
  i2 = i1;
  while (HEAP8[i2] | 0 != 0) {
    i2 = i2 + 1 | 0;
  }
  return i2 - i1 | 0;
}
function _memcpy(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0;
  i4 = i1 | 0;
  if ((i1 & 3) == (i2 & 3)) {
    while (i1 & 3) {
      if ((i3 | 0) == 0) return i4 | 0;
      HEAP8[i1] = HEAP8[i2] | 0;
      i1 = i1 + 1 | 0;
      i2 = i2 + 1 | 0;
      i3 = i3 - 1 | 0;
    }
    while ((i3 | 0) >= 4) {
      HEAP32[i1 >> 2] = HEAP32[i2 >> 2] | 0;
      i1 = i1 + 4 | 0;
      i2 = i2 + 4 | 0;
      i3 = i3 - 4 | 0;
    }
  }
  while ((i3 | 0) > 0) {
    HEAP8[i1] = HEAP8[i2] | 0;
    i1 = i1 + 1 | 0;
    i2 = i2 + 1 | 0;
    i3 = i3 - 1 | 0;
  }
  return i4 | 0;
}
function _memset(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0;
  i4 = i1 + i3 | 0;
  if (i3 | 0 >= 20) {
    i3 = i1 & 3;
    i5 = i2 | i2 << 8 | i2 << 16 | i2 << 24;
    i6 = i4 & ~3;
    if (i3) {
      i3 = i1 + 4 - i3 | 0;
      while ((i1 | 0) < (i3 | 0)) {
        HEAP8[i1] = i2;
        i1 = i1 + 1 | 0;
      }
    }
    while ((i1 | 0) < (i6 | 0)) {
      HEAP32[i1 >> 2] = i5;
      i1 = i1 + 4 | 0;
    }
  }
  while ((i1 | 0) < (i4 | 0)) {
    HEAP8[i1] = i2;
    i1 = i1 + 1 | 0;
  }
}






  
  function dynCall_vi(index,a1) {
    index = index|0;
    a1=a1|0;
    FUNCTION_TABLE_vi[index&1](a1|0);
  }


  function dynCall_ii(index,a1) {
    index = index|0;
    a1=a1|0;
    return FUNCTION_TABLE_ii[index&1](a1|0)|0;
  }


  function dynCall_iii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    return FUNCTION_TABLE_iii[index&1](a1|0,a2|0)|0;
  }


  function dynCall_v(index) {
    index = index|0;
    
    FUNCTION_TABLE_v[index&1]();
  }

function b0(p0) { p0 = p0|0; abort(0);  };
  function b1(p0) { p0 = p0|0; abort(1); return 0 };
  function b2(p0,p1) { p0 = p0|0;p1 = p1|0; abort(2); return 0 };
  function b3() { ; abort(3);  };
  var FUNCTION_TABLE_vi = [b0,b0];
  
  var FUNCTION_TABLE_ii = [b1,b1];
  
  var FUNCTION_TABLE_iii = [b2,b2];
  
  var FUNCTION_TABLE_v = [b3,b3];
  

  return { _strlen: _strlen, _free: _free, _main: _main, _memset: _memset, _malloc: _malloc, _memcpy: _memcpy, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, setTempRet1: setTempRet1, setTempRet2: setTempRet2, setTempRet3: setTempRet3, setTempRet4: setTempRet4, setTempRet5: setTempRet5, setTempRet6: setTempRet6, setTempRet7: setTempRet7, setTempRet8: setTempRet8, setTempRet9: setTempRet9, dynCall_vi: dynCall_vi, dynCall_ii: dynCall_ii, dynCall_iii: dynCall_iii, dynCall_v: dynCall_v };
})({ Math: Math, Int8Array: Int8Array, Int16Array: Int16Array, Int32Array: Int32Array, Uint8Array: Uint8Array, Uint16Array: Uint16Array, Uint32Array: Uint32Array, Float32Array: Float32Array, Float64Array: Float64Array }, { abort: abort, assert: assert, asmPrintInt: asmPrintInt, asmPrintFloat: asmPrintFloat, copyTempDouble: copyTempDouble, copyTempFloat: copyTempFloat, Runtime_bitshift64: Runtime_bitshift64, min: Math_min, _strtol: _strtol, _pwrite: _pwrite, _llvm_stackrestore: _llvm_stackrestore, _sysconf: _sysconf, _llvm_stacksave: _llvm_stacksave, ___setErrNo: ___setErrNo, _fwrite: _fwrite, _time: _time, _abort: _abort, _write: _write, _atoi: _atoi, _fprintf: _fprintf, _sbrk: _sbrk, __parseInt: __parseInt, _printf: _printf, __formatString: __formatString, ___errno_location: ___errno_location, ___assert_func: ___assert_func, _isspace: _isspace, STACKTOP: STACKTOP, STACK_MAX: STACK_MAX, tempDoublePtr: tempDoublePtr, ABORT: ABORT, NaN: NaN, Infinity: Infinity }, buffer);
var _strlen = Module["_strlen"] = asm._strlen;
var _free = Module["_free"] = asm._free;
var _main = Module["_main"] = asm._main;
var _memset = Module["_memset"] = asm._memset;
var _malloc = Module["_malloc"] = asm._malloc;
var _memcpy = Module["_memcpy"] = asm._memcpy;
var dynCall_vi = Module["dynCall_vi"] = asm.dynCall_vi;
var dynCall_ii = Module["dynCall_ii"] = asm.dynCall_ii;
var dynCall_iii = Module["dynCall_iii"] = asm.dynCall_iii;
var dynCall_v = Module["dynCall_v"] = asm.dynCall_v;
Runtime.stackAlloc = function(size) { return asm.stackAlloc(size) };
Runtime.stackSave = function() { return asm.stackSave() };
Runtime.stackRestore = function(top) { asm.stackRestore(top) };
// Warning: printing of i64 values may be slightly rounded! No deep i64 math used, so precise i64 code not included
var i64Math = null;

// === Auto-generated postamble setup entry stuff ===

Module.callMain = function callMain(args) {
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_STATIC) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_STATIC));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_STATIC);


  var ret;

  ret = Module['_main'](argc, argv, 0);


  return ret;
}




function run(args) {
  args = args || Module['arguments'];

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }

  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }

  function doRun() {
    var ret = 0;
    calledRun = true;
    if (Module['_main']) {
      preMain();
      ret = Module.callMain(args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = Module.run = run;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

initRuntime();

var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}

if (shouldRunNow) {
  var ret = run(['400', '3000']);
}

// {{POST_RUN_ADDITIONS}}






  // {{MODULE_ADDITIONS}}


// EMSCRIPTEN_GENERATED_FUNCTIONS: ["_strlen","_free","_main","_memset","_malloc","_memcpy"]



