// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
try {
  this['Module'] = Module;
} catch(e) {
  this['Module'] = Module = {};
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function(filename) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename).toString();
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename).toString();
    }
    return ret;
  };

  Module['load'] = function(f) {
    globalEval(read(f));
  };

  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
}

if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  // Polyfill over SpiderMonkey/V8 differences
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function(f) { snarf(f) };
  }

  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}

if (ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }

  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }
}

if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}

if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...
  var TRY_USE_DUMP = false;
  if (!Module['print']) {
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  Module['load'] = importScripts;
}

if (!ENVIRONMENT_IS_WORKER && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_SHELL) {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];

  
// === Auto-generated preamble library stuff ===

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (/^\[\d+\ x\ (.*)\]/.test(type)) return true; // [15 x ?] blocks. Like structs
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  BITSHIFT64_SHL: 0,
  BITSHIFT64_ASHR: 1,
  BITSHIFT64_LSHR: 2,
  bitshift64: function (low, high, op, bits) {
    var ret;
    var ander = Math.pow(2, bits)-1;
    if (bits < 32) {
      switch (op) {
        case Runtime.BITSHIFT64_SHL:
          ret = [low << bits, (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits))];
          break;
        case Runtime.BITSHIFT64_ASHR:
          ret = [(((low >>> bits ) | ((high&ander) << (32 - bits))) >> 0) >>> 0, (high >> bits) >>> 0];
          break;
        case Runtime.BITSHIFT64_LSHR:
          ret = [((low >>> bits) | ((high&ander) << (32 - bits))) >>> 0, high >>> bits];
          break;
      }
    } else if (bits == 32) {
      switch (op) {
        case Runtime.BITSHIFT64_SHL:
          ret = [0, low];
          break;
        case Runtime.BITSHIFT64_ASHR:
          ret = [high, (high|0) < 0 ? ander : 0];
          break;
        case Runtime.BITSHIFT64_LSHR:
          ret = [high, 0];
          break;
      }
    } else { // bits > 32
      switch (op) {
        case Runtime.BITSHIFT64_SHL:
          ret = [0, low << (bits - 32)];
          break;
        case Runtime.BITSHIFT64_ASHR:
          ret = [(high >> (bits - 32)) >>> 0, (high|0) < 0 ? ander : 0];
          break;
        case Runtime.BITSHIFT64_LSHR:
          ret = [high >>>  (bits - 32) , 0];
          break;
      }
    }
    HEAP32[tempDoublePtr>>2] = ret[0]; // cannot use utility functions since we are in runtime itself
    HEAP32[tempDoublePtr+4>>2] = ret[1];
  },
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = size;
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Types.types[field].alignSize;
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      alignSize = type.packed ? 1 : Math.min(alignSize, Runtime.QUANTUM_SIZE);
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  addFunction: function (func, sig) {
    //assert(sig); // TODO: support asm
    var table = FUNCTION_TABLE; // TODO: support asm
    var ret = table.length;
    table.push(func);
    table.push(0);
    return ret;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function stackAlloc(size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+3)>>2)<<2); return ret; },
  staticAlloc: function staticAlloc(size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+3)>>2)<<2); if (STATICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function alignMemory(size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 4))*(quantum ? quantum : 4); return ret; },
  makeBigInt: function makeBigInt(low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>0)))+((+(((high)>>>0)))*(+(4294967296)))) : ((+(((low)>>>0)))+((+(((high)|0)))*(+(4294967296))))); return ret; },
  QUANTUM_SIZE: 4,
  __dummy__: 0
}







//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.
var setjmpId = 1; // Used in setjmp/longjmp
var setjmpLabels = {};

var ABORT = false;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = eval('_' + ident);
  } catch(e) {
    try {
      func = globalScope['Module']['_' + ident]; // closure exported function
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;

// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,Math.min(Math.floor((value)/(+(4294967296))), (+(4294967295)))>>>0],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF32[((ptr)>>2)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;

// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF32[((ptr)>>2)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_NONE = 3; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// Simple unoptimized memset - necessary during startup
var _memset = function(ptr, value, num) {
  var stop = ptr + num;
  while (ptr < stop) {
    HEAP8[(ptr++)]=value;
  }
}

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    _memset(ret, 0, size);
    return ret;
  }

  if (singleType === 'i8') {
    HEAPU8.set(new Uint8Array(slab), ret);
    return ret;
  }

  var i = 0, type;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);
    i += Runtime.getNativeTypeSize(type);
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  var utf8 = new Runtime.UTF8Processor();
  var nullTerminated = typeof(length) == "undefined";
  var ret = "";
  var i = 0;
  var t;
  while (1) {
    t = HEAPU8[((ptr)+(i))];
    if (nullTerminated && t == 0) break;
    ret += utf8.processCChar(t);
    i += 1;
    if (!nullTerminated && i == length) break;
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

function Array_stringify(array) {
  var ret = "";
  for (var i = 0; i < array.length; i++) {
    ret += String.fromCharCode(array[i]);
  }
  return ret;
}
Module['Array_stringify'] = Array_stringify;

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STACK_ROOT, STACKTOP, STACK_MAX;
var STATICTOP;
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Compile with -s TOTAL_MEMORY=X with X higher than the current value.');
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 134217728;
var FAST_MEMORY = Module['FAST_MEMORY'] || 10485760;

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

STACK_ROOT = STACKTOP = Runtime.alignMemory(1);
STACK_MAX = TOTAL_STACK; // we lose a little stack here, but TOTAL_STACK is nice and round so use that as the max

var tempDoublePtr = Runtime.alignMemory(allocate(12, 'i8', ALLOC_STACK), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}

STATICTOP = STACK_MAX;
assert(STATICTOP < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY

var nullString = allocate(intArrayFromString('(null)'), 'i8', ALLOC_STACK);

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown

function initRuntime() {
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}

// Tools

// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[((buffer)+(i))]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[((buffer)+(i))]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 6000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data

// === Body ===



assert(STATICTOP == STACK_MAX); assert(STACK_MAX == TOTAL_STACK);

STATICTOP += 14120;

assert(STATICTOP < TOTAL_MEMORY);




































allocate([111,107,46,0] /* ok.\00 */, "i8", ALLOC_NONE, 5242880);
allocate([12,0,8,0,140,0,8,0,76,0,8,0,204,0,8,0,44,0,8,0,172,0,8,0,108,0,8,0,236,0,8,0,28,0,8,0,156,0,8,0,92,0,8,0,220,0,8,0,60,0,8,0,188,0,8,0,124,0,8,0,252,0,8,0,2,0,8,0,130,0,8,0,66,0,8,0,194,0,8,0,34,0,8,0,162,0,8,0,98,0,8,0,226,0,8,0,18,0,8,0,146,0,8,0,82,0,8,0,210,0,8,0,50,0,8,0,178,0,8,0,114,0,8,0,242,0,8,0,10,0,8,0,138,0,8,0,74,0,8,0,202,0,8,0,42,0,8,0,170,0,8,0,106,0,8,0,234,0,8,0,26,0,8,0,154,0,8,0,90,0,8,0,218,0,8,0,58,0,8,0,186,0,8,0,122,0,8,0,250,0,8,0,6,0,8,0,134,0,8,0,70,0,8,0,198,0,8,0,38,0,8,0,166,0,8,0,102,0,8,0,230,0,8,0,22,0,8,0,150,0,8,0,86,0,8,0,214,0,8,0,54,0,8,0,182,0,8,0,118,0,8,0,246,0,8,0,14,0,8,0,142,0,8,0,78,0,8,0,206,0,8,0,46,0,8,0,174,0,8,0,110,0,8,0,238,0,8,0,30,0,8,0,158,0,8,0,94,0,8,0,222,0,8,0,62,0,8,0,190,0,8,0,126,0,8,0,254,0,8,0,1,0,8,0,129,0,8,0,65,0,8,0,193,0,8,0,33,0,8,0,161,0,8,0,97,0,8,0,225,0,8,0,17,0,8,0,145,0,8,0,81,0,8,0,209,0,8,0,49,0,8,0,177,0,8,0,113,0,8,0,241,0,8,0,9,0,8,0,137,0,8,0,73,0,8,0,201,0,8,0,41,0,8,0,169,0,8,0,105,0,8,0,233,0,8,0,25,0,8,0,153,0,8,0,89,0,8,0,217,0,8,0,57,0,8,0,185,0,8,0,121,0,8,0,249,0,8,0,5,0,8,0,133,0,8,0,69,0,8,0,197,0,8,0,37,0,8,0,165,0,8,0,101,0,8,0,229,0,8,0,21,0,8,0,149,0,8,0,85,0,8,0,213,0,8,0,53,0,8,0,181,0,8,0,117,0,8,0,245,0,8,0,13,0,8,0,141,0,8,0,77,0,8,0,205,0,8,0,45,0,8,0,173,0,8,0,109,0,8,0,237,0,8,0,29,0,8,0,157,0,8,0,93,0,8,0,221,0,8,0,61,0,8,0,189,0,8,0,125,0,8,0,253,0,8,0,19,0,9,0,19,1,9,0,147,0,9,0,147,1,9,0,83,0,9,0,83,1,9,0,211,0,9,0,211,1,9,0,51,0,9,0,51,1,9,0,179,0,9,0,179,1,9,0,115,0,9,0,115,1,9,0,243,0,9,0,243,1,9,0,11,0,9,0,11,1,9,0,139,0,9,0,139,1,9,0,75,0,9,0,75,1,9,0,203,0,9,0,203,1,9,0,43,0,9,0,43,1,9,0,171,0,9,0,171,1,9,0,107,0,9,0,107,1,9,0,235,0,9,0,235,1,9,0,27,0,9,0,27,1,9,0,155,0,9,0,155,1,9,0,91,0,9,0,91,1,9,0,219,0,9,0,219,1,9,0,59,0,9,0,59,1,9,0,187,0,9,0,187,1,9,0,123,0,9,0,123,1,9,0,251,0,9,0,251,1,9,0,7,0,9,0,7,1,9,0,135,0,9,0,135,1,9,0,71,0,9,0,71,1,9,0,199,0,9,0,199,1,9,0,39,0,9,0,39,1,9,0,167,0,9,0,167,1,9,0,103,0,9,0,103,1,9,0,231,0,9,0,231,1,9,0,23,0,9,0,23,1,9,0,151,0,9,0,151,1,9,0,87,0,9,0,87,1,9,0,215,0,9,0,215,1,9,0,55,0,9,0,55,1,9,0,183,0,9,0,183,1,9,0,119,0,9,0,119,1,9,0,247,0,9,0,247,1,9,0,15,0,9,0,15,1,9,0,143,0,9,0,143,1,9,0,79,0,9,0,79,1,9,0,207,0,9,0,207,1,9,0,47,0,9,0,47,1,9,0,175,0,9,0,175,1,9,0,111,0,9,0,111,1,9,0,239,0,9,0,239,1,9,0,31,0,9,0,31,1,9,0,159,0,9,0,159,1,9,0,95,0,9,0,95,1,9,0,223,0,9,0,223,1,9,0,63,0,9,0,63,1,9,0,191,0,9,0,191,1,9,0,127,0,9,0,127,1,9,0,255,0,9,0,255,1,9,0,0,0,7,0,64,0,7,0,32,0,7,0,96,0,7,0,16,0,7,0,80,0,7,0,48,0,7,0,112,0,7,0,8,0,7,0,72,0,7,0,40,0,7,0,104,0,7,0,24,0,7,0,88,0,7,0,56,0,7,0,120,0,7,0,4,0,7,0,68,0,7,0,36,0,7,0,100,0,7,0,20,0,7,0,84,0,7,0,52,0,7,0,116,0,7,0,3,0,8,0,131,0,8,0,67,0,8,0,195,0,8,0,35,0,8,0,163,0,8,0,99,0,8,0,227,0,8,0], "i8", ALLOC_NONE, 5242884);
allocate([0,0,0,0,0,0,0,0,1,1,0,0,30,1,0,0,15,0,0,0], "i8", ALLOC_NONE, 5244036);
allocate([0,0,5,0,16,0,5,0,8,0,5,0,24,0,5,0,4,0,5,0,20,0,5,0,12,0,5,0,28,0,5,0,2,0,5,0,18,0,5,0,10,0,5,0,26,0,5,0,6,0,5,0,22,0,5,0,14,0,5,0,30,0,5,0,1,0,5,0,17,0,5,0,9,0,5,0,25,0,5,0,5,0,5,0,21,0,5,0,13,0,5,0,29,0,5,0,3,0,5,0,19,0,5,0,11,0,5,0,27,0,5,0,7,0,5,0,23,0,5,0], "i8", ALLOC_NONE, 5244056);
allocate([0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,15,0,0,0], "i8", ALLOC_NONE, 5244176);
allocate([0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,7,0,0,0], "i8", ALLOC_NONE, 5244196);
allocate(24, "i8", ALLOC_NONE, 5244216);
allocate([16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,17,0,17,0,17,0,17,0,18,0,18,0,18,0,18,0,19,0,19,0,19,0,19,0,20,0,20,0,20,0,20,0,21,0,21,0,21,0,21,0,16,0,73,0,195,0], "i8", ALLOC_NONE, 5244240);
allocate([3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,13,0,15,0,17,0,19,0,23,0,27,0,31,0,35,0,43,0,51,0,59,0,67,0,83,0,99,0,115,0,131,0,163,0,195,0,227,0,2,1,0,0,0,0], "i8", ALLOC_NONE, 5244304);
allocate([16,0,16,0,16,0,16,0,17,0,17,0,18,0,18,0,19,0,19,0,20,0,20,0,21,0,21,0,22,0,22,0,23,0,23,0,24,0,24,0,25,0,25,0,26,0,26,0,27,0,27,0,28,0,28,0,29,0,29,0,64,0,64,0], "i8", ALLOC_NONE, 5244368);
allocate([1,0,2,0,3,0,4,0,5,0,7,0,9,0,13,0,17,0,25,0,33,0,49,0,65,0,97,0,129,0,193,0,1,1,129,1,1,2,1,3,1,4,1,6,1,8,1,12,1,16,1,24,1,32,1,48,1,64,1,96,0,0,0,0], "i8", ALLOC_NONE, 5244432);
allocate([16,0,17,0,18,0,0,0,8,0,7,0,9,0,6,0,10,0,5,0,11,0,4,0,12,0,3,0,13,0,2,0,14,0,1,0,15,0], "i8", ALLOC_NONE, 5244496);
allocate([96,7,0,0,0,8,80,0,0,8,16,0,20,8,115,0,18,7,31,0,0,8,112,0,0,8,48,0,0,9,192,0,16,7,10,0,0,8,96,0,0,8,32,0,0,9,160,0,0,8,0,0,0,8,128,0,0,8,64,0,0,9,224,0,16,7,6,0,0,8,88,0,0,8,24,0,0,9,144,0,19,7,59,0,0,8,120,0,0,8,56,0,0,9,208,0,17,7,17,0,0,8,104,0,0,8,40,0,0,9,176,0,0,8,8,0,0,8,136,0,0,8,72,0,0,9,240,0,16,7,4,0,0,8,84,0,0,8,20,0,21,8,227,0,19,7,43,0,0,8,116,0,0,8,52,0,0,9,200,0,17,7,13,0,0,8,100,0,0,8,36,0,0,9,168,0,0,8,4,0,0,8,132,0,0,8,68,0,0,9,232,0,16,7,8,0,0,8,92,0,0,8,28,0,0,9,152,0,20,7,83,0,0,8,124,0,0,8,60,0,0,9,216,0,18,7,23,0,0,8,108,0,0,8,44,0,0,9,184,0,0,8,12,0,0,8,140,0,0,8,76,0,0,9,248,0,16,7,3,0,0,8,82,0,0,8,18,0,21,8,163,0,19,7,35,0,0,8,114,0,0,8,50,0,0,9,196,0,17,7,11,0,0,8,98,0,0,8,34,0,0,9,164,0,0,8,2,0,0,8,130,0,0,8,66,0,0,9,228,0,16,7,7,0,0,8,90,0,0,8,26,0,0,9,148,0,20,7,67,0,0,8,122,0,0,8,58,0,0,9,212,0,18,7,19,0,0,8,106,0,0,8,42,0,0,9,180,0,0,8,10,0,0,8,138,0,0,8,74,0,0,9,244,0,16,7,5,0,0,8,86,0,0,8,22,0,64,8,0,0,19,7,51,0,0,8,118,0,0,8,54,0,0,9,204,0,17,7,15,0,0,8,102,0,0,8,38,0,0,9,172,0,0,8,6,0,0,8,134,0,0,8,70,0,0,9,236,0,16,7,9,0,0,8,94,0,0,8,30,0,0,9,156,0,20,7,99,0,0,8,126,0,0,8,62,0,0,9,220,0,18,7,27,0,0,8,110,0,0,8,46,0,0,9,188,0,0,8,14,0,0,8,142,0,0,8,78,0,0,9,252,0,96,7,0,0,0,8,81,0,0,8,17,0,21,8,131,0,18,7,31,0,0,8,113,0,0,8,49,0,0,9,194,0,16,7,10,0,0,8,97,0,0,8,33,0,0,9,162,0,0,8,1,0,0,8,129,0,0,8,65,0,0,9,226,0,16,7,6,0,0,8,89,0,0,8,25,0,0,9,146,0,19,7,59,0,0,8,121,0,0,8,57,0,0,9,210,0,17,7,17,0,0,8,105,0,0,8,41,0,0,9,178,0,0,8,9,0,0,8,137,0,0,8,73,0,0,9,242,0,16,7,4,0,0,8,85,0,0,8,21,0,16,8,2,1,19,7,43,0,0,8,117,0,0,8,53,0,0,9,202,0,17,7,13,0,0,8,101,0,0,8,37,0,0,9,170,0,0,8,5,0,0,8,133,0,0,8,69,0,0,9,234,0,16,7,8,0,0,8,93,0,0,8,29,0,0,9,154,0,20,7,83,0,0,8,125,0,0,8,61,0,0,9,218,0,18,7,23,0,0,8,109,0,0,8,45,0,0,9,186,0,0,8,13,0,0,8,141,0,0,8,77,0,0,9,250,0,16,7,3,0,0,8,83,0,0,8,19,0,21,8,195,0,19,7,35,0,0,8,115,0,0,8,51,0,0,9,198,0,17,7,11,0,0,8,99,0,0,8,35,0,0,9,166,0,0,8,3,0,0,8,131,0,0,8,67,0,0,9,230,0,16,7,7,0,0,8,91,0,0,8,27,0,0,9,150,0,20,7,67,0,0,8,123,0,0,8,59,0,0,9,214,0,18,7,19,0,0,8,107,0,0,8,43,0,0,9,182,0,0,8,11,0,0,8,139,0,0,8,75,0,0,9,246,0,16,7,5,0,0,8,87,0,0,8,23,0,64,8,0,0,19,7,51,0,0,8,119,0,0,8,55,0,0,9,206,0,17,7,15,0,0,8,103,0,0,8,39,0,0,9,174,0,0,8,7,0,0,8,135,0,0,8,71,0,0,9,238,0,16,7,9,0,0,8,95,0,0,8,31,0,0,9,158,0,20,7,99,0,0,8,127,0,0,8,63,0,0,9,222,0,18,7,27,0,0,8,111,0,0,8,47,0,0,9,190,0,0,8,15,0,0,8,143,0,0,8,79,0,0,9,254,0,96,7,0,0,0,8,80,0,0,8,16,0,20,8,115,0,18,7,31,0,0,8,112,0,0,8,48,0,0,9,193,0,16,7,10,0,0,8,96,0,0,8,32,0,0,9,161,0,0,8,0,0,0,8,128,0,0,8,64,0,0,9,225,0,16,7,6,0,0,8,88,0,0,8,24,0,0,9,145,0,19,7,59,0,0,8,120,0,0,8,56,0,0,9,209,0,17,7,17,0,0,8,104,0,0,8,40,0,0,9,177,0,0,8,8,0,0,8,136,0,0,8,72,0,0,9,241,0,16,7,4,0,0,8,84,0,0,8,20,0,21,8,227,0,19,7,43,0,0,8,116,0,0,8,52,0,0,9,201,0,17,7,13,0,0,8,100,0,0,8,36,0,0,9,169,0,0,8,4,0,0,8,132,0,0,8,68,0,0,9,233,0,16,7,8,0,0,8,92,0,0,8,28,0,0,9,153,0,20,7,83,0,0,8,124,0,0,8,60,0,0,9,217,0,18,7,23,0,0,8,108,0,0,8,44,0,0,9,185,0,0,8,12,0,0,8,140,0,0,8,76,0,0,9,249,0,16,7,3,0,0,8,82,0,0,8,18,0,21,8,163,0,19,7,35,0,0,8,114,0,0,8,50,0,0,9,197,0,17,7,11,0,0,8,98,0,0,8,34,0,0,9,165,0,0,8,2,0,0,8,130,0,0,8,66,0,0,9,229,0,16,7,7,0,0,8,90,0,0,8,26,0,0,9,149,0,20,7,67,0,0,8,122,0,0,8,58,0,0,9,213,0,18,7,19,0,0,8,106,0,0,8,42,0,0,9,181,0,0,8,10,0,0,8,138,0,0,8,74,0,0,9,245,0,16,7,5,0,0,8,86,0,0,8,22,0,64,8,0,0,19,7,51,0,0,8,118,0,0,8,54,0,0,9,205,0,17,7,15,0,0,8,102,0,0,8,38,0,0,9,173,0,0,8,6,0,0,8,134,0,0,8,70,0,0,9,237,0,16,7,9,0,0,8,94,0,0,8,30,0,0,9,157,0,20,7,99,0,0,8,126,0,0,8,62,0,0,9,221,0,18,7,27,0,0,8,110,0,0,8,46,0,0,9,189,0,0,8,14,0,0,8,142,0,0,8,78,0,0,9,253,0,96,7,0,0,0,8,81,0,0,8,17,0,21,8,131,0,18,7,31,0,0,8,113,0,0,8,49,0,0,9,195,0,16,7,10,0,0,8,97,0,0,8,33,0,0,9,163,0,0,8,1,0,0,8,129,0,0,8,65,0,0,9,227,0,16,7,6,0,0,8,89,0,0,8,25,0,0,9,147,0,19,7,59,0,0,8,121,0,0,8,57,0,0,9,211,0,17,7,17,0,0,8,105,0,0,8,41,0,0,9,179,0,0,8,9,0,0,8,137,0,0,8,73,0,0,9,243,0,16,7,4,0,0,8,85,0,0,8,21,0,16,8,2,1,19,7,43,0,0,8,117,0,0,8,53,0,0,9,203,0,17,7,13,0,0,8,101,0,0,8,37,0,0,9,171,0,0,8,5,0,0,8,133,0,0,8,69,0,0,9,235,0,16,7,8,0,0,8,93,0,0,8,29,0,0,9,155,0,20,7,83,0,0,8,125,0,0,8,61,0,0,9,219,0,18,7,23,0,0,8,109,0,0,8,45,0,0,9,187,0,0,8,13,0,0,8,141,0,0,8,77,0,0,9,251,0,16,7,3,0,0,8,83,0,0,8,19,0,21,8,195,0,19,7,35,0,0,8,115,0,0,8,51,0,0,9,199,0,17,7,11,0,0,8,99,0,0,8,35,0,0,9,167,0,0,8,3,0,0,8,131,0,0,8,67,0,0,9,231,0,16,7,7,0,0,8,91,0,0,8,27,0,0,9,151,0,20,7,67,0,0,8,123,0,0,8,59,0,0,9,215,0,18,7,19,0,0,8,107,0,0,8,43,0,0,9,183,0,0,8,11,0,0,8,139,0,0,8,75,0,0,9,247,0,16,7,5,0,0,8,87,0,0,8,23,0,64,8,0,0,19,7,51,0,0,8,119,0,0,8,55,0,0,9,207,0,17,7,15,0,0,8,103,0,0,8,39,0,0,9,175,0,0,8,7,0,0,8,135,0,0,8,71,0,0,9,239,0,16,7,9,0,0,8,95,0,0,8,31,0,0,9,159,0,20,7,99,0,0,8,127,0,0,8,63,0,0,9,223,0,18,7,27,0,0,8,111,0,0,8,47,0,0,9,191,0,0,8,15,0,0,8,143,0,0,8,79,0,0,9,255,0], "i8", ALLOC_NONE, 5244536);
allocate([16,5,1,0,23,5,1,1,19,5,17,0,27,5,1,16,17,5,5,0,25,5,1,4,21,5,65,0,29,5,1,64,16,5,3,0,24,5,1,2,20,5,33,0,28,5,1,32,18,5,9,0,26,5,1,8,22,5,129,0,64,5,0,0,16,5,2,0,23,5,129,1,19,5,25,0,27,5,1,24,17,5,7,0,25,5,1,6,21,5,97,0,29,5,1,96,16,5,4,0,24,5,1,3,20,5,49,0,28,5,1,48,18,5,13,0,26,5,1,12,22,5,193,0,64,5,0,0], "i8", ALLOC_NONE, 5246584);
allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0], "i8", ALLOC_NONE, 5246712);
allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0], "i8", ALLOC_NONE, 5246828);
allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,7,0,0,0], "i8", ALLOC_NONE, 5246948);
allocate(4, "i8", ALLOC_NONE, 5247024);
allocate(4, "i8", ALLOC_NONE, 5247028);
allocate([0,0,0,0,150,48,7,119,44,97,14,238,186,81,9,153,25,196,109,7,143,244,106,112,53,165,99,233,163,149,100,158,50,136,219,14,164,184,220,121,30,233,213,224,136,217,210,151,43,76,182,9,189,124,177,126,7,45,184,231,145,29,191,144,100,16,183,29,242,32,176,106,72,113,185,243,222,65,190,132,125,212,218,26,235,228,221,109,81,181,212,244,199,133,211,131,86,152,108,19,192,168,107,100,122,249,98,253,236,201,101,138,79,92,1,20,217,108,6,99,99,61,15,250,245,13,8,141,200,32,110,59,94,16,105,76,228,65,96,213,114,113,103,162,209,228,3,60,71,212,4,75,253,133,13,210,107,181,10,165,250,168,181,53,108,152,178,66,214,201,187,219,64,249,188,172,227,108,216,50,117,92,223,69,207,13,214,220,89,61,209,171,172,48,217,38,58,0,222,81,128,81,215,200,22,97,208,191,181,244,180,33,35,196,179,86,153,149,186,207,15,165,189,184,158,184,2,40,8,136,5,95,178,217,12,198,36,233,11,177,135,124,111,47,17,76,104,88,171,29,97,193,61,45,102,182,144,65,220,118,6,113,219,1,188,32,210,152,42,16,213,239,137,133,177,113,31,181,182,6,165,228,191,159,51,212,184,232,162,201,7,120,52,249,0,15,142,168,9,150,24,152,14,225,187,13,106,127,45,61,109,8,151,108,100,145,1,92,99,230,244,81,107,107,98,97,108,28,216,48,101,133,78,0,98,242,237,149,6,108,123,165,1,27,193,244,8,130,87,196,15,245,198,217,176,101,80,233,183,18,234,184,190,139,124,136,185,252,223,29,221,98,73,45,218,21,243,124,211,140,101,76,212,251,88,97,178,77,206,81,181,58,116,0,188,163,226,48,187,212,65,165,223,74,215,149,216,61,109,196,209,164,251,244,214,211,106,233,105,67,252,217,110,52,70,136,103,173,208,184,96,218,115,45,4,68,229,29,3,51,95,76,10,170,201,124,13,221,60,113,5,80,170,65,2,39,16,16,11,190,134,32,12,201,37,181,104,87,179,133,111,32,9,212,102,185,159,228,97,206,14,249,222,94,152,201,217,41,34,152,208,176,180,168,215,199,23,61,179,89,129,13,180,46,59,92,189,183,173,108,186,192,32,131,184,237,182,179,191,154,12,226,182,3,154,210,177,116,57,71,213,234,175,119,210,157,21,38,219,4,131,22,220,115,18,11,99,227,132,59,100,148,62,106,109,13,168,90,106,122,11,207,14,228,157,255,9,147,39,174,0,10,177,158,7,125,68,147,15,240,210,163,8,135,104,242,1,30,254,194,6,105,93,87,98,247,203,103,101,128,113,54,108,25,231,6,107,110,118,27,212,254,224,43,211,137,90,122,218,16,204,74,221,103,111,223,185,249,249,239,190,142,67,190,183,23,213,142,176,96,232,163,214,214,126,147,209,161,196,194,216,56,82,242,223,79,241,103,187,209,103,87,188,166,221,6,181,63,75,54,178,72,218,43,13,216,76,27,10,175,246,74,3,54,96,122,4,65,195,239,96,223,85,223,103,168,239,142,110,49,121,190,105,70,140,179,97,203,26,131,102,188,160,210,111,37,54,226,104,82,149,119,12,204,3,71,11,187,185,22,2,34,47,38,5,85,190,59,186,197,40,11,189,178,146,90,180,43,4,106,179,92,167,255,215,194,49,207,208,181,139,158,217,44,29,174,222,91,176,194,100,155,38,242,99,236,156,163,106,117,10,147,109,2,169,6,9,156,63,54,14,235,133,103,7,114,19,87,0,5,130,74,191,149,20,122,184,226,174,43,177,123,56,27,182,12,155,142,210,146,13,190,213,229,183,239,220,124,33,223,219,11,212,210,211,134,66,226,212,241,248,179,221,104,110,131,218,31,205,22,190,129,91,38,185,246,225,119,176,111,119,71,183,24,230,90,8,136,112,106,15,255,202,59,6,102,92,11,1,17,255,158,101,143,105,174,98,248,211,255,107,97,69,207,108,22,120,226,10,160,238,210,13,215,84,131,4,78,194,179,3,57,97,38,103,167,247,22,96,208,77,71,105,73,219,119,110,62,74,106,209,174,220,90,214,217,102,11,223,64,240,59,216,55,83,174,188,169,197,158,187,222,127,207,178,71,233,255,181,48,28,242,189,189,138,194,186,202,48,147,179,83,166,163,180,36,5,54,208,186,147,6,215,205,41,87,222,84,191,103,217,35,46,122,102,179,184,74,97,196,2,27,104,93,148,43,111,42,55,190,11,180,161,142,12,195,27,223,5,90,141,239,2,45,0,0,0,0,65,49,27,25,130,98,54,50,195,83,45,43,4,197,108,100,69,244,119,125,134,167,90,86,199,150,65,79,8,138,217,200,73,187,194,209,138,232,239,250,203,217,244,227,12,79,181,172,77,126,174,181,142,45,131,158,207,28,152,135,81,18,194,74,16,35,217,83,211,112,244,120,146,65,239,97,85,215,174,46,20,230,181,55,215,181,152,28,150,132,131,5,89,152,27,130,24,169,0,155,219,250,45,176,154,203,54,169,93,93,119,230,28,108,108,255,223,63,65,212,158,14,90,205,162,36,132,149,227,21,159,140,32,70,178,167,97,119,169,190,166,225,232,241,231,208,243,232,36,131,222,195,101,178,197,218,170,174,93,93,235,159,70,68,40,204,107,111,105,253,112,118,174,107,49,57,239,90,42,32,44,9,7,11,109,56,28,18,243,54,70,223,178,7,93,198,113,84,112,237,48,101,107,244,247,243,42,187,182,194,49,162,117,145,28,137,52,160,7,144,251,188,159,23,186,141,132,14,121,222,169,37,56,239,178,60,255,121,243,115,190,72,232,106,125,27,197,65,60,42,222,88,5,79,121,240,68,126,98,233,135,45,79,194,198,28,84,219,1,138,21,148,64,187,14,141,131,232,35,166,194,217,56,191,13,197,160,56,76,244,187,33,143,167,150,10,206,150,141,19,9,0,204,92,72,49,215,69,139,98,250,110,202,83,225,119,84,93,187,186,21,108,160,163,214,63,141,136,151,14,150,145,80,152,215,222,17,169,204,199,210,250,225,236,147,203,250,245,92,215,98,114,29,230,121,107,222,181,84,64,159,132,79,89,88,18,14,22,25,35,21,15,218,112,56,36,155,65,35,61,167,107,253,101,230,90,230,124,37,9,203,87,100,56,208,78,163,174,145,1,226,159,138,24,33,204,167,51,96,253,188,42,175,225,36,173,238,208,63,180,45,131,18,159,108,178,9,134,171,36,72,201,234,21,83,208,41,70,126,251,104,119,101,226,246,121,63,47,183,72,36,54,116,27,9,29,53,42,18,4,242,188,83,75,179,141,72,82,112,222,101,121,49,239,126,96,254,243,230,231,191,194,253,254,124,145,208,213,61,160,203,204,250,54,138,131,187,7,145,154,120,84,188,177,57,101,167,168,75,152,131,59,10,169,152,34,201,250,181,9,136,203,174,16,79,93,239,95,14,108,244,70,205,63,217,109,140,14,194,116,67,18,90,243,2,35,65,234,193,112,108,193,128,65,119,216,71,215,54,151,6,230,45,142,197,181,0,165,132,132,27,188,26,138,65,113,91,187,90,104,152,232,119,67,217,217,108,90,30,79,45,21,95,126,54,12,156,45,27,39,221,28,0,62,18,0,152,185,83,49,131,160,144,98,174,139,209,83,181,146,22,197,244,221,87,244,239,196,148,167,194,239,213,150,217,246,233,188,7,174,168,141,28,183,107,222,49,156,42,239,42,133,237,121,107,202,172,72,112,211,111,27,93,248,46,42,70,225,225,54,222,102,160,7,197,127,99,84,232,84,34,101,243,77,229,243,178,2,164,194,169,27,103,145,132,48,38,160,159,41,184,174,197,228,249,159,222,253,58,204,243,214,123,253,232,207,188,107,169,128,253,90,178,153,62,9,159,178,127,56,132,171,176,36,28,44,241,21,7,53,50,70,42,30,115,119,49,7,180,225,112,72,245,208,107,81,54,131,70,122,119,178,93,99,78,215,250,203,15,230,225,210,204,181,204,249,141,132,215,224,74,18,150,175,11,35,141,182,200,112,160,157,137,65,187,132,70,93,35,3,7,108,56,26,196,63,21,49,133,14,14,40,66,152,79,103,3,169,84,126,192,250,121,85,129,203,98,76,31,197,56,129,94,244,35,152,157,167,14,179,220,150,21,170,27,0,84,229,90,49,79,252,153,98,98,215,216,83,121,206,23,79,225,73,86,126,250,80,149,45,215,123,212,28,204,98,19,138,141,45,82,187,150,52,145,232,187,31,208,217,160,6,236,243,126,94,173,194,101,71,110,145,72,108,47,160,83,117,232,54,18,58,169,7,9,35,106,84,36,8,43,101,63,17,228,121,167,150,165,72,188,143,102,27,145,164,39,42,138,189,224,188,203,242,161,141,208,235,98,222,253,192,35,239,230,217,189,225,188,20,252,208,167,13,63,131,138,38,126,178,145,63,185,36,208,112,248,21,203,105,59,70,230,66,122,119,253,91,181,107,101,220,244,90,126,197,55,9,83,238,118,56,72,247,177,174,9,184,240,159,18,161,51,204,63,138,114,253,36,147,0,0,0,0,55,106,194,1,110,212,132,3,89,190,70,2,220,168,9,7,235,194,203,6,178,124,141,4,133,22,79,5,184,81,19,14,143,59,209,15,214,133,151,13,225,239,85,12,100,249,26,9,83,147,216,8,10,45,158,10,61,71,92,11,112,163,38,28,71,201,228,29,30,119,162,31,41,29,96,30,172,11,47,27,155,97,237,26,194,223,171,24,245,181,105,25,200,242,53,18,255,152,247,19,166,38,177,17,145,76,115,16,20,90,60,21,35,48,254,20,122,142,184,22,77,228,122,23,224,70,77,56,215,44,143,57,142,146,201,59,185,248,11,58,60,238,68,63,11,132,134,62,82,58,192,60,101,80,2,61,88,23,94,54,111,125,156,55,54,195,218,53,1,169,24,52,132,191,87,49,179,213,149,48,234,107,211,50,221,1,17,51,144,229,107,36,167,143,169,37,254,49,239,39,201,91,45,38,76,77,98,35,123,39,160,34,34,153,230,32,21,243,36,33,40,180,120,42,31,222,186,43,70,96,252,41,113,10,62,40,244,28,113,45,195,118,179,44,154,200,245,46,173,162,55,47,192,141,154,112,247,231,88,113,174,89,30,115,153,51,220,114,28,37,147,119,43,79,81,118,114,241,23,116,69,155,213,117,120,220,137,126,79,182,75,127,22,8,13,125,33,98,207,124,164,116,128,121,147,30,66,120,202,160,4,122,253,202,198,123,176,46,188,108,135,68,126,109,222,250,56,111,233,144,250,110,108,134,181,107,91,236,119,106,2,82,49,104,53,56,243,105,8,127,175,98,63,21,109,99,102,171,43,97,81,193,233,96,212,215,166,101,227,189,100,100,186,3,34,102,141,105,224,103,32,203,215,72,23,161,21,73,78,31,83,75,121,117,145,74,252,99,222,79,203,9,28,78,146,183,90,76,165,221,152,77,152,154,196,70,175,240,6,71,246,78,64,69,193,36,130,68,68,50,205,65,115,88,15,64,42,230,73,66,29,140,139,67,80,104,241,84,103,2,51,85,62,188,117,87,9,214,183,86,140,192,248,83,187,170,58,82,226,20,124,80,213,126,190,81,232,57,226,90,223,83,32,91,134,237,102,89,177,135,164,88,52,145,235,93,3,251,41,92,90,69,111,94,109,47,173,95,128,27,53,225,183,113,247,224,238,207,177,226,217,165,115,227,92,179,60,230,107,217,254,231,50,103,184,229,5,13,122,228,56,74,38,239,15,32,228,238,86,158,162,236,97,244,96,237,228,226,47,232,211,136,237,233,138,54,171,235,189,92,105,234,240,184,19,253,199,210,209,252,158,108,151,254,169,6,85,255,44,16,26,250,27,122,216,251,66,196,158,249,117,174,92,248,72,233,0,243,127,131,194,242,38,61,132,240,17,87,70,241,148,65,9,244,163,43,203,245,250,149,141,247,205,255,79,246,96,93,120,217,87,55,186,216,14,137,252,218,57,227,62,219,188,245,113,222,139,159,179,223,210,33,245,221,229,75,55,220,216,12,107,215,239,102,169,214,182,216,239,212,129,178,45,213,4,164,98,208,51,206,160,209,106,112,230,211,93,26,36,210,16,254,94,197,39,148,156,196,126,42,218,198,73,64,24,199,204,86,87,194,251,60,149,195,162,130,211,193,149,232,17,192,168,175,77,203,159,197,143,202,198,123,201,200,241,17,11,201,116,7,68,204,67,109,134,205,26,211,192,207,45,185,2,206,64,150,175,145,119,252,109,144,46,66,43,146,25,40,233,147,156,62,166,150,171,84,100,151,242,234,34,149,197,128,224,148,248,199,188,159,207,173,126,158,150,19,56,156,161,121,250,157,36,111,181,152,19,5,119,153,74,187,49,155,125,209,243,154,48,53,137,141,7,95,75,140,94,225,13,142,105,139,207,143,236,157,128,138,219,247,66,139,130,73,4,137,181,35,198,136,136,100,154,131,191,14,88,130,230,176,30,128,209,218,220,129,84,204,147,132,99,166,81,133,58,24,23,135,13,114,213,134,160,208,226,169,151,186,32,168,206,4,102,170,249,110,164,171,124,120,235,174,75,18,41,175,18,172,111,173,37,198,173,172,24,129,241,167,47,235,51,166,118,85,117,164,65,63,183,165,196,41,248,160,243,67,58,161,170,253,124,163,157,151,190,162,208,115,196,181,231,25,6,180,190,167,64,182,137,205,130,183,12,219,205,178,59,177,15,179,98,15,73,177,85,101,139,176,104,34,215,187,95,72,21,186,6,246,83,184,49,156,145,185,180,138,222,188,131,224,28,189,218,94,90,191,237,52,152,190,0,0,0,0,101,103,188,184,139,200,9,170,238,175,181,18,87,151,98,143,50,240,222,55,220,95,107,37,185,56,215,157,239,40,180,197,138,79,8,125,100,224,189,111,1,135,1,215,184,191,214,74,221,216,106,242,51,119,223,224,86,16,99,88,159,87,25,80,250,48,165,232,20,159,16,250,113,248,172,66,200,192,123,223,173,167,199,103,67,8,114,117,38,111,206,205,112,127,173,149,21,24,17,45,251,183,164,63,158,208,24,135,39,232,207,26,66,143,115,162,172,32,198,176,201,71,122,8,62,175,50,160,91,200,142,24,181,103,59,10,208,0,135,178,105,56,80,47,12,95,236,151,226,240,89,133,135,151,229,61,209,135,134,101,180,224,58,221,90,79,143,207,63,40,51,119,134,16,228,234,227,119,88,82,13,216,237,64,104,191,81,248,161,248,43,240,196,159,151,72,42,48,34,90,79,87,158,226,246,111,73,127,147,8,245,199,125,167,64,213,24,192,252,109,78,208,159,53,43,183,35,141,197,24,150,159,160,127,42,39,25,71,253,186,124,32,65,2,146,143,244,16,247,232,72,168,61,88,20,155,88,63,168,35,182,144,29,49,211,247,161,137,106,207,118,20,15,168,202,172,225,7,127,190,132,96,195,6,210,112,160,94,183,23,28,230,89,184,169,244,60,223,21,76,133,231,194,209,224,128,126,105,14,47,203,123,107,72,119,195,162,15,13,203,199,104,177,115,41,199,4,97,76,160,184,217,245,152,111,68,144,255,211,252,126,80,102,238,27,55,218,86,77,39,185,14,40,64,5,182,198,239,176,164,163,136,12,28,26,176,219,129,127,215,103,57,145,120,210,43,244,31,110,147,3,247,38,59,102,144,154,131,136,63,47,145,237,88,147,41,84,96,68,180,49,7,248,12,223,168,77,30,186,207,241,166,236,223,146,254,137,184,46,70,103,23,155,84,2,112,39,236,187,72,240,113,222,47,76,201,48,128,249,219,85,231,69,99,156,160,63,107,249,199,131,211,23,104,54,193,114,15,138,121,203,55,93,228,174,80,225,92,64,255,84,78,37,152,232,246,115,136,139,174,22,239,55,22,248,64,130,4,157,39,62,188,36,31,233,33,65,120,85,153,175,215,224,139,202,176,92,51,59,182,89,237,94,209,229,85,176,126,80,71,213,25,236,255,108,33,59,98,9,70,135,218,231,233,50,200,130,142,142,112,212,158,237,40,177,249,81,144,95,86,228,130,58,49,88,58,131,9,143,167,230,110,51,31,8,193,134,13,109,166,58,181,164,225,64,189,193,134,252,5,47,41,73,23,74,78,245,175,243,118,34,50,150,17,158,138,120,190,43,152,29,217,151,32,75,201,244,120,46,174,72,192,192,1,253,210,165,102,65,106,28,94,150,247,121,57,42,79,151,150,159,93,242,241,35,229,5,25,107,77,96,126,215,245,142,209,98,231,235,182,222,95,82,142,9,194,55,233,181,122,217,70,0,104,188,33,188,208,234,49,223,136,143,86,99,48,97,249,214,34,4,158,106,154,189,166,189,7,216,193,1,191,54,110,180,173,83,9,8,21,154,78,114,29,255,41,206,165,17,134,123,183,116,225,199,15,205,217,16,146,168,190,172,42,70,17,25,56,35,118,165,128,117,102,198,216,16,1,122,96,254,174,207,114,155,201,115,202,34,241,164,87,71,150,24,239,169,57,173,253,204,94,17,69,6,238,77,118,99,137,241,206,141,38,68,220,232,65,248,100,81,121,47,249,52,30,147,65,218,177,38,83,191,214,154,235,233,198,249,179,140,161,69,11,98,14,240,25,7,105,76,161,190,81,155,60,219,54,39,132,53,153,146,150,80,254,46,46,153,185,84,38,252,222,232,158,18,113,93,140,119,22,225,52,206,46,54,169,171,73,138,17,69,230,63,3,32,129,131,187,118,145,224,227,19,246,92,91,253,89,233,73,152,62,85,241,33,6,130,108,68,97,62,212,170,206,139,198,207,169,55,126,56,65,127,214,93,38,195,110,179,137,118,124,214,238,202,196,111,214,29,89,10,177,161,225,228,30,20,243,129,121,168,75,215,105,203,19,178,14,119,171,92,161,194,185,57,198,126,1,128,254,169,156,229,153,21,36,11,54,160,54,110,81,28,142,167,22,102,134,194,113,218,62,44,222,111,44,73,185,211,148,240,129,4,9,149,230,184,177,123,73,13,163,30,46,177,27,72,62,210,67,45,89,110,251,195,246,219,233,166,145,103,81,31,169,176,204,122,206,12,116,148,97,185,102,241,6,5,222,0,0,0,0,119,7,48,150,238,14,97,44,153,9,81,186,7,109,196,25,112,106,244,143,233,99,165,53,158,100,149,163,14,219,136,50,121,220,184,164,224,213,233,30,151,210,217,136,9,182,76,43,126,177,124,189,231,184,45,7,144,191,29,145,29,183,16,100,106,176,32,242,243,185,113,72,132,190,65,222,26,218,212,125,109,221,228,235,244,212,181,81,131,211,133,199,19,108,152,86,100,107,168,192,253,98,249,122,138,101,201,236,20,1,92,79,99,6,108,217,250,15,61,99,141,8,13,245,59,110,32,200,76,105,16,94,213,96,65,228,162,103,113,114,60,3,228,209,75,4,212,71,210,13,133,253,165,10,181,107,53,181,168,250,66,178,152,108,219,187,201,214,172,188,249,64,50,216,108,227,69,223,92,117,220,214,13,207,171,209,61,89,38,217,48,172,81,222,0,58,200,215,81,128,191,208,97,22,33,180,244,181,86,179,196,35,207,186,149,153,184,189,165,15,40,2,184,158,95,5,136,8,198,12,217,178,177,11,233,36,47,111,124,135,88,104,76,17,193,97,29,171,182,102,45,61,118,220,65,144,1,219,113,6,152,210,32,188,239,213,16,42,113,177,133,137,6,182,181,31,159,191,228,165,232,184,212,51,120,7,201,162,15,0,249,52,150,9,168,142,225,14,152,24,127,106,13,187,8,109,61,45,145,100,108,151,230,99,92,1,107,107,81,244,28,108,97,98,133,101,48,216,242,98,0,78,108,6,149,237,27,1,165,123,130,8,244,193,245,15,196,87,101,176,217,198,18,183,233,80,139,190,184,234,252,185,136,124,98,221,29,223,21,218,45,73,140,211,124,243,251,212,76,101,77,178,97,88,58,181,81,206,163,188,0,116,212,187,48,226,74,223,165,65,61,216,149,215,164,209,196,109,211,214,244,251,67,105,233,106,52,110,217,252,173,103,136,70,218,96,184,208,68,4,45,115,51,3,29,229,170,10,76,95,221,13,124,201,80,5,113,60,39,2,65,170,190,11,16,16,201,12,32,134,87,104,181,37,32,111,133,179,185,102,212,9,206,97,228,159,94,222,249,14,41,217,201,152,176,208,152,34,199,215,168,180,89,179,61,23,46,180,13,129,183,189,92,59,192,186,108,173,237,184,131,32,154,191,179,182,3,182,226,12,116,177,210,154,234,213,71,57,157,210,119,175,4,219,38,21,115,220,22,131,227,99,11,18,148,100,59,132,13,109,106,62,122,106,90,168,228,14,207,11,147,9,255,157,10,0,174,39,125,7,158,177,240,15,147,68,135,8,163,210,30,1,242,104,105,6,194,254,247,98,87,93,128,101,103,203,25,108,54,113,110,107,6,231,254,212,27,118,137,211,43,224,16,218,122,90,103,221,74,204,249,185,223,111,142,190,239,249,23,183,190,67,96,176,142,213,214,214,163,232,161,209,147,126,56,216,194,196,79,223,242,82,209,187,103,241,166,188,87,103,63,181,6,221,72,178,54,75,216,13,43,218,175,10,27,76,54,3,74,246,65,4,122,96,223,96,239,195,168,103,223,85,49,110,142,239,70,105,190,121,203,97,179,140,188,102,131,26,37,111,210,160,82,104,226,54,204,12,119,149,187,11,71,3,34,2,22,185,85,5,38,47,197,186,59,190,178,189,11,40,43,180,90,146,92,179,106,4,194,215,255,167,181,208,207,49,44,217,158,139,91,222,174,29,155,100,194,176,236,99,242,38,117,106,163,156,2,109,147,10,156,9,6,169,235,14,54,63,114,7,103,133,5,0,87,19,149,191,74,130,226,184,122,20,123,177,43,174,12,182,27,56,146,210,142,155,229,213,190,13,124,220,239,183,11,219,223,33,134,211,210,212,241,212,226,66,104,221,179,248,31,218,131,110,129,190,22,205,246,185,38,91,111,176,119,225,24,183,71,119,136,8,90,230,255,15,106,112,102,6,59,202,17,1,11,92,143,101,158,255,248,98,174,105,97,107,255,211,22,108,207,69,160,10,226,120,215,13,210,238,78,4,131,84,57,3,179,194,167,103,38,97,208,96,22,247,73,105,71,77,62,110,119,219,174,209,106,74,217,214,90,220,64,223,11,102,55,216,59,240,169,188,174,83,222,187,158,197,71,178,207,127,48,181,255,233,189,189,242,28,202,186,194,138,83,179,147,48,36,180,163,166,186,208,54,5,205,215,6,147,84,222,87,41,35,217,103,191,179,102,122,46,196,97,74,184,93,104,27,2,42,111,43,148,180,11,190,55,195,12,142,161,90,5,223,27,45,2,239,141,0,0,0,0,25,27,49,65,50,54,98,130,43,45,83,195,100,108,197,4,125,119,244,69,86,90,167,134,79,65,150,199,200,217,138,8,209,194,187,73,250,239,232,138,227,244,217,203,172,181,79,12,181,174,126,77,158,131,45,142,135,152,28,207,74,194,18,81,83,217,35,16,120,244,112,211,97,239,65,146,46,174,215,85,55,181,230,20,28,152,181,215,5,131,132,150,130,27,152,89,155,0,169,24,176,45,250,219,169,54,203,154,230,119,93,93,255,108,108,28,212,65,63,223,205,90,14,158,149,132,36,162,140,159,21,227,167,178,70,32,190,169,119,97,241,232,225,166,232,243,208,231,195,222,131,36,218,197,178,101,93,93,174,170,68,70,159,235,111,107,204,40,118,112,253,105,57,49,107,174,32,42,90,239,11,7,9,44,18,28,56,109,223,70,54,243,198,93,7,178,237,112,84,113,244,107,101,48,187,42,243,247,162,49,194,182,137,28,145,117,144,7,160,52,23,159,188,251,14,132,141,186,37,169,222,121,60,178,239,56,115,243,121,255,106,232,72,190,65,197,27,125,88,222,42,60,240,121,79,5,233,98,126,68,194,79,45,135,219,84,28,198,148,21,138,1,141,14,187,64,166,35,232,131,191,56,217,194,56,160,197,13,33,187,244,76,10,150,167,143,19,141,150,206,92,204,0,9,69,215,49,72,110,250,98,139,119,225,83,202,186,187,93,84,163,160,108,21,136,141,63,214,145,150,14,151,222,215,152,80,199,204,169,17,236,225,250,210,245,250,203,147,114,98,215,92,107,121,230,29,64,84,181,222,89,79,132,159,22,14,18,88,15,21,35,25,36,56,112,218,61,35,65,155,101,253,107,167,124,230,90,230,87,203,9,37,78,208,56,100,1,145,174,163,24,138,159,226,51,167,204,33,42,188,253,96,173,36,225,175,180,63,208,238,159,18,131,45,134,9,178,108,201,72,36,171,208,83,21,234,251,126,70,41,226,101,119,104,47,63,121,246,54,36,72,183,29,9,27,116,4,18,42,53,75,83,188,242,82,72,141,179,121,101,222,112,96,126,239,49,231,230,243,254,254,253,194,191,213,208,145,124,204,203,160,61,131,138,54,250,154,145,7,187,177,188,84,120,168,167,101,57,59,131,152,75,34,152,169,10,9,181,250,201,16,174,203,136,95,239,93,79,70,244,108,14,109,217,63,205,116,194,14,140,243,90,18,67,234,65,35,2,193,108,112,193,216,119,65,128,151,54,215,71,142,45,230,6,165,0,181,197,188,27,132,132,113,65,138,26,104,90,187,91,67,119,232,152,90,108,217,217,21,45,79,30,12,54,126,95,39,27,45,156,62,0,28,221,185,152,0,18,160,131,49,83,139,174,98,144,146,181,83,209,221,244,197,22,196,239,244,87,239,194,167,148,246,217,150,213,174,7,188,233,183,28,141,168,156,49,222,107,133,42,239,42,202,107,121,237,211,112,72,172,248,93,27,111,225,70,42,46,102,222,54,225,127,197,7,160,84,232,84,99,77,243,101,34,2,178,243,229,27,169,194,164,48,132,145,103,41,159,160,38,228,197,174,184,253,222,159,249,214,243,204,58,207,232,253,123,128,169,107,188,153,178,90,253,178,159,9,62,171,132,56,127,44,28,36,176,53,7,21,241,30,42,70,50,7,49,119,115,72,112,225,180,81,107,208,245,122,70,131,54,99,93,178,119,203,250,215,78,210,225,230,15,249,204,181,204,224,215,132,141,175,150,18,74,182,141,35,11,157,160,112,200,132,187,65,137,3,35,93,70,26,56,108,7,49,21,63,196,40,14,14,133,103,79,152,66,126,84,169,3,85,121,250,192,76,98,203,129,129,56,197,31,152,35,244,94,179,14,167,157,170,21,150,220,229,84,0,27,252,79,49,90,215,98,98,153,206,121,83,216,73,225,79,23,80,250,126,86,123,215,45,149,98,204,28,212,45,141,138,19,52,150,187,82,31,187,232,145,6,160,217,208,94,126,243,236,71,101,194,173,108,72,145,110,117,83,160,47,58,18,54,232,35,9,7,169,8,36,84,106,17,63,101,43,150,167,121,228,143,188,72,165,164,145,27,102,189,138,42,39,242,203,188,224,235,208,141,161,192,253,222,98,217,230,239,35,20,188,225,189,13,167,208,252,38,138,131,63,63,145,178,126,112,208,36,185,105,203,21,248,66,230,70,59,91,253,119,122,220,101,107,181,197,126,90,244,238,83,9,55,247,72,56,118,184,9,174,177,161,18,159,240,138,63,204,51,147,36,253,114,0,0,0,0,1,194,106,55,3,132,212,110,2,70,190,89,7,9,168,220,6,203,194,235,4,141,124,178,5,79,22,133,14,19,81,184,15,209,59,143,13,151,133,214,12,85,239,225,9,26,249,100,8,216,147,83,10,158,45,10,11,92,71,61,28,38,163,112,29,228,201,71,31,162,119,30,30,96,29,41,27,47,11,172,26,237,97,155,24,171,223,194,25,105,181,245,18,53,242,200,19,247,152,255,17,177,38,166,16,115,76,145,21,60,90,20,20,254,48,35,22,184,142,122,23,122,228,77,56,77,70,224,57,143,44,215,59,201,146,142,58,11,248,185,63,68,238,60,62,134,132,11,60,192,58,82,61,2,80,101,54,94,23,88,55,156,125,111,53,218,195,54,52,24,169,1,49,87,191,132,48,149,213,179,50,211,107,234,51,17,1,221,36,107,229,144,37,169,143,167,39,239,49,254,38,45,91,201,35,98,77,76,34,160,39,123,32,230,153,34,33,36,243,21,42,120,180,40,43,186,222,31,41,252,96,70,40,62,10,113,45,113,28,244,44,179,118,195,46,245,200,154,47,55,162,173,112,154,141,192,113,88,231,247,115,30,89,174,114,220,51,153,119,147,37,28,118,81,79,43,116,23,241,114,117,213,155,69,126,137,220,120,127,75,182,79,125,13,8,22,124,207,98,33,121,128,116,164,120,66,30,147,122,4,160,202,123,198,202,253,108,188,46,176,109,126,68,135,111,56,250,222,110,250,144,233,107,181,134,108,106,119,236,91,104,49,82,2,105,243,56,53,98,175,127,8,99,109,21,63,97,43,171,102,96,233,193,81,101,166,215,212,100,100,189,227,102,34,3,186,103,224,105,141,72,215,203,32,73,21,161,23,75,83,31,78,74,145,117,121,79,222,99,252,78,28,9,203,76,90,183,146,77,152,221,165,70,196,154,152,71,6,240,175,69,64,78,246,68,130,36,193,65,205,50,68,64,15,88,115,66,73,230,42,67,139,140,29,84,241,104,80,85,51,2,103,87,117,188,62,86,183,214,9,83,248,192,140,82,58,170,187,80,124,20,226,81,190,126,213,90,226,57,232,91,32,83,223,89,102,237,134,88,164,135,177,93,235,145,52,92,41,251,3,94,111,69,90,95,173,47,109,225,53,27,128,224,247,113,183,226,177,207,238,227,115,165,217,230,60,179,92,231,254,217,107,229,184,103,50,228,122,13,5,239,38,74,56,238,228,32,15,236,162,158,86,237,96,244,97,232,47,226,228,233,237,136,211,235,171,54,138,234,105,92,189,253,19,184,240,252,209,210,199,254,151,108,158,255,85,6,169,250,26,16,44,251,216,122,27,249,158,196,66,248,92,174,117,243,0,233,72,242,194,131,127,240,132,61,38,241,70,87,17,244,9,65,148,245,203,43,163,247,141,149,250,246,79,255,205,217,120,93,96,216,186,55,87,218,252,137,14,219,62,227,57,222,113,245,188,223,179,159,139,221,245,33,210,220,55,75,229,215,107,12,216,214,169,102,239,212,239,216,182,213,45,178,129,208,98,164,4,209,160,206,51,211,230,112,106,210,36,26,93,197,94,254,16,196,156,148,39,198,218,42,126,199,24,64,73,194,87,86,204,195,149,60,251,193,211,130,162,192,17,232,149,203,77,175,168,202,143,197,159,200,201,123,198,201,11,17,241,204,68,7,116,205,134,109,67,207,192,211,26,206,2,185,45,145,175,150,64,144,109,252,119,146,43,66,46,147,233,40,25,150,166,62,156,151,100,84,171,149,34,234,242,148,224,128,197,159,188,199,248,158,126,173,207,156,56,19,150,157,250,121,161,152,181,111,36,153,119,5,19,155,49,187,74,154,243,209,125,141,137,53,48,140,75,95,7,142,13,225,94,143,207,139,105,138,128,157,236,139,66,247,219,137,4,73,130,136,198,35,181,131,154,100,136,130,88,14,191,128,30,176,230,129,220,218,209,132,147,204,84,133,81,166,99,135,23,24,58,134,213,114,13,169,226,208,160,168,32,186,151,170,102,4,206,171,164,110,249,174,235,120,124,175,41,18,75,173,111,172,18,172,173,198,37,167,241,129,24,166,51,235,47,164,117,85,118,165,183,63,65,160,248,41,196,161,58,67,243,163,124,253,170,162,190,151,157,181,196,115,208,180,6,25,231,182,64,167,190,183,130,205,137,178,205,219,12,179,15,177,59,177,73,15,98,176,139,101,85,187,215,34,104,186,21,72,95,184,83,246,6,185,145,156,49,188,222,138,180,189,28,224,131,191,90,94,218,190,152,52,237,0,0,0,0,184,188,103,101,170,9,200,139,18,181,175,238,143,98,151,87,55,222,240,50,37,107,95,220,157,215,56,185,197,180,40,239,125,8,79,138,111,189,224,100,215,1,135,1,74,214,191,184,242,106,216,221,224,223,119,51,88,99,16,86,80,25,87,159,232,165,48,250,250,16,159,20,66,172,248,113,223,123,192,200,103,199,167,173,117,114,8,67,205,206,111,38,149,173,127,112,45,17,24,21,63,164,183,251,135,24,208,158,26,207,232,39,162,115,143,66,176,198,32,172,8,122,71,201,160,50,175,62,24,142,200,91,10,59,103,181,178,135,0,208,47,80,56,105,151,236,95,12,133,89,240,226,61,229,151,135,101,134,135,209,221,58,224,180,207,143,79,90,119,51,40,63,234,228,16,134,82,88,119,227,64,237,216,13,248,81,191,104,240,43,248,161,72,151,159,196,90,34,48,42,226,158,87,79,127,73,111,246,199,245,8,147,213,64,167,125,109,252,192,24,53,159,208,78,141,35,183,43,159,150,24,197,39,42,127,160,186,253,71,25,2,65,32,124,16,244,143,146,168,72,232,247,155,20,88,61,35,168,63,88,49,29,144,182,137,161,247,211,20,118,207,106,172,202,168,15,190,127,7,225,6,195,96,132,94,160,112,210,230,28,23,183,244,169,184,89,76,21,223,60,209,194,231,133,105,126,128,224,123,203,47,14,195,119,72,107,203,13,15,162,115,177,104,199,97,4,199,41,217,184,160,76,68,111,152,245,252,211,255,144,238,102,80,126,86,218,55,27,14,185,39,77,182,5,64,40,164,176,239,198,28,12,136,163,129,219,176,26,57,103,215,127,43,210,120,145,147,110,31,244,59,38,247,3,131,154,144,102,145,47,63,136,41,147,88,237,180,68,96,84,12,248,7,49,30,77,168,223,166,241,207,186,254,146,223,236,70,46,184,137,84,155,23,103,236,39,112,2,113,240,72,187,201,76,47,222,219,249,128,48,99,69,231,85,107,63,160,156,211,131,199,249,193,54,104,23,121,138,15,114,228,93,55,203,92,225,80,174,78,84,255,64,246,232,152,37,174,139,136,115,22,55,239,22,4,130,64,248,188,62,39,157,33,233,31,36,153,85,120,65,139,224,215,175,51,92,176,202,237,89,182,59,85,229,209,94,71,80,126,176,255,236,25,213,98,59,33,108,218,135,70,9,200,50,233,231,112,142,142,130,40,237,158,212,144,81,249,177,130,228,86,95,58,88,49,58,167,143,9,131,31,51,110,230,13,134,193,8,181,58,166,109,189,64,225,164,5,252,134,193,23,73,41,47,175,245,78,74,50,34,118,243,138,158,17,150,152,43,190,120,32,151,217,29,120,244,201,75,192,72,174,46,210,253,1,192,106,65,102,165,247,150,94,28,79,42,57,121,93,159,150,151,229,35,241,242,77,107,25,5,245,215,126,96,231,98,209,142,95,222,182,235,194,9,142,82,122,181,233,55,104,0,70,217,208,188,33,188,136,223,49,234,48,99,86,143,34,214,249,97,154,106,158,4,7,189,166,189,191,1,193,216,173,180,110,54,21,8,9,83,29,114,78,154,165,206,41,255,183,123,134,17,15,199,225,116,146,16,217,205,42,172,190,168,56,25,17,70,128,165,118,35,216,198,102,117,96,122,1,16,114,207,174,254,202,115,201,155,87,164,241,34,239,24,150,71,253,173,57,169,69,17,94,204,118,77,238,6,206,241,137,99,220,68,38,141,100,248,65,232,249,47,121,81,65,147,30,52,83,38,177,218,235,154,214,191,179,249,198,233,11,69,161,140,25,240,14,98,161,76,105,7,60,155,81,190,132,39,54,219,150,146,153,53,46,46,254,80,38,84,185,153,158,232,222,252,140,93,113,18,52,225,22,119,169,54,46,206,17,138,73,171,3,63,230,69,187,131,129,32,227,224,145,118,91,92,246,19,73,233,89,253,241,85,62,152,108,130,6,33,212,62,97,68,198,139,206,170,126,55,169,207,214,127,65,56,110,195,38,93,124,118,137,179,196,202,238,214,89,29,214,111,225,161,177,10,243,20,30,228,75,168,121,129,19,203,105,215,171,119,14,178,185,194,161,92,1,126,198,57,156,169,254,128,36,21,153,229,54,160,54,11,142,28,81,110,134,102,22,167,62,218,113,194,44,111,222,44,148,211,185,73,9,4,129,240,177,184,230,149,163,13,73,123,27,177,46,30,67,210,62,72,251,110,89,45,233,219,246,195,81,103,145,166,204,176,169,31,116,12,206,122,102,185,97,148,222,5,6,241], "i8", ALLOC_NONE, 5247032);
allocate([0,0,0,0,0,0,0,0,8,0,0,0,4,0,4,0,8,0,4,0,2,0,0,0,4,0,5,0,16,0,8,0,2,0,0,0,4,0,6,0,32,0,32,0,2,0,0,0,4,0,4,0,16,0,16,0,6,0,0,0,8,0,16,0,32,0,32,0,6,0,0,0,8,0,16,0,128,0,128,0,6,0,0,0,8,0,32,0,128,0,256,0,6,0,0,0,32,0,128,0,258,0,1024,0,6,0,0,0,32,0,258,0,258,0,4096,0,6,0,0,0], ["i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0,"i16",0,"i16",0,"i16",0,"i16",0,"*",0,0,0], ALLOC_NONE, 5255224);
allocate([16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15] /* \10\11\12\00\08\07\0 */, "i8", ALLOC_NONE, 5255344);
allocate([0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0], "i8", ALLOC_NONE, 5255364);
allocate([0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,128,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,96,0,0], "i8", ALLOC_NONE, 5255480);
allocate([98,117,102,102,101,114,32,101,114,114,111,114,0] /* buffer error\00 */, "i8", ALLOC_NONE, 5255600);
allocate([105,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,0] /* insufficient memory\ */, "i8", ALLOC_NONE, 5255616);
allocate([115,116,114,101,97,109,32,101,114,114,111,114,0] /* stream error\00 */, "i8", ALLOC_NONE, 5255636);
allocate([115,116,114,99,109,112,40,98,117,102,102,101,114,44,32,98,117,102,102,101,114,51,41,32,61,61,32,48,0] /* strcmp(buffer, buffe */, "i8", ALLOC_NONE, 5255652);
allocate([100,101,99,111,109,112,114,101,115,115,101,100,83,105,122,101,32,61,61,32,115,105,122,101,0] /* decompressedSize ==  */, "i8", ALLOC_NONE, 5255684);
allocate([47,116,109,112,47,101,109,115,99,114,105,112,116,101,110,95,116,101,109,112,47,122,108,105,98,46,99,0] /* /tmp/emscripten_temp */, "i8", ALLOC_NONE, 5255712);
allocate([115,105,122,101,115,58,32,37,100,44,37,100,10,0] /* sizes: %d,%d\0A\00 */, "i8", ALLOC_NONE, 5255740);
allocate([0,1,2,3,4,5,6,7,8,8,9,9,10,10,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28] /* \00\01\02\03\04\05\0 */, "i8", ALLOC_NONE, 5255756);
allocate(468, "i8", ALLOC_NONE, 5256012);
allocate([0,1,2,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,0,0,16,17,18,18,19,19,20,20,20,20,21,21,21,21,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29] /* \00\01\02\03\04\04\0 */, "i8", ALLOC_NONE, 5256480);
allocate([100,111,105,116,0] /* doit\00 */, "i8", ALLOC_NONE, 5256992);
HEAP32[((5244036)>>2)]=((5242884)|0);
HEAP32[((5244040)>>2)]=((5246712)|0);
HEAP32[((5244176)>>2)]=((5244056)|0);
HEAP32[((5244180)>>2)]=((5246828)|0);
HEAP32[((5244200)>>2)]=((5246948)|0);

  
  
  
  
  var ERRNO_CODES={E2BIG:7,EACCES:13,EADDRINUSE:98,EADDRNOTAVAIL:99,EAFNOSUPPORT:97,EAGAIN:11,EALREADY:114,EBADF:9,EBADMSG:74,EBUSY:16,ECANCELED:125,ECHILD:10,ECONNABORTED:103,ECONNREFUSED:111,ECONNRESET:104,EDEADLK:35,EDESTADDRREQ:89,EDOM:33,EDQUOT:122,EEXIST:17,EFAULT:14,EFBIG:27,EHOSTUNREACH:113,EIDRM:43,EILSEQ:84,EINPROGRESS:115,EINTR:4,EINVAL:22,EIO:5,EISCONN:106,EISDIR:21,ELOOP:40,EMFILE:24,EMLINK:31,EMSGSIZE:90,EMULTIHOP:72,ENAMETOOLONG:36,ENETDOWN:100,ENETRESET:102,ENETUNREACH:101,ENFILE:23,ENOBUFS:105,ENODATA:61,ENODEV:19,ENOENT:2,ENOEXEC:8,ENOLCK:37,ENOLINK:67,ENOMEM:12,ENOMSG:42,ENOPROTOOPT:92,ENOSPC:28,ENOSR:63,ENOSTR:60,ENOSYS:38,ENOTCONN:107,ENOTDIR:20,ENOTEMPTY:39,ENOTRECOVERABLE:131,ENOTSOCK:88,ENOTSUP:95,ENOTTY:25,ENXIO:6,EOVERFLOW:75,EOWNERDEAD:130,EPERM:1,EPIPE:32,EPROTO:71,EPROTONOSUPPORT:93,EPROTOTYPE:91,ERANGE:34,EROFS:30,ESPIPE:29,ESRCH:3,ESTALE:116,ETIME:62,ETIMEDOUT:110,ETXTBSY:26,EWOULDBLOCK:11,EXDEV:18};
  
  function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      if (!___setErrNo.ret) ___setErrNo.ret = allocate([0], 'i32', ALLOC_STATIC);
      HEAP32[((___setErrNo.ret)>>2)]=value
      return value;
    }
  
  var _stdin=allocate(1, "i32*", ALLOC_STACK);
  
  var _stdout=allocate(1, "i32*", ALLOC_STACK);
  
  var _stderr=allocate(1, "i32*", ALLOC_STACK);
  
  var __impure_ptr=allocate(1, "i32*", ALLOC_STACK);var FS={currentPath:"/",nextInode:2,streams:[null],ignorePermissions:true,joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
  
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
  
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
  
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
  
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function(chunkSize, length) {
            this.length = length;
            this.chunkSize = chunkSize;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % chunkSize;
            var chunkNum = Math.floor(idx / chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
    
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
          if (!hasByteServing) chunkSize = datalength;
    
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
    
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
    
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
    
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
    
          var lazyArray = new LazyUint8Array(chunkSize, datalength);
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * lazyArray.chunkSize;
            var end = (chunkNum+1) * lazyArray.chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile) {
        Browser.ensureObjects();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureRoot();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
  
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === '\n'.charCodeAt(0)) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
  
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
  
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        FS.createDevice(devFolder, 'tty', input, output);
  
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          isTerminal: !stdinOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stdoutOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          isTerminal: !stderrOverridden,
          error: false,
          eof: false,
          ungotten: []
        };
        assert(Math.max(_stdin, _stdout, _stderr) < 128); // make sure these are low, we flatten arrays with these
        HEAP32[((_stdin)>>2)]=1;
        HEAP32[((_stdout)>>2)]=2;
        HEAP32[((_stderr)>>2)]=3;
  
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
  
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_STATIC) ], 'void*', ALLOC_NONE, __impure_ptr);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output('\n'.charCodeAt(0));
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output('\n'.charCodeAt(0));
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};
  
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[((buf)+(i))];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[((buf)+(i))]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  
  
   function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF32[(((varargs)+(argIndex))>>2)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[(textIndex+1)];
        if (curr == '%'.charCodeAt(0)) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case '+'.charCodeAt(0):
                flagAlwaysSigned = true;
                break;
              case '-'.charCodeAt(0):
                flagLeftAlign = true;
                break;
              case '#'.charCodeAt(0):
                flagAlternative = true;
                break;
              case '0'.charCodeAt(0):
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[(textIndex+1)];
          }
  
          // Handle width.
          var width = 0;
          if (next == '*'.charCodeAt(0)) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[(textIndex+1)];
          } else {
            while (next >= '0'.charCodeAt(0) && next <= '9'.charCodeAt(0)) {
              width = width * 10 + (next - '0'.charCodeAt(0));
              textIndex++;
              next = HEAP8[(textIndex+1)];
            }
          }
  
          // Handle precision.
          var precisionSet = false;
          if (next == '.'.charCodeAt(0)) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[(textIndex+1)];
            if (next == '*'.charCodeAt(0)) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[(textIndex+1)];
                if (precisionChr < '0'.charCodeAt(0) ||
                    precisionChr > '9'.charCodeAt(0)) break;
                precision = precision * 10 + (precisionChr - '0'.charCodeAt(0));
                textIndex++;
              }
            }
            next = HEAP8[(textIndex+1)];
          } else {
            var precision = 6; // Standard default.
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[(textIndex+2)];
              if (nextNext == 'h'.charCodeAt(0)) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[(textIndex+2)];
              if (nextNext == 'l'.charCodeAt(0)) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[(textIndex+1)];
  
          // Handle type specifier.
          if (['d', 'i', 'u', 'o', 'x', 'X', 'p'].indexOf(String.fromCharCode(next)) != -1) {
            // Integer.
            var signed = next == 'd'.charCodeAt(0) || next == 'i'.charCodeAt(0);
            argSize = argSize || 4;
            var currArg = getNextArg('i' + (argSize * 8));
            var argText;
            // Flatten i64-1 [low, high] into a (slightly rounded) double
            if (argSize == 8) {
              currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 'u'.charCodeAt(0));
            }
            // Truncate to requested size.
            if (argSize <= 4) {
              var limit = Math.pow(256, argSize) - 1;
              currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
            }
            // Format the number.
            var currAbsArg = Math.abs(currArg);
            var prefix = '';
            if (next == 'd'.charCodeAt(0) || next == 'i'.charCodeAt(0)) {
              argText = reSign(currArg, 8 * argSize, 1).toString(10);
            } else if (next == 'u'.charCodeAt(0)) {
              argText = unSign(currArg, 8 * argSize, 1).toString(10);
              currArg = Math.abs(currArg);
            } else if (next == 'o'.charCodeAt(0)) {
              argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
            } else if (next == 'x'.charCodeAt(0) || next == 'X'.charCodeAt(0)) {
              prefix = flagAlternative ? '0x' : '';
              if (currArg < 0) {
                // Represent negative numbers in hex as 2's complement.
                currArg = -currArg;
                argText = (currAbsArg - 1).toString(16);
                var buffer = [];
                for (var i = 0; i < argText.length; i++) {
                  buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                }
                argText = buffer.join('');
                while (argText.length < argSize * 2) argText = 'f' + argText;
              } else {
                argText = currAbsArg.toString(16);
              }
              if (next == 'X'.charCodeAt(0)) {
                prefix = prefix.toUpperCase();
                argText = argText.toUpperCase();
              }
            } else if (next == 'p'.charCodeAt(0)) {
              if (currAbsArg === 0) {
                argText = '(nil)';
              } else {
                prefix = '0x';
                argText = currAbsArg.toString(16);
              }
            }
            if (precisionSet) {
              while (argText.length < precision) {
                argText = '0' + argText;
              }
            }
  
            // Add sign if needed
            if (flagAlwaysSigned) {
              if (currArg < 0) {
                prefix = '-' + prefix;
              } else {
                prefix = '+' + prefix;
              }
            }
  
            // Add padding.
            while (prefix.length + argText.length < width) {
              if (flagLeftAlign) {
                argText += ' ';
              } else {
                if (flagZeroPad) {
                  argText = '0' + argText;
                } else {
                  prefix = ' ' + prefix;
                }
              }
            }
  
            // Insert the result into the buffer.
            argText = prefix + argText;
            argText.split('').forEach(function(chr) {
              ret.push(chr.charCodeAt(0));
            });
          } else if (['f', 'F', 'e', 'E', 'g', 'G'].indexOf(String.fromCharCode(next)) != -1) {
            // Float.
            var currArg = getNextArg('double');
            var argText;
  
            if (isNaN(currArg)) {
              argText = 'nan';
              flagZeroPad = false;
            } else if (!isFinite(currArg)) {
              argText = (currArg < 0 ? '-' : '') + 'inf';
              flagZeroPad = false;
            } else {
              var isGeneral = false;
              var effectivePrecision = Math.min(precision, 20);
  
              // Convert g/G to f/F or e/E, as per:
              // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
              if (next == 'g'.charCodeAt(0) || next == 'G'.charCodeAt(0)) {
                isGeneral = true;
                precision = precision || 1;
                var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                if (precision > exponent && exponent >= -4) {
                  next = ((next == 'g'.charCodeAt(0)) ? 'f' : 'F').charCodeAt(0);
                  precision -= exponent + 1;
                } else {
                  next = ((next == 'g'.charCodeAt(0)) ? 'e' : 'E').charCodeAt(0);
                  precision--;
                }
                effectivePrecision = Math.min(precision, 20);
              }
  
              if (next == 'e'.charCodeAt(0) || next == 'E'.charCodeAt(0)) {
                argText = currArg.toExponential(effectivePrecision);
                // Make sure the exponent has at least 2 digits.
                if (/[eE][-+]\d$/.test(argText)) {
                  argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                }
              } else if (next == 'f'.charCodeAt(0) || next == 'F'.charCodeAt(0)) {
                argText = currArg.toFixed(effectivePrecision);
              }
  
              var parts = argText.split('e');
              if (isGeneral && !flagAlternative) {
                // Discard trailing zeros and periods.
                while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                       (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                  parts[0] = parts[0].slice(0, -1);
                }
              } else {
                // Make sure we have a period in alternative mode.
                if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                // Zero pad until required precision.
                while (precision > effectivePrecision++) parts[0] += '0';
              }
              argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
              // Capitalize 'E' if needed.
              if (next == 'E'.charCodeAt(0)) argText = argText.toUpperCase();
  
              // Add sign.
              if (flagAlwaysSigned && currArg >= 0) {
                argText = '+' + argText;
              }
            }
  
            // Add padding.
            while (argText.length < width) {
              if (flagLeftAlign) {
                argText += ' ';
              } else {
                if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                  argText = argText[0] + '0' + argText.slice(1);
                } else {
                  argText = (flagZeroPad ? '0' : ' ') + argText;
                }
              }
            }
  
            // Adjust case.
            if (next < 'a'.charCodeAt(0)) argText = argText.toUpperCase();
  
            // Insert the result into the buffer.
            argText.split('').forEach(function(chr) {
              ret.push(chr.charCodeAt(0));
            });
          } else if (next == 's'.charCodeAt(0)) {
            // String.
            var arg = getNextArg('i8*') || nullString;
            var argLength = _strlen(arg);
            if (precisionSet) argLength = Math.min(argLength, precision);
            if (!flagLeftAlign) {
              while (argLength < width--) {
                ret.push(' '.charCodeAt(0));
              }
            }
            for (var i = 0; i < argLength; i++) {
              ret.push(HEAPU8[(arg++)]);
            }
            if (flagLeftAlign) {
              while (argLength < width--) {
                ret.push(' '.charCodeAt(0));
              }
            }
          } else if (next == 'c'.charCodeAt(0)) {
            // Character.
            if (flagLeftAlign) ret.push(getNextArg('i8'));
            while (--width > 0) {
              ret.push(' '.charCodeAt(0));
            }
            if (!flagLeftAlign) ret.push(getNextArg('i8'));
          } else if (next == 'n'.charCodeAt(0)) {
            // Write the length written so far to the next parameter.
            var ptr = getNextArg('i32*');
            HEAP32[((ptr)>>2)]=ret.length
          } else if (next == '%'.charCodeAt(0)) {
            // Literal percent sign.
            ret.push(curr);
          } else {
            // Unknown specifiers remain untouched.
            for (var i = startTextIndex; i < textIndex + 2; i++) {
              ret.push(HEAP8[(i)]);
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  function ___assert_func(filename, line, func, condition) {
      throw 'Assertion failed: ' + (condition ? Pointer_stringify(condition) : 'unknown condition') + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + new Error().stack;
    }

  
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[((px)+(i))];
        var y = HEAPU8[((py)+(i))];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }

  
  
  
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == '-'.charCodeAt(0)) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == '+'.charCodeAt(0)) {
        str++;
      }
  
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == '0'.charCodeAt(0)) {
          if (HEAP8[(str+1)] == 'x'.charCodeAt(0) ||
              HEAP8[(str+1)] == 'X'.charCodeAt(0)) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      }
      if (!finalBase) finalBase = 10;
  
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
  
      // Apply sign.
      ret *= multiplier;
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
  
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
  
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
  
      if (bits == 64) {
        return (asm.setTempRet0(Math.min(Math.floor((ret)/(+(4294967296))), (+(4294967295)))>>>0),ret>>>0);
      }
  
      return ret;
    }function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }

  
   var _llvm_memset_p0i8_i32;

  
   var _llvm_memcpy_p0i8_p0i8_i32;

  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }

  
  function ___errno_location() {
      return ___setErrNo.ret;
    }var ___errno;

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
  
      // We need to make sure no one else allocates unfreeable memory!
      // We must control this entirely. So we don't even need to do
      // unfreeable allocations - the HEAP is ours, from STATICTOP up.
      // TODO: We could in theory slice off the top of the HEAP when
      //       sbrk gets a negative increment in |bytes|...
      var self = _sbrk;
      if (!self.called) {
        STATICTOP = alignMemoryPage(STATICTOP); // make sure we start out aligned
        self.called = true;
        _sbrk.DYNAMIC_START = STATICTOP;
      }
      var ret = STATICTOP;
      if (bytes != 0) Runtime.staticAlloc(bytes);
      return ret;  // Previous break location.
    }

  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }

  function _llvm_lifetime_start() {}

  function _llvm_lifetime_end() {}

  
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }
  
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[(_fputc.ret)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return -1;
      } else {
        return chr;
      }
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc('\n'.charCodeAt(0), stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }




  function _free(){}

  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],ensureObjects:function () {
        if (Browser.ensured) return;
        Browser.ensured = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'jpeg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(-3)];
          return ret;
        }
  
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = [];
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/.exec(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            setTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', { alpha: false });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
  
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},requestFullScreen:function () {
        var canvas = Module['canvas'];
        function fullScreenChange() {
          var isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                        canvas['mozRequestPointerLock'] ||
                                        canvas['webkitRequestPointerLock'];
            canvas.requestPointerLock();
            isFullScreen = true;
          }
          if (Module['onFullScreen']) Module['onFullScreen'](isFullScreen);
        }
  
        document.addEventListener('fullscreenchange', fullScreenChange, false);
        document.addEventListener('mozfullscreenchange', fullScreenChange, false);
        document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
  
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
  
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen(); 
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200) {
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      }};
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___setErrNo(0);
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function() { Browser.requestFullScreen() };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  

if (!Math.imul) Math.imul = function(x, y) { return (x*y)|0 }; // # not a real polyfill since semantics not identical, but close and fairly fast
var Runtime_bitshift64 = Runtime.bitshift64;
var Math_min = Math.min;
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
var asm = (function(global, env, buffer) {
  'use asm';
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);

  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var NaN=+env.NaN;
  var Infinity=+env.Infinity;

  var __THREW__ = 0;
  var undef = 0;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;

  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var abort=env.abort;
  var assert=env.assert;
  var asmPrintInt=env.asmPrintInt;
  var asmPrintFloat=env.asmPrintFloat;
  var copyTempDouble=env.copyTempDouble;
  var copyTempFloat=env.copyTempFloat;
  var Runtime_bitshift64=env.Runtime_bitshift64;
  var Math_min=env.min;
  var _strncmp=env._strncmp;
  var _llvm_lifetime_end=env._llvm_lifetime_end;
  var _sysconf=env._sysconf;
  var _abort=env._abort;
  var _fprintf=env._fprintf;
  var _printf=env._printf;
  var _strtol=env._strtol;
  var _fputc=env._fputc;
  var _puts=env._puts;
  var ___setErrNo=env.___setErrNo;
  var _fwrite=env._fwrite;
  var _write=env._write;
  var _fputs=env._fputs;
  var _isspace=env._isspace;
  var __formatString=env.__formatString;
  var _free=env._free;
  var _atoi=env._atoi;
  var ___assert_func=env.___assert_func;
  var _pwrite=env._pwrite;
  var _sbrk=env._sbrk;
  var ___errno_location=env.___errno_location;
  var _llvm_lifetime_start=env._llvm_lifetime_start;
  var _llvm_bswap_i32=env._llvm_bswap_i32;
  var __parseInt=env.__parseInt;
  var _time=env._time;
  var _strcmp=env._strcmp;

  function stackAlloc(size) {
    size = size|0;
    var ret = 0;
    ret = STACKTOP;
    STACKTOP = (STACKTOP + size)|0;
    STACKTOP = ((STACKTOP + 3)>>2)<<2;
    return ret|0;
  }
  function stackSave() {
    return STACKTOP|0;
  }
  function stackRestore(top) {
    top = top|0;
    STACKTOP = top;
  }
  function setThrew(threw) {
    threw = threw|0;
    __THREW__ = threw;
  }

  function setTempRet0(value) {
    value = value|0;
    tempRet0 = value;
  }

  function setTempRet1(value) {
    value = value|0;
    tempRet1 = value;
  }

  function setTempRet2(value) {
    value = value|0;
    tempRet2 = value;
  }

  function setTempRet3(value) {
    value = value|0;
    tempRet3 = value;
  }

  function setTempRet4(value) {
    value = value|0;
    tempRet4 = value;
  }

  function setTempRet5(value) {
    value = value|0;
    tempRet5 = value;
  }

  function setTempRet6(value) {
    value = value|0;
    tempRet6 = value;
  }

  function setTempRet7(value) {
    value = value|0;
    tempRet7 = value;
  }

  function setTempRet8(value) {
    value = value|0;
    tempRet8 = value;
  }

  function setTempRet9(value) {
    value = value|0;
    tempRet9 = value;
  }

function _doit(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i72 = 0, i73 = 0, i74 = 0, i75 = 0, i76 = 0, i77 = 0, i78 = 0, i79 = 0, i80 = 0, i81 = 0, i82 = 0, i83 = 0, i84 = 0, i85 = 0, i86 = 0, i87 = 0, i88 = 0, i89 = 0, i90 = 0, i91 = 0, i92 = 0, i93 = 0, i94 = 0, i95 = 0, i96 = 0, i97 = 0, i98 = 0, i99 = 0, i100 = 0, i101 = 0, i102 = 0, i103 = 0, i104 = 0, i105 = 0, i106 = 0, i107 = 0, i108 = 0, i109 = 0, i110 = 0, i111 = 0, i112 = 0, i113 = 0, i114 = 0, i115 = 0, i116 = 0, i117 = 0, i118 = 0, i119 = 0, i120 = 0, i121 = 0, i122 = 0, i123 = 0, i124 = 0, i125 = 0, i126 = 0, i127 = 0, i128 = 0, i129 = 0, i130 = 0, i131 = 0, i132 = 0, i133 = 0, i134 = 0, i135 = 0, i136 = 0, i137 = 0, i138 = 0, i139 = 0, i140 = 0, i141 = 0, i142 = 0, i143 = 0, i144 = 0, i145 = 0, i146 = 0, i147 = 0, i148 = 0, i149 = 0, i150 = 0, i151 = 0, i152 = 0, i153 = 0, i154 = 0, i155 = 0, i156 = 0, i157 = 0, i158 = 0, i159 = 0, i160 = 0, i161 = 0, i162 = 0, i163 = 0, i164 = 0, i165 = 0, i166 = 0, i167 = 0, i168 = 0, i169 = 0, i170 = 0, i171 = 0, i172 = 0, i173 = 0, i174 = 0, i175 = 0, i176 = 0, i177 = 0, i178 = 0, i179 = 0, i180 = 0, i181 = 0, i182 = 0, i183 = 0, i184 = 0, i185 = 0, i186 = 0, i187 = 0, i188 = 0, i189 = 0, i190 = 0, i191 = 0, i192 = 0, i193 = 0, i194 = 0, i195 = 0, i196 = 0, i197 = 0, i198 = 0, i199 = 0, i200 = 0, i201 = 0, i202 = 0, i203 = 0, i204 = 0, i205 = 0, i206 = 0, i207 = 0, i208 = 0, i209 = 0, i210 = 0, i211 = 0, i212 = 0, i213 = 0, i214 = 0, i215 = 0, i216 = 0, i217 = 0, i218 = 0, i219 = 0, i220 = 0, i221 = 0, i222 = 0, i223 = 0, i224 = 0, i225 = 0, i226 = 0, i227 = 0, i228 = 0, i229 = 0, i230 = 0, i231 = 0, i232 = 0, i233 = 0, i234 = 0, i235 = 0, i236 = 0, i237 = 0, i238 = 0, i239 = 0, i240 = 0, i241 = 0, i242 = 0, i243 = 0, i244 = 0, i245 = 0, i246 = 0, i247 = 0, i248 = 0, i249 = 0, i250 = 0, i251 = 0, i252 = 0, i253 = 0, i254 = 0, i255 = 0, i256 = 0, i257 = 0, i258 = 0, i259 = 0, i260 = 0, i261 = 0, i262 = 0, i263 = 0, i264 = 0, i265 = 0, i266 = 0, i267 = 0, i268 = 0, i269 = 0, i270 = 0, i271 = 0, i272 = 0, i273 = 0, i274 = 0, i275 = 0, i276 = 0, i277 = 0, i278 = 0, i279 = 0, i280 = 0, i281 = 0, i282 = 0, i283 = 0, i284 = 0, i285 = 0, i286 = 0, i287 = 0, i288 = 0, i289 = 0, i290 = 0, i291 = 0, i292 = 0, i293 = 0, i294 = 0, i295 = 0, i296 = 0, i297 = 0, i298 = 0, i299 = 0, i300 = 0, i301 = 0, i302 = 0, i303 = 0, i304 = 0, i305 = 0, i306 = 0, i307 = 0, i308 = 0, i309 = 0, i310 = 0, i311 = 0, i312 = 0, i313 = 0, i314 = 0, i315 = 0, i316 = 0, i317 = 0, i318 = 0, i319 = 0, i320 = 0, i321 = 0, i322 = 0, i323 = 0, i324 = 0, i325 = 0, i326 = 0, i327 = 0, i328 = 0, i329 = 0, i330 = 0, i331 = 0, i332 = 0, i333 = 0, i334 = 0, i335 = 0, i336 = 0, i337 = 0, i338 = 0, i339 = 0, i340 = 0, i341 = 0, i342 = 0, i343 = 0, i344 = 0, i345 = 0, i346 = 0, i347 = 0, i348 = 0, i349 = 0, i350 = 0, i351 = 0, i352 = 0, i353 = 0, i354 = 0, i355 = 0, i356 = 0, i357 = 0, i358 = 0, i359 = 0, i360 = 0, i361 = 0, i362 = 0, i363 = 0, i364 = 0, i365 = 0, i366 = 0, i367 = 0, i368 = 0, i369 = 0, i370 = 0, i371 = 0, i372 = 0, i373 = 0, i374 = 0, i375 = 0, i376 = 0, i377 = 0, i378 = 0, i379 = 0, i380 = 0, i381 = 0, i382 = 0, i383 = 0, i384 = 0, i385 = 0, i386 = 0, i387 = 0, i388 = 0, i389 = 0, i390 = 0, i391 = 0, i392 = 0, i393 = 0, i394 = 0, i395 = 0, i396 = 0, i397 = 0, i398 = 0, i399 = 0, i400 = 0, i401 = 0, i402 = 0, i403 = 0, i404 = 0, i405 = 0, i406 = 0, i407 = 0, i408 = 0, i409 = 0, i410 = 0, i411 = 0, i412 = 0, i413 = 0, i414 = 0, i415 = 0, i416 = 0, i417 = 0, i418 = 0, i419 = 0, i420 = 0, i421 = 0, i422 = 0, i423 = 0, i424 = 0, i425 = 0, i426 = 0, i427 = 0, i428 = 0, i429 = 0, i430 = 0, i431 = 0, i432 = 0, i433 = 0, i434 = 0, i435 = 0, i436 = 0, i437 = 0, i438 = 0, i439 = 0, i440 = 0, i441 = 0, i442 = 0, i443 = 0, i444 = 0, i445 = 0, i446 = 0, i447 = 0, i448 = 0, i449 = 0, i450 = 0, i451 = 0, i452 = 0, i453 = 0, i454 = 0, i455 = 0, i456 = 0, i457 = 0, i458 = 0, i459 = 0, i460 = 0, i461 = 0, i462 = 0, i463 = 0, i464 = 0, i465 = 0, i466 = 0, i467 = 0, i468 = 0, i469 = 0, i470 = 0, i471 = 0, i472 = 0, i473 = 0, i474 = 0;
  i4 = STACKTOP;
  STACKTOP = STACKTOP + 60 | 0;
  i5 = i4 | 0;
  i6 = i4 + 4 | 0;
  i7 = (((i2 + 13 | 0) + (i2 >>> 12) | 0) + (i2 >>> 14) | 0) + (i2 >>> 25) | 0;
  i8 = HEAP32[1311757] | 0;
  if ((i8 | 0) == 0) {
    i9 = _malloc(i7) | 0;
    HEAP32[1311757] = i9;
    i10 = i9;
  } else {
    i10 = i8;
  }
  if ((HEAP32[1311756] | 0) == 0) {
    HEAP32[1311756] = _malloc(i2) | 0;
    i11 = HEAP32[1311757] | 0;
  } else {
    i11 = i10;
  }
  i10 = i6 | 0;
  HEAP32[i10 >> 2] = i1;
  i8 = i6 + 4 | 0;
  HEAP32[i8 >> 2] = i2;
  i9 = i6 + 12 | 0;
  HEAP32[i9 >> 2] = i11;
  i11 = i6 + 16 | 0;
  HEAP32[i11 >> 2] = i7;
  i12 = i6 + 32 | 0;
  HEAP32[i12 >> 2] = 0;
  i13 = i6 + 36 | 0;
  HEAP32[i13 >> 2] = 0;
  i14 = i6 + 40 | 0;
  HEAP32[i14 >> 2] = 0;
  i15 = i6 + 24 | 0;
  HEAP32[i15 >> 2] = 0;
  HEAP32[i12 >> 2] = 4;
  HEAP32[i14 >> 2] = 0;
  HEAP32[i13 >> 2] = 10;
  i16 = _zcalloc(0, 1, 5828) | 0;
  L7 : do {
    if ((i16 | 0) == 0) {
      i17 = i7;
    } else {
      i18 = i6 + 28 | 0;
      HEAP32[i18 >> 2] = i16;
      HEAP32[i16 >> 2] = i6;
      HEAP32[i16 + 24 >> 2] = 1;
      HEAP32[i16 + 28 >> 2] = 0;
      HEAP32[i16 + 48 >> 2] = 15;
      i19 = i16 + 44 | 0;
      HEAP32[i19 >> 2] = 32768;
      HEAP32[i16 + 52 >> 2] = 32767;
      HEAP32[i16 + 80 >> 2] = 15;
      i20 = i16 + 76 | 0;
      HEAP32[i20 >> 2] = 32768;
      HEAP32[i16 + 84 >> 2] = 32767;
      HEAP32[i16 + 88 >> 2] = 5;
      i21 = i16 + 56 | 0;
      HEAP32[i21 >> 2] = FUNCTION_TABLE_iiii[HEAP32[i12 >> 2] & 15](HEAP32[i14 >> 2] | 0, 32768, 2) | 0;
      i22 = FUNCTION_TABLE_iiii[HEAP32[i12 >> 2] & 15](HEAP32[i14 >> 2] | 0, HEAP32[i19 >> 2] | 0, 2) | 0;
      i23 = i16 + 64 | 0;
      HEAP32[i23 >> 2] = i22;
      _memset(i22 | 0, 0, HEAP32[i19 >> 2] << 1 | 0);
      i19 = i16 + 68 | 0;
      HEAP32[i19 >> 2] = FUNCTION_TABLE_iiii[HEAP32[i12 >> 2] & 15](HEAP32[i14 >> 2] | 0, HEAP32[i20 >> 2] | 0, 2) | 0;
      HEAP32[i16 + 5824 >> 2] = 0;
      i20 = i16 + 5788 | 0;
      HEAP32[i20 >> 2] = 16384;
      i22 = FUNCTION_TABLE_iiii[HEAP32[i12 >> 2] & 15](HEAP32[i14 >> 2] | 0, 16384, 4) | 0;
      i24 = i22;
      HEAP32[i16 + 8 >> 2] = i22;
      i25 = HEAP32[i20 >> 2] | 0;
      HEAP32[i16 + 12 >> 2] = i25 << 2;
      do {
        if ((HEAP32[i21 >> 2] | 0) != 0) {
          if ((HEAP32[i23 >> 2] | 0) == 0) {
            break;
          }
          if ((HEAP32[i19 >> 2] | 0) == 0 | (i22 | 0) == 0) {
            break;
          }
          HEAP32[i16 + 5796 >> 2] = i24 + (i25 >>> 1 << 1) | 0;
          HEAP32[i16 + 5784 >> 2] = i22 + (i25 * 3 & -1 & -1) | 0;
          HEAP32[i16 + 132 >> 2] = 6;
          HEAP32[i16 + 136 >> 2] = 0;
          HEAP8[i16 + 36 | 0] = 8;
          i20 = HEAP32[i18 >> 2] | 0;
          if ((i20 | 0) == 0) {
            i17 = i7;
            break L7;
          }
          if ((HEAP32[i12 >> 2] | 0) == 0) {
            i17 = i7;
            break L7;
          }
          if ((HEAP32[i13 >> 2] | 0) == 0) {
            i17 = i7;
            break L7;
          }
          i26 = i6 + 20 | 0;
          HEAP32[i26 >> 2] = 0;
          i27 = i6 + 8 | 0;
          HEAP32[i27 >> 2] = 0;
          HEAP32[i15 >> 2] = 0;
          HEAP32[i6 + 44 >> 2] = 2;
          HEAP32[i20 + 20 >> 2] = 0;
          HEAP32[i20 + 16 >> 2] = HEAP32[i20 + 8 >> 2] | 0;
          i28 = i20 + 24 | 0;
          i29 = HEAP32[i28 >> 2] | 0;
          if ((i29 | 0) < 0) {
            i30 = -i29 | 0;
            HEAP32[i28 >> 2] = i30;
            i31 = i30;
          } else {
            i31 = i29;
          }
          HEAP32[i20 + 4 >> 2] = (i31 | 0) != 0 ? 42 : 113;
          i29 = i6 + 48 | 0;
          HEAP32[i29 >> 2] = (i31 | 0) != 2 & 1;
          HEAP32[i20 + 40 >> 2] = 0;
          HEAP32[i20 + 2840 >> 2] = i20 + 148 | 0;
          HEAP32[i20 + 2848 >> 2] = 5244036;
          HEAP32[i20 + 2852 >> 2] = i20 + 2440 | 0;
          HEAP32[i20 + 2860 >> 2] = 5244176;
          HEAP32[i20 + 2864 >> 2] = i20 + 2684 | 0;
          HEAP32[i20 + 2872 >> 2] = 5244196;
          HEAP16[i20 + 5816 >> 1] = 0;
          HEAP32[i20 + 5820 >> 2] = 0;
          HEAP32[i20 + 5812 >> 2] = 8;
          _init_block(i20);
          HEAP32[i20 + 60 >> 2] = HEAP32[i20 + 44 >> 2] << 1;
          i30 = i20 + 76 | 0;
          i28 = i20 + 68 | 0;
          HEAP16[(HEAP32[i28 >> 2] | 0) + ((HEAP32[i30 >> 2] | 0) - 1 << 1) >> 1] = 0;
          _memset(HEAP32[i28 >> 2] | 0, 0, (HEAP32[i30 >> 2] << 1) - 2 | 0);
          i30 = HEAP32[i20 + 132 >> 2] | 0;
          HEAP32[i20 + 128 >> 2] = HEAPU16[5255226 + (i30 * 12 & -1) >> 1] | 0;
          HEAP32[i20 + 140 >> 2] = HEAPU16[5255224 + (i30 * 12 & -1) >> 1] | 0;
          HEAP32[i20 + 144 >> 2] = HEAPU16[5255228 + (i30 * 12 & -1) >> 1] | 0;
          HEAP32[i20 + 124 >> 2] = HEAPU16[5255230 + (i30 * 12 & -1) >> 1] | 0;
          HEAP32[i20 + 108 >> 2] = 0;
          HEAP32[i20 + 92 >> 2] = 0;
          HEAP32[i20 + 116 >> 2] = 0;
          HEAP32[i20 + 120 >> 2] = 2;
          HEAP32[i20 + 96 >> 2] = 2;
          HEAP32[i20 + 112 >> 2] = 0;
          HEAP32[i20 + 104 >> 2] = 0;
          HEAP32[i20 + 72 >> 2] = 0;
          i20 = HEAP32[i18 >> 2] | 0;
          i30 = i20;
          if ((i20 | 0) == 0) {
            i17 = i7;
            break L7;
          }
          L20 : do {
            if ((HEAP32[i9 >> 2] | 0) == 0) {
              i32 = 30;
            } else {
              if ((HEAP32[i10 >> 2] | 0) == 0) {
                if ((HEAP32[i8 >> 2] | 0) != 0) {
                  i32 = 30;
                  break;
                }
              }
              i28 = i20 + 4 | 0;
              i33 = HEAP32[i28 >> 2] | 0;
              if ((HEAP32[i11 >> 2] | 0) == 0) {
                HEAP32[i15 >> 2] = 5255600;
                break;
              }
              i34 = i20;
              HEAP32[i20 >> 2] = i6;
              i35 = i20 + 40 | 0;
              HEAP32[i35 >> 2] = 4;
              do {
                if ((i33 | 0) == 42) {
                  if ((HEAP32[i20 + 24 >> 2] | 0) != 2) {
                    i36 = (HEAP32[i20 + 48 >> 2] << 12) - 30720 | 0;
                    do {
                      if ((HEAP32[i20 + 136 >> 2] | 0) > 1) {
                        i37 = 0;
                      } else {
                        i38 = HEAP32[i20 + 132 >> 2] | 0;
                        if ((i38 | 0) < 2) {
                          i37 = 0;
                          break;
                        }
                        if ((i38 | 0) < 6) {
                          i37 = 64;
                          break;
                        }
                        i37 = (i38 | 0) == 6 ? 128 : 192;
                      }
                    } while (0);
                    i38 = i37 | i36;
                    i39 = i20 + 108 | 0;
                    i40 = (HEAP32[i39 >> 2] | 0) == 0 ? i38 : i38 | 32;
                    i38 = (i40 | (i40 >>> 0) % 31) ^ 31;
                    HEAP32[i28 >> 2] = 113;
                    i40 = i20 + 20 | 0;
                    i41 = HEAP32[i40 >> 2] | 0;
                    HEAP32[i40 >> 2] = i41 + 1 | 0;
                    i42 = i20 + 8 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = i38 >>> 8 & 255;
                    i41 = HEAP32[i40 >> 2] | 0;
                    HEAP32[i40 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = i38 & 255;
                    if ((HEAP32[i39 >> 2] | 0) != 0) {
                      i39 = HEAP32[i29 >> 2] | 0;
                      i38 = HEAP32[i40 >> 2] | 0;
                      HEAP32[i40 >> 2] = i38 + 1 | 0;
                      HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = i39 >>> 24 & 255;
                      i38 = HEAP32[i40 >> 2] | 0;
                      HEAP32[i40 >> 2] = i38 + 1 | 0;
                      HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = i39 >>> 16 & 255;
                      i39 = HEAP32[i29 >> 2] | 0;
                      i38 = HEAP32[i40 >> 2] | 0;
                      HEAP32[i40 >> 2] = i38 + 1 | 0;
                      HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = i39 >>> 8 & 255;
                      i38 = HEAP32[i40 >> 2] | 0;
                      HEAP32[i40 >> 2] = i38 + 1 | 0;
                      HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = i39 & 255;
                    }
                    HEAP32[i29 >> 2] = 1;
                    i43 = HEAP32[i28 >> 2] | 0;
                    i32 = 54;
                    break;
                  }
                  HEAP32[i29 >> 2] = 0;
                  i39 = i20 + 20 | 0;
                  i38 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i38 + 1 | 0;
                  i42 = i20 + 8 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = 31;
                  i38 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i38 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = -117;
                  i38 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i38 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i38 | 0] = 8;
                  i38 = i20 + 28 | 0;
                  i40 = HEAP32[i38 >> 2] | 0;
                  if ((i40 | 0) == 0) {
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = 0;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = 0;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = 0;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = 0;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = 0;
                    i41 = HEAP32[i20 + 132 >> 2] | 0;
                    do {
                      if ((i41 | 0) == 9) {
                        i44 = 2;
                      } else {
                        if ((HEAP32[i20 + 136 >> 2] | 0) > 1) {
                          i44 = 4;
                          break;
                        }
                        i44 = (i41 | 0) < 2 ? 4 : 0;
                      }
                    } while (0);
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = i44;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = 3;
                    HEAP32[i28 >> 2] = 113;
                    break;
                  }
                  i41 = ((HEAP32[i40 + 44 >> 2] | 0) != 0 ? 2 : 0) | (HEAP32[i40 >> 2] | 0) != 0 & 1 | ((HEAP32[i40 + 16 >> 2] | 0) == 0 ? 0 : 4) | ((HEAP32[i40 + 28 >> 2] | 0) == 0 ? 0 : 8) | ((HEAP32[i40 + 36 >> 2] | 0) == 0 ? 0 : 16);
                  i36 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i36 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i36 | 0] = i41;
                  i41 = HEAP32[(HEAP32[i38 >> 2] | 0) + 4 >> 2] & 255;
                  i36 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i36 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i36 | 0] = i41;
                  i41 = (HEAP32[(HEAP32[i38 >> 2] | 0) + 4 >> 2] | 0) >>> 8 & 255;
                  i36 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i36 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i36 | 0] = i41;
                  i41 = (HEAP32[(HEAP32[i38 >> 2] | 0) + 4 >> 2] | 0) >>> 16 & 255;
                  i36 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i36 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i36 | 0] = i41;
                  i41 = (HEAP32[(HEAP32[i38 >> 2] | 0) + 4 >> 2] | 0) >>> 24 & 255;
                  i36 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i36 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i36 | 0] = i41;
                  i41 = HEAP32[i20 + 132 >> 2] | 0;
                  do {
                    if ((i41 | 0) == 9) {
                      i45 = 2;
                    } else {
                      if ((HEAP32[i20 + 136 >> 2] | 0) > 1) {
                        i45 = 4;
                        break;
                      }
                      i45 = (i41 | 0) < 2 ? 4 : 0;
                    }
                  } while (0);
                  i41 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i41 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = i45;
                  i41 = HEAP32[(HEAP32[i38 >> 2] | 0) + 12 >> 2] & 255;
                  i40 = HEAP32[i39 >> 2] | 0;
                  HEAP32[i39 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i42 >> 2] | 0) + i40 | 0] = i41;
                  i41 = HEAP32[i38 >> 2] | 0;
                  if ((HEAP32[i41 + 16 >> 2] | 0) == 0) {
                    i46 = i41;
                  } else {
                    i40 = HEAP32[i41 + 20 >> 2] & 255;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = i40;
                    i40 = (HEAP32[(HEAP32[i38 >> 2] | 0) + 20 >> 2] | 0) >>> 8 & 255;
                    i41 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i41 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i41 | 0] = i40;
                    i46 = HEAP32[i38 >> 2] | 0;
                  }
                  if ((HEAP32[i46 + 44 >> 2] | 0) != 0) {
                    HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, HEAP32[i42 >> 2] | 0, HEAP32[i39 >> 2] | 0) | 0;
                  }
                  HEAP32[i20 + 32 >> 2] = 0;
                  HEAP32[i28 >> 2] = 69;
                  i47 = i38;
                  i32 = 56;
                  break;
                } else {
                  i43 = i33;
                  i32 = 54;
                }
              } while (0);
              do {
                if ((i32 | 0) == 54) {
                  if ((i43 | 0) != 69) {
                    i48 = i43;
                    i32 = 77;
                    break;
                  }
                  i47 = i20 + 28 | 0;
                  i32 = 56;
                  break;
                }
              } while (0);
              do {
                if ((i32 | 0) == 56) {
                  i33 = HEAP32[i47 >> 2] | 0;
                  if ((HEAP32[i33 + 16 >> 2] | 0) == 0) {
                    HEAP32[i28 >> 2] = 73;
                    i49 = i33;
                    i32 = 79;
                    break;
                  }
                  i40 = i20 + 20 | 0;
                  i41 = HEAP32[i40 >> 2] | 0;
                  i36 = i20 + 32 | 0;
                  i50 = HEAP32[i36 >> 2] | 0;
                  L66 : do {
                    if (i50 >>> 0 < (HEAP32[i33 + 20 >> 2] & 65535) >>> 0) {
                      i51 = i20 + 12 | 0;
                      i52 = i20 + 8 | 0;
                      i53 = i41;
                      i54 = i33;
                      i55 = i41;
                      i56 = i50;
                      while (1) {
                        if ((i55 | 0) == (HEAP32[i51 >> 2] | 0)) {
                          if ((HEAP32[i54 + 44 >> 2] | 0) != 0 & i55 >>> 0 > i53 >>> 0) {
                            HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, (HEAP32[i52 >> 2] | 0) + i53 | 0, i55 - i53 | 0) | 0;
                          }
                          i57 = HEAP32[i18 >> 2] | 0;
                          i58 = HEAP32[i57 + 20 >> 2] | 0;
                          i59 = HEAP32[i11 >> 2] | 0;
                          i60 = i58 >>> 0 > i59 >>> 0 ? i59 : i58;
                          do {
                            if ((i60 | 0) != 0) {
                              _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i57 + 16 >> 2] | 0, i60);
                              HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i60 | 0;
                              i58 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                              HEAP32[i58 >> 2] = (HEAP32[i58 >> 2] | 0) + i60 | 0;
                              HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i60 | 0;
                              HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i60 | 0;
                              i58 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                              HEAP32[i58 >> 2] = (HEAP32[i58 >> 2] | 0) - i60 | 0;
                              i58 = HEAP32[i18 >> 2] | 0;
                              if ((HEAP32[i58 + 20 >> 2] | 0) != 0) {
                                break;
                              }
                              HEAP32[i58 + 16 >> 2] = HEAP32[i58 + 8 >> 2] | 0;
                            }
                          } while (0);
                          i61 = HEAP32[i40 >> 2] | 0;
                          if ((i61 | 0) == (HEAP32[i51 >> 2] | 0)) {
                            break;
                          }
                          i62 = i61;
                          i63 = i61;
                          i64 = HEAP32[i36 >> 2] | 0;
                          i65 = HEAP32[i47 >> 2] | 0;
                        } else {
                          i62 = i53;
                          i63 = i55;
                          i64 = i56;
                          i65 = i54;
                        }
                        i60 = HEAP8[(HEAP32[i65 + 16 >> 2] | 0) + i64 | 0] | 0;
                        HEAP32[i40 >> 2] = i63 + 1 | 0;
                        HEAP8[(HEAP32[i52 >> 2] | 0) + i63 | 0] = i60;
                        i60 = (HEAP32[i36 >> 2] | 0) + 1 | 0;
                        HEAP32[i36 >> 2] = i60;
                        i57 = HEAP32[i47 >> 2] | 0;
                        if (i60 >>> 0 >= (HEAP32[i57 + 20 >> 2] & 65535) >>> 0) {
                          i66 = i62;
                          i67 = i57;
                          break L66;
                        }
                        i53 = i62;
                        i54 = i57;
                        i55 = HEAP32[i40 >> 2] | 0;
                        i56 = i60;
                      }
                      i66 = i61;
                      i67 = HEAP32[i47 >> 2] | 0;
                    } else {
                      i66 = i41;
                      i67 = i33;
                    }
                  } while (0);
                  do {
                    if ((HEAP32[i67 + 44 >> 2] | 0) == 0) {
                      i68 = i67;
                    } else {
                      i33 = HEAP32[i40 >> 2] | 0;
                      if (i33 >>> 0 <= i66 >>> 0) {
                        i68 = i67;
                        break;
                      }
                      HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, (HEAP32[i20 + 8 >> 2] | 0) + i66 | 0, i33 - i66 | 0) | 0;
                      i68 = HEAP32[i47 >> 2] | 0;
                    }
                  } while (0);
                  if ((HEAP32[i36 >> 2] | 0) == (HEAP32[i68 + 20 >> 2] | 0)) {
                    HEAP32[i36 >> 2] = 0;
                    HEAP32[i28 >> 2] = 73;
                    i49 = i68;
                    i32 = 79;
                    break;
                  } else {
                    i48 = HEAP32[i28 >> 2] | 0;
                    i32 = 77;
                    break;
                  }
                }
              } while (0);
              do {
                if ((i32 | 0) == 77) {
                  if ((i48 | 0) != 73) {
                    i69 = i48;
                    i32 = 97;
                    break;
                  }
                  i49 = HEAP32[i20 + 28 >> 2] | 0;
                  i32 = 79;
                  break;
                }
              } while (0);
              do {
                if ((i32 | 0) == 79) {
                  i40 = i20 + 28 | 0;
                  if ((HEAP32[i49 + 28 >> 2] | 0) == 0) {
                    HEAP32[i28 >> 2] = 91;
                    i70 = i40;
                    i32 = 99;
                    break;
                  }
                  i33 = i20 + 20 | 0;
                  i41 = HEAP32[i33 >> 2] | 0;
                  i50 = i20 + 12 | 0;
                  i38 = i20 + 8 | 0;
                  i39 = i20 + 32 | 0;
                  i42 = i41;
                  i56 = i41;
                  while (1) {
                    if ((i56 | 0) == (HEAP32[i50 >> 2] | 0)) {
                      if ((HEAP32[(HEAP32[i40 >> 2] | 0) + 44 >> 2] | 0) != 0 & i56 >>> 0 > i42 >>> 0) {
                        HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, (HEAP32[i38 >> 2] | 0) + i42 | 0, i56 - i42 | 0) | 0;
                      }
                      i41 = HEAP32[i18 >> 2] | 0;
                      i55 = HEAP32[i41 + 20 >> 2] | 0;
                      i54 = HEAP32[i11 >> 2] | 0;
                      i53 = i55 >>> 0 > i54 >>> 0 ? i54 : i55;
                      do {
                        if ((i53 | 0) != 0) {
                          _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i41 + 16 >> 2] | 0, i53);
                          HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i53 | 0;
                          i55 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                          HEAP32[i55 >> 2] = (HEAP32[i55 >> 2] | 0) + i53 | 0;
                          HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i53 | 0;
                          HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i53 | 0;
                          i55 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                          HEAP32[i55 >> 2] = (HEAP32[i55 >> 2] | 0) - i53 | 0;
                          i55 = HEAP32[i18 >> 2] | 0;
                          if ((HEAP32[i55 + 20 >> 2] | 0) != 0) {
                            break;
                          }
                          HEAP32[i55 + 16 >> 2] = HEAP32[i55 + 8 >> 2] | 0;
                        }
                      } while (0);
                      i53 = HEAP32[i33 >> 2] | 0;
                      if ((i53 | 0) == (HEAP32[i50 >> 2] | 0)) {
                        i71 = 1;
                        i72 = i53;
                        break;
                      } else {
                        i73 = i53;
                        i74 = i53;
                      }
                    } else {
                      i73 = i42;
                      i74 = i56;
                    }
                    i53 = HEAP32[i39 >> 2] | 0;
                    HEAP32[i39 >> 2] = i53 + 1 | 0;
                    i41 = HEAP8[(HEAP32[(HEAP32[i40 >> 2] | 0) + 28 >> 2] | 0) + i53 | 0] | 0;
                    HEAP32[i33 >> 2] = i74 + 1 | 0;
                    HEAP8[(HEAP32[i38 >> 2] | 0) + i74 | 0] = i41;
                    if (i41 << 24 >> 24 == 0) {
                      i71 = 0;
                      i72 = i73;
                      break;
                    }
                    i42 = i73;
                    i56 = HEAP32[i33 >> 2] | 0;
                  }
                  do {
                    if ((HEAP32[(HEAP32[i40 >> 2] | 0) + 44 >> 2] | 0) != 0) {
                      i56 = HEAP32[i33 >> 2] | 0;
                      if (i56 >>> 0 <= i72 >>> 0) {
                        break;
                      }
                      HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, (HEAP32[i38 >> 2] | 0) + i72 | 0, i56 - i72 | 0) | 0;
                    }
                  } while (0);
                  if ((i71 | 0) == 0) {
                    HEAP32[i39 >> 2] = 0;
                    HEAP32[i28 >> 2] = 91;
                    i70 = i40;
                    i32 = 99;
                    break;
                  } else {
                    i69 = HEAP32[i28 >> 2] | 0;
                    i32 = 97;
                    break;
                  }
                }
              } while (0);
              do {
                if ((i32 | 0) == 97) {
                  if ((i69 | 0) != 91) {
                    i75 = i69;
                    i32 = 117;
                    break;
                  }
                  i70 = i20 + 28 | 0;
                  i32 = 99;
                  break;
                }
              } while (0);
              do {
                if ((i32 | 0) == 99) {
                  if ((HEAP32[(HEAP32[i70 >> 2] | 0) + 36 >> 2] | 0) == 0) {
                    HEAP32[i28 >> 2] = 103;
                    i76 = i70;
                    i32 = 119;
                    break;
                  }
                  i38 = i20 + 20 | 0;
                  i33 = HEAP32[i38 >> 2] | 0;
                  i56 = i20 + 12 | 0;
                  i42 = i20 + 8 | 0;
                  i50 = i20 + 32 | 0;
                  i36 = i33;
                  i41 = i33;
                  while (1) {
                    if ((i41 | 0) == (HEAP32[i56 >> 2] | 0)) {
                      if ((HEAP32[(HEAP32[i70 >> 2] | 0) + 44 >> 2] | 0) != 0 & i41 >>> 0 > i36 >>> 0) {
                        HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, (HEAP32[i42 >> 2] | 0) + i36 | 0, i41 - i36 | 0) | 0;
                      }
                      i33 = HEAP32[i18 >> 2] | 0;
                      i53 = HEAP32[i33 + 20 >> 2] | 0;
                      i55 = HEAP32[i11 >> 2] | 0;
                      i54 = i53 >>> 0 > i55 >>> 0 ? i55 : i53;
                      do {
                        if ((i54 | 0) != 0) {
                          _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i33 + 16 >> 2] | 0, i54);
                          HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i54 | 0;
                          i53 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                          HEAP32[i53 >> 2] = (HEAP32[i53 >> 2] | 0) + i54 | 0;
                          HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i54 | 0;
                          HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i54 | 0;
                          i53 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                          HEAP32[i53 >> 2] = (HEAP32[i53 >> 2] | 0) - i54 | 0;
                          i53 = HEAP32[i18 >> 2] | 0;
                          if ((HEAP32[i53 + 20 >> 2] | 0) != 0) {
                            break;
                          }
                          HEAP32[i53 + 16 >> 2] = HEAP32[i53 + 8 >> 2] | 0;
                        }
                      } while (0);
                      i54 = HEAP32[i38 >> 2] | 0;
                      if ((i54 | 0) == (HEAP32[i56 >> 2] | 0)) {
                        i77 = 1;
                        i78 = i54;
                        break;
                      } else {
                        i79 = i54;
                        i80 = i54;
                      }
                    } else {
                      i79 = i36;
                      i80 = i41;
                    }
                    i54 = HEAP32[i50 >> 2] | 0;
                    HEAP32[i50 >> 2] = i54 + 1 | 0;
                    i33 = HEAP8[(HEAP32[(HEAP32[i70 >> 2] | 0) + 36 >> 2] | 0) + i54 | 0] | 0;
                    HEAP32[i38 >> 2] = i80 + 1 | 0;
                    HEAP8[(HEAP32[i42 >> 2] | 0) + i80 | 0] = i33;
                    if (i33 << 24 >> 24 == 0) {
                      i77 = 0;
                      i78 = i79;
                      break;
                    }
                    i36 = i79;
                    i41 = HEAP32[i38 >> 2] | 0;
                  }
                  do {
                    if ((HEAP32[(HEAP32[i70 >> 2] | 0) + 44 >> 2] | 0) != 0) {
                      i41 = HEAP32[i38 >> 2] | 0;
                      if (i41 >>> 0 <= i78 >>> 0) {
                        break;
                      }
                      HEAP32[i29 >> 2] = _crc32(HEAP32[i29 >> 2] | 0, (HEAP32[i42 >> 2] | 0) + i78 | 0, i41 - i78 | 0) | 0;
                    }
                  } while (0);
                  if ((i77 | 0) == 0) {
                    HEAP32[i28 >> 2] = 103;
                    i76 = i70;
                    i32 = 119;
                    break;
                  } else {
                    i75 = HEAP32[i28 >> 2] | 0;
                    i32 = 117;
                    break;
                  }
                }
              } while (0);
              do {
                if ((i32 | 0) == 117) {
                  if ((i75 | 0) != 103) {
                    break;
                  }
                  i76 = i20 + 28 | 0;
                  i32 = 119;
                  break;
                }
              } while (0);
              do {
                if ((i32 | 0) == 119) {
                  if ((HEAP32[(HEAP32[i76 >> 2] | 0) + 44 >> 2] | 0) == 0) {
                    HEAP32[i28 >> 2] = 113;
                    break;
                  }
                  i42 = i20 + 20 | 0;
                  i38 = i20 + 12 | 0;
                  do {
                    if (((HEAP32[i42 >> 2] | 0) + 2 | 0) >>> 0 > (HEAP32[i38 >> 2] | 0) >>> 0) {
                      i41 = HEAP32[i18 >> 2] | 0;
                      i36 = HEAP32[i41 + 20 >> 2] | 0;
                      i50 = HEAP32[i11 >> 2] | 0;
                      i56 = i36 >>> 0 > i50 >>> 0 ? i50 : i36;
                      if ((i56 | 0) == 0) {
                        break;
                      }
                      _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i41 + 16 >> 2] | 0, i56);
                      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i56 | 0;
                      i41 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                      HEAP32[i41 >> 2] = (HEAP32[i41 >> 2] | 0) + i56 | 0;
                      HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i56 | 0;
                      HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i56 | 0;
                      i41 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                      HEAP32[i41 >> 2] = (HEAP32[i41 >> 2] | 0) - i56 | 0;
                      i56 = HEAP32[i18 >> 2] | 0;
                      if ((HEAP32[i56 + 20 >> 2] | 0) != 0) {
                        break;
                      }
                      HEAP32[i56 + 16 >> 2] = HEAP32[i56 + 8 >> 2] | 0;
                    }
                  } while (0);
                  i56 = HEAP32[i42 >> 2] | 0;
                  if ((i56 + 2 | 0) >>> 0 > (HEAP32[i38 >> 2] | 0) >>> 0) {
                    break;
                  }
                  i41 = HEAP32[i29 >> 2] & 255;
                  HEAP32[i42 >> 2] = i56 + 1 | 0;
                  i36 = i20 + 8 | 0;
                  HEAP8[(HEAP32[i36 >> 2] | 0) + i56 | 0] = i41;
                  i41 = (HEAP32[i29 >> 2] | 0) >>> 8 & 255;
                  i56 = HEAP32[i42 >> 2] | 0;
                  HEAP32[i42 >> 2] = i56 + 1 | 0;
                  HEAP8[(HEAP32[i36 >> 2] | 0) + i56 | 0] = i41;
                  HEAP32[i29 >> 2] = 0;
                  HEAP32[i28 >> 2] = 113;
                }
              } while (0);
              i41 = i20 + 20 | 0;
              do {
                if ((HEAP32[i41 >> 2] | 0) == 0) {
                  i56 = HEAP32[i8 >> 2] | 0;
                  i81 = (i56 | 0) == 0 ? 0 : i56;
                } else {
                  i56 = HEAP32[i18 >> 2] | 0;
                  i36 = HEAP32[i56 + 20 >> 2] | 0;
                  i50 = HEAP32[i11 >> 2] | 0;
                  i40 = i36 >>> 0 > i50 >>> 0 ? i50 : i36;
                  if ((i40 | 0) == 0) {
                    i82 = i50;
                  } else {
                    _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i56 + 16 >> 2] | 0, i40);
                    HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i40 | 0;
                    i56 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                    HEAP32[i56 >> 2] = (HEAP32[i56 >> 2] | 0) + i40 | 0;
                    HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i40 | 0;
                    HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i40 | 0;
                    i56 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                    HEAP32[i56 >> 2] = (HEAP32[i56 >> 2] | 0) - i40 | 0;
                    i40 = HEAP32[i18 >> 2] | 0;
                    if ((HEAP32[i40 + 20 >> 2] | 0) == 0) {
                      HEAP32[i40 + 16 >> 2] = HEAP32[i40 + 8 >> 2] | 0;
                    }
                    i82 = HEAP32[i11 >> 2] | 0;
                  }
                  if ((i82 | 0) == 0) {
                    HEAP32[i35 >> 2] = -1;
                    break L20;
                  } else {
                    i81 = HEAP32[i8 >> 2] | 0;
                    break;
                  }
                }
              } while (0);
              i40 = (HEAP32[i28 >> 2] | 0) == 666;
              i56 = (i81 | 0) == 0;
              do {
                if (i40) {
                  if (i56) {
                    i32 = 140;
                    break;
                  }
                  HEAP32[i15 >> 2] = 5255600;
                  break L20;
                } else {
                  if (i56) {
                    i32 = 140;
                    break;
                  } else {
                    i32 = 141;
                    break;
                  }
                }
              } while (0);
              do {
                if ((i32 | 0) == 140) {
                  if ((HEAP32[i20 + 116 >> 2] | 0) == 0 ^ 1 | i40 ^ 1) {
                    i32 = 141;
                    break;
                  } else {
                    break;
                  }
                }
              } while (0);
              L183 : do {
                if ((i32 | 0) == 141) {
                  i40 = HEAP32[i20 + 136 >> 2] | 0;
                  L185 : do {
                    if ((i40 | 0) == 2) {
                      i56 = i20 + 116 | 0;
                      i50 = i20 + 96 | 0;
                      i36 = i20 + 108 | 0;
                      i39 = i20 + 56 | 0;
                      i33 = i20 + 5792 | 0;
                      i54 = i20 + 5796 | 0;
                      i53 = i20 + 5784 | 0;
                      i55 = i20 + 5788 | 0;
                      i52 = i20 + 92 | 0;
                      i51 = i20;
                      while (1) {
                        if ((HEAP32[i56 >> 2] | 0) == 0) {
                          _fill_window(i30);
                          if ((HEAP32[i56 >> 2] | 0) == 0) {
                            break;
                          }
                        }
                        HEAP32[i50 >> 2] = 0;
                        i60 = HEAP8[(HEAP32[i39 >> 2] | 0) + (HEAP32[i36 >> 2] | 0) | 0] | 0;
                        HEAP16[(HEAP32[i54 >> 2] | 0) + (HEAP32[i33 >> 2] << 1) >> 1] = 0;
                        i57 = HEAP32[i33 >> 2] | 0;
                        HEAP32[i33 >> 2] = i57 + 1 | 0;
                        HEAP8[(HEAP32[i53 >> 2] | 0) + i57 | 0] = i60;
                        i57 = i30 + 148 + ((i60 & 255) << 2) | 0;
                        HEAP16[i57 >> 1] = (HEAP16[i57 >> 1] | 0) + 1 & 65535;
                        i57 = (HEAP32[i33 >> 2] | 0) == ((HEAP32[i55 >> 2] | 0) - 1 | 0);
                        HEAP32[i56 >> 2] = (HEAP32[i56 >> 2] | 0) - 1 | 0;
                        i60 = (HEAP32[i36 >> 2] | 0) + 1 | 0;
                        HEAP32[i36 >> 2] = i60;
                        if (!i57) {
                          continue;
                        }
                        i57 = HEAP32[i52 >> 2] | 0;
                        if ((i57 | 0) > -1) {
                          i83 = (HEAP32[i39 >> 2] | 0) + i57 | 0;
                        } else {
                          i83 = 0;
                        }
                        __tr_flush_block(i51, i83, i60 - i57 | 0, 0);
                        HEAP32[i52 >> 2] = HEAP32[i36 >> 2] | 0;
                        i57 = HEAP32[i34 >> 2] | 0;
                        i60 = i57 + 28 | 0;
                        i58 = HEAP32[i60 >> 2] | 0;
                        i59 = HEAP32[i58 + 20 >> 2] | 0;
                        i84 = i57 + 16 | 0;
                        i85 = HEAP32[i84 >> 2] | 0;
                        i86 = i59 >>> 0 > i85 >>> 0 ? i85 : i59;
                        do {
                          if ((i86 | 0) != 0) {
                            i59 = i57 + 12 | 0;
                            _memcpy(HEAP32[i59 >> 2] | 0, HEAP32[i58 + 16 >> 2] | 0, i86);
                            HEAP32[i59 >> 2] = (HEAP32[i59 >> 2] | 0) + i86 | 0;
                            i59 = (HEAP32[i60 >> 2] | 0) + 16 | 0;
                            HEAP32[i59 >> 2] = (HEAP32[i59 >> 2] | 0) + i86 | 0;
                            i59 = i57 + 20 | 0;
                            HEAP32[i59 >> 2] = (HEAP32[i59 >> 2] | 0) + i86 | 0;
                            HEAP32[i84 >> 2] = (HEAP32[i84 >> 2] | 0) - i86 | 0;
                            i59 = (HEAP32[i60 >> 2] | 0) + 20 | 0;
                            HEAP32[i59 >> 2] = (HEAP32[i59 >> 2] | 0) - i86 | 0;
                            i59 = HEAP32[i60 >> 2] | 0;
                            if ((HEAP32[i59 + 20 >> 2] | 0) != 0) {
                              break;
                            }
                            HEAP32[i59 + 16 >> 2] = HEAP32[i59 + 8 >> 2] | 0;
                          }
                        } while (0);
                        if ((HEAP32[(HEAP32[i34 >> 2] | 0) + 16 >> 2] | 0) == 0) {
                          break L185;
                        }
                      }
                      i56 = HEAP32[i52 >> 2] | 0;
                      if ((i56 | 0) > -1) {
                        i87 = (HEAP32[i39 >> 2] | 0) + i56 | 0;
                      } else {
                        i87 = 0;
                      }
                      __tr_flush_block(i51, i87, (HEAP32[i36 >> 2] | 0) - i56 | 0, 1);
                      HEAP32[i52 >> 2] = HEAP32[i36 >> 2] | 0;
                      i56 = HEAP32[i34 >> 2] | 0;
                      i55 = i56 + 28 | 0;
                      i33 = HEAP32[i55 >> 2] | 0;
                      i53 = HEAP32[i33 + 20 >> 2] | 0;
                      i54 = i56 + 16 | 0;
                      i50 = HEAP32[i54 >> 2] | 0;
                      i60 = i53 >>> 0 > i50 >>> 0 ? i50 : i53;
                      do {
                        if ((i60 | 0) != 0) {
                          i53 = i56 + 12 | 0;
                          _memcpy(HEAP32[i53 >> 2] | 0, HEAP32[i33 + 16 >> 2] | 0, i60);
                          HEAP32[i53 >> 2] = (HEAP32[i53 >> 2] | 0) + i60 | 0;
                          i53 = (HEAP32[i55 >> 2] | 0) + 16 | 0;
                          HEAP32[i53 >> 2] = (HEAP32[i53 >> 2] | 0) + i60 | 0;
                          i53 = i56 + 20 | 0;
                          HEAP32[i53 >> 2] = (HEAP32[i53 >> 2] | 0) + i60 | 0;
                          HEAP32[i54 >> 2] = (HEAP32[i54 >> 2] | 0) - i60 | 0;
                          i53 = (HEAP32[i55 >> 2] | 0) + 20 | 0;
                          HEAP32[i53 >> 2] = (HEAP32[i53 >> 2] | 0) - i60 | 0;
                          i53 = HEAP32[i55 >> 2] | 0;
                          if ((HEAP32[i53 + 20 >> 2] | 0) != 0) {
                            break;
                          }
                          HEAP32[i53 + 16 >> 2] = HEAP32[i53 + 8 >> 2] | 0;
                        }
                      } while (0);
                      i88 = (HEAP32[(HEAP32[i34 >> 2] | 0) + 16 >> 2] | 0) == 0 ? 2 : 3;
                      i32 = 194;
                      break;
                    } else if ((i40 | 0) == 3) {
                      i55 = i20 + 116 | 0;
                      i60 = i20 + 96 | 0;
                      i54 = i20 + 108 | 0;
                      i56 = i20 + 5792 | 0;
                      i33 = i20 + 5796 | 0;
                      i36 = i20 + 5784 | 0;
                      i52 = i20 + 2440 | 0;
                      i51 = i20 + 5788 | 0;
                      i39 = i20 + 56 | 0;
                      i53 = i20 + 92 | 0;
                      i50 = i20;
                      L209 : while (1) {
                        i86 = HEAP32[i55 >> 2] | 0;
                        do {
                          if (i86 >>> 0 < 258) {
                            _fill_window(i30);
                            i84 = HEAP32[i55 >> 2] | 0;
                            if ((i84 | 0) == 0) {
                              break L209;
                            }
                            HEAP32[i60 >> 2] = 0;
                            if (i84 >>> 0 > 2) {
                              i89 = i84;
                              i32 = 164;
                              break;
                            }
                            i90 = HEAP32[i54 >> 2] | 0;
                            i32 = 179;
                            break;
                          } else {
                            HEAP32[i60 >> 2] = 0;
                            i89 = i86;
                            i32 = 164;
                            break;
                          }
                        } while (0);
                        do {
                          if ((i32 | 0) == 164) {
                            i32 = 0;
                            i86 = HEAP32[i54 >> 2] | 0;
                            if ((i86 | 0) == 0) {
                              i90 = 0;
                              i32 = 179;
                              break;
                            }
                            i84 = HEAP32[i39 >> 2] | 0;
                            i57 = HEAP8[i84 + (i86 - 1 | 0) | 0] | 0;
                            if (i57 << 24 >> 24 != HEAP8[i84 + i86 | 0] << 24 >> 24) {
                              i90 = i86;
                              i32 = 179;
                              break;
                            }
                            if (i57 << 24 >> 24 != HEAP8[i84 + (i86 + 1 | 0) | 0] << 24 >> 24) {
                              i90 = i86;
                              i32 = 179;
                              break;
                            }
                            i58 = i84 + (i86 + 2 | 0) | 0;
                            if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                              i90 = i86;
                              i32 = 179;
                              break;
                            }
                            i59 = i84 + (i86 + 258 | 0) | 0;
                            i84 = i58;
                            while (1) {
                              i58 = i84 + 1 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 2 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 3 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 4 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 5 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 6 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 7 | 0;
                              if (i57 << 24 >> 24 != HEAP8[i58] << 24 >> 24) {
                                i91 = i58;
                                break;
                              }
                              i58 = i84 + 8 | 0;
                              if (i57 << 24 >> 24 == HEAP8[i58] << 24 >> 24 & i58 >>> 0 < i59 >>> 0) {
                                i84 = i58;
                              } else {
                                i91 = i58;
                                break;
                              }
                            }
                            i84 = (i91 - i59 | 0) + 258 | 0;
                            i57 = i84 >>> 0 > i89 >>> 0 ? i89 : i84;
                            HEAP32[i60 >> 2] = i57;
                            if (i57 >>> 0 <= 2) {
                              i90 = i86;
                              i32 = 179;
                              break;
                            }
                            i84 = i57 + 253 | 0;
                            HEAP16[(HEAP32[i33 >> 2] | 0) + (HEAP32[i56 >> 2] << 1) >> 1] = 1;
                            i57 = HEAP32[i56 >> 2] | 0;
                            HEAP32[i56 >> 2] = i57 + 1 | 0;
                            HEAP8[(HEAP32[i36 >> 2] | 0) + i57 | 0] = i84 & 255;
                            i57 = i30 + 148 + ((HEAPU8[5255756 + (i84 & 255) | 0] | 0 | 256) + 1 << 2) | 0;
                            HEAP16[i57 >> 1] = (HEAP16[i57 >> 1] | 0) + 1 & 65535;
                            HEAP16[i52 >> 1] = (HEAP16[i52 >> 1] | 0) + 1 & 65535;
                            i57 = (HEAP32[i56 >> 2] | 0) == ((HEAP32[i51 >> 2] | 0) - 1 | 0) & 1;
                            i84 = HEAP32[i60 >> 2] | 0;
                            HEAP32[i55 >> 2] = (HEAP32[i55 >> 2] | 0) - i84 | 0;
                            i58 = (HEAP32[i54 >> 2] | 0) + i84 | 0;
                            HEAP32[i54 >> 2] = i58;
                            HEAP32[i60 >> 2] = 0;
                            i92 = i57;
                            i93 = i58;
                            break;
                          }
                        } while (0);
                        if ((i32 | 0) == 179) {
                          i32 = 0;
                          i58 = HEAP8[(HEAP32[i39 >> 2] | 0) + i90 | 0] | 0;
                          HEAP16[(HEAP32[i33 >> 2] | 0) + (HEAP32[i56 >> 2] << 1) >> 1] = 0;
                          i57 = HEAP32[i56 >> 2] | 0;
                          HEAP32[i56 >> 2] = i57 + 1 | 0;
                          HEAP8[(HEAP32[i36 >> 2] | 0) + i57 | 0] = i58;
                          i57 = i30 + 148 + ((i58 & 255) << 2) | 0;
                          HEAP16[i57 >> 1] = (HEAP16[i57 >> 1] | 0) + 1 & 65535;
                          i57 = (HEAP32[i56 >> 2] | 0) == ((HEAP32[i51 >> 2] | 0) - 1 | 0) & 1;
                          HEAP32[i55 >> 2] = (HEAP32[i55 >> 2] | 0) - 1 | 0;
                          i58 = (HEAP32[i54 >> 2] | 0) + 1 | 0;
                          HEAP32[i54 >> 2] = i58;
                          i92 = i57;
                          i93 = i58;
                        }
                        if ((i92 | 0) == 0) {
                          continue;
                        }
                        i58 = HEAP32[i53 >> 2] | 0;
                        if ((i58 | 0) > -1) {
                          i94 = (HEAP32[i39 >> 2] | 0) + i58 | 0;
                        } else {
                          i94 = 0;
                        }
                        __tr_flush_block(i50, i94, i93 - i58 | 0, 0);
                        HEAP32[i53 >> 2] = HEAP32[i54 >> 2] | 0;
                        i58 = HEAP32[i34 >> 2] | 0;
                        i57 = i58 + 28 | 0;
                        i84 = HEAP32[i57 >> 2] | 0;
                        i85 = HEAP32[i84 + 20 >> 2] | 0;
                        i95 = i58 + 16 | 0;
                        i96 = HEAP32[i95 >> 2] | 0;
                        i97 = i85 >>> 0 > i96 >>> 0 ? i96 : i85;
                        do {
                          if ((i97 | 0) != 0) {
                            i85 = i58 + 12 | 0;
                            _memcpy(HEAP32[i85 >> 2] | 0, HEAP32[i84 + 16 >> 2] | 0, i97);
                            HEAP32[i85 >> 2] = (HEAP32[i85 >> 2] | 0) + i97 | 0;
                            i85 = (HEAP32[i57 >> 2] | 0) + 16 | 0;
                            HEAP32[i85 >> 2] = (HEAP32[i85 >> 2] | 0) + i97 | 0;
                            i85 = i58 + 20 | 0;
                            HEAP32[i85 >> 2] = (HEAP32[i85 >> 2] | 0) + i97 | 0;
                            HEAP32[i95 >> 2] = (HEAP32[i95 >> 2] | 0) - i97 | 0;
                            i85 = (HEAP32[i57 >> 2] | 0) + 20 | 0;
                            HEAP32[i85 >> 2] = (HEAP32[i85 >> 2] | 0) - i97 | 0;
                            i85 = HEAP32[i57 >> 2] | 0;
                            if ((HEAP32[i85 + 20 >> 2] | 0) != 0) {
                              break;
                            }
                            HEAP32[i85 + 16 >> 2] = HEAP32[i85 + 8 >> 2] | 0;
                          }
                        } while (0);
                        if ((HEAP32[(HEAP32[i34 >> 2] | 0) + 16 >> 2] | 0) == 0) {
                          break L185;
                        }
                      }
                      i55 = HEAP32[i53 >> 2] | 0;
                      if ((i55 | 0) > -1) {
                        i98 = (HEAP32[i39 >> 2] | 0) + i55 | 0;
                      } else {
                        i98 = 0;
                      }
                      __tr_flush_block(i50, i98, (HEAP32[i54 >> 2] | 0) - i55 | 0, 1);
                      HEAP32[i53 >> 2] = HEAP32[i54 >> 2] | 0;
                      i55 = HEAP32[i34 >> 2] | 0;
                      i51 = i55 + 28 | 0;
                      i56 = HEAP32[i51 >> 2] | 0;
                      i36 = HEAP32[i56 + 20 >> 2] | 0;
                      i33 = i55 + 16 | 0;
                      i60 = HEAP32[i33 >> 2] | 0;
                      i52 = i36 >>> 0 > i60 >>> 0 ? i60 : i36;
                      do {
                        if ((i52 | 0) != 0) {
                          i36 = i55 + 12 | 0;
                          _memcpy(HEAP32[i36 >> 2] | 0, HEAP32[i56 + 16 >> 2] | 0, i52);
                          HEAP32[i36 >> 2] = (HEAP32[i36 >> 2] | 0) + i52 | 0;
                          i36 = (HEAP32[i51 >> 2] | 0) + 16 | 0;
                          HEAP32[i36 >> 2] = (HEAP32[i36 >> 2] | 0) + i52 | 0;
                          i36 = i55 + 20 | 0;
                          HEAP32[i36 >> 2] = (HEAP32[i36 >> 2] | 0) + i52 | 0;
                          HEAP32[i33 >> 2] = (HEAP32[i33 >> 2] | 0) - i52 | 0;
                          i36 = (HEAP32[i51 >> 2] | 0) + 20 | 0;
                          HEAP32[i36 >> 2] = (HEAP32[i36 >> 2] | 0) - i52 | 0;
                          i36 = HEAP32[i51 >> 2] | 0;
                          if ((HEAP32[i36 + 20 >> 2] | 0) != 0) {
                            break;
                          }
                          HEAP32[i36 + 16 >> 2] = HEAP32[i36 + 8 >> 2] | 0;
                        }
                      } while (0);
                      i88 = (HEAP32[(HEAP32[i34 >> 2] | 0) + 16 >> 2] | 0) == 0 ? 2 : 3;
                      i32 = 194;
                      break;
                    } else {
                      i51 = FUNCTION_TABLE_iii[HEAP32[5255232 + ((HEAP32[i20 + 132 >> 2] | 0) * 12 & -1) >> 2] & 15](i30, 4) | 0;
                      if ((i51 - 2 | 0) >>> 0 < 2) {
                        i88 = i51;
                        i32 = 194;
                        break;
                      } else {
                        i99 = i51;
                        i32 = 195;
                        break;
                      }
                    }
                  } while (0);
                  do {
                    if ((i32 | 0) == 194) {
                      HEAP32[i28 >> 2] = 666;
                      i99 = i88;
                      i32 = 195;
                      break;
                    }
                  } while (0);
                  do {
                    if ((i32 | 0) == 195) {
                      if ((i99 | 0) == 2 | (i99 | 0) == 0) {
                        break;
                      } else if ((i99 | 0) != 1) {
                        break L183;
                      }
                      __tr_stored_block(i20, 0, 0, 0);
                      i40 = HEAP32[i18 >> 2] | 0;
                      i42 = HEAP32[i40 + 20 >> 2] | 0;
                      i38 = HEAP32[i11 >> 2] | 0;
                      i51 = i42 >>> 0 > i38 >>> 0 ? i38 : i42;
                      if ((i51 | 0) == 0) {
                        i100 = i38;
                      } else {
                        _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i40 + 16 >> 2] | 0, i51);
                        HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i51 | 0;
                        i40 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                        HEAP32[i40 >> 2] = (HEAP32[i40 >> 2] | 0) + i51 | 0;
                        HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i51 | 0;
                        HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i51 | 0;
                        i40 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                        HEAP32[i40 >> 2] = (HEAP32[i40 >> 2] | 0) - i51 | 0;
                        i51 = HEAP32[i18 >> 2] | 0;
                        if ((HEAP32[i51 + 20 >> 2] | 0) == 0) {
                          HEAP32[i51 + 16 >> 2] = HEAP32[i51 + 8 >> 2] | 0;
                        }
                        i100 = HEAP32[i11 >> 2] | 0;
                      }
                      if ((i100 | 0) != 0) {
                        break L183;
                      }
                      HEAP32[i35 >> 2] = -1;
                      break L20;
                    }
                  } while (0);
                  if ((HEAP32[i11 >> 2] | 0) != 0) {
                    break L20;
                  }
                  HEAP32[i35 >> 2] = -1;
                  break L20;
                }
              } while (0);
              i35 = i20 + 24 | 0;
              i28 = HEAP32[i35 >> 2] | 0;
              if ((i28 | 0) >= 1) {
                i34 = HEAP32[i29 >> 2] | 0;
                if ((i28 | 0) == 2) {
                  i28 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i28 + 1 | 0;
                  i51 = i20 + 8 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i28 | 0] = i34 & 255;
                  i28 = (HEAP32[i29 >> 2] | 0) >>> 8 & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                  i28 = (HEAP32[i29 >> 2] | 0) >>> 16 & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                  i28 = (HEAP32[i29 >> 2] | 0) >>> 24 & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                  i28 = HEAP32[i27 >> 2] & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                  i28 = (HEAP32[i27 >> 2] | 0) >>> 8 & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                  i28 = (HEAP32[i27 >> 2] | 0) >>> 16 & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                  i28 = (HEAP32[i27 >> 2] | 0) >>> 24 & 255;
                  i40 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i40 + 1 | 0;
                  HEAP8[(HEAP32[i51 >> 2] | 0) + i40 | 0] = i28;
                } else {
                  i28 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i28 + 1 | 0;
                  i40 = i20 + 8 | 0;
                  HEAP8[(HEAP32[i40 >> 2] | 0) + i28 | 0] = i34 >>> 24 & 255;
                  i28 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i28 + 1 | 0;
                  HEAP8[(HEAP32[i40 >> 2] | 0) + i28 | 0] = i34 >>> 16 & 255;
                  i34 = HEAP32[i29 >> 2] | 0;
                  i28 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i28 + 1 | 0;
                  HEAP8[(HEAP32[i40 >> 2] | 0) + i28 | 0] = i34 >>> 8 & 255;
                  i28 = HEAP32[i41 >> 2] | 0;
                  HEAP32[i41 >> 2] = i28 + 1 | 0;
                  HEAP8[(HEAP32[i40 >> 2] | 0) + i28 | 0] = i34 & 255;
                }
                i34 = HEAP32[i18 >> 2] | 0;
                i28 = HEAP32[i34 + 20 >> 2] | 0;
                i40 = HEAP32[i11 >> 2] | 0;
                i51 = i28 >>> 0 > i40 >>> 0 ? i40 : i28;
                do {
                  if ((i51 | 0) != 0) {
                    _memcpy(HEAP32[i9 >> 2] | 0, HEAP32[i34 + 16 >> 2] | 0, i51);
                    HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + i51 | 0;
                    i28 = (HEAP32[i18 >> 2] | 0) + 16 | 0;
                    HEAP32[i28 >> 2] = (HEAP32[i28 >> 2] | 0) + i51 | 0;
                    HEAP32[i26 >> 2] = (HEAP32[i26 >> 2] | 0) + i51 | 0;
                    HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i51 | 0;
                    i28 = (HEAP32[i18 >> 2] | 0) + 20 | 0;
                    HEAP32[i28 >> 2] = (HEAP32[i28 >> 2] | 0) - i51 | 0;
                    i28 = HEAP32[i18 >> 2] | 0;
                    if ((HEAP32[i28 + 20 >> 2] | 0) != 0) {
                      break;
                    }
                    HEAP32[i28 + 16 >> 2] = HEAP32[i28 + 8 >> 2] | 0;
                  }
                } while (0);
                i51 = HEAP32[i35 >> 2] | 0;
                if ((i51 | 0) > 0) {
                  HEAP32[i35 >> 2] = -i51 | 0;
                }
                if ((HEAP32[i41 >> 2] | 0) != 0) {
                  break;
                }
              }
              i51 = HEAP32[i26 >> 2] | 0;
              i34 = HEAP32[i18 >> 2] | 0;
              if ((i34 | 0) == 0) {
                i17 = i51;
                break L7;
              }
              i28 = HEAP32[i34 + 4 >> 2] | 0;
              if (!((i28 | 0) == 666 | (i28 | 0) == 113 | (i28 | 0) == 103 | (i28 | 0) == 91 | (i28 | 0) == 73 | (i28 | 0) == 69 | (i28 | 0) == 42)) {
                i17 = i51;
                break L7;
              }
              i28 = HEAP32[i34 + 8 >> 2] | 0;
              if ((i28 | 0) == 0) {
                i101 = i34;
              } else {
                FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i28);
                i101 = HEAP32[i18 >> 2] | 0;
              }
              i28 = HEAP32[i101 + 68 >> 2] | 0;
              if ((i28 | 0) == 0) {
                i102 = i101;
              } else {
                FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i28);
                i102 = HEAP32[i18 >> 2] | 0;
              }
              i28 = HEAP32[i102 + 64 >> 2] | 0;
              if ((i28 | 0) == 0) {
                i103 = i102;
              } else {
                FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i28);
                i103 = HEAP32[i18 >> 2] | 0;
              }
              i28 = HEAP32[i103 + 56 >> 2] | 0;
              if ((i28 | 0) == 0) {
                i104 = i103;
              } else {
                FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i28);
                i104 = HEAP32[i18 >> 2] | 0;
              }
              FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i104);
              HEAP32[i18 >> 2] = 0;
              i17 = i51;
              break L7;
            }
          } while (0);
          if ((i32 | 0) == 30) {
            HEAP32[i15 >> 2] = 5255636;
          }
          i26 = HEAP32[i18 >> 2] | 0;
          if ((i26 | 0) == 0) {
            i17 = i7;
            break L7;
          }
          i29 = HEAP32[i26 + 4 >> 2] | 0;
          if (!((i29 | 0) == 666 | (i29 | 0) == 113 | (i29 | 0) == 103 | (i29 | 0) == 91 | (i29 | 0) == 73 | (i29 | 0) == 69 | (i29 | 0) == 42)) {
            i17 = i7;
            break L7;
          }
          i29 = HEAP32[i26 + 8 >> 2] | 0;
          if ((i29 | 0) == 0) {
            i105 = i26;
          } else {
            FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i29);
            i105 = HEAP32[i18 >> 2] | 0;
          }
          i29 = HEAP32[i105 + 68 >> 2] | 0;
          if ((i29 | 0) == 0) {
            i106 = i105;
          } else {
            FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i29);
            i106 = HEAP32[i18 >> 2] | 0;
          }
          i29 = HEAP32[i106 + 64 >> 2] | 0;
          if ((i29 | 0) == 0) {
            i107 = i106;
          } else {
            FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i29);
            i107 = HEAP32[i18 >> 2] | 0;
          }
          i29 = HEAP32[i107 + 56 >> 2] | 0;
          if ((i29 | 0) == 0) {
            i108 = i107;
          } else {
            FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i29);
            i108 = HEAP32[i18 >> 2] | 0;
          }
          FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i108);
          HEAP32[i18 >> 2] = 0;
          i17 = i7;
          break L7;
        }
      } while (0);
      HEAP32[i16 + 4 >> 2] = 666;
      HEAP32[i15 >> 2] = 5255616;
      i25 = HEAP32[i18 >> 2] | 0;
      if ((i25 | 0) == 0) {
        i17 = i7;
        break;
      }
      i22 = HEAP32[i25 + 4 >> 2] | 0;
      if (!((i22 | 0) == 666 | (i22 | 0) == 113 | (i22 | 0) == 103 | (i22 | 0) == 91 | (i22 | 0) == 73 | (i22 | 0) == 69 | (i22 | 0) == 42)) {
        i17 = i7;
        break;
      }
      i22 = HEAP32[i25 + 8 >> 2] | 0;
      if ((i22 | 0) == 0) {
        i109 = i25;
      } else {
        FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i22);
        i109 = HEAP32[i18 >> 2] | 0;
      }
      i22 = HEAP32[i109 + 68 >> 2] | 0;
      if ((i22 | 0) == 0) {
        i110 = i109;
      } else {
        FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i22);
        i110 = HEAP32[i18 >> 2] | 0;
      }
      i22 = HEAP32[i110 + 64 >> 2] | 0;
      if ((i22 | 0) == 0) {
        i111 = i110;
      } else {
        FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i22);
        i111 = HEAP32[i18 >> 2] | 0;
      }
      i22 = HEAP32[i111 + 56 >> 2] | 0;
      if ((i22 | 0) == 0) {
        i112 = i111;
      } else {
        FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i22);
        i112 = HEAP32[i18 >> 2] | 0;
      }
      FUNCTION_TABLE_vii[HEAP32[i13 >> 2] & 15](HEAP32[i14 >> 2] | 0, i112);
      HEAP32[i18 >> 2] = 0;
      i17 = i7;
    }
  } while (0);
  i7 = (i3 | 0) == 0;
  if (i7) {
    _printf(5255740, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = i2, HEAP32[tempInt + 4 >> 2] = i17, tempInt) | 0) | 0;
  }
  i3 = HEAP32[1311756] | 0;
  i112 = HEAP32[1311757] | 0;
  i14 = _zcalloc(0, 1, 7116) | 0;
  L332 : do {
    if ((i14 | 0) != 0) {
      HEAP32[i14 + 52 >> 2] = 0;
      i13 = i14 + 52 | 0;
      i111 = i13;
      i110 = i14 + 36 | 0;
      i109 = i14 + 8 | 0;
      HEAP32[i109 >> 2] = 1;
      HEAP32[i110 >> 2] = 15;
      i15 = i14 + 28 | 0;
      HEAP32[i15 >> 2] = 0;
      i16 = i14;
      HEAP32[i16 >> 2] = 0;
      i108 = i14 + 4 | 0;
      HEAP32[i108 >> 2] = 0;
      i107 = i14 + 12 | 0;
      HEAP32[i107 >> 2] = 0;
      i106 = i14 + 20 | 0;
      HEAP32[i106 >> 2] = 32768;
      HEAP32[i14 + 32 >> 2] = 0;
      i105 = i14 + 40 | 0;
      HEAP32[i105 >> 2] = 0;
      i104 = i14 + 44 | 0;
      HEAP32[i104 >> 2] = 0;
      i103 = i14 + 48 | 0;
      HEAP32[i103 >> 2] = 0;
      i102 = i14 + 56 | 0;
      HEAP32[i102 >> 2] = 0;
      i101 = i14 + 60 | 0;
      HEAP32[i101 >> 2] = 0;
      i11 = i14 + 1328 | 0;
      HEAP32[i14 + 108 >> 2] = i11;
      i9 = i14 + 80 | 0;
      HEAP32[i9 >> 2] = i11;
      i100 = i14 + 76 | 0;
      HEAP32[i100 >> 2] = i11;
      i99 = i14 + 7104 | 0;
      HEAP32[i99 >> 2] = 1;
      i88 = i14 + 7108 | 0;
      HEAP32[i88 >> 2] = -1;
      i98 = i5 | 0;
      L334 : do {
        if ((i3 | 0) != 0) {
          if (!((i112 | 0) != 0 | (i17 | 0) == 0)) {
            break;
          }
          i93 = i14 + 24 | 0;
          i94 = i5 + 1 | 0;
          i92 = i14 + 16 | 0;
          i90 = i14 + 32 | 0;
          i89 = i14 + 64 | 0;
          i91 = i14 + 84 | 0;
          i87 = i14 + 88 | 0;
          i83 = i14 + 76 | 0;
          i81 = i14 + 72 | 0;
          i8 = i14 + 7112 | 0;
          i82 = i14 + 68 | 0;
          i76 = i14 + 96 | 0;
          i75 = i14 + 100 | 0;
          i70 = i14 + 92 | 0;
          i77 = i14 + 104 | 0;
          i78 = i14 + 108 | 0;
          i79 = i78;
          i80 = i78;
          i78 = i14 + 112 | 0;
          i69 = i78;
          i71 = i14 + 752 | 0;
          i72 = i78;
          i78 = i14 + 624 | 0;
          i73 = i14 + 80 | 0;
          i74 = i5 + 2 | 0;
          i49 = i5 + 3 | 0;
          i48 = 0;
          i68 = i2;
          i47 = 0;
          i66 = 0;
          i67 = i2;
          i61 = i17;
          i62 = i3;
          i63 = i112;
          i64 = 0;
          i65 = i17;
          i43 = 0;
          L337 : while (1) {
            L339 : do {
              if ((i64 | 0) == 27) {
                i113 = i68;
                i114 = i47;
                i115 = i66;
                i116 = i61;
                i117 = i63;
                i118 = i43;
                i119 = HEAP32[i109 >> 2] | 0;
                i32 = 571;
                break;
              } else if ((i64 | 0) == 6) {
                i120 = i47;
                i121 = i66;
                i122 = i61;
                i123 = i63;
                i124 = HEAP32[i92 >> 2] | 0;
                i32 = 318;
                break;
              } else if ((i64 | 0) == 21) {
                i125 = i48;
                i126 = i47;
                i127 = i66;
                i128 = i61;
                i129 = i63;
                i130 = HEAP32[i81 >> 2] | 0;
                i32 = 515;
                break;
              } else if ((i64 | 0) == 23) {
                i131 = i48;
                i132 = i47;
                i133 = i66;
                i134 = i61;
                i135 = i63;
                i136 = HEAP32[i81 >> 2] | 0;
                i32 = 534;
                break;
              } else if ((i64 | 0) == 18) {
                i137 = i48;
                i138 = i47;
                i139 = i66;
                i140 = i61;
                i141 = i63;
                i142 = HEAP32[i77 >> 2] | 0;
                i32 = 396;
                break;
              } else if ((i64 | 0) == 1) {
                L346 : do {
                  if (i47 >>> 0 < 16) {
                    i46 = i63;
                    i45 = i61;
                    i44 = i66;
                    i37 = i47;
                    while (1) {
                      if ((i45 | 0) == 0) {
                        i143 = i48;
                        i144 = i68;
                        i145 = i37;
                        i146 = i44;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i6 = i45 - 1 | 0;
                      i10 = i46 + 1 | 0;
                      i31 = ((HEAPU8[i46] | 0) << i37) + i44 | 0;
                      i12 = i37 + 8 | 0;
                      if (i12 >>> 0 < 16) {
                        i46 = i10;
                        i45 = i6;
                        i44 = i31;
                        i37 = i12;
                      } else {
                        i149 = i10;
                        i150 = i6;
                        i151 = i31;
                        i152 = i12;
                        break L346;
                      }
                    }
                  } else {
                    i149 = i63;
                    i150 = i61;
                    i151 = i66;
                    i152 = i47;
                  }
                } while (0);
                HEAP32[i92 >> 2] = i151;
                if ((i151 & 255 | 0) != 8) {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i48;
                  i154 = i68;
                  i155 = i152;
                  i156 = i151;
                  i157 = i67;
                  i158 = i150;
                  i159 = i62;
                  i160 = i149;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                if ((i151 & 57344 | 0) != 0) {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i48;
                  i154 = i68;
                  i155 = i152;
                  i156 = i151;
                  i157 = i67;
                  i158 = i150;
                  i159 = i62;
                  i160 = i149;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                i37 = HEAP32[i90 >> 2] | 0;
                if ((i37 | 0) == 0) {
                  i163 = i151;
                } else {
                  HEAP32[i37 >> 2] = i151 >>> 8 & 1;
                  i163 = HEAP32[i92 >> 2] | 0;
                }
                if ((i163 & 512 | 0) != 0) {
                  HEAP8[i98] = i151 & 255;
                  HEAP8[i94] = i151 >>> 8 & 255;
                  HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i98, 2) | 0;
                }
                HEAP32[i16 >> 2] = 2;
                i164 = i149;
                i165 = i150;
                i166 = 0;
                i167 = 0;
                i32 = 282;
                break;
              } else if ((i64 | 0) == 9) {
                L364 : do {
                  if (i47 >>> 0 < 32) {
                    i37 = i63;
                    i44 = i61;
                    i45 = i66;
                    i46 = i47;
                    while (1) {
                      if ((i44 | 0) == 0) {
                        i143 = i48;
                        i144 = i68;
                        i145 = i46;
                        i146 = i45;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i12 = i44 - 1 | 0;
                      i31 = i37 + 1 | 0;
                      i6 = ((HEAPU8[i37] | 0) << i46) + i45 | 0;
                      i10 = i46 + 8 | 0;
                      if (i10 >>> 0 < 32) {
                        i37 = i31;
                        i44 = i12;
                        i45 = i6;
                        i46 = i10;
                      } else {
                        i168 = i31;
                        i169 = i12;
                        i170 = i6;
                        break L364;
                      }
                    }
                  } else {
                    i168 = i63;
                    i169 = i61;
                    i170 = i66;
                  }
                } while (0);
                HEAP32[i93 >> 2] = _llvm_bswap_i32(i170 | 0) | 0;
                HEAP32[i16 >> 2] = 10;
                i171 = 0;
                i172 = 0;
                i173 = i169;
                i174 = i168;
                i32 = 356;
                break;
              } else if ((i64 | 0) == 16) {
                L370 : do {
                  if (i47 >>> 0 < 14) {
                    i46 = i63;
                    i45 = i61;
                    i44 = i66;
                    i37 = i47;
                    while (1) {
                      if ((i45 | 0) == 0) {
                        i143 = i48;
                        i144 = i68;
                        i145 = i37;
                        i146 = i44;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i6 = i45 - 1 | 0;
                      i12 = i46 + 1 | 0;
                      i31 = ((HEAPU8[i46] | 0) << i37) + i44 | 0;
                      i10 = i37 + 8 | 0;
                      if (i10 >>> 0 < 14) {
                        i46 = i12;
                        i45 = i6;
                        i44 = i31;
                        i37 = i10;
                      } else {
                        i175 = i12;
                        i176 = i6;
                        i177 = i31;
                        i178 = i10;
                        break L370;
                      }
                    }
                  } else {
                    i175 = i63;
                    i176 = i61;
                    i177 = i66;
                    i178 = i47;
                  }
                } while (0);
                i37 = (i177 & 31) + 257 | 0;
                HEAP32[i76 >> 2] = i37;
                i44 = (i177 >>> 5 & 31) + 1 | 0;
                HEAP32[i75 >> 2] = i44;
                HEAP32[i70 >> 2] = (i177 >>> 10 & 15) + 4 | 0;
                i45 = i177 >>> 14;
                i46 = i178 - 14 | 0;
                if (i37 >>> 0 > 286 | i44 >>> 0 > 30) {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i48;
                  i154 = i68;
                  i155 = i46;
                  i156 = i45;
                  i157 = i67;
                  i158 = i176;
                  i159 = i62;
                  i160 = i175;
                  i161 = i65;
                  i162 = i43;
                  break;
                } else {
                  HEAP32[i77 >> 2] = 0;
                  HEAP32[i16 >> 2] = 17;
                  i179 = i175;
                  i180 = i176;
                  i181 = i45;
                  i182 = i46;
                  i183 = 0;
                  i32 = 387;
                  break;
                }
              } else if ((i64 | 0) == 0) {
                i46 = HEAP32[i109 >> 2] | 0;
                if ((i46 | 0) == 0) {
                  HEAP32[i16 >> 2] = 12;
                  i153 = i48;
                  i154 = i68;
                  i155 = i47;
                  i156 = i66;
                  i157 = i67;
                  i158 = i61;
                  i159 = i62;
                  i160 = i63;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                L382 : do {
                  if (i47 >>> 0 < 16) {
                    i45 = i63;
                    i44 = i61;
                    i37 = i66;
                    i10 = i47;
                    while (1) {
                      if ((i44 | 0) == 0) {
                        i143 = i48;
                        i144 = i68;
                        i145 = i10;
                        i146 = i37;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i31 = i44 - 1 | 0;
                      i6 = i45 + 1 | 0;
                      i12 = ((HEAPU8[i45] | 0) << i10) + i37 | 0;
                      i22 = i10 + 8 | 0;
                      if (i22 >>> 0 < 16) {
                        i45 = i6;
                        i44 = i31;
                        i37 = i12;
                        i10 = i22;
                      } else {
                        i184 = i6;
                        i185 = i31;
                        i186 = i12;
                        i187 = i22;
                        break L382;
                      }
                    }
                  } else {
                    i184 = i63;
                    i185 = i61;
                    i186 = i66;
                    i187 = i47;
                  }
                } while (0);
                if ((i46 & 2 | 0) != 0 & (i186 | 0) == 35615) {
                  HEAP32[i93 >> 2] = 0;
                  HEAP8[i98] = 31;
                  HEAP8[i94] = -117;
                  HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i98, 2) | 0;
                  HEAP32[i16 >> 2] = 1;
                  i153 = i48;
                  i154 = i68;
                  i155 = 0;
                  i156 = 0;
                  i157 = i67;
                  i158 = i185;
                  i159 = i62;
                  i160 = i184;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                HEAP32[i92 >> 2] = 0;
                i10 = HEAP32[i90 >> 2] | 0;
                if ((i10 | 0) == 0) {
                  i188 = i46;
                } else {
                  HEAP32[i10 + 48 >> 2] = -1;
                  i188 = HEAP32[i109 >> 2] | 0;
                }
                do {
                  if ((i188 & 1 | 0) != 0) {
                    if (((((i186 << 8 & 65280) + (i186 >>> 8) | 0) >>> 0) % 31 | 0) != 0) {
                      break;
                    }
                    if ((i186 & 15 | 0) != 8) {
                      HEAP32[i16 >> 2] = 29;
                      i153 = i48;
                      i154 = i68;
                      i155 = i187;
                      i156 = i186;
                      i157 = i67;
                      i158 = i185;
                      i159 = i62;
                      i160 = i184;
                      i161 = i65;
                      i162 = i43;
                      break L339;
                    }
                    i10 = i186 >>> 4;
                    i37 = i187 - 4 | 0;
                    i44 = (i10 & 15) + 8 | 0;
                    i45 = HEAP32[i110 >> 2] | 0;
                    do {
                      if ((i45 | 0) == 0) {
                        HEAP32[i110 >> 2] = i44;
                      } else {
                        if (i44 >>> 0 <= i45 >>> 0) {
                          break;
                        }
                        HEAP32[i16 >> 2] = 29;
                        i153 = i48;
                        i154 = i68;
                        i155 = i37;
                        i156 = i10;
                        i157 = i67;
                        i158 = i185;
                        i159 = i62;
                        i160 = i184;
                        i161 = i65;
                        i162 = i43;
                        break L339;
                      }
                    } while (0);
                    HEAP32[i106 >> 2] = 1 << i44;
                    HEAP32[i93 >> 2] = 1;
                    HEAP32[i16 >> 2] = i186 >>> 12 & 2 ^ 11;
                    i153 = i48;
                    i154 = i68;
                    i155 = 0;
                    i156 = 0;
                    i157 = i67;
                    i158 = i185;
                    i159 = i62;
                    i160 = i184;
                    i161 = i65;
                    i162 = i43;
                    break L339;
                  }
                } while (0);
                HEAP32[i16 >> 2] = 29;
                i153 = i48;
                i154 = i68;
                i155 = i187;
                i156 = i186;
                i157 = i67;
                i158 = i185;
                i159 = i62;
                i160 = i184;
                i161 = i65;
                i162 = i43;
                break;
              } else if ((i64 | 0) == 2) {
                if (i47 >>> 0 < 32) {
                  i164 = i63;
                  i165 = i61;
                  i166 = i66;
                  i167 = i47;
                  i32 = 282;
                  break;
                } else {
                  i189 = i63;
                  i190 = i61;
                  i191 = i66;
                  i32 = 284;
                  break;
                }
              } else if ((i64 | 0) == 3) {
                if (i47 >>> 0 < 16) {
                  i192 = i63;
                  i193 = i61;
                  i194 = i66;
                  i195 = i47;
                  i32 = 290;
                  break;
                } else {
                  i196 = i63;
                  i197 = i61;
                  i198 = i66;
                  i32 = 292;
                  break;
                }
              } else if ((i64 | 0) == 4) {
                i199 = i47;
                i200 = i66;
                i201 = i61;
                i202 = i63;
                i32 = 297;
              } else if ((i64 | 0) == 5) {
                i203 = i47;
                i204 = i66;
                i205 = i61;
                i206 = i63;
                i32 = 308;
              } else if ((i64 | 0) == 7) {
                i207 = i47;
                i208 = i66;
                i209 = i61;
                i210 = i63;
                i32 = 331;
              } else if ((i64 | 0) == 8) {
                i211 = i47;
                i212 = i66;
                i213 = i61;
                i214 = i63;
                i32 = 344;
              } else if ((i64 | 0) == 10) {
                i171 = i47;
                i172 = i66;
                i173 = i61;
                i174 = i63;
                i32 = 356;
              } else if ((i64 | 0) == 11 | (i64 | 0) == 12) {
                i215 = i47;
                i216 = i66;
                i217 = i61;
                i218 = i63;
                i32 = 359;
              } else if ((i64 | 0) == 13) {
                i46 = i47 & 7;
                i10 = i66 >>> (i46 >>> 0);
                i37 = i47 - i46 | 0;
                L408 : do {
                  if (i37 >>> 0 < 32) {
                    i46 = i63;
                    i45 = i61;
                    i22 = i10;
                    i12 = i37;
                    while (1) {
                      if ((i45 | 0) == 0) {
                        i143 = i48;
                        i144 = i68;
                        i145 = i12;
                        i146 = i22;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i31 = i45 - 1 | 0;
                      i6 = i46 + 1 | 0;
                      i25 = ((HEAPU8[i46] | 0) << i12) + i22 | 0;
                      i24 = i12 + 8 | 0;
                      if (i24 >>> 0 < 32) {
                        i46 = i6;
                        i45 = i31;
                        i22 = i25;
                        i12 = i24;
                      } else {
                        i219 = i6;
                        i220 = i31;
                        i221 = i25;
                        i222 = i24;
                        break L408;
                      }
                    }
                  } else {
                    i219 = i63;
                    i220 = i61;
                    i221 = i10;
                    i222 = i37;
                  }
                } while (0);
                i37 = i221 & 65535;
                if ((i37 | 0) == (i221 >>> 16 ^ 65535 | 0)) {
                  HEAP32[i89 >> 2] = i37;
                  HEAP32[i16 >> 2] = 14;
                  i223 = 0;
                  i224 = 0;
                  i225 = i220;
                  i226 = i219;
                  i32 = 376;
                  break;
                } else {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i48;
                  i154 = i68;
                  i155 = i222;
                  i156 = i221;
                  i157 = i67;
                  i158 = i220;
                  i159 = i62;
                  i160 = i219;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
              } else if ((i64 | 0) == 14) {
                i223 = i47;
                i224 = i66;
                i225 = i61;
                i226 = i63;
                i32 = 376;
              } else if ((i64 | 0) == 15) {
                i227 = i47;
                i228 = i66;
                i229 = i61;
                i230 = i63;
                i32 = 377;
              } else if ((i64 | 0) == 17) {
                i37 = HEAP32[i77 >> 2] | 0;
                if (i37 >>> 0 < (HEAP32[i70 >> 2] | 0) >>> 0) {
                  i179 = i63;
                  i180 = i61;
                  i181 = i66;
                  i182 = i47;
                  i183 = i37;
                  i32 = 387;
                  break;
                } else {
                  i231 = i63;
                  i232 = i61;
                  i233 = i66;
                  i234 = i47;
                  i235 = i37;
                  i32 = 391;
                  break;
                }
              } else if ((i64 | 0) == 19) {
                i236 = i48;
                i237 = i47;
                i238 = i66;
                i239 = i61;
                i240 = i63;
                i32 = 433;
              } else if ((i64 | 0) == 20) {
                i241 = i48;
                i242 = i47;
                i243 = i66;
                i244 = i61;
                i245 = i63;
                i32 = 434;
              } else if ((i64 | 0) == 22) {
                i246 = i48;
                i247 = i47;
                i248 = i66;
                i249 = i61;
                i250 = i63;
                i32 = 522;
              } else if ((i64 | 0) == 24) {
                i251 = i48;
                i252 = i47;
                i253 = i66;
                i254 = i61;
                i255 = i63;
                i32 = 540;
              } else if ((i64 | 0) == 25) {
                if ((i67 | 0) == 0) {
                  i143 = i48;
                  i144 = i68;
                  i145 = i47;
                  i146 = i66;
                  i147 = 0;
                  i148 = i43;
                  break L337;
                }
                HEAP8[i62] = HEAP32[i89 >> 2] & 255;
                HEAP32[i16 >> 2] = 20;
                i153 = i48;
                i154 = i68;
                i155 = i47;
                i156 = i66;
                i157 = i67 - 1 | 0;
                i158 = i61;
                i159 = i62 + 1 | 0;
                i160 = i63;
                i161 = i65;
                i162 = i43;
                break;
              } else if ((i64 | 0) == 26) {
                i37 = HEAP32[i109 >> 2] | 0;
                do {
                  if ((i37 | 0) == 0) {
                    i256 = i68;
                    i257 = i47;
                    i258 = i66;
                    i259 = i61;
                    i260 = i63;
                    i261 = i43;
                  } else {
                    L422 : do {
                      if (i47 >>> 0 < 32) {
                        i10 = i63;
                        i12 = i61;
                        i22 = i66;
                        i45 = i47;
                        while (1) {
                          if ((i12 | 0) == 0) {
                            i143 = i48;
                            i144 = i68;
                            i145 = i45;
                            i146 = i22;
                            i147 = i67;
                            i148 = i43;
                            break L337;
                          }
                          i46 = i12 - 1 | 0;
                          i44 = i10 + 1 | 0;
                          i24 = ((HEAPU8[i10] | 0) << i45) + i22 | 0;
                          i25 = i45 + 8 | 0;
                          if (i25 >>> 0 < 32) {
                            i10 = i44;
                            i12 = i46;
                            i22 = i24;
                            i45 = i25;
                          } else {
                            i262 = i44;
                            i263 = i46;
                            i264 = i24;
                            i265 = i25;
                            break L422;
                          }
                        }
                      } else {
                        i262 = i63;
                        i263 = i61;
                        i264 = i66;
                        i265 = i47;
                      }
                    } while (0);
                    i45 = i68 - i67 | 0;
                    i22 = i43 + i45 | 0;
                    HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + i45 | 0;
                    i12 = HEAP32[i92 >> 2] | 0;
                    if ((i68 | 0) == (i67 | 0)) {
                      i266 = i12;
                    } else {
                      i10 = HEAP32[i93 >> 2] | 0;
                      i25 = i62 + (-i45 | 0) | 0;
                      if ((i12 | 0) == 0) {
                        i267 = _adler32(i10, i25, i45) | 0;
                      } else {
                        i267 = _crc32(i10, i25, i45) | 0;
                      }
                      HEAP32[i93 >> 2] = i267;
                      i266 = i12;
                    }
                    if ((i266 | 0) == 0) {
                      i268 = _llvm_bswap_i32(i264 | 0) | 0;
                    } else {
                      i268 = i264;
                    }
                    if ((i268 | 0) == (HEAP32[i93 >> 2] | 0)) {
                      i256 = i67;
                      i257 = 0;
                      i258 = 0;
                      i259 = i263;
                      i260 = i262;
                      i261 = i22;
                      break;
                    }
                    HEAP32[i16 >> 2] = 29;
                    i153 = i48;
                    i154 = i67;
                    i155 = i265;
                    i156 = i264;
                    i157 = i67;
                    i158 = i263;
                    i159 = i62;
                    i160 = i262;
                    i161 = i65;
                    i162 = i22;
                    break L339;
                  }
                } while (0);
                HEAP32[i16 >> 2] = 27;
                i113 = i256;
                i114 = i257;
                i115 = i258;
                i116 = i259;
                i117 = i260;
                i118 = i261;
                i119 = i37;
                i32 = 571;
                break;
              } else if ((i64 | 0) == 29) {
                i32 = 579;
                break L337;
              } else if ((i64 | 0) == 28) {
                i143 = 1;
                i144 = i68;
                i145 = i47;
                i146 = i66;
                i147 = i67;
                i148 = i43;
                break L337;
              } else {
                break L334;
              }
            } while (0);
            L439 : do {
              if ((i32 | 0) == 282) {
                while (1) {
                  i32 = 0;
                  if ((i165 | 0) == 0) {
                    i143 = i48;
                    i144 = i68;
                    i145 = i167;
                    i146 = i166;
                    i147 = i67;
                    i148 = i43;
                    break L337;
                  }
                  i41 = i165 - 1 | 0;
                  i35 = i164 + 1 | 0;
                  i22 = ((HEAPU8[i164] | 0) << i167) + i166 | 0;
                  i12 = i167 + 8 | 0;
                  if (i12 >>> 0 < 32) {
                    i164 = i35;
                    i165 = i41;
                    i166 = i22;
                    i167 = i12;
                    i32 = 282;
                  } else {
                    i189 = i35;
                    i190 = i41;
                    i191 = i22;
                    i32 = 284;
                    break L439;
                  }
                }
              } else if ((i32 | 0) == 356) {
                i32 = 0;
                if ((HEAP32[i107 >> 2] | 0) == 0) {
                  i32 = 357;
                  break L337;
                }
                HEAP32[i93 >> 2] = 1;
                HEAP32[i16 >> 2] = 11;
                i215 = i171;
                i216 = i172;
                i217 = i173;
                i218 = i174;
                i32 = 359;
                break;
              } else if ((i32 | 0) == 376) {
                i32 = 0;
                HEAP32[i16 >> 2] = 15;
                i227 = i223;
                i228 = i224;
                i229 = i225;
                i230 = i226;
                i32 = 377;
                break;
              } else if ((i32 | 0) == 387) {
                while (1) {
                  i32 = 0;
                  L448 : do {
                    if (i182 >>> 0 < 3) {
                      i37 = i179;
                      i22 = i180;
                      i41 = i181;
                      i35 = i182;
                      while (1) {
                        if ((i22 | 0) == 0) {
                          i143 = i48;
                          i144 = i68;
                          i145 = i35;
                          i146 = i41;
                          i147 = i67;
                          i148 = i43;
                          break L337;
                        }
                        i12 = i22 - 1 | 0;
                        i45 = i37 + 1 | 0;
                        i25 = ((HEAPU8[i37] | 0) << i35) + i41 | 0;
                        i10 = i35 + 8 | 0;
                        if (i10 >>> 0 < 3) {
                          i37 = i45;
                          i22 = i12;
                          i41 = i25;
                          i35 = i10;
                        } else {
                          i269 = i45;
                          i270 = i12;
                          i271 = i25;
                          i272 = i10;
                          break L448;
                        }
                      }
                    } else {
                      i269 = i179;
                      i270 = i180;
                      i271 = i181;
                      i272 = i182;
                    }
                  } while (0);
                  HEAP32[i77 >> 2] = i183 + 1 | 0;
                  HEAP16[i72 + ((HEAPU16[5244496 + (i183 << 1) >> 1] | 0) << 1) >> 1] = i271 & 7;
                  i35 = i271 >>> 3;
                  i41 = i272 - 3 | 0;
                  i22 = HEAP32[i77 >> 2] | 0;
                  if (i22 >>> 0 < (HEAP32[i70 >> 2] | 0) >>> 0) {
                    i179 = i269;
                    i180 = i270;
                    i181 = i35;
                    i182 = i41;
                    i183 = i22;
                    i32 = 387;
                  } else {
                    i231 = i269;
                    i232 = i270;
                    i233 = i35;
                    i234 = i41;
                    i235 = i22;
                    i32 = 391;
                    break L439;
                  }
                }
              } else if ((i32 | 0) == 571) {
                i32 = 0;
                if ((i119 | 0) == 0) {
                  i273 = i114;
                  i274 = i115;
                  i32 = 578;
                  break L337;
                }
                if ((HEAP32[i92 >> 2] | 0) == 0) {
                  i273 = i114;
                  i274 = i115;
                  i32 = 578;
                  break L337;
                }
                L456 : do {
                  if (i114 >>> 0 < 32) {
                    i22 = i117;
                    i41 = i116;
                    i35 = i115;
                    i37 = i114;
                    while (1) {
                      if ((i41 | 0) == 0) {
                        i143 = i48;
                        i144 = i113;
                        i145 = i37;
                        i146 = i35;
                        i147 = i67;
                        i148 = i118;
                        break L337;
                      }
                      i10 = i41 - 1 | 0;
                      i25 = i22 + 1 | 0;
                      i12 = ((HEAPU8[i22] | 0) << i37) + i35 | 0;
                      i45 = i37 + 8 | 0;
                      if (i45 >>> 0 < 32) {
                        i22 = i25;
                        i41 = i10;
                        i35 = i12;
                        i37 = i45;
                      } else {
                        i275 = i25;
                        i276 = i10;
                        i277 = i12;
                        i278 = i45;
                        break L456;
                      }
                    }
                  } else {
                    i275 = i117;
                    i276 = i116;
                    i277 = i115;
                    i278 = i114;
                  }
                } while (0);
                if ((i277 | 0) == (HEAP32[i15 >> 2] | 0)) {
                  i273 = 0;
                  i274 = 0;
                  i32 = 578;
                  break L337;
                }
                HEAP32[i16 >> 2] = 29;
                i153 = i48;
                i154 = i113;
                i155 = i278;
                i156 = i277;
                i157 = i67;
                i158 = i276;
                i159 = i62;
                i160 = i275;
                i161 = i65;
                i162 = i118;
                break;
              }
            } while (0);
            do {
              if ((i32 | 0) == 284) {
                i32 = 0;
                i37 = HEAP32[i90 >> 2] | 0;
                if ((i37 | 0) != 0) {
                  HEAP32[i37 + 4 >> 2] = i191;
                }
                if ((HEAP32[i92 >> 2] & 512 | 0) != 0) {
                  HEAP8[i98] = i191 & 255;
                  HEAP8[i94] = i191 >>> 8 & 255;
                  HEAP8[i74] = i191 >>> 16 & 255;
                  HEAP8[i49] = i191 >>> 24 & 255;
                  HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i98, 4) | 0;
                }
                HEAP32[i16 >> 2] = 3;
                i192 = i189;
                i193 = i190;
                i194 = 0;
                i195 = 0;
                i32 = 290;
                break;
              } else if ((i32 | 0) == 359) {
                i32 = 0;
                if ((HEAP32[i108 >> 2] | 0) != 0) {
                  i37 = i215 & 7;
                  HEAP32[i16 >> 2] = 26;
                  i153 = i48;
                  i154 = i68;
                  i155 = i215 - i37 | 0;
                  i156 = i216 >>> (i37 >>> 0);
                  i157 = i67;
                  i158 = i217;
                  i159 = i62;
                  i160 = i218;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                L474 : do {
                  if (i215 >>> 0 < 3) {
                    i37 = i218;
                    i35 = i217;
                    i41 = i216;
                    i22 = i215;
                    while (1) {
                      if ((i35 | 0) == 0) {
                        i143 = i48;
                        i144 = i68;
                        i145 = i22;
                        i146 = i41;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i45 = i35 - 1 | 0;
                      i12 = i37 + 1 | 0;
                      i10 = ((HEAPU8[i37] | 0) << i22) + i41 | 0;
                      i25 = i22 + 8 | 0;
                      if (i25 >>> 0 < 3) {
                        i37 = i12;
                        i35 = i45;
                        i41 = i10;
                        i22 = i25;
                      } else {
                        i279 = i12;
                        i280 = i45;
                        i281 = i10;
                        i282 = i25;
                        break L474;
                      }
                    }
                  } else {
                    i279 = i218;
                    i280 = i217;
                    i281 = i216;
                    i282 = i215;
                  }
                } while (0);
                HEAP32[i108 >> 2] = i281 & 1;
                i22 = i281 >>> 1 & 3;
                if ((i22 | 0) == 0) {
                  HEAP32[i16 >> 2] = 13;
                } else if ((i22 | 0) == 1) {
                  HEAP32[i100 >> 2] = 5244536;
                  HEAP32[i91 >> 2] = 9;
                  HEAP32[i9 >> 2] = 5246584;
                  HEAP32[i87 >> 2] = 5;
                  HEAP32[i16 >> 2] = 19;
                } else if ((i22 | 0) == 2) {
                  HEAP32[i16 >> 2] = 16;
                } else if ((i22 | 0) == 3) {
                  HEAP32[i16 >> 2] = 29;
                }
                i153 = i48;
                i154 = i68;
                i155 = i282 - 3 | 0;
                i156 = i281 >>> 3;
                i157 = i67;
                i158 = i280;
                i159 = i62;
                i160 = i279;
                i161 = i65;
                i162 = i43;
                break;
              } else if ((i32 | 0) == 377) {
                i32 = 0;
                i22 = HEAP32[i89 >> 2] | 0;
                if ((i22 | 0) == 0) {
                  HEAP32[i16 >> 2] = 11;
                  i153 = i48;
                  i154 = i68;
                  i155 = i227;
                  i156 = i228;
                  i157 = i67;
                  i158 = i229;
                  i159 = i62;
                  i160 = i230;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                i41 = i22 >>> 0 > i229 >>> 0 ? i229 : i22;
                i22 = i41 >>> 0 > i67 >>> 0 ? i67 : i41;
                if ((i22 | 0) == 0) {
                  i143 = i48;
                  i144 = i68;
                  i145 = i227;
                  i146 = i228;
                  i147 = i67;
                  i148 = i43;
                  break L337;
                }
                _memcpy(i62, i230, i22);
                HEAP32[i89 >> 2] = (HEAP32[i89 >> 2] | 0) - i22 | 0;
                i153 = i48;
                i154 = i68;
                i155 = i227;
                i156 = i228;
                i157 = i67 - i22 | 0;
                i158 = i229 - i22 | 0;
                i159 = i62 + i22 | 0;
                i160 = i230 + i22 | 0;
                i161 = i65;
                i162 = i43;
                break;
              } else if ((i32 | 0) == 391) {
                i32 = 0;
                L491 : do {
                  if (i235 >>> 0 < 19) {
                    i22 = i235;
                    while (1) {
                      HEAP32[i77 >> 2] = i22 + 1 | 0;
                      HEAP16[i72 + ((HEAPU16[5244496 + (i22 << 1) >> 1] | 0) << 1) >> 1] = 0;
                      i41 = HEAP32[i77 >> 2] | 0;
                      if (i41 >>> 0 < 19) {
                        i22 = i41;
                      } else {
                        break L491;
                      }
                    }
                  }
                } while (0);
                HEAP32[i80 >> 2] = i11;
                HEAP32[i100 >> 2] = i11;
                HEAP32[i91 >> 2] = 7;
                i22 = _inflate_table(0, i69, 19, i79, i91, i71) | 0;
                if ((i22 | 0) == 0) {
                  HEAP32[i77 >> 2] = 0;
                  HEAP32[i16 >> 2] = 18;
                  i137 = 0;
                  i138 = i234;
                  i139 = i233;
                  i140 = i232;
                  i141 = i231;
                  i142 = 0;
                  i32 = 396;
                  break;
                } else {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i22;
                  i154 = i68;
                  i155 = i234;
                  i156 = i233;
                  i157 = i67;
                  i158 = i232;
                  i159 = i62;
                  i160 = i231;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
              }
            } while (0);
            L498 : do {
              if ((i32 | 0) == 290) {
                while (1) {
                  i32 = 0;
                  if ((i193 | 0) == 0) {
                    i143 = i48;
                    i144 = i68;
                    i145 = i195;
                    i146 = i194;
                    i147 = i67;
                    i148 = i43;
                    break L337;
                  }
                  i22 = i193 - 1 | 0;
                  i41 = i192 + 1 | 0;
                  i35 = ((HEAPU8[i192] | 0) << i195) + i194 | 0;
                  i37 = i195 + 8 | 0;
                  if (i37 >>> 0 < 16) {
                    i192 = i41;
                    i193 = i22;
                    i194 = i35;
                    i195 = i37;
                    i32 = 290;
                  } else {
                    i196 = i41;
                    i197 = i22;
                    i198 = i35;
                    i32 = 292;
                    break L498;
                  }
                }
              } else if ((i32 | 0) == 396) {
                i32 = 0;
                i35 = HEAP32[i76 >> 2] | 0;
                i22 = HEAP32[i75 >> 2] | 0;
                do {
                  if (i142 >>> 0 < (i22 + i35 | 0) >>> 0) {
                    i41 = i141;
                    i37 = i140;
                    i25 = i139;
                    i10 = i138;
                    i45 = i142;
                    i12 = i35;
                    i24 = i22;
                    L504 : while (1) {
                      i46 = (1 << HEAP32[i91 >> 2]) - 1 | 0;
                      i44 = i46 & i25;
                      i31 = HEAP32[i83 >> 2] | 0;
                      i6 = HEAPU8[i31 + (i44 << 2) + 1 | 0] | 0;
                      L506 : do {
                        if (i6 >>> 0 > i10 >>> 0) {
                          i19 = i41;
                          i23 = i37;
                          i21 = i25;
                          i29 = i10;
                          while (1) {
                            if ((i23 | 0) == 0) {
                              i143 = i137;
                              i144 = i68;
                              i145 = i29;
                              i146 = i21;
                              i147 = i67;
                              i148 = i43;
                              break L337;
                            }
                            i26 = i23 - 1 | 0;
                            i20 = i19 + 1 | 0;
                            i27 = ((HEAPU8[i19] | 0) << i29) + i21 | 0;
                            i30 = i29 + 8 | 0;
                            i51 = i46 & i27;
                            i28 = HEAPU8[i31 + (i51 << 2) + 1 | 0] | 0;
                            if (i28 >>> 0 > i30 >>> 0) {
                              i19 = i20;
                              i23 = i26;
                              i21 = i27;
                              i29 = i30;
                            } else {
                              i283 = i20;
                              i284 = i26;
                              i285 = i27;
                              i286 = i30;
                              i287 = i51;
                              i288 = i28;
                              break L506;
                            }
                          }
                        } else {
                          i283 = i41;
                          i284 = i37;
                          i285 = i25;
                          i286 = i10;
                          i287 = i44;
                          i288 = i6;
                        }
                      } while (0);
                      i6 = HEAP16[i31 + (i287 << 2) + 2 >> 1] | 0;
                      L511 : do {
                        if ((i6 & 65535) < 16) {
                          L513 : do {
                            if (i286 >>> 0 < i288 >>> 0) {
                              i44 = i283;
                              i46 = i284;
                              i29 = i285;
                              i21 = i286;
                              while (1) {
                                if ((i46 | 0) == 0) {
                                  i143 = i137;
                                  i144 = i68;
                                  i145 = i21;
                                  i146 = i29;
                                  i147 = i67;
                                  i148 = i43;
                                  break L337;
                                }
                                i23 = i46 - 1 | 0;
                                i19 = i44 + 1 | 0;
                                i86 = ((HEAPU8[i44] | 0) << i21) + i29 | 0;
                                i59 = i21 + 8 | 0;
                                if (i59 >>> 0 < i288 >>> 0) {
                                  i44 = i19;
                                  i46 = i23;
                                  i29 = i86;
                                  i21 = i59;
                                } else {
                                  i289 = i19;
                                  i290 = i23;
                                  i291 = i86;
                                  i292 = i59;
                                  break L513;
                                }
                              }
                            } else {
                              i289 = i283;
                              i290 = i284;
                              i291 = i285;
                              i292 = i286;
                            }
                          } while (0);
                          HEAP32[i77 >> 2] = i45 + 1 | 0;
                          HEAP16[i72 + (i45 << 1) >> 1] = i6;
                          i293 = i292 - i288 | 0;
                          i294 = i291 >>> (i288 >>> 0);
                          i295 = i290;
                          i296 = i289;
                        } else {
                          if ((i6 << 16 >> 16 | 0) == 16) {
                            i21 = i288 + 2 | 0;
                            L527 : do {
                              if (i286 >>> 0 < i21 >>> 0) {
                                i29 = i283;
                                i46 = i284;
                                i44 = i285;
                                i59 = i286;
                                while (1) {
                                  if ((i46 | 0) == 0) {
                                    i143 = i137;
                                    i144 = i68;
                                    i145 = i59;
                                    i146 = i44;
                                    i147 = i67;
                                    i148 = i43;
                                    break L337;
                                  }
                                  i86 = i46 - 1 | 0;
                                  i23 = i29 + 1 | 0;
                                  i19 = ((HEAPU8[i29] | 0) << i59) + i44 | 0;
                                  i28 = i59 + 8 | 0;
                                  if (i28 >>> 0 < i21 >>> 0) {
                                    i29 = i23;
                                    i46 = i86;
                                    i44 = i19;
                                    i59 = i28;
                                  } else {
                                    i297 = i23;
                                    i298 = i86;
                                    i299 = i19;
                                    i300 = i28;
                                    break L527;
                                  }
                                }
                              } else {
                                i297 = i283;
                                i298 = i284;
                                i299 = i285;
                                i300 = i286;
                              }
                            } while (0);
                            i301 = i299 >>> (i288 >>> 0);
                            i302 = i300 - i288 | 0;
                            if ((i45 | 0) == 0) {
                              i32 = 413;
                              break L504;
                            }
                            i303 = HEAP16[i72 + (i45 - 1 << 1) >> 1] | 0;
                            i304 = (i301 & 3) + 3 | 0;
                            i305 = i302 - 2 | 0;
                            i306 = i301 >>> 2;
                            i307 = i298;
                            i308 = i297;
                          } else if ((i6 << 16 >> 16 | 0) == 17) {
                            i21 = i288 + 3 | 0;
                            L534 : do {
                              if (i286 >>> 0 < i21 >>> 0) {
                                i59 = i283;
                                i44 = i284;
                                i46 = i285;
                                i29 = i286;
                                while (1) {
                                  if ((i44 | 0) == 0) {
                                    i143 = i137;
                                    i144 = i68;
                                    i145 = i29;
                                    i146 = i46;
                                    i147 = i67;
                                    i148 = i43;
                                    break L337;
                                  }
                                  i28 = i44 - 1 | 0;
                                  i19 = i59 + 1 | 0;
                                  i86 = ((HEAPU8[i59] | 0) << i29) + i46 | 0;
                                  i23 = i29 + 8 | 0;
                                  if (i23 >>> 0 < i21 >>> 0) {
                                    i59 = i19;
                                    i44 = i28;
                                    i46 = i86;
                                    i29 = i23;
                                  } else {
                                    i309 = i19;
                                    i310 = i28;
                                    i311 = i86;
                                    i312 = i23;
                                    break L534;
                                  }
                                }
                              } else {
                                i309 = i283;
                                i310 = i284;
                                i311 = i285;
                                i312 = i286;
                              }
                            } while (0);
                            i21 = i311 >>> (i288 >>> 0);
                            i303 = 0;
                            i304 = (i21 & 7) + 3 | 0;
                            i305 = (-3 - i288 | 0) + i312 | 0;
                            i306 = i21 >>> 3;
                            i307 = i310;
                            i308 = i309;
                          } else {
                            i21 = i288 + 7 | 0;
                            L521 : do {
                              if (i286 >>> 0 < i21 >>> 0) {
                                i29 = i283;
                                i46 = i284;
                                i44 = i285;
                                i59 = i286;
                                while (1) {
                                  if ((i46 | 0) == 0) {
                                    i143 = i137;
                                    i144 = i68;
                                    i145 = i59;
                                    i146 = i44;
                                    i147 = i67;
                                    i148 = i43;
                                    break L337;
                                  }
                                  i23 = i46 - 1 | 0;
                                  i86 = i29 + 1 | 0;
                                  i28 = ((HEAPU8[i29] | 0) << i59) + i44 | 0;
                                  i19 = i59 + 8 | 0;
                                  if (i19 >>> 0 < i21 >>> 0) {
                                    i29 = i86;
                                    i46 = i23;
                                    i44 = i28;
                                    i59 = i19;
                                  } else {
                                    i313 = i86;
                                    i314 = i23;
                                    i315 = i28;
                                    i316 = i19;
                                    break L521;
                                  }
                                }
                              } else {
                                i313 = i283;
                                i314 = i284;
                                i315 = i285;
                                i316 = i286;
                              }
                            } while (0);
                            i21 = i315 >>> (i288 >>> 0);
                            i303 = 0;
                            i304 = (i21 & 127) + 11 | 0;
                            i305 = (-7 - i288 | 0) + i316 | 0;
                            i306 = i21 >>> 7;
                            i307 = i314;
                            i308 = i313;
                          }
                          if ((i45 + i304 | 0) >>> 0 > (i24 + i12 | 0) >>> 0) {
                            i32 = 422;
                            break L504;
                          } else {
                            i317 = i304;
                            i318 = i45;
                          }
                          while (1) {
                            i21 = i317 - 1 | 0;
                            HEAP32[i77 >> 2] = i318 + 1 | 0;
                            HEAP16[i72 + (i318 << 1) >> 1] = i303;
                            if ((i21 | 0) == 0) {
                              i293 = i305;
                              i294 = i306;
                              i295 = i307;
                              i296 = i308;
                              break L511;
                            }
                            i317 = i21;
                            i318 = HEAP32[i77 >> 2] | 0;
                          }
                        }
                      } while (0);
                      i6 = HEAP32[i77 >> 2] | 0;
                      i319 = HEAP32[i76 >> 2] | 0;
                      i31 = HEAP32[i75 >> 2] | 0;
                      if (i6 >>> 0 < (i31 + i319 | 0) >>> 0) {
                        i41 = i296;
                        i37 = i295;
                        i25 = i294;
                        i10 = i293;
                        i45 = i6;
                        i12 = i319;
                        i24 = i31;
                      } else {
                        i32 = 425;
                        break;
                      }
                    }
                    if ((i32 | 0) == 413) {
                      i32 = 0;
                      HEAP32[i16 >> 2] = 29;
                      i153 = i137;
                      i154 = i68;
                      i155 = i302;
                      i156 = i301;
                      i157 = i67;
                      i158 = i298;
                      i159 = i62;
                      i160 = i297;
                      i161 = i65;
                      i162 = i43;
                      break L498;
                    } else if ((i32 | 0) == 422) {
                      i32 = 0;
                      HEAP32[i16 >> 2] = 29;
                      i153 = i137;
                      i154 = i68;
                      i155 = i305;
                      i156 = i306;
                      i157 = i67;
                      i158 = i307;
                      i159 = i62;
                      i160 = i308;
                      i161 = i65;
                      i162 = i43;
                      break L498;
                    } else if ((i32 | 0) == 425) {
                      i32 = 0;
                      if ((HEAP32[i16 >> 2] | 0) == 29) {
                        i153 = i137;
                        i154 = i68;
                        i155 = i293;
                        i156 = i294;
                        i157 = i67;
                        i158 = i295;
                        i159 = i62;
                        i160 = i296;
                        i161 = i65;
                        i162 = i43;
                        break L498;
                      } else {
                        i320 = i319;
                        i321 = i293;
                        i322 = i294;
                        i323 = i295;
                        i324 = i296;
                        break;
                      }
                    }
                  } else {
                    i320 = i35;
                    i321 = i138;
                    i322 = i139;
                    i323 = i140;
                    i324 = i141;
                  }
                } while (0);
                if (HEAP16[i78 >> 1] << 16 >> 16 == 0) {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i137;
                  i154 = i68;
                  i155 = i321;
                  i156 = i322;
                  i157 = i67;
                  i158 = i323;
                  i159 = i62;
                  i160 = i324;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                HEAP32[i80 >> 2] = i11;
                HEAP32[i100 >> 2] = i11;
                HEAP32[i91 >> 2] = 9;
                i35 = _inflate_table(1, i69, i320, i79, i91, i71) | 0;
                if ((i35 | 0) != 0) {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i35;
                  i154 = i68;
                  i155 = i321;
                  i156 = i322;
                  i157 = i67;
                  i158 = i323;
                  i159 = i62;
                  i160 = i324;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                HEAP32[i9 >> 2] = HEAP32[i79 >> 2] | 0;
                HEAP32[i87 >> 2] = 6;
                i35 = _inflate_table(2, i69 + (HEAP32[i76 >> 2] << 1) | 0, HEAP32[i75 >> 2] | 0, i79, i87, i71) | 0;
                if ((i35 | 0) == 0) {
                  HEAP32[i16 >> 2] = 19;
                  i236 = 0;
                  i237 = i321;
                  i238 = i322;
                  i239 = i323;
                  i240 = i324;
                  i32 = 433;
                  break;
                } else {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i35;
                  i154 = i68;
                  i155 = i321;
                  i156 = i322;
                  i157 = i67;
                  i158 = i323;
                  i159 = i62;
                  i160 = i324;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
              }
            } while (0);
            do {
              if ((i32 | 0) == 292) {
                i32 = 0;
                i35 = HEAP32[i90 >> 2] | 0;
                if ((i35 | 0) != 0) {
                  HEAP32[i35 + 8 >> 2] = i198 & 255;
                  HEAP32[(HEAP32[i90 >> 2] | 0) + 12 >> 2] = i198 >>> 8;
                }
                if ((HEAP32[i92 >> 2] & 512 | 0) != 0) {
                  HEAP8[i98] = i198 & 255;
                  HEAP8[i94] = i198 >>> 8 & 255;
                  HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i98, 2) | 0;
                }
                HEAP32[i16 >> 2] = 4;
                i199 = 0;
                i200 = 0;
                i201 = i197;
                i202 = i196;
                i32 = 297;
                break;
              } else if ((i32 | 0) == 433) {
                i32 = 0;
                HEAP32[i16 >> 2] = 20;
                i241 = i236;
                i242 = i237;
                i243 = i238;
                i244 = i239;
                i245 = i240;
                i32 = 434;
                break;
              }
            } while (0);
            do {
              if ((i32 | 0) == 297) {
                i32 = 0;
                i35 = HEAP32[i92 >> 2] | 0;
                do {
                  if ((i35 & 1024 | 0) == 0) {
                    i22 = HEAP32[i90 >> 2] | 0;
                    if ((i22 | 0) == 0) {
                      i325 = i199;
                      i326 = i200;
                      i327 = i201;
                      i328 = i202;
                      break;
                    }
                    HEAP32[i22 + 16 >> 2] = 0;
                    i325 = i199;
                    i326 = i200;
                    i327 = i201;
                    i328 = i202;
                  } else {
                    L571 : do {
                      if (i199 >>> 0 < 16) {
                        i22 = i202;
                        i24 = i201;
                        i12 = i200;
                        i45 = i199;
                        while (1) {
                          if ((i24 | 0) == 0) {
                            i143 = i48;
                            i144 = i68;
                            i145 = i45;
                            i146 = i12;
                            i147 = i67;
                            i148 = i43;
                            break L337;
                          }
                          i10 = i24 - 1 | 0;
                          i25 = i22 + 1 | 0;
                          i37 = ((HEAPU8[i22] | 0) << i45) + i12 | 0;
                          i41 = i45 + 8 | 0;
                          if (i41 >>> 0 < 16) {
                            i22 = i25;
                            i24 = i10;
                            i12 = i37;
                            i45 = i41;
                          } else {
                            i329 = i25;
                            i330 = i10;
                            i331 = i37;
                            break L571;
                          }
                        }
                      } else {
                        i329 = i202;
                        i330 = i201;
                        i331 = i200;
                      }
                    } while (0);
                    HEAP32[i89 >> 2] = i331;
                    i45 = HEAP32[i90 >> 2] | 0;
                    if ((i45 | 0) == 0) {
                      i332 = i35;
                    } else {
                      HEAP32[i45 + 20 >> 2] = i331;
                      i332 = HEAP32[i92 >> 2] | 0;
                    }
                    if ((i332 & 512 | 0) == 0) {
                      i325 = 0;
                      i326 = 0;
                      i327 = i330;
                      i328 = i329;
                      break;
                    }
                    HEAP8[i98] = i331 & 255;
                    HEAP8[i94] = i331 >>> 8 & 255;
                    HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i98, 2) | 0;
                    i325 = 0;
                    i326 = 0;
                    i327 = i330;
                    i328 = i329;
                  }
                } while (0);
                HEAP32[i16 >> 2] = 5;
                i203 = i325;
                i204 = i326;
                i205 = i327;
                i206 = i328;
                i32 = 308;
                break;
              } else if ((i32 | 0) == 434) {
                i32 = 0;
                if (!(i244 >>> 0 > 5 & i67 >>> 0 > 257)) {
                  HEAP32[i88 >> 2] = 0;
                  i35 = (1 << HEAP32[i91 >> 2]) - 1 | 0;
                  i45 = i35 & i243;
                  i12 = HEAP32[i83 >> 2] | 0;
                  i24 = HEAP8[i12 + (i45 << 2) + 1 | 0] | 0;
                  i22 = i24 & 255;
                  L586 : do {
                    if (i22 >>> 0 > i242 >>> 0) {
                      i37 = i245;
                      i10 = i244;
                      i25 = i243;
                      i41 = i242;
                      while (1) {
                        if ((i10 | 0) == 0) {
                          i143 = i241;
                          i144 = i68;
                          i145 = i41;
                          i146 = i25;
                          i147 = i67;
                          i148 = i43;
                          break L337;
                        }
                        i31 = i10 - 1 | 0;
                        i6 = i37 + 1 | 0;
                        i21 = ((HEAPU8[i37] | 0) << i41) + i25 | 0;
                        i59 = i41 + 8 | 0;
                        i44 = i35 & i21;
                        i46 = HEAP8[i12 + (i44 << 2) + 1 | 0] | 0;
                        i29 = i46 & 255;
                        if (i29 >>> 0 > i59 >>> 0) {
                          i37 = i6;
                          i10 = i31;
                          i25 = i21;
                          i41 = i59;
                        } else {
                          i333 = i6;
                          i334 = i31;
                          i335 = i21;
                          i336 = i59;
                          i337 = i46;
                          i338 = i44;
                          i339 = i29;
                          break L586;
                        }
                      }
                    } else {
                      i333 = i245;
                      i334 = i244;
                      i335 = i243;
                      i336 = i242;
                      i337 = i24;
                      i338 = i45;
                      i339 = i22;
                    }
                  } while (0);
                  i22 = HEAP8[i12 + (i338 << 2) | 0] | 0;
                  i45 = HEAP16[i12 + (i338 << 2) + 2 >> 1] | 0;
                  i24 = i22 & 255;
                  do {
                    if (i22 << 24 >> 24 == 0) {
                      i340 = 0;
                      i341 = i337;
                      i342 = i45;
                      i343 = i336;
                      i344 = i335;
                      i345 = i334;
                      i346 = i333;
                      i347 = 0;
                    } else {
                      if ((i24 & 240 | 0) != 0) {
                        i340 = i22;
                        i341 = i337;
                        i342 = i45;
                        i343 = i336;
                        i344 = i335;
                        i345 = i334;
                        i346 = i333;
                        i347 = 0;
                        break;
                      }
                      i35 = i45 & 65535;
                      i41 = (1 << i339 + i24) - 1 | 0;
                      i25 = ((i335 & i41) >>> (i339 >>> 0)) + i35 | 0;
                      i10 = HEAP8[i12 + (i25 << 2) + 1 | 0] | 0;
                      L594 : do {
                        if (((i10 & 255) + i339 | 0) >>> 0 > i336 >>> 0) {
                          i37 = i333;
                          i29 = i334;
                          i44 = i335;
                          i46 = i336;
                          while (1) {
                            if ((i29 | 0) == 0) {
                              i143 = i241;
                              i144 = i68;
                              i145 = i46;
                              i146 = i44;
                              i147 = i67;
                              i148 = i43;
                              break L337;
                            }
                            i59 = i29 - 1 | 0;
                            i21 = i37 + 1 | 0;
                            i31 = ((HEAPU8[i37] | 0) << i46) + i44 | 0;
                            i6 = i46 + 8 | 0;
                            i19 = ((i31 & i41) >>> (i339 >>> 0)) + i35 | 0;
                            i28 = HEAP8[i12 + (i19 << 2) + 1 | 0] | 0;
                            if (((i28 & 255) + i339 | 0) >>> 0 > i6 >>> 0) {
                              i37 = i21;
                              i29 = i59;
                              i44 = i31;
                              i46 = i6;
                            } else {
                              i348 = i21;
                              i349 = i59;
                              i350 = i31;
                              i351 = i6;
                              i352 = i19;
                              i353 = i28;
                              break L594;
                            }
                          }
                        } else {
                          i348 = i333;
                          i349 = i334;
                          i350 = i335;
                          i351 = i336;
                          i352 = i25;
                          i353 = i10;
                        }
                      } while (0);
                      i10 = HEAP16[i12 + (i352 << 2) + 2 >> 1] | 0;
                      i25 = HEAP8[i12 + (i352 << 2) | 0] | 0;
                      HEAP32[i88 >> 2] = i339;
                      i340 = i25;
                      i341 = i353;
                      i342 = i10;
                      i343 = i351 - i339 | 0;
                      i344 = i350 >>> (i339 >>> 0);
                      i345 = i349;
                      i346 = i348;
                      i347 = i339;
                    }
                  } while (0);
                  i12 = i341 & 255;
                  i24 = i344 >>> (i12 >>> 0);
                  i45 = i343 - i12 | 0;
                  HEAP32[i88 >> 2] = i347 + i12 | 0;
                  HEAP32[i89 >> 2] = i342 & 65535;
                  i12 = i340 & 255;
                  if (i340 << 24 >> 24 == 0) {
                    HEAP32[i16 >> 2] = 25;
                    i153 = i241;
                    i154 = i68;
                    i155 = i45;
                    i156 = i24;
                    i157 = i67;
                    i158 = i345;
                    i159 = i62;
                    i160 = i346;
                    i161 = i65;
                    i162 = i43;
                    break;
                  }
                  if ((i12 & 32 | 0) != 0) {
                    HEAP32[i88 >> 2] = -1;
                    HEAP32[i16 >> 2] = 11;
                    i153 = i241;
                    i154 = i68;
                    i155 = i45;
                    i156 = i24;
                    i157 = i67;
                    i158 = i345;
                    i159 = i62;
                    i160 = i346;
                    i161 = i65;
                    i162 = i43;
                    break;
                  }
                  if ((i12 & 64 | 0) == 0) {
                    i22 = i12 & 15;
                    HEAP32[i81 >> 2] = i22;
                    HEAP32[i16 >> 2] = 21;
                    i125 = i241;
                    i126 = i45;
                    i127 = i24;
                    i128 = i345;
                    i129 = i346;
                    i130 = i22;
                    i32 = 515;
                    break;
                  } else {
                    HEAP32[i16 >> 2] = 29;
                    i153 = i241;
                    i154 = i68;
                    i155 = i45;
                    i156 = i24;
                    i157 = i67;
                    i158 = i345;
                    i159 = i62;
                    i160 = i346;
                    i161 = i65;
                    i162 = i43;
                    break;
                  }
                }
                HEAP32[i102 >> 2] = i243;
                HEAP32[i101 >> 2] = i242;
                i24 = i245 + (i244 - 6 | 0) | 0;
                i45 = i62 + (i67 - 258 | 0) | 0;
                i22 = HEAP32[i104 >> 2] | 0;
                i12 = HEAP32[i103 >> 2] | 0;
                i10 = HEAP32[i111 >> 2] | 0;
                i25 = HEAP32[i83 >> 2] | 0;
                i35 = HEAP32[i73 >> 2] | 0;
                i41 = (1 << HEAP32[i91 >> 2]) - 1 | 0;
                i46 = (1 << HEAP32[i87 >> 2]) - 1 | 0;
                i44 = i62 + (i67 + (i68 ^ -1) | 0) | 0;
                i29 = i10 - 1 | 0;
                i37 = (i12 | 0) == 0;
                i28 = (HEAP32[i105 >> 2] | 0) - 1 | 0;
                i19 = i28 + i12 | 0;
                i6 = i12 - 1 | 0;
                i31 = i44 - 1 | 0;
                i59 = i44 - i12 | 0;
                i21 = i245 - 1 | 0;
                i23 = i62 - 1 | 0;
                i86 = i243;
                i51 = i242;
                L610 : while (1) {
                  if (i51 >>> 0 < 15) {
                    i30 = i21 + 2 | 0;
                    i354 = i30;
                    i355 = (((HEAPU8[i21 + 1 | 0] | 0) << i51) + i86 | 0) + ((HEAPU8[i30] | 0) << i51 + 8) | 0;
                    i356 = i51 + 16 | 0;
                  } else {
                    i354 = i21;
                    i355 = i86;
                    i356 = i51;
                  }
                  i30 = i355 & i41;
                  i27 = HEAP8[i25 + (i30 << 2) | 0] | 0;
                  i26 = HEAP16[i25 + (i30 << 2) + 2 >> 1] | 0;
                  i20 = HEAPU8[i25 + (i30 << 2) + 1 | 0] | 0;
                  i30 = i355 >>> (i20 >>> 0);
                  i34 = i356 - i20 | 0;
                  L615 : do {
                    if (i27 << 24 >> 24 == 0) {
                      i357 = i26;
                      i358 = i30;
                      i359 = i34;
                      i32 = 439;
                    } else {
                      i20 = i26;
                      i360 = i30;
                      i361 = i34;
                      i40 = i27;
                      while (1) {
                        i362 = i40 & 255;
                        if ((i362 & 16 | 0) != 0) {
                          break;
                        }
                        if ((i362 & 64 | 0) != 0) {
                          i32 = 487;
                          break L610;
                        }
                        i38 = (i360 & (1 << i362) - 1) + (i20 & 65535) | 0;
                        i42 = HEAP8[i25 + (i38 << 2) | 0] | 0;
                        i52 = HEAP16[i25 + (i38 << 2) + 2 >> 1] | 0;
                        i33 = HEAPU8[i25 + (i38 << 2) + 1 | 0] | 0;
                        i38 = i360 >>> (i33 >>> 0);
                        i55 = i361 - i33 | 0;
                        if (i42 << 24 >> 24 == 0) {
                          i357 = i52;
                          i358 = i38;
                          i359 = i55;
                          i32 = 439;
                          break L615;
                        } else {
                          i20 = i52;
                          i360 = i38;
                          i361 = i55;
                          i40 = i42;
                        }
                      }
                      i40 = i20 & 65535;
                      i42 = i362 & 15;
                      if ((i42 | 0) == 0) {
                        i363 = i40;
                        i364 = i354;
                        i365 = i360;
                        i366 = i361;
                      } else {
                        if (i361 >>> 0 < i42 >>> 0) {
                          i55 = i354 + 1 | 0;
                          i367 = i55;
                          i368 = ((HEAPU8[i55] | 0) << i361) + i360 | 0;
                          i369 = i361 + 8 | 0;
                        } else {
                          i367 = i354;
                          i368 = i360;
                          i369 = i361;
                        }
                        i363 = (i368 & (1 << i42) - 1) + i40 | 0;
                        i364 = i367;
                        i365 = i368 >>> (i42 >>> 0);
                        i366 = i369 - i42 | 0;
                      }
                      if (i366 >>> 0 < 15) {
                        i42 = i364 + 2 | 0;
                        i370 = i42;
                        i371 = (((HEAPU8[i364 + 1 | 0] | 0) << i366) + i365 | 0) + ((HEAPU8[i42] | 0) << i366 + 8) | 0;
                        i372 = i366 + 16 | 0;
                      } else {
                        i370 = i364;
                        i371 = i365;
                        i372 = i366;
                      }
                      i42 = i371 & i46;
                      i40 = HEAP16[i35 + (i42 << 2) + 2 >> 1] | 0;
                      i55 = HEAPU8[i35 + (i42 << 2) + 1 | 0] | 0;
                      i38 = i371 >>> (i55 >>> 0);
                      i52 = i372 - i55 | 0;
                      i55 = HEAPU8[i35 + (i42 << 2) | 0] | 0;
                      L630 : do {
                        if ((i55 & 16 | 0) == 0) {
                          i42 = i40;
                          i373 = i38;
                          i374 = i52;
                          i33 = i55;
                          while (1) {
                            if ((i33 & 64 | 0) != 0) {
                              i32 = 484;
                              break L610;
                            }
                            i56 = (i373 & (1 << i33) - 1) + (i42 & 65535) | 0;
                            i54 = HEAP16[i35 + (i56 << 2) + 2 >> 1] | 0;
                            i53 = HEAPU8[i35 + (i56 << 2) + 1 | 0] | 0;
                            i50 = i373 >>> (i53 >>> 0);
                            i39 = i374 - i53 | 0;
                            i53 = HEAPU8[i35 + (i56 << 2) | 0] | 0;
                            if ((i53 & 16 | 0) == 0) {
                              i42 = i54;
                              i373 = i50;
                              i374 = i39;
                              i33 = i53;
                            } else {
                              i375 = i54;
                              i376 = i50;
                              i377 = i39;
                              i378 = i53;
                              break L630;
                            }
                          }
                        } else {
                          i375 = i40;
                          i376 = i38;
                          i377 = i52;
                          i378 = i55;
                        }
                      } while (0);
                      i55 = i375 & 65535;
                      i52 = i378 & 15;
                      do {
                        if (i377 >>> 0 < i52 >>> 0) {
                          i38 = i370 + 1 | 0;
                          i40 = ((HEAPU8[i38] | 0) << i377) + i376 | 0;
                          i20 = i377 + 8 | 0;
                          if (i20 >>> 0 >= i52 >>> 0) {
                            i379 = i38;
                            i380 = i40;
                            i381 = i20;
                            break;
                          }
                          i38 = i370 + 2 | 0;
                          i379 = i38;
                          i380 = ((HEAPU8[i38] | 0) << i20) + i40 | 0;
                          i381 = i377 + 16 | 0;
                        } else {
                          i379 = i370;
                          i380 = i376;
                          i381 = i377;
                        }
                      } while (0);
                      i40 = (i380 & (1 << i52) - 1) + i55 | 0;
                      i382 = i380 >>> (i52 >>> 0);
                      i383 = i381 - i52 | 0;
                      i20 = i23;
                      i38 = i20 - i44 | 0;
                      if (i40 >>> 0 <= i38 >>> 0) {
                        i33 = i23 + (-i40 | 0) | 0;
                        i42 = i363;
                        i53 = i23;
                        while (1) {
                          HEAP8[i53 + 1 | 0] = HEAP8[i33 + 1 | 0] | 0;
                          HEAP8[i53 + 2 | 0] = HEAP8[i33 + 2 | 0] | 0;
                          i39 = i33 + 3 | 0;
                          i384 = i53 + 3 | 0;
                          HEAP8[i384] = HEAP8[i39] | 0;
                          i385 = i42 - 3 | 0;
                          if (i385 >>> 0 > 2) {
                            i33 = i39;
                            i42 = i385;
                            i53 = i384;
                          } else {
                            break;
                          }
                        }
                        if ((i385 | 0) == 0) {
                          i386 = i379;
                          i387 = i384;
                          i388 = i382;
                          i389 = i383;
                          break;
                        }
                        i42 = i53 + 4 | 0;
                        HEAP8[i42] = HEAP8[i33 + 4 | 0] | 0;
                        if (i385 >>> 0 <= 1) {
                          i386 = i379;
                          i387 = i42;
                          i388 = i382;
                          i389 = i383;
                          break;
                        }
                        i42 = i53 + 5 | 0;
                        HEAP8[i42] = HEAP8[i33 + 5 | 0] | 0;
                        i386 = i379;
                        i387 = i42;
                        i388 = i382;
                        i389 = i383;
                        break;
                      }
                      i42 = i40 - i38 | 0;
                      if (i42 >>> 0 > i22 >>> 0) {
                        if ((HEAP32[i99 >> 2] | 0) != 0) {
                          i32 = 454;
                          break L610;
                        }
                      }
                      do {
                        if (i37) {
                          i52 = i10 + (i28 - i42 | 0) | 0;
                          if (i42 >>> 0 >= i363 >>> 0) {
                            i390 = i52;
                            i391 = i363;
                            i392 = i23;
                            break;
                          }
                          i55 = i363 - i42 | 0;
                          i39 = i40 - i20 | 0;
                          i50 = i52;
                          i52 = i42;
                          i54 = i23;
                          while (1) {
                            i56 = i50 + 1 | 0;
                            i36 = i54 + 1 | 0;
                            HEAP8[i36] = HEAP8[i56] | 0;
                            i60 = i52 - 1 | 0;
                            if ((i60 | 0) == 0) {
                              break;
                            } else {
                              i50 = i56;
                              i52 = i60;
                              i54 = i36;
                            }
                          }
                          i390 = i23 + ((i31 + i39 | 0) + (1 - i40 | 0) | 0) | 0;
                          i391 = i55;
                          i392 = i23 + (i44 + i39 | 0) | 0;
                        } else {
                          if (i12 >>> 0 >= i42 >>> 0) {
                            i54 = i10 + (i6 - i42 | 0) | 0;
                            if (i42 >>> 0 >= i363 >>> 0) {
                              i390 = i54;
                              i391 = i363;
                              i392 = i23;
                              break;
                            }
                            i52 = i363 - i42 | 0;
                            i50 = i40 - i20 | 0;
                            i36 = i54;
                            i54 = i42;
                            i60 = i23;
                            while (1) {
                              i56 = i36 + 1 | 0;
                              i57 = i60 + 1 | 0;
                              HEAP8[i57] = HEAP8[i56] | 0;
                              i97 = i54 - 1 | 0;
                              if ((i97 | 0) == 0) {
                                break;
                              } else {
                                i36 = i56;
                                i54 = i97;
                                i60 = i57;
                              }
                            }
                            i390 = i23 + ((i31 + i50 | 0) + (1 - i40 | 0) | 0) | 0;
                            i391 = i52;
                            i392 = i23 + (i44 + i50 | 0) | 0;
                            break;
                          }
                          i60 = i10 + (i19 - i42 | 0) | 0;
                          i54 = i42 - i12 | 0;
                          if (i54 >>> 0 >= i363 >>> 0) {
                            i390 = i60;
                            i391 = i363;
                            i392 = i23;
                            break;
                          }
                          i36 = i363 - i54 | 0;
                          i39 = i40 - i20 | 0;
                          i55 = i60;
                          i60 = i54;
                          i54 = i23;
                          while (1) {
                            i57 = i55 + 1 | 0;
                            i97 = i54 + 1 | 0;
                            HEAP8[i97] = HEAP8[i57] | 0;
                            i56 = i60 - 1 | 0;
                            if ((i56 | 0) == 0) {
                              break;
                            } else {
                              i55 = i57;
                              i60 = i56;
                              i54 = i97;
                            }
                          }
                          i54 = i23 + (i59 + i39 | 0) | 0;
                          if (i12 >>> 0 >= i36 >>> 0) {
                            i390 = i29;
                            i391 = i36;
                            i392 = i54;
                            break;
                          }
                          i60 = i36 - i12 | 0;
                          i55 = i29;
                          i50 = i12;
                          i52 = i54;
                          while (1) {
                            i54 = i55 + 1 | 0;
                            i97 = i52 + 1 | 0;
                            HEAP8[i97] = HEAP8[i54] | 0;
                            i56 = i50 - 1 | 0;
                            if ((i56 | 0) == 0) {
                              break;
                            } else {
                              i55 = i54;
                              i50 = i56;
                              i52 = i97;
                            }
                          }
                          i390 = i23 + ((i31 + i39 | 0) + (1 - i40 | 0) | 0) | 0;
                          i391 = i60;
                          i392 = i23 + (i44 + i39 | 0) | 0;
                        }
                      } while (0);
                      L673 : do {
                        if (i391 >>> 0 > 2) {
                          i40 = i392;
                          i20 = i391;
                          i42 = i390;
                          while (1) {
                            HEAP8[i40 + 1 | 0] = HEAP8[i42 + 1 | 0] | 0;
                            HEAP8[i40 + 2 | 0] = HEAP8[i42 + 2 | 0] | 0;
                            i38 = i42 + 3 | 0;
                            i33 = i40 + 3 | 0;
                            HEAP8[i33] = HEAP8[i38] | 0;
                            i53 = i20 - 3 | 0;
                            if (i53 >>> 0 > 2) {
                              i40 = i33;
                              i20 = i53;
                              i42 = i38;
                            } else {
                              i393 = i33;
                              i394 = i53;
                              i395 = i38;
                              break L673;
                            }
                          }
                        } else {
                          i393 = i392;
                          i394 = i391;
                          i395 = i390;
                        }
                      } while (0);
                      if ((i394 | 0) == 0) {
                        i386 = i379;
                        i387 = i393;
                        i388 = i382;
                        i389 = i383;
                        break;
                      }
                      i42 = i393 + 1 | 0;
                      HEAP8[i42] = HEAP8[i395 + 1 | 0] | 0;
                      if (i394 >>> 0 <= 1) {
                        i386 = i379;
                        i387 = i42;
                        i388 = i382;
                        i389 = i383;
                        break;
                      }
                      i42 = i393 + 2 | 0;
                      HEAP8[i42] = HEAP8[i395 + 2 | 0] | 0;
                      i386 = i379;
                      i387 = i42;
                      i388 = i382;
                      i389 = i383;
                      break;
                    }
                  } while (0);
                  if ((i32 | 0) == 439) {
                    i32 = 0;
                    i27 = i23 + 1 | 0;
                    HEAP8[i27] = i357 & 255;
                    i386 = i354;
                    i387 = i27;
                    i388 = i358;
                    i389 = i359;
                  }
                  if (i386 >>> 0 < i24 >>> 0 & i387 >>> 0 < i45 >>> 0) {
                    i21 = i386;
                    i23 = i387;
                    i86 = i388;
                    i51 = i389;
                  } else {
                    i396 = i386;
                    i397 = i387;
                    i398 = i388;
                    i399 = i389;
                    break;
                  }
                }
                do {
                  if ((i32 | 0) == 454) {
                    i32 = 0;
                    HEAP32[i16 >> 2] = 29;
                    i396 = i379;
                    i397 = i23;
                    i398 = i382;
                    i399 = i383;
                  } else if ((i32 | 0) == 484) {
                    i32 = 0;
                    HEAP32[i16 >> 2] = 29;
                    i396 = i370;
                    i397 = i23;
                    i398 = i373;
                    i399 = i374;
                  } else if ((i32 | 0) == 487) {
                    i32 = 0;
                    if ((i362 & 32 | 0) == 0) {
                      HEAP32[i16 >> 2] = 29;
                      i396 = i354;
                      i397 = i23;
                      i398 = i360;
                      i399 = i361;
                      break;
                    } else {
                      HEAP32[i16 >> 2] = 11;
                      i396 = i354;
                      i397 = i23;
                      i398 = i360;
                      i399 = i361;
                      break;
                    }
                  }
                } while (0);
                i23 = i399 >>> 3;
                i51 = i396 + (-i23 | 0) | 0;
                i86 = i399 - (i23 << 3) | 0;
                i21 = (1 << i86) - 1 & i398;
                i44 = i396 + (1 - i23 | 0) | 0;
                i23 = i397 + 1 | 0;
                if (i51 >>> 0 < i24 >>> 0) {
                  i400 = i24 - i51 | 0;
                } else {
                  i400 = i24 - i51 | 0;
                }
                i51 = i400 + 5 | 0;
                if (i397 >>> 0 < i45 >>> 0) {
                  i401 = i45 - i397 | 0;
                } else {
                  i401 = i45 - i397 | 0;
                }
                i31 = i401 + 257 | 0;
                HEAP32[i102 >> 2] = i21;
                HEAP32[i101 >> 2] = i86;
                if ((HEAP32[i16 >> 2] | 0) != 11) {
                  i153 = i241;
                  i154 = i68;
                  i155 = i86;
                  i156 = i21;
                  i157 = i31;
                  i158 = i51;
                  i159 = i23;
                  i160 = i44;
                  i161 = i51;
                  i162 = i43;
                  break;
                }
                HEAP32[i88 >> 2] = -1;
                i153 = i241;
                i154 = i68;
                i155 = i86;
                i156 = i21;
                i157 = i31;
                i158 = i51;
                i159 = i23;
                i160 = i44;
                i161 = i51;
                i162 = i43;
                break;
              }
            } while (0);
            do {
              if ((i32 | 0) == 308) {
                i32 = 0;
                i51 = HEAP32[i92 >> 2] | 0;
                if ((i51 & 1024 | 0) == 0) {
                  i402 = i205;
                  i403 = i206;
                  i404 = i51;
                } else {
                  i44 = HEAP32[i89 >> 2] | 0;
                  i23 = i44 >>> 0 > i205 >>> 0 ? i205 : i44;
                  if ((i23 | 0) == 0) {
                    i405 = i205;
                    i406 = i206;
                    i407 = i44;
                    i408 = i51;
                  } else {
                    i31 = HEAP32[i90 >> 2] | 0;
                    do {
                      if ((i31 | 0) == 0) {
                        i409 = i51;
                      } else {
                        i21 = HEAP32[i31 + 16 >> 2] | 0;
                        if ((i21 | 0) == 0) {
                          i409 = i51;
                          break;
                        }
                        i86 = (HEAP32[i31 + 20 >> 2] | 0) - i44 | 0;
                        i12 = HEAP32[i31 + 24 >> 2] | 0;
                        _memcpy(i21 + i86 | 0, i206, (i86 + i23 | 0) >>> 0 > i12 >>> 0 ? i12 - i86 | 0 : i23);
                        i409 = HEAP32[i92 >> 2] | 0;
                      }
                    } while (0);
                    if ((i409 & 512 | 0) != 0) {
                      HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i206, i23) | 0;
                    }
                    i31 = (HEAP32[i89 >> 2] | 0) - i23 | 0;
                    HEAP32[i89 >> 2] = i31;
                    i405 = i205 - i23 | 0;
                    i406 = i206 + i23 | 0;
                    i407 = i31;
                    i408 = i409;
                  }
                  if ((i407 | 0) == 0) {
                    i402 = i405;
                    i403 = i406;
                    i404 = i408;
                  } else {
                    i143 = i48;
                    i144 = i68;
                    i145 = i203;
                    i146 = i204;
                    i147 = i67;
                    i148 = i43;
                    break L337;
                  }
                }
                HEAP32[i89 >> 2] = 0;
                HEAP32[i16 >> 2] = 6;
                i120 = i203;
                i121 = i204;
                i122 = i402;
                i123 = i403;
                i124 = i404;
                i32 = 318;
                break;
              } else if ((i32 | 0) == 515) {
                i32 = 0;
                if ((i130 | 0) == 0) {
                  i410 = i126;
                  i411 = i127;
                  i412 = i128;
                  i413 = i129;
                  i414 = HEAP32[i89 >> 2] | 0;
                } else {
                  L718 : do {
                    if (i126 >>> 0 < i130 >>> 0) {
                      i31 = i129;
                      i44 = i128;
                      i51 = i127;
                      i45 = i126;
                      while (1) {
                        if ((i44 | 0) == 0) {
                          i143 = i125;
                          i144 = i68;
                          i145 = i45;
                          i146 = i51;
                          i147 = i67;
                          i148 = i43;
                          break L337;
                        }
                        i24 = i44 - 1 | 0;
                        i86 = i31 + 1 | 0;
                        i12 = ((HEAPU8[i31] | 0) << i45) + i51 | 0;
                        i21 = i45 + 8 | 0;
                        if (i21 >>> 0 < i130 >>> 0) {
                          i31 = i86;
                          i44 = i24;
                          i51 = i12;
                          i45 = i21;
                        } else {
                          i415 = i86;
                          i416 = i24;
                          i417 = i12;
                          i418 = i21;
                          break L718;
                        }
                      }
                    } else {
                      i415 = i129;
                      i416 = i128;
                      i417 = i127;
                      i418 = i126;
                    }
                  } while (0);
                  i23 = (HEAP32[i89 >> 2] | 0) + ((1 << i130) - 1 & i417) | 0;
                  HEAP32[i89 >> 2] = i23;
                  HEAP32[i88 >> 2] = (HEAP32[i88 >> 2] | 0) + i130 | 0;
                  i410 = i418 - i130 | 0;
                  i411 = i417 >>> (i130 >>> 0);
                  i412 = i416;
                  i413 = i415;
                  i414 = i23;
                }
                HEAP32[i8 >> 2] = i414;
                HEAP32[i16 >> 2] = 22;
                i246 = i125;
                i247 = i410;
                i248 = i411;
                i249 = i412;
                i250 = i413;
                i32 = 522;
                break;
              }
            } while (0);
            do {
              if ((i32 | 0) == 318) {
                i32 = 0;
                do {
                  if ((i124 & 2048 | 0) == 0) {
                    i23 = HEAP32[i90 >> 2] | 0;
                    if ((i23 | 0) == 0) {
                      i419 = i122;
                      i420 = i123;
                      break;
                    }
                    HEAP32[i23 + 28 >> 2] = 0;
                    i419 = i122;
                    i420 = i123;
                  } else {
                    if ((i122 | 0) == 0) {
                      i143 = i48;
                      i144 = i68;
                      i145 = i120;
                      i146 = i121;
                      i147 = i67;
                      i148 = i43;
                      break L337;
                    } else {
                      i421 = 0;
                    }
                    while (1) {
                      i422 = i421 + 1 | 0;
                      i23 = HEAP8[i123 + i421 | 0] | 0;
                      i45 = HEAP32[i90 >> 2] | 0;
                      do {
                        if ((i45 | 0) != 0) {
                          i51 = i45 + 28 | 0;
                          if ((HEAP32[i51 >> 2] | 0) == 0) {
                            break;
                          }
                          i44 = HEAP32[i89 >> 2] | 0;
                          if (i44 >>> 0 >= (HEAP32[i45 + 32 >> 2] | 0) >>> 0) {
                            break;
                          }
                          HEAP32[i89 >> 2] = i44 + 1 | 0;
                          HEAP8[(HEAP32[i51 >> 2] | 0) + i44 | 0] = i23;
                        }
                      } while (0);
                      i423 = i23 << 24 >> 24 != 0;
                      if (i423 & i422 >>> 0 < i122 >>> 0) {
                        i421 = i422;
                      } else {
                        break;
                      }
                    }
                    if ((HEAP32[i92 >> 2] & 512 | 0) != 0) {
                      HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i123, i422) | 0;
                    }
                    if (i423) {
                      i143 = i48;
                      i144 = i68;
                      i145 = i120;
                      i146 = i121;
                      i147 = i67;
                      i148 = i43;
                      break L337;
                    } else {
                      i419 = i122 - i422 | 0;
                      i420 = i123 + i422 | 0;
                    }
                  }
                } while (0);
                HEAP32[i89 >> 2] = 0;
                HEAP32[i16 >> 2] = 7;
                i207 = i120;
                i208 = i121;
                i209 = i419;
                i210 = i420;
                i32 = 331;
                break;
              } else if ((i32 | 0) == 522) {
                i32 = 0;
                i45 = (1 << HEAP32[i87 >> 2]) - 1 | 0;
                i44 = i45 & i248;
                i51 = HEAP32[i73 >> 2] | 0;
                i31 = HEAP8[i51 + (i44 << 2) + 1 | 0] | 0;
                i21 = i31 & 255;
                L743 : do {
                  if (i21 >>> 0 > i247 >>> 0) {
                    i12 = i250;
                    i24 = i249;
                    i86 = i248;
                    i29 = i247;
                    while (1) {
                      if ((i24 | 0) == 0) {
                        i143 = i246;
                        i144 = i68;
                        i145 = i29;
                        i146 = i86;
                        i147 = i67;
                        i148 = i43;
                        break L337;
                      }
                      i59 = i24 - 1 | 0;
                      i19 = i12 + 1 | 0;
                      i10 = ((HEAPU8[i12] | 0) << i29) + i86 | 0;
                      i6 = i29 + 8 | 0;
                      i28 = i45 & i10;
                      i37 = HEAP8[i51 + (i28 << 2) + 1 | 0] | 0;
                      i22 = i37 & 255;
                      if (i22 >>> 0 > i6 >>> 0) {
                        i12 = i19;
                        i24 = i59;
                        i86 = i10;
                        i29 = i6;
                      } else {
                        i424 = i19;
                        i425 = i59;
                        i426 = i10;
                        i427 = i6;
                        i428 = i37;
                        i429 = i28;
                        i430 = i22;
                        break L743;
                      }
                    }
                  } else {
                    i424 = i250;
                    i425 = i249;
                    i426 = i248;
                    i427 = i247;
                    i428 = i31;
                    i429 = i44;
                    i430 = i21;
                  }
                } while (0);
                i21 = HEAP8[i51 + (i429 << 2) | 0] | 0;
                i44 = HEAP16[i51 + (i429 << 2) + 2 >> 1] | 0;
                i31 = i21 & 255;
                if ((i31 & 240 | 0) == 0) {
                  i45 = i44 & 65535;
                  i29 = (1 << i430 + i31) - 1 | 0;
                  i31 = ((i426 & i29) >>> (i430 >>> 0)) + i45 | 0;
                  i86 = HEAP8[i51 + (i31 << 2) + 1 | 0] | 0;
                  L751 : do {
                    if (((i86 & 255) + i430 | 0) >>> 0 > i427 >>> 0) {
                      i24 = i424;
                      i12 = i425;
                      i22 = i426;
                      i28 = i427;
                      while (1) {
                        if ((i12 | 0) == 0) {
                          i143 = i246;
                          i144 = i68;
                          i145 = i28;
                          i146 = i22;
                          i147 = i67;
                          i148 = i43;
                          break L337;
                        }
                        i37 = i12 - 1 | 0;
                        i6 = i24 + 1 | 0;
                        i10 = ((HEAPU8[i24] | 0) << i28) + i22 | 0;
                        i59 = i28 + 8 | 0;
                        i19 = ((i10 & i29) >>> (i430 >>> 0)) + i45 | 0;
                        i35 = HEAP8[i51 + (i19 << 2) + 1 | 0] | 0;
                        if (((i35 & 255) + i430 | 0) >>> 0 > i59 >>> 0) {
                          i24 = i6;
                          i12 = i37;
                          i22 = i10;
                          i28 = i59;
                        } else {
                          i431 = i6;
                          i432 = i37;
                          i433 = i10;
                          i434 = i59;
                          i435 = i19;
                          i436 = i35;
                          break L751;
                        }
                      }
                    } else {
                      i431 = i424;
                      i432 = i425;
                      i433 = i426;
                      i434 = i427;
                      i435 = i31;
                      i436 = i86;
                    }
                  } while (0);
                  i86 = HEAP16[i51 + (i435 << 2) + 2 >> 1] | 0;
                  i31 = HEAP8[i51 + (i435 << 2) | 0] | 0;
                  i45 = (HEAP32[i88 >> 2] | 0) + i430 | 0;
                  HEAP32[i88 >> 2] = i45;
                  i437 = i31;
                  i438 = i436;
                  i439 = i86;
                  i440 = i434 - i430 | 0;
                  i441 = i433 >>> (i430 >>> 0);
                  i442 = i432;
                  i443 = i431;
                  i444 = i45;
                } else {
                  i437 = i21;
                  i438 = i428;
                  i439 = i44;
                  i440 = i427;
                  i441 = i426;
                  i442 = i425;
                  i443 = i424;
                  i444 = HEAP32[i88 >> 2] | 0;
                }
                i45 = i438 & 255;
                i86 = i441 >>> (i45 >>> 0);
                i31 = i440 - i45 | 0;
                HEAP32[i88 >> 2] = i444 + i45 | 0;
                i45 = i437 & 255;
                if ((i45 & 64 | 0) == 0) {
                  HEAP32[i82 >> 2] = i439 & 65535;
                  i29 = i45 & 15;
                  HEAP32[i81 >> 2] = i29;
                  HEAP32[i16 >> 2] = 23;
                  i131 = i246;
                  i132 = i31;
                  i133 = i86;
                  i134 = i442;
                  i135 = i443;
                  i136 = i29;
                  i32 = 534;
                  break;
                } else {
                  HEAP32[i16 >> 2] = 29;
                  i153 = i246;
                  i154 = i68;
                  i155 = i31;
                  i156 = i86;
                  i157 = i67;
                  i158 = i442;
                  i159 = i62;
                  i160 = i443;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
              }
            } while (0);
            do {
              if ((i32 | 0) == 331) {
                i32 = 0;
                do {
                  if ((HEAP32[i92 >> 2] & 4096 | 0) == 0) {
                    i86 = HEAP32[i90 >> 2] | 0;
                    if ((i86 | 0) == 0) {
                      i445 = i209;
                      i446 = i210;
                      break;
                    }
                    HEAP32[i86 + 36 >> 2] = 0;
                    i445 = i209;
                    i446 = i210;
                  } else {
                    if ((i209 | 0) == 0) {
                      i143 = i48;
                      i144 = i68;
                      i145 = i207;
                      i146 = i208;
                      i147 = i67;
                      i148 = i43;
                      break L337;
                    } else {
                      i447 = 0;
                    }
                    while (1) {
                      i448 = i447 + 1 | 0;
                      i86 = HEAP8[i210 + i447 | 0] | 0;
                      i31 = HEAP32[i90 >> 2] | 0;
                      do {
                        if ((i31 | 0) != 0) {
                          i29 = i31 + 36 | 0;
                          if ((HEAP32[i29 >> 2] | 0) == 0) {
                            break;
                          }
                          i45 = HEAP32[i89 >> 2] | 0;
                          if (i45 >>> 0 >= (HEAP32[i31 + 40 >> 2] | 0) >>> 0) {
                            break;
                          }
                          HEAP32[i89 >> 2] = i45 + 1 | 0;
                          HEAP8[(HEAP32[i29 >> 2] | 0) + i45 | 0] = i86;
                        }
                      } while (0);
                      i449 = i86 << 24 >> 24 != 0;
                      if (i449 & i448 >>> 0 < i209 >>> 0) {
                        i447 = i448;
                      } else {
                        break;
                      }
                    }
                    if ((HEAP32[i92 >> 2] & 512 | 0) != 0) {
                      HEAP32[i93 >> 2] = _crc32(HEAP32[i93 >> 2] | 0, i210, i448) | 0;
                    }
                    if (i449) {
                      i143 = i48;
                      i144 = i68;
                      i145 = i207;
                      i146 = i208;
                      i147 = i67;
                      i148 = i43;
                      break L337;
                    } else {
                      i445 = i209 - i448 | 0;
                      i446 = i210 + i448 | 0;
                    }
                  }
                } while (0);
                HEAP32[i16 >> 2] = 8;
                i211 = i207;
                i212 = i208;
                i213 = i445;
                i214 = i446;
                i32 = 344;
                break;
              } else if ((i32 | 0) == 534) {
                i32 = 0;
                if ((i136 | 0) == 0) {
                  i450 = i132;
                  i451 = i133;
                  i452 = i134;
                  i453 = i135;
                } else {
                  L781 : do {
                    if (i132 >>> 0 < i136 >>> 0) {
                      i44 = i135;
                      i21 = i134;
                      i51 = i133;
                      i31 = i132;
                      while (1) {
                        if ((i21 | 0) == 0) {
                          i143 = i131;
                          i144 = i68;
                          i145 = i31;
                          i146 = i51;
                          i147 = i67;
                          i148 = i43;
                          break L337;
                        }
                        i23 = i21 - 1 | 0;
                        i45 = i44 + 1 | 0;
                        i29 = ((HEAPU8[i44] | 0) << i31) + i51 | 0;
                        i28 = i31 + 8 | 0;
                        if (i28 >>> 0 < i136 >>> 0) {
                          i44 = i45;
                          i21 = i23;
                          i51 = i29;
                          i31 = i28;
                        } else {
                          i454 = i45;
                          i455 = i23;
                          i456 = i29;
                          i457 = i28;
                          break L781;
                        }
                      }
                    } else {
                      i454 = i135;
                      i455 = i134;
                      i456 = i133;
                      i457 = i132;
                    }
                  } while (0);
                  HEAP32[i82 >> 2] = (HEAP32[i82 >> 2] | 0) + ((1 << i136) - 1 & i456) | 0;
                  HEAP32[i88 >> 2] = (HEAP32[i88 >> 2] | 0) + i136 | 0;
                  i450 = i457 - i136 | 0;
                  i451 = i456 >>> (i136 >>> 0);
                  i452 = i455;
                  i453 = i454;
                }
                HEAP32[i16 >> 2] = 24;
                i251 = i131;
                i252 = i450;
                i253 = i451;
                i254 = i452;
                i255 = i453;
                i32 = 540;
                break;
              }
            } while (0);
            L787 : do {
              if ((i32 | 0) == 344) {
                i32 = 0;
                i31 = HEAP32[i92 >> 2] | 0;
                do {
                  if ((i31 & 512 | 0) == 0) {
                    i458 = i211;
                    i459 = i212;
                    i460 = i213;
                    i461 = i214;
                  } else {
                    L791 : do {
                      if (i211 >>> 0 < 16) {
                        i51 = i214;
                        i21 = i213;
                        i44 = i212;
                        i28 = i211;
                        while (1) {
                          if ((i21 | 0) == 0) {
                            i143 = i48;
                            i144 = i68;
                            i145 = i28;
                            i146 = i44;
                            i147 = i67;
                            i148 = i43;
                            break L337;
                          }
                          i29 = i21 - 1 | 0;
                          i23 = i51 + 1 | 0;
                          i45 = ((HEAPU8[i51] | 0) << i28) + i44 | 0;
                          i22 = i28 + 8 | 0;
                          if (i22 >>> 0 < 16) {
                            i51 = i23;
                            i21 = i29;
                            i44 = i45;
                            i28 = i22;
                          } else {
                            i462 = i23;
                            i463 = i29;
                            i464 = i45;
                            i465 = i22;
                            break L791;
                          }
                        }
                      } else {
                        i462 = i214;
                        i463 = i213;
                        i464 = i212;
                        i465 = i211;
                      }
                    } while (0);
                    if ((i464 | 0) == (HEAP32[i93 >> 2] & 65535 | 0)) {
                      i458 = 0;
                      i459 = 0;
                      i460 = i463;
                      i461 = i462;
                      break;
                    }
                    HEAP32[i16 >> 2] = 29;
                    i153 = i48;
                    i154 = i68;
                    i155 = i465;
                    i156 = i464;
                    i157 = i67;
                    i158 = i463;
                    i159 = i62;
                    i160 = i462;
                    i161 = i65;
                    i162 = i43;
                    break L787;
                  }
                } while (0);
                i28 = HEAP32[i90 >> 2] | 0;
                if ((i28 | 0) != 0) {
                  HEAP32[i28 + 44 >> 2] = i31 >>> 9 & 1;
                  HEAP32[(HEAP32[i90 >> 2] | 0) + 48 >> 2] = 1;
                }
                HEAP32[i93 >> 2] = 0;
                HEAP32[i16 >> 2] = 11;
                i153 = i48;
                i154 = i68;
                i155 = i458;
                i156 = i459;
                i157 = i67;
                i158 = i460;
                i159 = i62;
                i160 = i461;
                i161 = i65;
                i162 = i43;
              } else if ((i32 | 0) == 540) {
                i32 = 0;
                if ((i67 | 0) == 0) {
                  i143 = i251;
                  i144 = i68;
                  i145 = i252;
                  i146 = i253;
                  i147 = 0;
                  i148 = i43;
                  break L337;
                }
                i28 = i68 - i67 | 0;
                i44 = HEAP32[i82 >> 2] | 0;
                if (i44 >>> 0 > i28 >>> 0) {
                  i21 = i44 - i28 | 0;
                  do {
                    if (i21 >>> 0 > (HEAP32[i104 >> 2] | 0) >>> 0) {
                      if ((HEAP32[i99 >> 2] | 0) == 0) {
                        break;
                      }
                      HEAP32[i16 >> 2] = 29;
                      i153 = i251;
                      i154 = i68;
                      i155 = i252;
                      i156 = i253;
                      i157 = i67;
                      i158 = i254;
                      i159 = i62;
                      i160 = i255;
                      i161 = i65;
                      i162 = i43;
                      break L787;
                    }
                  } while (0);
                  i31 = HEAP32[i103 >> 2] | 0;
                  if (i21 >>> 0 > i31 >>> 0) {
                    i28 = i21 - i31 | 0;
                    i466 = (HEAP32[i111 >> 2] | 0) + ((HEAP32[i105 >> 2] | 0) - i28 | 0) | 0;
                    i467 = i28;
                  } else {
                    i466 = (HEAP32[i111 >> 2] | 0) + (i31 - i21 | 0) | 0;
                    i467 = i21;
                  }
                  i31 = HEAP32[i89 >> 2] | 0;
                  i468 = i466;
                  i469 = i467 >>> 0 > i31 >>> 0 ? i31 : i467;
                  i470 = i31;
                } else {
                  i31 = HEAP32[i89 >> 2] | 0;
                  i468 = i62 + (-i44 | 0) | 0;
                  i469 = i31;
                  i470 = i31;
                }
                i31 = i469 >>> 0 > i67 >>> 0 ? i67 : i469;
                HEAP32[i89 >> 2] = i470 - i31 | 0;
                i28 = i67 ^ -1;
                i51 = i469 ^ -1;
                i86 = i28 >>> 0 > i51 >>> 0 ? i28 : i51;
                i51 = i468;
                i28 = i31;
                i22 = i62;
                while (1) {
                  HEAP8[i22] = HEAP8[i51] | 0;
                  i45 = i28 - 1 | 0;
                  if ((i45 | 0) == 0) {
                    break;
                  } else {
                    i51 = i51 + 1 | 0;
                    i28 = i45;
                    i22 = i22 + 1 | 0;
                  }
                }
                i22 = i67 - i31 | 0;
                i28 = i62 + (i86 ^ -1) | 0;
                if ((HEAP32[i89 >> 2] | 0) != 0) {
                  i153 = i251;
                  i154 = i68;
                  i155 = i252;
                  i156 = i253;
                  i157 = i22;
                  i158 = i254;
                  i159 = i28;
                  i160 = i255;
                  i161 = i65;
                  i162 = i43;
                  break;
                }
                HEAP32[i16 >> 2] = 20;
                i153 = i251;
                i154 = i68;
                i155 = i252;
                i156 = i253;
                i157 = i22;
                i158 = i254;
                i159 = i28;
                i160 = i255;
                i161 = i65;
                i162 = i43;
              }
            } while (0);
            i48 = i153;
            i68 = i154;
            i47 = i155;
            i66 = i156;
            i67 = i157;
            i61 = i158;
            i62 = i159;
            i63 = i160;
            i64 = HEAP32[i16 >> 2] | 0;
            i65 = i161;
            i43 = i162;
          }
          if ((i32 | 0) == 357) {
            HEAP32[i102 >> 2] = i172;
            HEAP32[i101 >> 2] = i171;
            break;
          } else if ((i32 | 0) == 578) {
            HEAP32[i16 >> 2] = 28;
            i143 = 1;
            i144 = i113;
            i145 = i273;
            i146 = i274;
            i147 = i67;
            i148 = i118;
          } else if ((i32 | 0) == 579) {
            i143 = -3;
            i144 = i68;
            i145 = i47;
            i146 = i66;
            i147 = i67;
            i148 = i43;
          }
          HEAP32[i102 >> 2] = i146;
          HEAP32[i101 >> 2] = i145;
          i65 = HEAP32[i105 >> 2] | 0;
          do {
            if ((i65 | 0) == 0) {
              if ((HEAP32[i16 >> 2] | 0) >>> 0 >= 26 | (i144 | 0) == (i147 | 0)) {
                break;
              } else {
                i32 = 582;
                break;
              }
            } else {
              i32 = 582;
            }
          } while (0);
          do {
            if ((i32 | 0) == 582) {
              i43 = HEAP32[i111 >> 2] | 0;
              do {
                if ((i43 | 0) == 0) {
                  i67 = _zcalloc(0, 1 << HEAP32[i110 >> 2], 1) | 0;
                  HEAP32[i13 >> 2] = i67;
                  if ((i67 | 0) == 0) {
                    HEAP32[i16 >> 2] = 30;
                    break L334;
                  } else {
                    i471 = i67;
                    i472 = HEAP32[i105 >> 2] | 0;
                    break;
                  }
                } else {
                  i471 = i43;
                  i472 = i65;
                }
              } while (0);
              if ((i472 | 0) == 0) {
                i43 = 1 << HEAP32[i110 >> 2];
                HEAP32[i105 >> 2] = i43;
                HEAP32[i103 >> 2] = 0;
                HEAP32[i104 >> 2] = 0;
                i473 = i43;
              } else {
                i473 = i472;
              }
              i43 = i144 - i147 | 0;
              if (i43 >>> 0 >= i473 >>> 0) {
                _memcpy(i471, i62 + (-i473 | 0) | 0, i473);
                HEAP32[i103 >> 2] = 0;
                HEAP32[i104 >> 2] = HEAP32[i105 >> 2] | 0;
                break;
              }
              i67 = HEAP32[i103 >> 2] | 0;
              i66 = i473 - i67 | 0;
              i47 = i66 >>> 0 > i43 >>> 0 ? i43 : i66;
              _memcpy(i471 + i67 | 0, i62 + (-i43 | 0) | 0, i47);
              i67 = i43 - i47 | 0;
              if ((i43 | 0) != (i47 | 0)) {
                _memcpy(HEAP32[i111 >> 2] | 0, i62 + (-i67 | 0) | 0, i67);
                HEAP32[i103 >> 2] = i67;
                HEAP32[i104 >> 2] = HEAP32[i105 >> 2] | 0;
                break;
              }
              i67 = (HEAP32[i103 >> 2] | 0) + i43 | 0;
              HEAP32[i103 >> 2] = i67;
              i47 = HEAP32[i105 >> 2] | 0;
              if ((i67 | 0) == (i47 | 0)) {
                HEAP32[i103 >> 2] = 0;
              }
              i67 = HEAP32[i104 >> 2] | 0;
              if (i67 >>> 0 >= i47 >>> 0) {
                break;
              }
              HEAP32[i104 >> 2] = i67 + i43 | 0;
            }
          } while (0);
          i65 = i144 - i147 | 0;
          i43 = i148 + i65 | 0;
          HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + i65 | 0;
          if (!((HEAP32[i109 >> 2] | 0) == 0 | (i144 | 0) == (i147 | 0))) {
            i67 = HEAP32[i93 >> 2] | 0;
            i47 = i62 + (-i65 | 0) | 0;
            if ((HEAP32[i92 >> 2] | 0) == 0) {
              i474 = _adler32(i67, i47, i65) | 0;
            } else {
              i474 = _crc32(i67, i47, i65) | 0;
            }
            HEAP32[i93 >> 2] = i474;
          }
          if ((((i143 | 0) == 0 ? -5 : i143) | 0) != 1) {
            break;
          }
          i65 = HEAP32[i111 >> 2] | 0;
          if ((i65 | 0) != 0) {
            _zcfree(0, i65);
          }
          _zcfree(0, i14);
          if ((i43 | 0) == (i2 | 0)) {
            break L332;
          }
          ___assert_func(5255712, 24, 5256992, 5255684);
          break L332;
        }
      } while (0);
      i109 = HEAP32[i111 >> 2] | 0;
      if ((i109 | 0) != 0) {
        _zcfree(0, i109);
      }
      _zcfree(0, i14);
    }
  } while (0);
  if (!i7) {
    STACKTOP = i4;
    return;
  }
  if ((_strcmp(i1 | 0, HEAP32[1311756] | 0) | 0) == 0) {
    STACKTOP = i4;
    return;
  }
  ___assert_func(5255712, 25, 5256992, 5255652);
  STACKTOP = i4;
  return;
}
function _main(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
  i1 = _atoi(HEAP32[i2 + 4 >> 2] | 0) | 0;
  i3 = _atoi(HEAP32[i2 + 8 >> 2] | 0) | 0;
  i2 = _malloc(i1) | 0;
  L874 : do {
    if ((i1 | 0) > 0) {
      i4 = 0;
      i5 = 0;
      i6 = 17;
      while (1) {
        do {
          if ((i5 | 0) > 0) {
            i7 = i6;
            i8 = i5 - 1 | 0;
          } else {
            if ((i4 & 7 | 0) == 0) {
              i7 = 0;
              i8 = i4 & 31;
              break;
            } else {
              i7 = ((Math_imul(i4, i4) & -1) >>> 0) % 6714 & 255;
              i8 = i5;
              break;
            }
          }
        } while (0);
        HEAP8[i2 + i4 | 0] = i7;
        i9 = i4 + 1 | 0;
        if ((i9 | 0) == (i1 | 0)) {
          break L874;
        } else {
          i4 = i9;
          i5 = i8;
          i6 = i7;
        }
      }
    }
  } while (0);
  if ((i3 | 0) > 0) {
    i10 = 0;
  } else {
    i11 = _puts(5242880) | 0;
    return 0;
  }
  while (1) {
    _doit(i2, i1, i10);
    i7 = i10 + 1 | 0;
    if ((i7 | 0) == (i3 | 0)) {
      break;
    } else {
      i10 = i7;
    }
  }
  i11 = _puts(5242880) | 0;
  return 0;
}
function _fill_window(i1) {
  i1 = i1 | 0;
  var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0;
  i2 = i1 + 44 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = i1 + 60 | 0;
  i5 = i1 + 116 | 0;
  i6 = i1 + 108 | 0;
  i7 = i3 - 262 | 0;
  i8 = i1 | 0;
  i9 = i1 + 56 | 0;
  i10 = i1 + 72 | 0;
  i11 = i1 + 88 | 0;
  i12 = i1 + 84 | 0;
  i13 = i1 + 112 | 0;
  i14 = i1 + 92 | 0;
  i15 = i1 + 76 | 0;
  i16 = i1 + 68 | 0;
  i17 = i1 + 64 | 0;
  i18 = HEAP32[i5 >> 2] | 0;
  i19 = i3;
  while (1) {
    i20 = HEAP32[i6 >> 2] | 0;
    i21 = ((HEAP32[i4 >> 2] | 0) - i18 | 0) - i20 | 0;
    if (i20 >>> 0 < (i7 + i19 | 0) >>> 0) {
      i22 = i21;
    } else {
      i20 = HEAP32[i9 >> 2] | 0;
      _memcpy(i20, i20 + i3 | 0, i3);
      HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) - i3 | 0;
      HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) - i3 | 0;
      HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) - i3 | 0;
      i20 = HEAP32[i15 >> 2] | 0;
      i23 = i20;
      i24 = (HEAP32[i16 >> 2] | 0) + (i20 << 1) | 0;
      while (1) {
        i20 = i24 - 2 | 0;
        i25 = HEAPU16[i20 >> 1] | 0;
        if (i25 >>> 0 < i3 >>> 0) {
          i26 = 0;
        } else {
          i26 = i25 - i3 & 65535;
        }
        HEAP16[i20 >> 1] = i26;
        i25 = i23 - 1 | 0;
        if ((i25 | 0) == 0) {
          break;
        } else {
          i23 = i25;
          i24 = i20;
        }
      }
      i24 = i3;
      i23 = (HEAP32[i17 >> 2] | 0) + (i3 << 1) | 0;
      while (1) {
        i20 = i23 - 2 | 0;
        i25 = HEAPU16[i20 >> 1] | 0;
        if (i25 >>> 0 < i3 >>> 0) {
          i27 = 0;
        } else {
          i27 = i25 - i3 & 65535;
        }
        HEAP16[i20 >> 1] = i27;
        i25 = i24 - 1 | 0;
        if ((i25 | 0) == 0) {
          break;
        } else {
          i24 = i25;
          i23 = i20;
        }
      }
      i22 = i21 + i3 | 0;
    }
    i23 = HEAP32[i8 >> 2] | 0;
    i24 = i23 + 4 | 0;
    i20 = HEAP32[i24 >> 2] | 0;
    if ((i20 | 0) == 0) {
      i28 = 656;
      break;
    }
    i25 = HEAP32[i5 >> 2] | 0;
    i29 = (HEAP32[i9 >> 2] | 0) + (i25 + (HEAP32[i6 >> 2] | 0) | 0) | 0;
    i30 = i20 >>> 0 > i22 >>> 0 ? i22 : i20;
    if ((i30 | 0) == 0) {
      i31 = 0;
      i32 = i25;
    } else {
      HEAP32[i24 >> 2] = i20 - i30 | 0;
      i20 = HEAP32[(HEAP32[i23 + 28 >> 2] | 0) + 24 >> 2] | 0;
      if ((i20 | 0) == 1) {
        i24 = i23 + 48 | 0;
        i25 = HEAP32[i23 >> 2] | 0;
        HEAP32[i24 >> 2] = _adler32(HEAP32[i24 >> 2] | 0, i25, i30) | 0;
        i33 = i25;
      } else if ((i20 | 0) == 2) {
        i20 = i23 + 48 | 0;
        i25 = HEAP32[i23 >> 2] | 0;
        HEAP32[i20 >> 2] = _crc32(HEAP32[i20 >> 2] | 0, i25, i30) | 0;
        i33 = i25;
      } else {
        i33 = HEAP32[i23 >> 2] | 0;
      }
      i25 = i23 | 0;
      _memcpy(i29, i33, i30);
      HEAP32[i25 >> 2] = (HEAP32[i25 >> 2] | 0) + i30 | 0;
      i25 = i23 + 8 | 0;
      HEAP32[i25 >> 2] = (HEAP32[i25 >> 2] | 0) + i30 | 0;
      i31 = i30;
      i32 = HEAP32[i5 >> 2] | 0;
    }
    i34 = i32 + i31 | 0;
    HEAP32[i5 >> 2] = i34;
    if (i34 >>> 0 > 2) {
      i30 = HEAP32[i6 >> 2] | 0;
      i25 = HEAP32[i9 >> 2] | 0;
      i23 = HEAPU8[i25 + i30 | 0] | 0;
      HEAP32[i10 >> 2] = i23;
      HEAP32[i10 >> 2] = ((HEAPU8[i25 + (i30 + 1 | 0) | 0] | 0) ^ i23 << HEAP32[i11 >> 2]) & HEAP32[i12 >> 2];
      if (i34 >>> 0 >= 262) {
        break;
      }
    }
    if ((HEAP32[(HEAP32[i8 >> 2] | 0) + 4 >> 2] | 0) == 0) {
      break;
    }
    i18 = i34;
    i19 = HEAP32[i2 >> 2] | 0;
  }
  if ((i28 | 0) == 656) {
    return;
  }
  i28 = i1 + 5824 | 0;
  i1 = HEAP32[i28 >> 2] | 0;
  i2 = HEAP32[i4 >> 2] | 0;
  if (i1 >>> 0 >= i2 >>> 0) {
    return;
  }
  i4 = i34 + (HEAP32[i6 >> 2] | 0) | 0;
  if (i1 >>> 0 < i4 >>> 0) {
    i6 = i2 - i4 | 0;
    i34 = i6 >>> 0 > 258 ? 258 : i6;
    _memset((HEAP32[i9 >> 2] | 0) + i4 | 0, 0, i34 | 0);
    HEAP32[i28 >> 2] = i34 + i4 | 0;
    return;
  }
  i34 = i4 + 258 | 0;
  if (i1 >>> 0 >= i34 >>> 0) {
    return;
  }
  i4 = i34 - i1 | 0;
  i34 = i2 - i1 | 0;
  i2 = i4 >>> 0 > i34 >>> 0 ? i34 : i4;
  _memset((HEAP32[i9 >> 2] | 0) + i1 | 0, 0, i2 | 0);
  HEAP32[i28 >> 2] = (HEAP32[i28 >> 2] | 0) + i2 | 0;
  return;
}
function _deflate_stored(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0;
  i3 = (HEAP32[i1 + 12 >> 2] | 0) - 5 | 0;
  i4 = i3 >>> 0 < 65535 ? i3 : 65535;
  i3 = i1 + 116 | 0;
  i5 = i1 + 108 | 0;
  i6 = i1 + 92 | 0;
  i7 = i1 + 44 | 0;
  i8 = i1 + 56 | 0;
  i9 = i1;
  i10 = i1 | 0;
  while (1) {
    i11 = HEAP32[i3 >> 2] | 0;
    if (i11 >>> 0 < 2) {
      _fill_window(i1);
      i12 = HEAP32[i3 >> 2] | 0;
      if ((i12 | i2 | 0) == 0) {
        i13 = 0;
        i14 = 689;
        break;
      }
      if ((i12 | 0) == 0) {
        i14 = 680;
        break;
      } else {
        i15 = i12;
      }
    } else {
      i15 = i11;
    }
    i11 = (HEAP32[i5 >> 2] | 0) + i15 | 0;
    HEAP32[i5 >> 2] = i11;
    HEAP32[i3 >> 2] = 0;
    i12 = HEAP32[i6 >> 2] | 0;
    i16 = i12 + i4 | 0;
    if ((i11 | 0) != 0 & i11 >>> 0 < i16 >>> 0) {
      i17 = i11;
      i18 = i12;
    } else {
      HEAP32[i3 >> 2] = i11 - i16 | 0;
      HEAP32[i5 >> 2] = i16;
      if ((i12 | 0) > -1) {
        i19 = (HEAP32[i8 >> 2] | 0) + i12 | 0;
      } else {
        i19 = 0;
      }
      __tr_flush_block(i9, i19, i4, 0);
      HEAP32[i6 >> 2] = HEAP32[i5 >> 2] | 0;
      i12 = HEAP32[i10 >> 2] | 0;
      i16 = i12 + 28 | 0;
      i11 = HEAP32[i16 >> 2] | 0;
      i20 = HEAP32[i11 + 20 >> 2] | 0;
      i21 = i12 + 16 | 0;
      i22 = HEAP32[i21 >> 2] | 0;
      i23 = i20 >>> 0 > i22 >>> 0 ? i22 : i20;
      do {
        if ((i23 | 0) != 0) {
          i20 = i12 + 12 | 0;
          _memcpy(HEAP32[i20 >> 2] | 0, HEAP32[i11 + 16 >> 2] | 0, i23);
          HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) + i23 | 0;
          i20 = (HEAP32[i16 >> 2] | 0) + 16 | 0;
          HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) + i23 | 0;
          i20 = i12 + 20 | 0;
          HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) + i23 | 0;
          HEAP32[i21 >> 2] = (HEAP32[i21 >> 2] | 0) - i23 | 0;
          i20 = (HEAP32[i16 >> 2] | 0) + 20 | 0;
          HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) - i23 | 0;
          i20 = HEAP32[i16 >> 2] | 0;
          if ((HEAP32[i20 + 20 >> 2] | 0) != 0) {
            break;
          }
          HEAP32[i20 + 16 >> 2] = HEAP32[i20 + 8 >> 2] | 0;
        }
      } while (0);
      if ((HEAP32[(HEAP32[i10 >> 2] | 0) + 16 >> 2] | 0) == 0) {
        i13 = 0;
        i14 = 690;
        break;
      }
      i17 = HEAP32[i5 >> 2] | 0;
      i18 = HEAP32[i6 >> 2] | 0;
    }
    i16 = i17 - i18 | 0;
    if (i16 >>> 0 < ((HEAP32[i7 >> 2] | 0) - 262 | 0) >>> 0) {
      continue;
    }
    if ((i18 | 0) > -1) {
      i24 = (HEAP32[i8 >> 2] | 0) + i18 | 0;
    } else {
      i24 = 0;
    }
    __tr_flush_block(i9, i24, i16, 0);
    HEAP32[i6 >> 2] = HEAP32[i5 >> 2] | 0;
    i16 = HEAP32[i10 >> 2] | 0;
    i23 = i16 + 28 | 0;
    i21 = HEAP32[i23 >> 2] | 0;
    i12 = HEAP32[i21 + 20 >> 2] | 0;
    i11 = i16 + 16 | 0;
    i20 = HEAP32[i11 >> 2] | 0;
    i22 = i12 >>> 0 > i20 >>> 0 ? i20 : i12;
    do {
      if ((i22 | 0) != 0) {
        i12 = i16 + 12 | 0;
        _memcpy(HEAP32[i12 >> 2] | 0, HEAP32[i21 + 16 >> 2] | 0, i22);
        HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + i22 | 0;
        i12 = (HEAP32[i23 >> 2] | 0) + 16 | 0;
        HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + i22 | 0;
        i12 = i16 + 20 | 0;
        HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + i22 | 0;
        HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) - i22 | 0;
        i12 = (HEAP32[i23 >> 2] | 0) + 20 | 0;
        HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) - i22 | 0;
        i12 = HEAP32[i23 >> 2] | 0;
        if ((HEAP32[i12 + 20 >> 2] | 0) != 0) {
          break;
        }
        HEAP32[i12 + 16 >> 2] = HEAP32[i12 + 8 >> 2] | 0;
      }
    } while (0);
    if ((HEAP32[(HEAP32[i10 >> 2] | 0) + 16 >> 2] | 0) == 0) {
      i13 = 0;
      i14 = 691;
      break;
    }
  }
  if ((i14 | 0) == 680) {
    i24 = HEAP32[i6 >> 2] | 0;
    if ((i24 | 0) > -1) {
      i25 = (HEAP32[i8 >> 2] | 0) + i24 | 0;
    } else {
      i25 = 0;
    }
    i8 = (i2 | 0) == 4;
    __tr_flush_block(i9, i25, (HEAP32[i5 >> 2] | 0) - i24 | 0, i8 & 1);
    HEAP32[i6 >> 2] = HEAP32[i5 >> 2] | 0;
    i5 = HEAP32[i10 >> 2] | 0;
    i6 = i5 + 28 | 0;
    i24 = HEAP32[i6 >> 2] | 0;
    i25 = HEAP32[i24 + 20 >> 2] | 0;
    i9 = i5 + 16 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    i18 = i25 >>> 0 > i2 >>> 0 ? i2 : i25;
    do {
      if ((i18 | 0) != 0) {
        i25 = i5 + 12 | 0;
        _memcpy(HEAP32[i25 >> 2] | 0, HEAP32[i24 + 16 >> 2] | 0, i18);
        HEAP32[i25 >> 2] = (HEAP32[i25 >> 2] | 0) + i18 | 0;
        i25 = (HEAP32[i6 >> 2] | 0) + 16 | 0;
        HEAP32[i25 >> 2] = (HEAP32[i25 >> 2] | 0) + i18 | 0;
        i25 = i5 + 20 | 0;
        HEAP32[i25 >> 2] = (HEAP32[i25 >> 2] | 0) + i18 | 0;
        HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) - i18 | 0;
        i25 = (HEAP32[i6 >> 2] | 0) + 20 | 0;
        HEAP32[i25 >> 2] = (HEAP32[i25 >> 2] | 0) - i18 | 0;
        i25 = HEAP32[i6 >> 2] | 0;
        if ((HEAP32[i25 + 20 >> 2] | 0) != 0) {
          break;
        }
        HEAP32[i25 + 16 >> 2] = HEAP32[i25 + 8 >> 2] | 0;
      }
    } while (0);
    if ((HEAP32[(HEAP32[i10 >> 2] | 0) + 16 >> 2] | 0) == 0) {
      i13 = i8 ? 2 : 0;
      return i13 | 0;
    } else {
      i13 = i8 ? 3 : 1;
      return i13 | 0;
    }
  } else if ((i14 | 0) == 689) {
    return i13 | 0;
  } else if ((i14 | 0) == 690) {
    return i13 | 0;
  } else if ((i14 | 0) == 691) {
    return i13 | 0;
  }
  return 0;
}
function _deflate_fast(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0;
  i3 = i1 + 116 | 0;
  i4 = (i2 | 0) == 0;
  i5 = i1 + 72 | 0;
  i6 = i1 + 88 | 0;
  i7 = i1 + 108 | 0;
  i8 = i1 + 56 | 0;
  i9 = i1 + 84 | 0;
  i10 = i1 + 68 | 0;
  i11 = i1 + 52 | 0;
  i12 = i1 + 64 | 0;
  i13 = i1 + 44 | 0;
  i14 = i1 + 96 | 0;
  i15 = i1 + 112 | 0;
  i16 = i1 + 5792 | 0;
  i17 = i1 + 5796 | 0;
  i18 = i1 + 5784 | 0;
  i19 = i1 + 5788 | 0;
  i20 = i1 + 128 | 0;
  i21 = i1 + 92 | 0;
  i22 = i1;
  i23 = i1 | 0;
  L979 : while (1) {
    do {
      if ((HEAP32[i3 >> 2] | 0) >>> 0 < 262) {
        _fill_window(i1);
        i24 = HEAP32[i3 >> 2] | 0;
        if (i24 >>> 0 < 262 & i4) {
          i25 = 0;
          i26 = 728;
          break L979;
        }
        if ((i24 | 0) == 0) {
          i26 = 719;
          break L979;
        }
        if (i24 >>> 0 > 2) {
          i26 = 699;
          break;
        } else {
          i26 = 702;
          break;
        }
      } else {
        i26 = 699;
      }
    } while (0);
    do {
      if ((i26 | 0) == 699) {
        i26 = 0;
        i24 = HEAP32[i7 >> 2] | 0;
        i27 = ((HEAPU8[(HEAP32[i8 >> 2] | 0) + (i24 + 2 | 0) | 0] | 0) ^ HEAP32[i5 >> 2] << HEAP32[i6 >> 2]) & HEAP32[i9 >> 2];
        HEAP32[i5 >> 2] = i27;
        i28 = HEAP16[(HEAP32[i10 >> 2] | 0) + (i27 << 1) >> 1] | 0;
        HEAP16[(HEAP32[i12 >> 2] | 0) + ((HEAP32[i11 >> 2] & i24) << 1) >> 1] = i28;
        i24 = i28 & 65535;
        HEAP16[(HEAP32[i10 >> 2] | 0) + (HEAP32[i5 >> 2] << 1) >> 1] = HEAP32[i7 >> 2] & 65535;
        if (i28 << 16 >> 16 == 0) {
          i26 = 702;
          break;
        }
        if (((HEAP32[i7 >> 2] | 0) - i24 | 0) >>> 0 > ((HEAP32[i13 >> 2] | 0) - 262 | 0) >>> 0) {
          i26 = 702;
          break;
        }
        i28 = _longest_match(i1, i24) | 0;
        HEAP32[i14 >> 2] = i28;
        i29 = i28;
        break;
      }
    } while (0);
    if ((i26 | 0) == 702) {
      i26 = 0;
      i29 = HEAP32[i14 >> 2] | 0;
    }
    do {
      if (i29 >>> 0 > 2) {
        i28 = i29 + 253 | 0;
        i24 = (HEAP32[i7 >> 2] | 0) - (HEAP32[i15 >> 2] | 0) | 0;
        HEAP16[(HEAP32[i17 >> 2] | 0) + (HEAP32[i16 >> 2] << 1) >> 1] = i24 & 65535;
        i27 = HEAP32[i16 >> 2] | 0;
        HEAP32[i16 >> 2] = i27 + 1 | 0;
        HEAP8[(HEAP32[i18 >> 2] | 0) + i27 | 0] = i28 & 255;
        i27 = i1 + 148 + ((HEAPU8[5255756 + (i28 & 255) | 0] | 0 | 256) + 1 << 2) | 0;
        HEAP16[i27 >> 1] = (HEAP16[i27 >> 1] | 0) + 1 & 65535;
        i27 = i24 + 65535 & 65535;
        if (i27 >>> 0 < 256) {
          i30 = i27;
        } else {
          i30 = (i27 >>> 7) + 256 | 0;
        }
        i27 = i1 + 2440 + ((HEAPU8[i30 + 5256480 | 0] | 0) << 2) | 0;
        HEAP16[i27 >> 1] = (HEAP16[i27 >> 1] | 0) + 1 & 65535;
        i27 = (HEAP32[i16 >> 2] | 0) == ((HEAP32[i19 >> 2] | 0) - 1 | 0) & 1;
        i24 = HEAP32[i14 >> 2] | 0;
        i28 = (HEAP32[i3 >> 2] | 0) - i24 | 0;
        HEAP32[i3 >> 2] = i28;
        if (!(i24 >>> 0 <= (HEAP32[i20 >> 2] | 0) >>> 0 & i28 >>> 0 > 2)) {
          i28 = (HEAP32[i7 >> 2] | 0) + i24 | 0;
          HEAP32[i7 >> 2] = i28;
          HEAP32[i14 >> 2] = 0;
          i31 = HEAP32[i8 >> 2] | 0;
          i32 = HEAPU8[i31 + i28 | 0] | 0;
          HEAP32[i5 >> 2] = i32;
          HEAP32[i5 >> 2] = ((HEAPU8[i31 + (i28 + 1 | 0) | 0] | 0) ^ i32 << HEAP32[i6 >> 2]) & HEAP32[i9 >> 2];
          i33 = i27;
          i34 = i28;
          break;
        }
        HEAP32[i14 >> 2] = i24 - 1 | 0;
        while (1) {
          i24 = HEAP32[i7 >> 2] | 0;
          i28 = i24 + 1 | 0;
          HEAP32[i7 >> 2] = i28;
          i32 = ((HEAPU8[(HEAP32[i8 >> 2] | 0) + (i24 + 3 | 0) | 0] | 0) ^ HEAP32[i5 >> 2] << HEAP32[i6 >> 2]) & HEAP32[i9 >> 2];
          HEAP32[i5 >> 2] = i32;
          HEAP16[(HEAP32[i12 >> 2] | 0) + ((HEAP32[i11 >> 2] & i28) << 1) >> 1] = HEAP16[(HEAP32[i10 >> 2] | 0) + (i32 << 1) >> 1] | 0;
          HEAP16[(HEAP32[i10 >> 2] | 0) + (HEAP32[i5 >> 2] << 1) >> 1] = HEAP32[i7 >> 2] & 65535;
          i32 = (HEAP32[i14 >> 2] | 0) - 1 | 0;
          HEAP32[i14 >> 2] = i32;
          if ((i32 | 0) == 0) {
            break;
          }
        }
        i32 = (HEAP32[i7 >> 2] | 0) + 1 | 0;
        HEAP32[i7 >> 2] = i32;
        i33 = i27;
        i34 = i32;
      } else {
        i32 = HEAP8[(HEAP32[i8 >> 2] | 0) + (HEAP32[i7 >> 2] | 0) | 0] | 0;
        HEAP16[(HEAP32[i17 >> 2] | 0) + (HEAP32[i16 >> 2] << 1) >> 1] = 0;
        i28 = HEAP32[i16 >> 2] | 0;
        HEAP32[i16 >> 2] = i28 + 1 | 0;
        HEAP8[(HEAP32[i18 >> 2] | 0) + i28 | 0] = i32;
        i28 = i1 + 148 + ((i32 & 255) << 2) | 0;
        HEAP16[i28 >> 1] = (HEAP16[i28 >> 1] | 0) + 1 & 65535;
        i28 = (HEAP32[i16 >> 2] | 0) == ((HEAP32[i19 >> 2] | 0) - 1 | 0) & 1;
        HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) - 1 | 0;
        i32 = (HEAP32[i7 >> 2] | 0) + 1 | 0;
        HEAP32[i7 >> 2] = i32;
        i33 = i28;
        i34 = i32;
      }
    } while (0);
    if ((i33 | 0) == 0) {
      continue;
    }
    i32 = HEAP32[i21 >> 2] | 0;
    if ((i32 | 0) > -1) {
      i35 = (HEAP32[i8 >> 2] | 0) + i32 | 0;
    } else {
      i35 = 0;
    }
    __tr_flush_block(i22, i35, i34 - i32 | 0, 0);
    HEAP32[i21 >> 2] = HEAP32[i7 >> 2] | 0;
    i32 = HEAP32[i23 >> 2] | 0;
    i28 = i32 + 28 | 0;
    i24 = HEAP32[i28 >> 2] | 0;
    i31 = HEAP32[i24 + 20 >> 2] | 0;
    i36 = i32 + 16 | 0;
    i37 = HEAP32[i36 >> 2] | 0;
    i38 = i31 >>> 0 > i37 >>> 0 ? i37 : i31;
    do {
      if ((i38 | 0) != 0) {
        i31 = i32 + 12 | 0;
        _memcpy(HEAP32[i31 >> 2] | 0, HEAP32[i24 + 16 >> 2] | 0, i38);
        HEAP32[i31 >> 2] = (HEAP32[i31 >> 2] | 0) + i38 | 0;
        i31 = (HEAP32[i28 >> 2] | 0) + 16 | 0;
        HEAP32[i31 >> 2] = (HEAP32[i31 >> 2] | 0) + i38 | 0;
        i31 = i32 + 20 | 0;
        HEAP32[i31 >> 2] = (HEAP32[i31 >> 2] | 0) + i38 | 0;
        HEAP32[i36 >> 2] = (HEAP32[i36 >> 2] | 0) - i38 | 0;
        i31 = (HEAP32[i28 >> 2] | 0) + 20 | 0;
        HEAP32[i31 >> 2] = (HEAP32[i31 >> 2] | 0) - i38 | 0;
        i31 = HEAP32[i28 >> 2] | 0;
        if ((HEAP32[i31 + 20 >> 2] | 0) != 0) {
          break;
        }
        HEAP32[i31 + 16 >> 2] = HEAP32[i31 + 8 >> 2] | 0;
      }
    } while (0);
    if ((HEAP32[(HEAP32[i23 >> 2] | 0) + 16 >> 2] | 0) == 0) {
      i25 = 0;
      i26 = 729;
      break;
    }
  }
  if ((i26 | 0) == 719) {
    i34 = HEAP32[i21 >> 2] | 0;
    if ((i34 | 0) > -1) {
      i39 = (HEAP32[i8 >> 2] | 0) + i34 | 0;
    } else {
      i39 = 0;
    }
    i8 = (i2 | 0) == 4;
    __tr_flush_block(i22, i39, (HEAP32[i7 >> 2] | 0) - i34 | 0, i8 & 1);
    HEAP32[i21 >> 2] = HEAP32[i7 >> 2] | 0;
    i7 = HEAP32[i23 >> 2] | 0;
    i21 = i7 + 28 | 0;
    i34 = HEAP32[i21 >> 2] | 0;
    i39 = HEAP32[i34 + 20 >> 2] | 0;
    i22 = i7 + 16 | 0;
    i2 = HEAP32[i22 >> 2] | 0;
    i35 = i39 >>> 0 > i2 >>> 0 ? i2 : i39;
    do {
      if ((i35 | 0) != 0) {
        i39 = i7 + 12 | 0;
        _memcpy(HEAP32[i39 >> 2] | 0, HEAP32[i34 + 16 >> 2] | 0, i35);
        HEAP32[i39 >> 2] = (HEAP32[i39 >> 2] | 0) + i35 | 0;
        i39 = (HEAP32[i21 >> 2] | 0) + 16 | 0;
        HEAP32[i39 >> 2] = (HEAP32[i39 >> 2] | 0) + i35 | 0;
        i39 = i7 + 20 | 0;
        HEAP32[i39 >> 2] = (HEAP32[i39 >> 2] | 0) + i35 | 0;
        HEAP32[i22 >> 2] = (HEAP32[i22 >> 2] | 0) - i35 | 0;
        i39 = (HEAP32[i21 >> 2] | 0) + 20 | 0;
        HEAP32[i39 >> 2] = (HEAP32[i39 >> 2] | 0) - i35 | 0;
        i39 = HEAP32[i21 >> 2] | 0;
        if ((HEAP32[i39 + 20 >> 2] | 0) != 0) {
          break;
        }
        HEAP32[i39 + 16 >> 2] = HEAP32[i39 + 8 >> 2] | 0;
      }
    } while (0);
    if ((HEAP32[(HEAP32[i23 >> 2] | 0) + 16 >> 2] | 0) == 0) {
      i25 = i8 ? 2 : 0;
      return i25 | 0;
    } else {
      i25 = i8 ? 3 : 1;
      return i25 | 0;
    }
  } else if ((i26 | 0) == 728) {
    return i25 | 0;
  } else if ((i26 | 0) == 729) {
    return i25 | 0;
  }
  return 0;
}
function _longest_match(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0;
  i3 = HEAP32[i1 + 124 >> 2] | 0;
  i4 = HEAP32[i1 + 56 >> 2] | 0;
  i5 = HEAP32[i1 + 108 >> 2] | 0;
  i6 = i4 + i5 | 0;
  i7 = HEAP32[i1 + 120 >> 2] | 0;
  i8 = HEAP32[i1 + 144 >> 2] | 0;
  i9 = (HEAP32[i1 + 44 >> 2] | 0) - 262 | 0;
  i10 = i5 >>> 0 > i9 >>> 0 ? i5 - i9 | 0 : 0;
  i9 = HEAP32[i1 + 64 >> 2] | 0;
  i11 = HEAP32[i1 + 52 >> 2] | 0;
  i12 = i4 + (i5 + 258 | 0) | 0;
  i13 = HEAP32[i1 + 116 >> 2] | 0;
  i14 = i8 >>> 0 > i13 >>> 0 ? i13 : i8;
  i8 = i1 + 112 | 0;
  i15 = i4 + (i5 + 1 | 0) | 0;
  i16 = i4 + (i5 + 2 | 0) | 0;
  i17 = i12;
  i18 = i5 + 257 | 0;
  i19 = HEAP8[i4 + (i7 + i5 | 0) | 0] | 0;
  i20 = HEAP8[i4 + ((i5 - 1 | 0) + i7 | 0) | 0] | 0;
  i21 = i2;
  i2 = i7 >>> 0 < (HEAP32[i1 + 140 >> 2] | 0) >>> 0 ? i3 : i3 >>> 2;
  i3 = i7;
  L1030 : while (1) {
    i7 = i4 + i21 | 0;
    do {
      if (HEAP8[i4 + (i21 + i3 | 0) | 0] << 24 >> 24 == i19 << 24 >> 24) {
        if (HEAP8[i4 + ((i3 - 1 | 0) + i21 | 0) | 0] << 24 >> 24 != i20 << 24 >> 24) {
          i22 = i19;
          i23 = i20;
          i24 = i3;
          break;
        }
        if (HEAP8[i7] << 24 >> 24 != HEAP8[i6] << 24 >> 24) {
          i22 = i19;
          i23 = i20;
          i24 = i3;
          break;
        }
        if (HEAP8[i4 + (i21 + 1 | 0) | 0] << 24 >> 24 != HEAP8[i15] << 24 >> 24) {
          i22 = i19;
          i23 = i20;
          i24 = i3;
          break;
        }
        i1 = i16;
        i25 = i4 + (i21 + 2 | 0) | 0;
        while (1) {
          i26 = i1 + 1 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 1 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 2 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 2 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 3 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 3 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 4 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 4 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 5 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 5 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 6 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 6 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 7 | 0;
          if (HEAP8[i26] << 24 >> 24 != HEAP8[i25 + 7 | 0] << 24 >> 24) {
            i27 = i26;
            break;
          }
          i26 = i1 + 8 | 0;
          i28 = i25 + 8 | 0;
          if (HEAP8[i26] << 24 >> 24 == HEAP8[i28] << 24 >> 24 & i26 >>> 0 < i12 >>> 0) {
            i1 = i26;
            i25 = i28;
          } else {
            i27 = i26;
            break;
          }
        }
        i25 = i27 - i17 | 0;
        i1 = i25 + 258 | 0;
        if ((i1 | 0) <= (i3 | 0)) {
          i22 = i19;
          i23 = i20;
          i24 = i3;
          break;
        }
        HEAP32[i8 >> 2] = i21;
        if ((i1 | 0) >= (i14 | 0)) {
          i29 = i1;
          i30 = 752;
          break L1030;
        }
        i22 = HEAP8[i4 + (i1 + i5 | 0) | 0] | 0;
        i23 = HEAP8[i4 + (i18 + i25 | 0) | 0] | 0;
        i24 = i1;
      } else {
        i22 = i19;
        i23 = i20;
        i24 = i3;
      }
    } while (0);
    i7 = HEAPU16[i9 + ((i21 & i11) << 1) >> 1] | 0;
    if (i7 >>> 0 <= i10 >>> 0) {
      i29 = i24;
      i30 = 753;
      break;
    }
    i1 = i2 - 1 | 0;
    if ((i1 | 0) == 0) {
      i29 = i24;
      i30 = 754;
      break;
    } else {
      i19 = i22;
      i20 = i23;
      i21 = i7;
      i2 = i1;
      i3 = i24;
    }
  }
  if ((i30 | 0) == 752) {
    i24 = i29 >>> 0 > i13 >>> 0;
    i3 = i24 ? i13 : i29;
    return i3 | 0;
  } else if ((i30 | 0) == 753) {
    i24 = i29 >>> 0 > i13 >>> 0;
    i3 = i24 ? i13 : i29;
    return i3 | 0;
  } else if ((i30 | 0) == 754) {
    i24 = i29 >>> 0 > i13 >>> 0;
    i3 = i24 ? i13 : i29;
    return i3 | 0;
  }
  return 0;
}
function _init_block(i1) {
  i1 = i1 | 0;
  var i2 = 0, i3 = 0;
  i2 = 0;
  while (1) {
    HEAP16[i1 + 148 + (i2 << 2) >> 1] = 0;
    i3 = i2 + 1 | 0;
    if ((i3 | 0) == 286) {
      break;
    } else {
      i2 = i3;
    }
  }
  HEAP16[i1 + 2440 >> 1] = 0;
  HEAP16[i1 + 2444 >> 1] = 0;
  HEAP16[i1 + 2448 >> 1] = 0;
  HEAP16[i1 + 2452 >> 1] = 0;
  HEAP16[i1 + 2456 >> 1] = 0;
  HEAP16[i1 + 2460 >> 1] = 0;
  HEAP16[i1 + 2464 >> 1] = 0;
  HEAP16[i1 + 2468 >> 1] = 0;
  HEAP16[i1 + 2472 >> 1] = 0;
  HEAP16[i1 + 2476 >> 1] = 0;
  HEAP16[i1 + 2480 >> 1] = 0;
  HEAP16[i1 + 2484 >> 1] = 0;
  HEAP16[i1 + 2488 >> 1] = 0;
  HEAP16[i1 + 2492 >> 1] = 0;
  HEAP16[i1 + 2496 >> 1] = 0;
  HEAP16[i1 + 2500 >> 1] = 0;
  HEAP16[i1 + 2504 >> 1] = 0;
  HEAP16[i1 + 2508 >> 1] = 0;
  HEAP16[i1 + 2512 >> 1] = 0;
  HEAP16[i1 + 2516 >> 1] = 0;
  HEAP16[i1 + 2520 >> 1] = 0;
  HEAP16[i1 + 2524 >> 1] = 0;
  HEAP16[i1 + 2528 >> 1] = 0;
  HEAP16[i1 + 2532 >> 1] = 0;
  HEAP16[i1 + 2536 >> 1] = 0;
  HEAP16[i1 + 2540 >> 1] = 0;
  HEAP16[i1 + 2544 >> 1] = 0;
  HEAP16[i1 + 2548 >> 1] = 0;
  HEAP16[i1 + 2552 >> 1] = 0;
  HEAP16[i1 + 2556 >> 1] = 0;
  HEAP16[i1 + 2684 >> 1] = 0;
  HEAP16[i1 + 2688 >> 1] = 0;
  HEAP16[i1 + 2692 >> 1] = 0;
  HEAP16[i1 + 2696 >> 1] = 0;
  HEAP16[i1 + 2700 >> 1] = 0;
  HEAP16[i1 + 2704 >> 1] = 0;
  HEAP16[i1 + 2708 >> 1] = 0;
  HEAP16[i1 + 2712 >> 1] = 0;
  HEAP16[i1 + 2716 >> 1] = 0;
  HEAP16[i1 + 2720 >> 1] = 0;
  HEAP16[i1 + 2724 >> 1] = 0;
  HEAP16[i1 + 2728 >> 1] = 0;
  HEAP16[i1 + 2732 >> 1] = 0;
  HEAP16[i1 + 2736 >> 1] = 0;
  HEAP16[i1 + 2740 >> 1] = 0;
  HEAP16[i1 + 2744 >> 1] = 0;
  HEAP16[i1 + 2748 >> 1] = 0;
  HEAP16[i1 + 2752 >> 1] = 0;
  HEAP16[i1 + 2756 >> 1] = 0;
  HEAP16[i1 + 1172 >> 1] = 1;
  HEAP32[i1 + 5804 >> 2] = 0;
  HEAP32[i1 + 5800 >> 2] = 0;
  HEAP32[i1 + 5808 >> 2] = 0;
  HEAP32[i1 + 5792 >> 2] = 0;
  return;
}
function _deflate_slow(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0;
  i3 = i1 + 116 | 0;
  i4 = (i2 | 0) == 0;
  i5 = i1 + 72 | 0;
  i6 = i1 + 88 | 0;
  i7 = i1 + 108 | 0;
  i8 = i1 + 56 | 0;
  i9 = i1 + 84 | 0;
  i10 = i1 + 68 | 0;
  i11 = i1 + 52 | 0;
  i12 = i1 + 64 | 0;
  i13 = i1 + 96 | 0;
  i14 = i1 + 120 | 0;
  i15 = i1 + 112 | 0;
  i16 = i1 + 100 | 0;
  i17 = i1 + 5792 | 0;
  i18 = i1 + 5796 | 0;
  i19 = i1 + 5784 | 0;
  i20 = i1 + 5788 | 0;
  i21 = i1 + 104 | 0;
  i22 = i1 + 92 | 0;
  i23 = i1;
  i24 = i1 | 0;
  i25 = i1 + 128 | 0;
  i26 = i1 + 44 | 0;
  i27 = i1 + 136 | 0;
  L1060 : while (1) {
    i28 = HEAP32[i3 >> 2] | 0;
    while (1) {
      do {
        if (i28 >>> 0 < 262) {
          _fill_window(i1);
          i29 = HEAP32[i3 >> 2] | 0;
          if (i29 >>> 0 < 262 & i4) {
            i30 = 0;
            i31 = 808;
            break L1060;
          }
          if ((i29 | 0) == 0) {
            i31 = 797;
            break L1060;
          }
          if (i29 >>> 0 > 2) {
            i31 = 765;
            break;
          }
          HEAP32[i14 >> 2] = HEAP32[i13 >> 2] | 0;
          HEAP32[i16 >> 2] = HEAP32[i15 >> 2] | 0;
          HEAP32[i13 >> 2] = 2;
          i32 = 2;
          i31 = 773;
          break;
        } else {
          i31 = 765;
        }
      } while (0);
      do {
        if ((i31 | 0) == 765) {
          i31 = 0;
          i29 = HEAP32[i7 >> 2] | 0;
          i33 = ((HEAPU8[(HEAP32[i8 >> 2] | 0) + (i29 + 2 | 0) | 0] | 0) ^ HEAP32[i5 >> 2] << HEAP32[i6 >> 2]) & HEAP32[i9 >> 2];
          HEAP32[i5 >> 2] = i33;
          i34 = HEAP16[(HEAP32[i10 >> 2] | 0) + (i33 << 1) >> 1] | 0;
          HEAP16[(HEAP32[i12 >> 2] | 0) + ((HEAP32[i11 >> 2] & i29) << 1) >> 1] = i34;
          i29 = i34 & 65535;
          HEAP16[(HEAP32[i10 >> 2] | 0) + (HEAP32[i5 >> 2] << 1) >> 1] = HEAP32[i7 >> 2] & 65535;
          i33 = HEAP32[i13 >> 2] | 0;
          HEAP32[i14 >> 2] = i33;
          HEAP32[i16 >> 2] = HEAP32[i15 >> 2] | 0;
          HEAP32[i13 >> 2] = 2;
          if (i34 << 16 >> 16 == 0) {
            i32 = 2;
            i31 = 773;
            break;
          }
          if (i33 >>> 0 >= (HEAP32[i25 >> 2] | 0) >>> 0) {
            i35 = i33;
            i36 = 2;
            break;
          }
          if (((HEAP32[i7 >> 2] | 0) - i29 | 0) >>> 0 > ((HEAP32[i26 >> 2] | 0) - 262 | 0) >>> 0) {
            i32 = 2;
            i31 = 773;
            break;
          }
          i33 = _longest_match(i1, i29) | 0;
          HEAP32[i13 >> 2] = i33;
          if (i33 >>> 0 >= 6) {
            i32 = i33;
            i31 = 773;
            break;
          }
          if ((HEAP32[i27 >> 2] | 0) != 1) {
            if ((i33 | 0) != 3) {
              i32 = i33;
              i31 = 773;
              break;
            }
            if (((HEAP32[i7 >> 2] | 0) - (HEAP32[i15 >> 2] | 0) | 0) >>> 0 <= 4096) {
              i32 = 3;
              i31 = 773;
              break;
            }
          }
          HEAP32[i13 >> 2] = 2;
          i32 = 2;
          i31 = 773;
          break;
        }
      } while (0);
      if ((i31 | 0) == 773) {
        i31 = 0;
        i35 = HEAP32[i14 >> 2] | 0;
        i36 = i32;
      }
      if (!(i35 >>> 0 < 3 | i36 >>> 0 > i35 >>> 0)) {
        break;
      }
      if ((HEAP32[i21 >> 2] | 0) == 0) {
        HEAP32[i21 >> 2] = 1;
        HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1 | 0;
        i33 = (HEAP32[i3 >> 2] | 0) - 1 | 0;
        HEAP32[i3 >> 2] = i33;
        i28 = i33;
        continue;
      }
      i33 = HEAP8[(HEAP32[i8 >> 2] | 0) + ((HEAP32[i7 >> 2] | 0) - 1 | 0) | 0] | 0;
      HEAP16[(HEAP32[i18 >> 2] | 0) + (HEAP32[i17 >> 2] << 1) >> 1] = 0;
      i29 = HEAP32[i17 >> 2] | 0;
      HEAP32[i17 >> 2] = i29 + 1 | 0;
      HEAP8[(HEAP32[i19 >> 2] | 0) + i29 | 0] = i33;
      i29 = i1 + 148 + ((i33 & 255) << 2) | 0;
      HEAP16[i29 >> 1] = (HEAP16[i29 >> 1] | 0) + 1 & 65535;
      do {
        if ((HEAP32[i17 >> 2] | 0) == ((HEAP32[i20 >> 2] | 0) - 1 | 0)) {
          i29 = HEAP32[i22 >> 2] | 0;
          if ((i29 | 0) > -1) {
            i37 = (HEAP32[i8 >> 2] | 0) + i29 | 0;
          } else {
            i37 = 0;
          }
          __tr_flush_block(i23, i37, (HEAP32[i7 >> 2] | 0) - i29 | 0, 0);
          HEAP32[i22 >> 2] = HEAP32[i7 >> 2] | 0;
          i29 = HEAP32[i24 >> 2] | 0;
          i33 = i29 + 28 | 0;
          i34 = HEAP32[i33 >> 2] | 0;
          i38 = HEAP32[i34 + 20 >> 2] | 0;
          i39 = i29 + 16 | 0;
          i40 = HEAP32[i39 >> 2] | 0;
          i41 = i38 >>> 0 > i40 >>> 0 ? i40 : i38;
          if ((i41 | 0) == 0) {
            break;
          }
          i38 = i29 + 12 | 0;
          _memcpy(HEAP32[i38 >> 2] | 0, HEAP32[i34 + 16 >> 2] | 0, i41);
          HEAP32[i38 >> 2] = (HEAP32[i38 >> 2] | 0) + i41 | 0;
          i38 = (HEAP32[i33 >> 2] | 0) + 16 | 0;
          HEAP32[i38 >> 2] = (HEAP32[i38 >> 2] | 0) + i41 | 0;
          i38 = i29 + 20 | 0;
          HEAP32[i38 >> 2] = (HEAP32[i38 >> 2] | 0) + i41 | 0;
          HEAP32[i39 >> 2] = (HEAP32[i39 >> 2] | 0) - i41 | 0;
          i39 = (HEAP32[i33 >> 2] | 0) + 20 | 0;
          HEAP32[i39 >> 2] = (HEAP32[i39 >> 2] | 0) - i41 | 0;
          i41 = HEAP32[i33 >> 2] | 0;
          if ((HEAP32[i41 + 20 >> 2] | 0) != 0) {
            break;
          }
          HEAP32[i41 + 16 >> 2] = HEAP32[i41 + 8 >> 2] | 0;
        }
      } while (0);
      HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1 | 0;
      i41 = (HEAP32[i3 >> 2] | 0) - 1 | 0;
      HEAP32[i3 >> 2] = i41;
      if ((HEAP32[(HEAP32[i24 >> 2] | 0) + 16 >> 2] | 0) == 0) {
        i30 = 0;
        i31 = 810;
        break L1060;
      } else {
        i28 = i41;
      }
    }
    i28 = HEAP32[i7 >> 2] | 0;
    i41 = (i28 - 3 | 0) + (HEAP32[i3 >> 2] | 0) | 0;
    i33 = i35 + 253 | 0;
    i39 = (i28 + 65535 | 0) - (HEAP32[i16 >> 2] | 0) | 0;
    HEAP16[(HEAP32[i18 >> 2] | 0) + (HEAP32[i17 >> 2] << 1) >> 1] = i39 & 65535;
    i28 = HEAP32[i17 >> 2] | 0;
    HEAP32[i17 >> 2] = i28 + 1 | 0;
    HEAP8[(HEAP32[i19 >> 2] | 0) + i28 | 0] = i33 & 255;
    i28 = i1 + 148 + ((HEAPU8[5255756 + (i33 & 255) | 0] | 0 | 256) + 1 << 2) | 0;
    HEAP16[i28 >> 1] = (HEAP16[i28 >> 1] | 0) + 1 & 65535;
    i28 = i39 + 65535 & 65535;
    if (i28 >>> 0 < 256) {
      i42 = i28;
    } else {
      i42 = (i28 >>> 7) + 256 | 0;
    }
    i28 = i1 + 2440 + ((HEAPU8[i42 + 5256480 | 0] | 0) << 2) | 0;
    HEAP16[i28 >> 1] = (HEAP16[i28 >> 1] | 0) + 1 & 65535;
    i28 = HEAP32[i17 >> 2] | 0;
    i39 = (HEAP32[i20 >> 2] | 0) - 1 | 0;
    i33 = HEAP32[i14 >> 2] | 0;
    HEAP32[i3 >> 2] = (1 - i33 | 0) + (HEAP32[i3 >> 2] | 0) | 0;
    i38 = i33 - 2 | 0;
    HEAP32[i14 >> 2] = i38;
    i33 = i38;
    while (1) {
      i38 = HEAP32[i7 >> 2] | 0;
      i29 = i38 + 1 | 0;
      HEAP32[i7 >> 2] = i29;
      if (i29 >>> 0 > i41 >>> 0) {
        i43 = i33;
      } else {
        i34 = ((HEAPU8[(HEAP32[i8 >> 2] | 0) + (i38 + 3 | 0) | 0] | 0) ^ HEAP32[i5 >> 2] << HEAP32[i6 >> 2]) & HEAP32[i9 >> 2];
        HEAP32[i5 >> 2] = i34;
        HEAP16[(HEAP32[i12 >> 2] | 0) + ((HEAP32[i11 >> 2] & i29) << 1) >> 1] = HEAP16[(HEAP32[i10 >> 2] | 0) + (i34 << 1) >> 1] | 0;
        HEAP16[(HEAP32[i10 >> 2] | 0) + (HEAP32[i5 >> 2] << 1) >> 1] = HEAP32[i7 >> 2] & 65535;
        i43 = HEAP32[i14 >> 2] | 0;
      }
      i34 = i43 - 1 | 0;
      HEAP32[i14 >> 2] = i34;
      if ((i34 | 0) == 0) {
        break;
      } else {
        i33 = i34;
      }
    }
    HEAP32[i21 >> 2] = 0;
    HEAP32[i13 >> 2] = 2;
    i33 = (HEAP32[i7 >> 2] | 0) + 1 | 0;
    HEAP32[i7 >> 2] = i33;
    if ((i28 | 0) != (i39 | 0)) {
      continue;
    }
    i41 = HEAP32[i22 >> 2] | 0;
    if ((i41 | 0) > -1) {
      i44 = (HEAP32[i8 >> 2] | 0) + i41 | 0;
    } else {
      i44 = 0;
    }
    __tr_flush_block(i23, i44, i33 - i41 | 0, 0);
    HEAP32[i22 >> 2] = HEAP32[i7 >> 2] | 0;
    i41 = HEAP32[i24 >> 2] | 0;
    i33 = i41 + 28 | 0;
    i34 = HEAP32[i33 >> 2] | 0;
    i29 = HEAP32[i34 + 20 >> 2] | 0;
    i38 = i41 + 16 | 0;
    i40 = HEAP32[i38 >> 2] | 0;
    i45 = i29 >>> 0 > i40 >>> 0 ? i40 : i29;
    do {
      if ((i45 | 0) != 0) {
        i29 = i41 + 12 | 0;
        _memcpy(HEAP32[i29 >> 2] | 0, HEAP32[i34 + 16 >> 2] | 0, i45);
        HEAP32[i29 >> 2] = (HEAP32[i29 >> 2] | 0) + i45 | 0;
        i29 = (HEAP32[i33 >> 2] | 0) + 16 | 0;
        HEAP32[i29 >> 2] = (HEAP32[i29 >> 2] | 0) + i45 | 0;
        i29 = i41 + 20 | 0;
        HEAP32[i29 >> 2] = (HEAP32[i29 >> 2] | 0) + i45 | 0;
        HEAP32[i38 >> 2] = (HEAP32[i38 >> 2] | 0) - i45 | 0;
        i29 = (HEAP32[i33 >> 2] | 0) + 20 | 0;
        HEAP32[i29 >> 2] = (HEAP32[i29 >> 2] | 0) - i45 | 0;
        i29 = HEAP32[i33 >> 2] | 0;
        if ((HEAP32[i29 + 20 >> 2] | 0) != 0) {
          break;
        }
        HEAP32[i29 + 16 >> 2] = HEAP32[i29 + 8 >> 2] | 0;
      }
    } while (0);
    if ((HEAP32[(HEAP32[i24 >> 2] | 0) + 16 >> 2] | 0) == 0) {
      i30 = 0;
      i31 = 809;
      break;
    }
  }
  if ((i31 | 0) == 797) {
    if ((HEAP32[i21 >> 2] | 0) != 0) {
      i44 = HEAP8[(HEAP32[i8 >> 2] | 0) + ((HEAP32[i7 >> 2] | 0) - 1 | 0) | 0] | 0;
      HEAP16[(HEAP32[i18 >> 2] | 0) + (HEAP32[i17 >> 2] << 1) >> 1] = 0;
      i18 = HEAP32[i17 >> 2] | 0;
      HEAP32[i17 >> 2] = i18 + 1 | 0;
      HEAP8[(HEAP32[i19 >> 2] | 0) + i18 | 0] = i44;
      i18 = i1 + 148 + ((i44 & 255) << 2) | 0;
      HEAP16[i18 >> 1] = (HEAP16[i18 >> 1] | 0) + 1 & 65535;
      HEAP32[i21 >> 2] = 0;
    }
    i21 = HEAP32[i22 >> 2] | 0;
    if ((i21 | 0) > -1) {
      i46 = (HEAP32[i8 >> 2] | 0) + i21 | 0;
    } else {
      i46 = 0;
    }
    i8 = (i2 | 0) == 4;
    __tr_flush_block(i23, i46, (HEAP32[i7 >> 2] | 0) - i21 | 0, i8 & 1);
    HEAP32[i22 >> 2] = HEAP32[i7 >> 2] | 0;
    i7 = HEAP32[i24 >> 2] | 0;
    i22 = i7 + 28 | 0;
    i21 = HEAP32[i22 >> 2] | 0;
    i46 = HEAP32[i21 + 20 >> 2] | 0;
    i23 = i7 + 16 | 0;
    i2 = HEAP32[i23 >> 2] | 0;
    i18 = i46 >>> 0 > i2 >>> 0 ? i2 : i46;
    do {
      if ((i18 | 0) != 0) {
        i46 = i7 + 12 | 0;
        _memcpy(HEAP32[i46 >> 2] | 0, HEAP32[i21 + 16 >> 2] | 0, i18);
        HEAP32[i46 >> 2] = (HEAP32[i46 >> 2] | 0) + i18 | 0;
        i46 = (HEAP32[i22 >> 2] | 0) + 16 | 0;
        HEAP32[i46 >> 2] = (HEAP32[i46 >> 2] | 0) + i18 | 0;
        i46 = i7 + 20 | 0;
        HEAP32[i46 >> 2] = (HEAP32[i46 >> 2] | 0) + i18 | 0;
        HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) - i18 | 0;
        i46 = (HEAP32[i22 >> 2] | 0) + 20 | 0;
        HEAP32[i46 >> 2] = (HEAP32[i46 >> 2] | 0) - i18 | 0;
        i46 = HEAP32[i22 >> 2] | 0;
        if ((HEAP32[i46 + 20 >> 2] | 0) != 0) {
          break;
        }
        HEAP32[i46 + 16 >> 2] = HEAP32[i46 + 8 >> 2] | 0;
      }
    } while (0);
    if ((HEAP32[(HEAP32[i24 >> 2] | 0) + 16 >> 2] | 0) == 0) {
      i30 = i8 ? 2 : 0;
      return i30 | 0;
    } else {
      i30 = i8 ? 3 : 1;
      return i30 | 0;
    }
  } else if ((i31 | 0) == 808) {
    return i30 | 0;
  } else if ((i31 | 0) == 809) {
    return i30 | 0;
  } else if ((i31 | 0) == 810) {
    return i30 | 0;
  }
  return 0;
}
function __tr_stored_block(i1, i2, i3, i4) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  i4 = i4 | 0;
  var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0;
  i5 = i1 + 5820 | 0;
  i6 = HEAP32[i5 >> 2] | 0;
  i7 = i4 & 65535;
  i4 = i1 + 5816 | 0;
  i8 = HEAPU16[i4 >> 1] | 0 | i7 << i6;
  i9 = i8 & 65535;
  HEAP16[i4 >> 1] = i9;
  if ((i6 | 0) > 13) {
    i10 = i1 + 20 | 0;
    i11 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i11 + 1 | 0;
    i12 = i1 + 8 | 0;
    HEAP8[(HEAP32[i12 >> 2] | 0) + i11 | 0] = i8 & 255;
    i8 = (HEAPU16[i4 >> 1] | 0) >>> 8 & 255;
    i11 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i11 + 1 | 0;
    HEAP8[(HEAP32[i12 >> 2] | 0) + i11 | 0] = i8;
    i8 = HEAP32[i5 >> 2] | 0;
    i11 = i7 >>> ((16 - i8 | 0) >>> 0) & 65535;
    HEAP16[i4 >> 1] = i11;
    i13 = i8 - 13 | 0;
    i14 = i11;
  } else {
    i13 = i6 + 3 | 0;
    i14 = i9;
  }
  HEAP32[i5 >> 2] = i13;
  do {
    if ((i13 | 0) > 8) {
      i9 = i1 + 20 | 0;
      i6 = HEAP32[i9 >> 2] | 0;
      HEAP32[i9 >> 2] = i6 + 1 | 0;
      i11 = i1 + 8 | 0;
      HEAP8[(HEAP32[i11 >> 2] | 0) + i6 | 0] = i14 & 255;
      i6 = (HEAPU16[i4 >> 1] | 0) >>> 8 & 255;
      i8 = HEAP32[i9 >> 2] | 0;
      HEAP32[i9 >> 2] = i8 + 1 | 0;
      HEAP8[(HEAP32[i11 >> 2] | 0) + i8 | 0] = i6;
      i15 = i9;
      i16 = i11;
    } else {
      if ((i13 | 0) > 0) {
        i11 = i1 + 20 | 0;
        i9 = HEAP32[i11 >> 2] | 0;
        HEAP32[i11 >> 2] = i9 + 1 | 0;
        i6 = i1 + 8 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i9 | 0] = i14 & 255;
        i15 = i11;
        i16 = i6;
        break;
      } else {
        i15 = i1 + 20 | 0;
        i16 = i1 + 8 | 0;
        break;
      }
    }
  } while (0);
  HEAP16[i4 >> 1] = 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i1 + 5812 >> 2] = 8;
  i1 = HEAP32[i15 >> 2] | 0;
  HEAP32[i15 >> 2] = i1 + 1 | 0;
  HEAP8[(HEAP32[i16 >> 2] | 0) + i1 | 0] = i3 & 255;
  i1 = HEAP32[i15 >> 2] | 0;
  HEAP32[i15 >> 2] = i1 + 1 | 0;
  HEAP8[(HEAP32[i16 >> 2] | 0) + i1 | 0] = i3 >>> 8 & 255;
  i1 = i3 & 65535 ^ 65535;
  i5 = HEAP32[i15 >> 2] | 0;
  HEAP32[i15 >> 2] = i5 + 1 | 0;
  HEAP8[(HEAP32[i16 >> 2] | 0) + i5 | 0] = i1 & 255;
  i5 = HEAP32[i15 >> 2] | 0;
  HEAP32[i15 >> 2] = i5 + 1 | 0;
  HEAP8[(HEAP32[i16 >> 2] | 0) + i5 | 0] = i1 >>> 8 & 255;
  if ((i3 | 0) == 0) {
    return;
  } else {
    i17 = i3;
    i18 = i2;
  }
  while (1) {
    i2 = i17 - 1 | 0;
    i3 = HEAP8[i18] | 0;
    i1 = HEAP32[i15 >> 2] | 0;
    HEAP32[i15 >> 2] = i1 + 1 | 0;
    HEAP8[(HEAP32[i16 >> 2] | 0) + i1 | 0] = i3;
    if ((i2 | 0) == 0) {
      break;
    } else {
      i17 = i2;
      i18 = i18 + 1 | 0;
    }
  }
  return;
}
function __tr_flush_block(i1, i2, i3, i4) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  i4 = i4 | 0;
  var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0;
  if ((HEAP32[i1 + 132 >> 2] | 0) > 0) {
    i5 = (HEAP32[i1 >> 2] | 0) + 44 | 0;
    if ((HEAP32[i5 >> 2] | 0) == 2) {
      i6 = -201342849;
      i7 = 0;
      while (1) {
        if ((i6 & 1 | 0) != 0) {
          if (HEAP16[i1 + 148 + (i7 << 2) >> 1] << 16 >> 16 != 0) {
            i8 = 0;
            break;
          }
        }
        i9 = i7 + 1 | 0;
        if ((i9 | 0) < 32) {
          i6 = i6 >>> 1;
          i7 = i9;
        } else {
          i10 = 831;
          break;
        }
      }
      L1159 : do {
        if ((i10 | 0) == 831) {
          if (HEAP16[i1 + 184 >> 1] << 16 >> 16 != 0) {
            i8 = 1;
            break;
          }
          if (HEAP16[i1 + 188 >> 1] << 16 >> 16 != 0) {
            i8 = 1;
            break;
          }
          if (HEAP16[i1 + 200 >> 1] << 16 >> 16 == 0) {
            i11 = 32;
          } else {
            i8 = 1;
            break;
          }
          while (1) {
            if ((i11 | 0) >= 256) {
              i8 = 0;
              break L1159;
            }
            if (HEAP16[i1 + 148 + (i11 << 2) >> 1] << 16 >> 16 == 0) {
              i11 = i11 + 1 | 0;
            } else {
              i8 = 1;
              break L1159;
            }
          }
        }
      } while (0);
      HEAP32[i5 >> 2] = i8;
    }
    _build_tree(i1, i1 + 2840 | 0);
    _build_tree(i1, i1 + 2852 | 0);
    i8 = HEAP32[i1 + 2844 >> 2] | 0;
    i5 = HEAP16[i1 + 150 >> 1] | 0;
    i11 = i5 << 16 >> 16 == 0;
    HEAP16[i1 + 148 + (i8 + 1 << 2) + 2 >> 1] = -1;
    i10 = i1 + 2752 | 0;
    i7 = i1 + 2756 | 0;
    i6 = i1 + 2748 | 0;
    i9 = i11 ? 3 : 4;
    i12 = i11 ? 138 : 7;
    i11 = i5 & 65535;
    i5 = 0;
    i13 = -1;
    L1168 : while (1) {
      i14 = 0;
      i15 = i5;
      while (1) {
        if ((i15 | 0) > (i8 | 0)) {
          break L1168;
        }
        i16 = i15 + 1 | 0;
        i17 = HEAP16[i1 + 148 + (i16 << 2) + 2 >> 1] | 0;
        i18 = i17 & 65535;
        i19 = i14 + 1 | 0;
        i20 = (i11 | 0) == (i18 | 0);
        if ((i19 | 0) < (i12 | 0) & i20) {
          i14 = i19;
          i15 = i16;
        } else {
          break;
        }
      }
      do {
        if ((i19 | 0) < (i9 | 0)) {
          i15 = i1 + 2684 + (i11 << 2) | 0;
          HEAP16[i15 >> 1] = (HEAPU16[i15 >> 1] | 0) + i19 & 65535;
        } else {
          if ((i11 | 0) == 0) {
            if ((i19 | 0) < 11) {
              HEAP16[i10 >> 1] = (HEAP16[i10 >> 1] | 0) + 1 & 65535;
              break;
            } else {
              HEAP16[i7 >> 1] = (HEAP16[i7 >> 1] | 0) + 1 & 65535;
              break;
            }
          } else {
            if ((i11 | 0) != (i13 | 0)) {
              i15 = i1 + 2684 + (i11 << 2) | 0;
              HEAP16[i15 >> 1] = (HEAP16[i15 >> 1] | 0) + 1 & 65535;
            }
            HEAP16[i6 >> 1] = (HEAP16[i6 >> 1] | 0) + 1 & 65535;
            break;
          }
        }
      } while (0);
      if (i17 << 16 >> 16 == 0) {
        i9 = 3;
        i12 = 138;
        i13 = i11;
        i11 = i18;
        i5 = i16;
        continue;
      }
      i9 = i20 ? 3 : 4;
      i12 = i20 ? 6 : 7;
      i13 = i11;
      i11 = i18;
      i5 = i16;
    }
    i16 = HEAP32[i1 + 2856 >> 2] | 0;
    i5 = HEAP16[i1 + 2442 >> 1] | 0;
    i18 = i5 << 16 >> 16 == 0;
    HEAP16[i1 + 2440 + (i16 + 1 << 2) + 2 >> 1] = -1;
    i11 = i18 ? 3 : 4;
    i13 = i18 ? 138 : 7;
    i18 = i5 & 65535;
    i5 = 0;
    i20 = -1;
    L1189 : while (1) {
      i12 = 0;
      i9 = i5;
      while (1) {
        if ((i9 | 0) > (i16 | 0)) {
          break L1189;
        }
        i21 = i9 + 1 | 0;
        i22 = HEAP16[i1 + 2440 + (i21 << 2) + 2 >> 1] | 0;
        i23 = i22 & 65535;
        i24 = i12 + 1 | 0;
        i25 = (i18 | 0) == (i23 | 0);
        if ((i24 | 0) < (i13 | 0) & i25) {
          i12 = i24;
          i9 = i21;
        } else {
          break;
        }
      }
      do {
        if ((i24 | 0) < (i11 | 0)) {
          i9 = i1 + 2684 + (i18 << 2) | 0;
          HEAP16[i9 >> 1] = (HEAPU16[i9 >> 1] | 0) + i24 & 65535;
        } else {
          if ((i18 | 0) == 0) {
            if ((i24 | 0) < 11) {
              HEAP16[i10 >> 1] = (HEAP16[i10 >> 1] | 0) + 1 & 65535;
              break;
            } else {
              HEAP16[i7 >> 1] = (HEAP16[i7 >> 1] | 0) + 1 & 65535;
              break;
            }
          } else {
            if ((i18 | 0) != (i20 | 0)) {
              i9 = i1 + 2684 + (i18 << 2) | 0;
              HEAP16[i9 >> 1] = (HEAP16[i9 >> 1] | 0) + 1 & 65535;
            }
            HEAP16[i6 >> 1] = (HEAP16[i6 >> 1] | 0) + 1 & 65535;
            break;
          }
        }
      } while (0);
      if (i22 << 16 >> 16 == 0) {
        i11 = 3;
        i13 = 138;
        i20 = i18;
        i18 = i23;
        i5 = i21;
        continue;
      }
      i11 = i25 ? 3 : 4;
      i13 = i25 ? 6 : 7;
      i20 = i18;
      i18 = i23;
      i5 = i21;
    }
    _build_tree(i1, i1 + 2864 | 0);
    i21 = 18;
    while (1) {
      if ((i21 | 0) <= 2) {
        break;
      }
      if (HEAP16[i1 + 2684 + ((HEAPU8[i21 + 5255344 | 0] | 0) << 2) + 2 >> 1] << 16 >> 16 == 0) {
        i21 = i21 - 1 | 0;
      } else {
        break;
      }
    }
    i5 = i1 + 5800 | 0;
    i23 = ((i21 * 3 & -1 & -1) + 17 | 0) + (HEAP32[i5 >> 2] | 0) | 0;
    HEAP32[i5 >> 2] = i23;
    i5 = (i23 + 10 | 0) >>> 3;
    i23 = ((HEAP32[i1 + 5804 >> 2] | 0) + 10 | 0) >>> 3;
    i26 = i23 >>> 0 > i5 >>> 0 ? i5 : i23;
    i27 = i23;
    i28 = i21;
  } else {
    i21 = i3 + 5 | 0;
    i26 = i21;
    i27 = i21;
    i28 = 0;
  }
  do {
    if ((i3 + 4 | 0) >>> 0 > i26 >>> 0 | (i2 | 0) == 0) {
      i21 = i1 + 5820 | 0;
      i23 = HEAP32[i21 >> 2] | 0;
      i5 = (i23 | 0) > 13;
      if ((HEAP32[i1 + 136 >> 2] | 0) == 4 | (i27 | 0) == (i26 | 0)) {
        i18 = i4 + 2 & 65535;
        i20 = i1 + 5816 | 0;
        i25 = HEAPU16[i20 >> 1] | 0 | i18 << i23;
        HEAP16[i20 >> 1] = i25 & 65535;
        if (i5) {
          i13 = i1 + 20 | 0;
          i11 = HEAP32[i13 >> 2] | 0;
          HEAP32[i13 >> 2] = i11 + 1 | 0;
          i22 = i1 + 8 | 0;
          HEAP8[(HEAP32[i22 >> 2] | 0) + i11 | 0] = i25 & 255;
          i25 = (HEAPU16[i20 >> 1] | 0) >>> 8 & 255;
          i11 = HEAP32[i13 >> 2] | 0;
          HEAP32[i13 >> 2] = i11 + 1 | 0;
          HEAP8[(HEAP32[i22 >> 2] | 0) + i11 | 0] = i25;
          i25 = HEAP32[i21 >> 2] | 0;
          HEAP16[i20 >> 1] = i18 >>> ((16 - i25 | 0) >>> 0) & 65535;
          i29 = i25 - 13 | 0;
        } else {
          i29 = i23 + 3 | 0;
        }
        HEAP32[i21 >> 2] = i29;
        _compress_block(i1, 5242884, 5244056);
        break;
      }
      i25 = i4 + 4 & 65535;
      i18 = i1 + 5816 | 0;
      i20 = HEAPU16[i18 >> 1] | 0 | i25 << i23;
      HEAP16[i18 >> 1] = i20 & 65535;
      if (i5) {
        i5 = i1 + 20 | 0;
        i11 = HEAP32[i5 >> 2] | 0;
        HEAP32[i5 >> 2] = i11 + 1 | 0;
        i22 = i1 + 8 | 0;
        HEAP8[(HEAP32[i22 >> 2] | 0) + i11 | 0] = i20 & 255;
        i11 = (HEAPU16[i18 >> 1] | 0) >>> 8 & 255;
        i13 = HEAP32[i5 >> 2] | 0;
        HEAP32[i5 >> 2] = i13 + 1 | 0;
        HEAP8[(HEAP32[i22 >> 2] | 0) + i13 | 0] = i11;
        i11 = HEAP32[i21 >> 2] | 0;
        i13 = i25 >>> ((16 - i11 | 0) >>> 0);
        HEAP16[i18 >> 1] = i13 & 65535;
        i30 = i11 - 13 | 0;
        i31 = i13;
      } else {
        i30 = i23 + 3 | 0;
        i31 = i20;
      }
      HEAP32[i21 >> 2] = i30;
      i20 = HEAP32[i1 + 2844 >> 2] | 0;
      i23 = HEAP32[i1 + 2856 >> 2] | 0;
      i13 = i28 + 1 | 0;
      i11 = i20 + 65280 & 65535;
      i25 = i31 & 65535 | i11 << i30;
      HEAP16[i18 >> 1] = i25 & 65535;
      if ((i30 | 0) > 11) {
        i22 = i1 + 20 | 0;
        i5 = HEAP32[i22 >> 2] | 0;
        HEAP32[i22 >> 2] = i5 + 1 | 0;
        i6 = i1 + 8 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i5 | 0] = i25 & 255;
        i5 = (HEAPU16[i18 >> 1] | 0) >>> 8 & 255;
        i7 = HEAP32[i22 >> 2] | 0;
        HEAP32[i22 >> 2] = i7 + 1 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i7 | 0] = i5;
        i5 = HEAP32[i21 >> 2] | 0;
        i7 = i11 >>> ((16 - i5 | 0) >>> 0);
        HEAP16[i18 >> 1] = i7 & 65535;
        i32 = i5 - 11 | 0;
        i33 = i7;
      } else {
        i32 = i30 + 5 | 0;
        i33 = i25;
      }
      HEAP32[i21 >> 2] = i32;
      i25 = i23 & 65535;
      i7 = i25 << i32 | i33 & 65535;
      HEAP16[i18 >> 1] = i7 & 65535;
      if ((i32 | 0) > 11) {
        i5 = i1 + 20 | 0;
        i11 = HEAP32[i5 >> 2] | 0;
        HEAP32[i5 >> 2] = i11 + 1 | 0;
        i6 = i1 + 8 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i11 | 0] = i7 & 255;
        i11 = (HEAPU16[i18 >> 1] | 0) >>> 8 & 255;
        i22 = HEAP32[i5 >> 2] | 0;
        HEAP32[i5 >> 2] = i22 + 1 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i22 | 0] = i11;
        i11 = HEAP32[i21 >> 2] | 0;
        i22 = i25 >>> ((16 - i11 | 0) >>> 0);
        HEAP16[i18 >> 1] = i22 & 65535;
        i34 = i11 - 11 | 0;
        i35 = i22;
      } else {
        i34 = i32 + 5 | 0;
        i35 = i7;
      }
      HEAP32[i21 >> 2] = i34;
      i7 = i28 + 65533 & 65535;
      i22 = i7 << i34 | i35 & 65535;
      HEAP16[i18 >> 1] = i22 & 65535;
      if ((i34 | 0) > 12) {
        i11 = i1 + 20 | 0;
        i25 = HEAP32[i11 >> 2] | 0;
        HEAP32[i11 >> 2] = i25 + 1 | 0;
        i6 = i1 + 8 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i25 | 0] = i22 & 255;
        i25 = (HEAPU16[i18 >> 1] | 0) >>> 8 & 255;
        i5 = HEAP32[i11 >> 2] | 0;
        HEAP32[i11 >> 2] = i5 + 1 | 0;
        HEAP8[(HEAP32[i6 >> 2] | 0) + i5 | 0] = i25;
        i25 = HEAP32[i21 >> 2] | 0;
        i5 = i7 >>> ((16 - i25 | 0) >>> 0);
        HEAP16[i18 >> 1] = i5 & 65535;
        i36 = i25 - 12 | 0;
        i37 = i5;
      } else {
        i36 = i34 + 4 | 0;
        i37 = i22;
      }
      HEAP32[i21 >> 2] = i36;
      L1241 : do {
        if ((i13 | 0) > 0) {
          i22 = i1 + 20 | 0;
          i5 = i1 + 8 | 0;
          i25 = 0;
          i7 = i36;
          i6 = i37;
          while (1) {
            i11 = HEAPU16[i1 + 2684 + ((HEAPU8[i25 + 5255344 | 0] | 0) << 2) + 2 >> 1] | 0;
            i10 = i11 << i7 | i6 & 65535;
            HEAP16[i18 >> 1] = i10 & 65535;
            if ((i7 | 0) > 13) {
              i24 = HEAP32[i22 >> 2] | 0;
              HEAP32[i22 >> 2] = i24 + 1 | 0;
              HEAP8[(HEAP32[i5 >> 2] | 0) + i24 | 0] = i10 & 255;
              i24 = (HEAPU16[i18 >> 1] | 0) >>> 8 & 255;
              i16 = HEAP32[i22 >> 2] | 0;
              HEAP32[i22 >> 2] = i16 + 1 | 0;
              HEAP8[(HEAP32[i5 >> 2] | 0) + i16 | 0] = i24;
              i24 = HEAP32[i21 >> 2] | 0;
              i16 = i11 >>> ((16 - i24 | 0) >>> 0);
              HEAP16[i18 >> 1] = i16 & 65535;
              i38 = i24 - 13 | 0;
              i39 = i16;
            } else {
              i38 = i7 + 3 | 0;
              i39 = i10;
            }
            HEAP32[i21 >> 2] = i38;
            i10 = i25 + 1 | 0;
            if ((i10 | 0) == (i13 | 0)) {
              break L1241;
            } else {
              i25 = i10;
              i7 = i38;
              i6 = i39;
            }
          }
        }
      } while (0);
      i13 = i1 + 148 | 0;
      _send_tree(i1, i13, i20);
      i21 = i1 + 2440 | 0;
      _send_tree(i1, i21, i23);
      _compress_block(i1, i13, i21);
    } else {
      __tr_stored_block(i1, i2, i3, i4);
    }
  } while (0);
  _init_block(i1);
  if ((i4 | 0) == 0) {
    return;
  }
  i4 = i1 + 5820 | 0;
  i3 = HEAP32[i4 >> 2] | 0;
  do {
    if ((i3 | 0) > 8) {
      i2 = i1 + 5816 | 0;
      i39 = HEAP16[i2 >> 1] & 255;
      i38 = i1 + 20 | 0;
      i37 = HEAP32[i38 >> 2] | 0;
      HEAP32[i38 >> 2] = i37 + 1 | 0;
      i36 = i1 + 8 | 0;
      HEAP8[(HEAP32[i36 >> 2] | 0) + i37 | 0] = i39;
      i39 = (HEAPU16[i2 >> 1] | 0) >>> 8 & 255;
      i37 = HEAP32[i38 >> 2] | 0;
      HEAP32[i38 >> 2] = i37 + 1 | 0;
      HEAP8[(HEAP32[i36 >> 2] | 0) + i37 | 0] = i39;
      i40 = i2;
    } else {
      i2 = i1 + 5816 | 0;
      if ((i3 | 0) <= 0) {
        i40 = i2;
        break;
      }
      i39 = HEAP16[i2 >> 1] & 255;
      i37 = i1 + 20 | 0;
      i36 = HEAP32[i37 >> 2] | 0;
      HEAP32[i37 >> 2] = i36 + 1 | 0;
      HEAP8[(HEAP32[i1 + 8 >> 2] | 0) + i36 | 0] = i39;
      i40 = i2;
    }
  } while (0);
  HEAP16[i40 >> 1] = 0;
  HEAP32[i4 >> 2] = 0;
  return;
}
function _build_tree(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0;
  i3 = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  i4 = i3 | 0;
  i5 = i2 | 0;
  i6 = HEAP32[i5 >> 2] | 0;
  i7 = i2 + 8 | 0;
  i8 = HEAP32[i7 >> 2] | 0;
  i9 = HEAP32[i8 >> 2] | 0;
  i10 = HEAP32[i8 + 12 >> 2] | 0;
  i8 = i1 + 5200 | 0;
  HEAP32[i8 >> 2] = 0;
  i11 = i1 + 5204 | 0;
  HEAP32[i11 >> 2] = 573;
  do {
    if ((i10 | 0) > 0) {
      i12 = 0;
      i13 = -1;
      while (1) {
        if (HEAP16[i6 + (i12 << 2) >> 1] << 16 >> 16 == 0) {
          HEAP16[i6 + (i12 << 2) + 2 >> 1] = 0;
          i14 = i13;
        } else {
          i15 = (HEAP32[i8 >> 2] | 0) + 1 | 0;
          HEAP32[i8 >> 2] = i15;
          HEAP32[i1 + 2908 + (i15 << 2) >> 2] = i12;
          HEAP8[i12 + (i1 + 5208) | 0] = 0;
          i14 = i12;
        }
        i15 = i12 + 1 | 0;
        if ((i15 | 0) == (i10 | 0)) {
          break;
        } else {
          i12 = i15;
          i13 = i14;
        }
      }
      i13 = HEAP32[i8 >> 2] | 0;
      if ((i13 | 0) < 2) {
        i16 = i13;
        i17 = i14;
        i18 = 909;
        break;
      } else {
        i19 = i14;
        break;
      }
    } else {
      i16 = 0;
      i17 = -1;
      i18 = 909;
    }
  } while (0);
  L1269 : do {
    if ((i18 | 0) == 909) {
      i14 = i1 + 5800 | 0;
      i13 = i1 + 5804 | 0;
      if ((i9 | 0) == 0) {
        i12 = i17;
        i15 = i16;
        while (1) {
          i20 = (i12 | 0) < 2;
          i21 = i12 + 1 | 0;
          i22 = i20 ? i21 : i12;
          i23 = i20 ? i21 : 0;
          i21 = i15 + 1 | 0;
          HEAP32[i8 >> 2] = i21;
          HEAP32[i1 + 2908 + (i21 << 2) >> 2] = i23;
          HEAP16[i6 + (i23 << 2) >> 1] = 1;
          HEAP8[i23 + (i1 + 5208) | 0] = 0;
          HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) - 1 | 0;
          i23 = HEAP32[i8 >> 2] | 0;
          if ((i23 | 0) < 2) {
            i12 = i22;
            i15 = i23;
          } else {
            i19 = i22;
            break L1269;
          }
        }
      } else {
        i15 = i17;
        i12 = i16;
        while (1) {
          i22 = (i15 | 0) < 2;
          i23 = i15 + 1 | 0;
          i21 = i22 ? i23 : i15;
          i20 = i22 ? i23 : 0;
          i23 = i12 + 1 | 0;
          HEAP32[i8 >> 2] = i23;
          HEAP32[i1 + 2908 + (i23 << 2) >> 2] = i20;
          HEAP16[i6 + (i20 << 2) >> 1] = 1;
          HEAP8[i20 + (i1 + 5208) | 0] = 0;
          HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) - 1 | 0;
          HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) - (HEAPU16[i9 + (i20 << 2) + 2 >> 1] | 0) | 0;
          i20 = HEAP32[i8 >> 2] | 0;
          if ((i20 | 0) < 2) {
            i15 = i21;
            i12 = i20;
          } else {
            i19 = i21;
            break L1269;
          }
        }
      }
    }
  } while (0);
  i9 = i2 + 4 | 0;
  HEAP32[i9 >> 2] = i19;
  i2 = HEAP32[i8 >> 2] | 0;
  L1277 : do {
    if ((i2 | 0) > 1) {
      i16 = (i2 | 0) / 2 & -1;
      i17 = i2;
      while (1) {
        i18 = HEAP32[i1 + 2908 + (i16 << 2) >> 2] | 0;
        i12 = i18 + (i1 + 5208) | 0;
        i15 = i16 << 1;
        L1281 : do {
          if ((i15 | 0) > (i17 | 0)) {
            i24 = i16;
          } else {
            i13 = i6 + (i18 << 2) | 0;
            i14 = i16;
            i21 = i15;
            i20 = i17;
            while (1) {
              do {
                if ((i21 | 0) < (i20 | 0)) {
                  i23 = i21 | 1;
                  i22 = HEAP32[i1 + 2908 + (i23 << 2) >> 2] | 0;
                  i25 = HEAP16[i6 + (i22 << 2) >> 1] | 0;
                  i26 = HEAP32[i1 + 2908 + (i21 << 2) >> 2] | 0;
                  i27 = HEAP16[i6 + (i26 << 2) >> 1] | 0;
                  if ((i25 & 65535) >= (i27 & 65535)) {
                    if (i25 << 16 >> 16 != i27 << 16 >> 16) {
                      i28 = i21;
                      break;
                    }
                    if ((HEAPU8[i22 + (i1 + 5208) | 0] | 0) > (HEAPU8[i26 + (i1 + 5208) | 0] | 0)) {
                      i28 = i21;
                      break;
                    }
                  }
                  i28 = i23;
                } else {
                  i28 = i21;
                }
              } while (0);
              i23 = HEAP16[i13 >> 1] | 0;
              i26 = HEAP32[i1 + 2908 + (i28 << 2) >> 2] | 0;
              i22 = HEAP16[i6 + (i26 << 2) >> 1] | 0;
              if ((i23 & 65535) < (i22 & 65535)) {
                i24 = i14;
                break L1281;
              }
              if (i23 << 16 >> 16 == i22 << 16 >> 16) {
                if ((HEAPU8[i12] | 0) <= (HEAPU8[i26 + (i1 + 5208) | 0] | 0)) {
                  i24 = i14;
                  break L1281;
                }
              }
              HEAP32[i1 + 2908 + (i14 << 2) >> 2] = i26;
              i26 = i28 << 1;
              i22 = HEAP32[i8 >> 2] | 0;
              if ((i26 | 0) > (i22 | 0)) {
                i24 = i28;
                break L1281;
              } else {
                i14 = i28;
                i21 = i26;
                i20 = i22;
              }
            }
          }
        } while (0);
        HEAP32[i1 + 2908 + (i24 << 2) >> 2] = i18;
        i12 = i16 - 1 | 0;
        i15 = HEAP32[i8 >> 2] | 0;
        if ((i12 | 0) > 0) {
          i16 = i12;
          i17 = i15;
        } else {
          i29 = i15;
          break L1277;
        }
      }
    } else {
      i29 = i2;
    }
  } while (0);
  i2 = i1 + 2912 | 0;
  i24 = i10;
  i10 = i29;
  while (1) {
    i29 = HEAP32[i2 >> 2] | 0;
    i28 = i10 - 1 | 0;
    HEAP32[i8 >> 2] = i28;
    i17 = HEAP32[i1 + 2908 + (i10 << 2) >> 2] | 0;
    HEAP32[i2 >> 2] = i17;
    i16 = i17 + (i1 + 5208) | 0;
    L1300 : do {
      if ((i28 | 0) < 2) {
        i30 = 1;
      } else {
        i15 = i6 + (i17 << 2) | 0;
        i12 = 1;
        i20 = 2;
        i21 = i28;
        while (1) {
          do {
            if ((i20 | 0) < (i21 | 0)) {
              i14 = i20 | 1;
              i13 = HEAP32[i1 + 2908 + (i14 << 2) >> 2] | 0;
              i22 = HEAP16[i6 + (i13 << 2) >> 1] | 0;
              i26 = HEAP32[i1 + 2908 + (i20 << 2) >> 2] | 0;
              i23 = HEAP16[i6 + (i26 << 2) >> 1] | 0;
              if ((i22 & 65535) >= (i23 & 65535)) {
                if (i22 << 16 >> 16 != i23 << 16 >> 16) {
                  i31 = i20;
                  break;
                }
                if ((HEAPU8[i13 + (i1 + 5208) | 0] | 0) > (HEAPU8[i26 + (i1 + 5208) | 0] | 0)) {
                  i31 = i20;
                  break;
                }
              }
              i31 = i14;
            } else {
              i31 = i20;
            }
          } while (0);
          i14 = HEAP16[i15 >> 1] | 0;
          i26 = HEAP32[i1 + 2908 + (i31 << 2) >> 2] | 0;
          i13 = HEAP16[i6 + (i26 << 2) >> 1] | 0;
          if ((i14 & 65535) < (i13 & 65535)) {
            i30 = i12;
            break L1300;
          }
          if (i14 << 16 >> 16 == i13 << 16 >> 16) {
            if ((HEAPU8[i16] | 0) <= (HEAPU8[i26 + (i1 + 5208) | 0] | 0)) {
              i30 = i12;
              break L1300;
            }
          }
          HEAP32[i1 + 2908 + (i12 << 2) >> 2] = i26;
          i26 = i31 << 1;
          i13 = HEAP32[i8 >> 2] | 0;
          if ((i26 | 0) > (i13 | 0)) {
            i30 = i31;
            break L1300;
          } else {
            i12 = i31;
            i20 = i26;
            i21 = i13;
          }
        }
      }
    } while (0);
    HEAP32[i1 + 2908 + (i30 << 2) >> 2] = i17;
    i16 = HEAP32[i2 >> 2] | 0;
    i28 = (HEAP32[i11 >> 2] | 0) - 1 | 0;
    HEAP32[i11 >> 2] = i28;
    HEAP32[i1 + 2908 + (i28 << 2) >> 2] = i29;
    i28 = (HEAP32[i11 >> 2] | 0) - 1 | 0;
    HEAP32[i11 >> 2] = i28;
    HEAP32[i1 + 2908 + (i28 << 2) >> 2] = i16;
    i28 = i6 + (i24 << 2) | 0;
    HEAP16[i28 >> 1] = (HEAP16[i6 + (i16 << 2) >> 1] | 0) + (HEAP16[i6 + (i29 << 2) >> 1] | 0) & 65535;
    i21 = HEAP8[i29 + (i1 + 5208) | 0] | 0;
    i20 = HEAP8[i16 + (i1 + 5208) | 0] | 0;
    i12 = i24 + (i1 + 5208) | 0;
    HEAP8[i12] = ((i21 & 255) < (i20 & 255) ? i20 : i21) + 1 & 255;
    i21 = i24 & 65535;
    HEAP16[i6 + (i16 << 2) + 2 >> 1] = i21;
    HEAP16[i6 + (i29 << 2) + 2 >> 1] = i21;
    i21 = i24 + 1 | 0;
    HEAP32[i2 >> 2] = i24;
    i16 = HEAP32[i8 >> 2] | 0;
    L1316 : do {
      if ((i16 | 0) < 2) {
        i32 = 1;
      } else {
        i20 = 1;
        i15 = 2;
        i18 = i16;
        while (1) {
          do {
            if ((i15 | 0) < (i18 | 0)) {
              i13 = i15 | 1;
              i26 = HEAP32[i1 + 2908 + (i13 << 2) >> 2] | 0;
              i14 = HEAP16[i6 + (i26 << 2) >> 1] | 0;
              i23 = HEAP32[i1 + 2908 + (i15 << 2) >> 2] | 0;
              i22 = HEAP16[i6 + (i23 << 2) >> 1] | 0;
              if ((i14 & 65535) >= (i22 & 65535)) {
                if (i14 << 16 >> 16 != i22 << 16 >> 16) {
                  i33 = i15;
                  break;
                }
                if ((HEAPU8[i26 + (i1 + 5208) | 0] | 0) > (HEAPU8[i23 + (i1 + 5208) | 0] | 0)) {
                  i33 = i15;
                  break;
                }
              }
              i33 = i13;
            } else {
              i33 = i15;
            }
          } while (0);
          i13 = HEAP16[i28 >> 1] | 0;
          i23 = HEAP32[i1 + 2908 + (i33 << 2) >> 2] | 0;
          i26 = HEAP16[i6 + (i23 << 2) >> 1] | 0;
          if ((i13 & 65535) < (i26 & 65535)) {
            i32 = i20;
            break L1316;
          }
          if (i13 << 16 >> 16 == i26 << 16 >> 16) {
            if ((HEAPU8[i12] | 0) <= (HEAPU8[i23 + (i1 + 5208) | 0] | 0)) {
              i32 = i20;
              break L1316;
            }
          }
          HEAP32[i1 + 2908 + (i20 << 2) >> 2] = i23;
          i23 = i33 << 1;
          i26 = HEAP32[i8 >> 2] | 0;
          if ((i23 | 0) > (i26 | 0)) {
            i32 = i33;
            break L1316;
          } else {
            i20 = i33;
            i15 = i23;
            i18 = i26;
          }
        }
      }
    } while (0);
    HEAP32[i1 + 2908 + (i32 << 2) >> 2] = i24;
    i12 = HEAP32[i8 >> 2] | 0;
    if ((i12 | 0) > 1) {
      i24 = i21;
      i10 = i12;
    } else {
      break;
    }
  }
  i10 = HEAP32[i2 >> 2] | 0;
  i2 = (HEAP32[i11 >> 2] | 0) - 1 | 0;
  HEAP32[i11 >> 2] = i2;
  HEAP32[i1 + 2908 + (i2 << 2) >> 2] = i10;
  i10 = HEAP32[i5 >> 2] | 0;
  i5 = HEAP32[i9 >> 2] | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  i7 = HEAP32[i9 >> 2] | 0;
  i2 = HEAP32[i9 + 4 >> 2] | 0;
  i24 = HEAP32[i9 + 8 >> 2] | 0;
  i8 = HEAP32[i9 + 16 >> 2] | 0;
  _memset(i1 + 2876 | 0, 0, 32);
  HEAP16[i10 + (HEAP32[i1 + 2908 + (HEAP32[i11 >> 2] << 2) >> 2] << 2) + 2 >> 1] = 0;
  i9 = (HEAP32[i11 >> 2] | 0) + 1 | 0;
  L1332 : do {
    if ((i9 | 0) < 573) {
      i11 = i1 + 5800 | 0;
      i32 = i1 + 5804 | 0;
      L1334 : do {
        if ((i7 | 0) == 0) {
          i33 = 0;
          i30 = i9;
          while (1) {
            i31 = HEAP32[i1 + 2908 + (i30 << 2) >> 2] | 0;
            i12 = i10 + (i31 << 2) + 2 | 0;
            i28 = (HEAPU16[i10 + ((HEAPU16[i12 >> 1] | 0) << 2) + 2 >> 1] | 0) + 1 | 0;
            i16 = (i28 | 0) > (i8 | 0);
            i29 = i16 ? i8 : i28;
            i28 = (i16 & 1) + i33 | 0;
            HEAP16[i12 >> 1] = i29 & 65535;
            if ((i31 | 0) <= (i5 | 0)) {
              i12 = i1 + 2876 + (i29 << 1) | 0;
              HEAP16[i12 >> 1] = (HEAP16[i12 >> 1] | 0) + 1 & 65535;
              if ((i31 | 0) < (i24 | 0)) {
                i34 = 0;
              } else {
                i34 = HEAP32[i2 + (i31 - i24 << 2) >> 2] | 0;
              }
              i12 = Math_imul(HEAPU16[i10 + (i31 << 2) >> 1] | 0, i34 + i29 | 0) & -1;
              HEAP32[i11 >> 2] = i12 + (HEAP32[i11 >> 2] | 0) | 0;
            }
            i12 = i30 + 1 | 0;
            if ((i12 | 0) == 573) {
              i35 = i28;
              break L1334;
            } else {
              i33 = i28;
              i30 = i12;
            }
          }
        } else {
          i30 = 0;
          i33 = i9;
          while (1) {
            i12 = HEAP32[i1 + 2908 + (i33 << 2) >> 2] | 0;
            i28 = i10 + (i12 << 2) + 2 | 0;
            i29 = (HEAPU16[i10 + ((HEAPU16[i28 >> 1] | 0) << 2) + 2 >> 1] | 0) + 1 | 0;
            i31 = (i29 | 0) > (i8 | 0);
            i16 = i31 ? i8 : i29;
            i29 = (i31 & 1) + i30 | 0;
            HEAP16[i28 >> 1] = i16 & 65535;
            if ((i12 | 0) <= (i5 | 0)) {
              i28 = i1 + 2876 + (i16 << 1) | 0;
              HEAP16[i28 >> 1] = (HEAP16[i28 >> 1] | 0) + 1 & 65535;
              if ((i12 | 0) < (i24 | 0)) {
                i36 = 0;
              } else {
                i36 = HEAP32[i2 + (i12 - i24 << 2) >> 2] | 0;
              }
              i28 = HEAPU16[i10 + (i12 << 2) >> 1] | 0;
              i31 = Math_imul(i28, i36 + i16 | 0) & -1;
              HEAP32[i11 >> 2] = i31 + (HEAP32[i11 >> 2] | 0) | 0;
              i31 = Math_imul((HEAPU16[i7 + (i12 << 2) + 2 >> 1] | 0) + i36 | 0, i28) & -1;
              HEAP32[i32 >> 2] = i31 + (HEAP32[i32 >> 2] | 0) | 0;
            }
            i31 = i33 + 1 | 0;
            if ((i31 | 0) == 573) {
              i35 = i29;
              break L1334;
            } else {
              i30 = i29;
              i33 = i31;
            }
          }
        }
      } while (0);
      if ((i35 | 0) == 0) {
        break;
      }
      i32 = i1 + 2876 + (i8 << 1) | 0;
      i21 = i35;
      while (1) {
        i33 = i8;
        while (1) {
          i30 = i33 - 1 | 0;
          i37 = i1 + 2876 + (i30 << 1) | 0;
          i38 = HEAP16[i37 >> 1] | 0;
          if (i38 << 16 >> 16 == 0) {
            i33 = i30;
          } else {
            break;
          }
        }
        HEAP16[i37 >> 1] = i38 - 1 & 65535;
        i30 = i1 + 2876 + (i33 << 1) | 0;
        HEAP16[i30 >> 1] = (HEAP16[i30 >> 1] | 0) + 2 & 65535;
        i39 = (HEAP16[i32 >> 1] | 0) - 1 & 65535;
        HEAP16[i32 >> 1] = i39;
        i30 = i21 - 2 | 0;
        if ((i30 | 0) > 0) {
          i21 = i30;
        } else {
          break;
        }
      }
      if ((i8 | 0) == 0) {
        break;
      } else {
        i40 = i8;
        i41 = 573;
        i42 = i39;
      }
      while (1) {
        i21 = i40 & 65535;
        L1361 : do {
          if (i42 << 16 >> 16 == 0) {
            i43 = i41;
          } else {
            i32 = i42 & 65535;
            i30 = i41;
            while (1) {
              i31 = i30;
              while (1) {
                i44 = i31 - 1 | 0;
                i45 = HEAP32[i1 + 2908 + (i44 << 2) >> 2] | 0;
                if ((i45 | 0) > (i5 | 0)) {
                  i31 = i44;
                } else {
                  break;
                }
              }
              i31 = i10 + (i45 << 2) + 2 | 0;
              i29 = HEAPU16[i31 >> 1] | 0;
              if ((i29 | 0) != (i40 | 0)) {
                i28 = Math_imul(HEAPU16[i10 + (i45 << 2) >> 1] | 0, i40 - i29 | 0) & -1;
                HEAP32[i11 >> 2] = i28 + (HEAP32[i11 >> 2] | 0) | 0;
                HEAP16[i31 >> 1] = i21;
              }
              i31 = i32 - 1 | 0;
              if ((i31 | 0) == 0) {
                i43 = i44;
                break L1361;
              } else {
                i32 = i31;
                i30 = i44;
              }
            }
          }
        } while (0);
        i21 = i40 - 1 | 0;
        if ((i21 | 0) == 0) {
          break L1332;
        }
        i40 = i21;
        i41 = i43;
        i42 = HEAP16[i1 + 2876 + (i21 << 1) >> 1] | 0;
      }
    }
  } while (0);
  i42 = 1;
  i43 = 0;
  while (1) {
    i41 = (HEAPU16[i1 + 2876 + (i42 - 1 << 1) >> 1] | 0) + (i43 & 65534) << 1;
    HEAP16[i4 + (i42 << 1) >> 1] = i41 & 65535;
    i40 = i42 + 1 | 0;
    if ((i40 | 0) == 16) {
      break;
    } else {
      i42 = i40;
      i43 = i41;
    }
  }
  if ((i19 | 0) < 0) {
    STACKTOP = i3;
    return;
  }
  i43 = i19 + 1 | 0;
  i19 = 0;
  while (1) {
    i42 = HEAP16[i6 + (i19 << 2) + 2 >> 1] | 0;
    i1 = i42 & 65535;
    if (i42 << 16 >> 16 != 0) {
      i42 = i4 + (i1 << 1) | 0;
      i41 = HEAP16[i42 >> 1] | 0;
      HEAP16[i42 >> 1] = i41 + 1 & 65535;
      i42 = 0;
      i40 = i1;
      i1 = i41 & 65535;
      while (1) {
        i46 = i42 | i1 & 1;
        i41 = i40 - 1 | 0;
        if ((i41 | 0) > 0) {
          i42 = i46 << 1;
          i40 = i41;
          i1 = i1 >>> 1;
        } else {
          break;
        }
      }
      HEAP16[i6 + (i19 << 2) >> 1] = i46 & 65535;
    }
    i1 = i19 + 1 | 0;
    if ((i1 | 0) == (i43 | 0)) {
      break;
    } else {
      i19 = i1;
    }
  }
  STACKTOP = i3;
  return;
}
function _compress_block(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0;
  i4 = i1 + 5792 | 0;
  L1390 : do {
    if ((HEAP32[i4 >> 2] | 0) == 0) {
      i5 = HEAP32[i1 + 5820 >> 2] | 0;
      i6 = HEAP16[i1 + 5816 >> 1] | 0;
    } else {
      i7 = i1 + 5796 | 0;
      i8 = i1 + 5784 | 0;
      i9 = i1 + 5820 | 0;
      i10 = i1 + 5816 | 0;
      i11 = i1 + 20 | 0;
      i12 = i1 + 8 | 0;
      i13 = 0;
      while (1) {
        i14 = HEAP16[(HEAP32[i7 >> 2] | 0) + (i13 << 1) >> 1] | 0;
        i15 = i14 & 65535;
        i16 = i13 + 1 | 0;
        i17 = HEAPU8[(HEAP32[i8 >> 2] | 0) + i13 | 0] | 0;
        do {
          if (i14 << 16 >> 16 == 0) {
            i18 = HEAPU16[i2 + (i17 << 2) + 2 >> 1] | 0;
            i19 = HEAP32[i9 >> 2] | 0;
            i20 = HEAPU16[i2 + (i17 << 2) >> 1] | 0;
            i21 = HEAPU16[i10 >> 1] | 0 | i20 << i19;
            i22 = i21 & 65535;
            HEAP16[i10 >> 1] = i22;
            if ((i19 | 0) > (16 - i18 | 0)) {
              i23 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i23 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i23 | 0] = i21 & 255;
              i21 = (HEAPU16[i10 >> 1] | 0) >>> 8 & 255;
              i23 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i23 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i23 | 0] = i21;
              i21 = HEAP32[i9 >> 2] | 0;
              i23 = i20 >>> ((16 - i21 | 0) >>> 0) & 65535;
              HEAP16[i10 >> 1] = i23;
              i20 = (i18 - 16 | 0) + i21 | 0;
              HEAP32[i9 >> 2] = i20;
              i24 = i20;
              i25 = i23;
              break;
            } else {
              i23 = i19 + i18 | 0;
              HEAP32[i9 >> 2] = i23;
              i24 = i23;
              i25 = i22;
              break;
            }
          } else {
            i22 = HEAPU8[i17 + 5255756 | 0] | 0;
            i23 = (i22 | 256) + 1 | 0;
            i18 = HEAPU16[i2 + (i23 << 2) + 2 >> 1] | 0;
            i19 = HEAP32[i9 >> 2] | 0;
            i20 = HEAPU16[i2 + (i23 << 2) >> 1] | 0;
            i23 = HEAPU16[i10 >> 1] | 0 | i20 << i19;
            i21 = i23 & 65535;
            HEAP16[i10 >> 1] = i21;
            if ((i19 | 0) > (16 - i18 | 0)) {
              i26 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i26 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i26 | 0] = i23 & 255;
              i23 = (HEAPU16[i10 >> 1] | 0) >>> 8 & 255;
              i26 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i26 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i26 | 0] = i23;
              i23 = HEAP32[i9 >> 2] | 0;
              i26 = i20 >>> ((16 - i23 | 0) >>> 0) & 65535;
              HEAP16[i10 >> 1] = i26;
              i27 = (i18 - 16 | 0) + i23 | 0;
              i28 = i26;
            } else {
              i27 = i19 + i18 | 0;
              i28 = i21;
            }
            HEAP32[i9 >> 2] = i27;
            i21 = HEAP32[5246712 + (i22 << 2) >> 2] | 0;
            do {
              if ((i22 - 8 | 0) >>> 0 < 20) {
                i18 = i17 - (HEAP32[5255364 + (i22 << 2) >> 2] | 0) & 65535;
                i19 = i18 << i27 | i28 & 65535;
                i26 = i19 & 65535;
                HEAP16[i10 >> 1] = i26;
                if ((i27 | 0) > (16 - i21 | 0)) {
                  i23 = HEAP32[i11 >> 2] | 0;
                  HEAP32[i11 >> 2] = i23 + 1 | 0;
                  HEAP8[(HEAP32[i12 >> 2] | 0) + i23 | 0] = i19 & 255;
                  i19 = (HEAPU16[i10 >> 1] | 0) >>> 8 & 255;
                  i23 = HEAP32[i11 >> 2] | 0;
                  HEAP32[i11 >> 2] = i23 + 1 | 0;
                  HEAP8[(HEAP32[i12 >> 2] | 0) + i23 | 0] = i19;
                  i19 = HEAP32[i9 >> 2] | 0;
                  i23 = i18 >>> ((16 - i19 | 0) >>> 0) & 65535;
                  HEAP16[i10 >> 1] = i23;
                  i18 = (i21 - 16 | 0) + i19 | 0;
                  HEAP32[i9 >> 2] = i18;
                  i29 = i18;
                  i30 = i23;
                  break;
                } else {
                  i23 = i27 + i21 | 0;
                  HEAP32[i9 >> 2] = i23;
                  i29 = i23;
                  i30 = i26;
                  break;
                }
              } else {
                i29 = i27;
                i30 = i28;
              }
            } while (0);
            i21 = i15 - 1 | 0;
            if (i21 >>> 0 < 256) {
              i31 = i21;
            } else {
              i31 = (i21 >>> 7) + 256 | 0;
            }
            i22 = HEAPU8[i31 + 5256480 | 0] | 0;
            i26 = HEAPU16[i3 + (i22 << 2) + 2 >> 1] | 0;
            i23 = HEAPU16[i3 + (i22 << 2) >> 1] | 0;
            i18 = i30 & 65535 | i23 << i29;
            i19 = i18 & 65535;
            HEAP16[i10 >> 1] = i19;
            if ((i29 | 0) > (16 - i26 | 0)) {
              i20 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i20 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i20 | 0] = i18 & 255;
              i18 = (HEAPU16[i10 >> 1] | 0) >>> 8 & 255;
              i20 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i20 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i20 | 0] = i18;
              i18 = HEAP32[i9 >> 2] | 0;
              i20 = i23 >>> ((16 - i18 | 0) >>> 0) & 65535;
              HEAP16[i10 >> 1] = i20;
              i32 = (i26 - 16 | 0) + i18 | 0;
              i33 = i20;
            } else {
              i32 = i29 + i26 | 0;
              i33 = i19;
            }
            HEAP32[i9 >> 2] = i32;
            i19 = HEAP32[5246828 + (i22 << 2) >> 2] | 0;
            if ((i22 - 4 | 0) >>> 0 >= 26) {
              i24 = i32;
              i25 = i33;
              break;
            }
            i26 = i21 - (HEAP32[5255480 + (i22 << 2) >> 2] | 0) & 65535;
            i22 = i26 << i32 | i33 & 65535;
            i21 = i22 & 65535;
            HEAP16[i10 >> 1] = i21;
            if ((i32 | 0) > (16 - i19 | 0)) {
              i20 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i20 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i20 | 0] = i22 & 255;
              i22 = (HEAPU16[i10 >> 1] | 0) >>> 8 & 255;
              i20 = HEAP32[i11 >> 2] | 0;
              HEAP32[i11 >> 2] = i20 + 1 | 0;
              HEAP8[(HEAP32[i12 >> 2] | 0) + i20 | 0] = i22;
              i22 = HEAP32[i9 >> 2] | 0;
              i20 = i26 >>> ((16 - i22 | 0) >>> 0) & 65535;
              HEAP16[i10 >> 1] = i20;
              i26 = (i19 - 16 | 0) + i22 | 0;
              HEAP32[i9 >> 2] = i26;
              i24 = i26;
              i25 = i20;
              break;
            } else {
              i20 = i32 + i19 | 0;
              HEAP32[i9 >> 2] = i20;
              i24 = i20;
              i25 = i21;
              break;
            }
          }
        } while (0);
        if (i16 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
          i13 = i16;
        } else {
          i5 = i24;
          i6 = i25;
          break L1390;
        }
      }
    }
  } while (0);
  i25 = i2 + 1026 | 0;
  i24 = HEAPU16[i25 >> 1] | 0;
  i4 = i1 + 5820 | 0;
  i32 = HEAPU16[i2 + 1024 >> 1] | 0;
  i2 = i1 + 5816 | 0;
  i33 = i6 & 65535 | i32 << i5;
  HEAP16[i2 >> 1] = i33 & 65535;
  if ((i5 | 0) > (16 - i24 | 0)) {
    i6 = i1 + 20 | 0;
    i29 = HEAP32[i6 >> 2] | 0;
    HEAP32[i6 >> 2] = i29 + 1 | 0;
    i30 = i1 + 8 | 0;
    HEAP8[(HEAP32[i30 >> 2] | 0) + i29 | 0] = i33 & 255;
    i33 = (HEAPU16[i2 >> 1] | 0) >>> 8 & 255;
    i29 = HEAP32[i6 >> 2] | 0;
    HEAP32[i6 >> 2] = i29 + 1 | 0;
    HEAP8[(HEAP32[i30 >> 2] | 0) + i29 | 0] = i33;
    i33 = HEAP32[i4 >> 2] | 0;
    HEAP16[i2 >> 1] = i32 >>> ((16 - i33 | 0) >>> 0) & 65535;
    i32 = (i24 - 16 | 0) + i33 | 0;
    HEAP32[i4 >> 2] = i32;
    i33 = HEAP16[i25 >> 1] | 0;
    i2 = i33 & 65535;
    i29 = i1 + 5812 | 0;
    HEAP32[i29 >> 2] = i2;
    return;
  } else {
    i32 = i5 + i24 | 0;
    HEAP32[i4 >> 2] = i32;
    i33 = HEAP16[i25 >> 1] | 0;
    i2 = i33 & 65535;
    i29 = i1 + 5812 | 0;
    HEAP32[i29 >> 2] = i2;
    return;
  }
}
function _send_tree(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0;
  i4 = HEAP16[i2 + 2 >> 1] | 0;
  i5 = i4 << 16 >> 16 == 0;
  i6 = i1 + 2754 | 0;
  i7 = i1 + 5820 | 0;
  i8 = i1 + 2752 | 0;
  i9 = i1 + 5816 | 0;
  i10 = i1 + 20 | 0;
  i11 = i1 + 8 | 0;
  i12 = i1 + 2758 | 0;
  i13 = i1 + 2756 | 0;
  i14 = i1 + 2750 | 0;
  i15 = i1 + 2748 | 0;
  i16 = 0;
  i17 = -1;
  i18 = i4 & 65535;
  i4 = i5 ? 138 : 7;
  i19 = i5 ? 3 : 4;
  L1430 : while (1) {
    i5 = i16;
    i20 = 0;
    while (1) {
      if ((i5 | 0) > (i3 | 0)) {
        break L1430;
      }
      i21 = i5 + 1 | 0;
      i22 = HEAP16[i2 + (i21 << 2) + 2 >> 1] | 0;
      i23 = i22 & 65535;
      i24 = i20 + 1 | 0;
      i25 = (i18 | 0) == (i23 | 0);
      if ((i24 | 0) < (i4 | 0) & i25) {
        i5 = i21;
        i20 = i24;
      } else {
        break;
      }
    }
    L1436 : do {
      if ((i24 | 0) < (i19 | 0)) {
        i5 = i1 + 2684 + (i18 << 2) + 2 | 0;
        i26 = i1 + 2684 + (i18 << 2) | 0;
        i27 = i24;
        i28 = HEAP32[i7 >> 2] | 0;
        i29 = HEAP16[i9 >> 1] | 0;
        while (1) {
          i30 = HEAPU16[i5 >> 1] | 0;
          i31 = HEAPU16[i26 >> 1] | 0;
          i32 = i29 & 65535 | i31 << i28;
          i33 = i32 & 65535;
          HEAP16[i9 >> 1] = i33;
          if ((i28 | 0) > (16 - i30 | 0)) {
            i34 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i34 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i34 | 0] = i32 & 255;
            i32 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i34 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i34 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i34 | 0] = i32;
            i32 = HEAP32[i7 >> 2] | 0;
            i34 = i31 >>> ((16 - i32 | 0) >>> 0) & 65535;
            HEAP16[i9 >> 1] = i34;
            i35 = (i30 - 16 | 0) + i32 | 0;
            i36 = i34;
          } else {
            i35 = i28 + i30 | 0;
            i36 = i33;
          }
          HEAP32[i7 >> 2] = i35;
          i33 = i27 - 1 | 0;
          if ((i33 | 0) == 0) {
            break L1436;
          } else {
            i27 = i33;
            i28 = i35;
            i29 = i36;
          }
        }
      } else {
        if ((i18 | 0) != 0) {
          if ((i18 | 0) == (i17 | 0)) {
            i37 = i24;
            i38 = HEAP32[i7 >> 2] | 0;
            i39 = HEAP16[i9 >> 1] | 0;
          } else {
            i29 = HEAPU16[i1 + 2684 + (i18 << 2) + 2 >> 1] | 0;
            i28 = HEAP32[i7 >> 2] | 0;
            i27 = HEAPU16[i1 + 2684 + (i18 << 2) >> 1] | 0;
            i26 = HEAPU16[i9 >> 1] | 0 | i27 << i28;
            i5 = i26 & 65535;
            HEAP16[i9 >> 1] = i5;
            if ((i28 | 0) > (16 - i29 | 0)) {
              i33 = HEAP32[i10 >> 2] | 0;
              HEAP32[i10 >> 2] = i33 + 1 | 0;
              HEAP8[(HEAP32[i11 >> 2] | 0) + i33 | 0] = i26 & 255;
              i26 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
              i33 = HEAP32[i10 >> 2] | 0;
              HEAP32[i10 >> 2] = i33 + 1 | 0;
              HEAP8[(HEAP32[i11 >> 2] | 0) + i33 | 0] = i26;
              i26 = HEAP32[i7 >> 2] | 0;
              i33 = i27 >>> ((16 - i26 | 0) >>> 0) & 65535;
              HEAP16[i9 >> 1] = i33;
              i40 = (i29 - 16 | 0) + i26 | 0;
              i41 = i33;
            } else {
              i40 = i28 + i29 | 0;
              i41 = i5;
            }
            HEAP32[i7 >> 2] = i40;
            i37 = i20;
            i38 = i40;
            i39 = i41;
          }
          i5 = HEAPU16[i14 >> 1] | 0;
          i29 = HEAPU16[i15 >> 1] | 0;
          i28 = i39 & 65535 | i29 << i38;
          HEAP16[i9 >> 1] = i28 & 65535;
          if ((i38 | 0) > (16 - i5 | 0)) {
            i33 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i33 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i33 | 0] = i28 & 255;
            i33 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i26 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i26 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i26 | 0] = i33;
            i33 = HEAP32[i7 >> 2] | 0;
            i26 = i29 >>> ((16 - i33 | 0) >>> 0);
            HEAP16[i9 >> 1] = i26 & 65535;
            i42 = (i5 - 16 | 0) + i33 | 0;
            i43 = i26;
          } else {
            i42 = i38 + i5 | 0;
            i43 = i28;
          }
          HEAP32[i7 >> 2] = i42;
          i28 = i37 + 65533 & 65535;
          i5 = i43 & 65535 | i28 << i42;
          HEAP16[i9 >> 1] = i5 & 65535;
          if ((i42 | 0) > 14) {
            i26 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i26 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i26 | 0] = i5 & 255;
            i5 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i26 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i26 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i26 | 0] = i5;
            i5 = HEAP32[i7 >> 2] | 0;
            HEAP16[i9 >> 1] = i28 >>> ((16 - i5 | 0) >>> 0) & 65535;
            HEAP32[i7 >> 2] = i5 - 14 | 0;
            break;
          } else {
            HEAP32[i7 >> 2] = i42 + 2 | 0;
            break;
          }
        }
        if ((i24 | 0) < 11) {
          i5 = HEAPU16[i6 >> 1] | 0;
          i28 = HEAP32[i7 >> 2] | 0;
          i26 = HEAPU16[i8 >> 1] | 0;
          i33 = HEAPU16[i9 >> 1] | 0 | i26 << i28;
          HEAP16[i9 >> 1] = i33 & 65535;
          if ((i28 | 0) > (16 - i5 | 0)) {
            i29 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i29 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i29 | 0] = i33 & 255;
            i29 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i27 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i27 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i27 | 0] = i29;
            i29 = HEAP32[i7 >> 2] | 0;
            i27 = i26 >>> ((16 - i29 | 0) >>> 0);
            HEAP16[i9 >> 1] = i27 & 65535;
            i44 = (i5 - 16 | 0) + i29 | 0;
            i45 = i27;
          } else {
            i44 = i28 + i5 | 0;
            i45 = i33;
          }
          HEAP32[i7 >> 2] = i44;
          i33 = i20 + 65534 & 65535;
          i5 = i45 & 65535 | i33 << i44;
          HEAP16[i9 >> 1] = i5 & 65535;
          if ((i44 | 0) > 13) {
            i28 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i28 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i28 | 0] = i5 & 255;
            i5 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i28 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i28 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i28 | 0] = i5;
            i5 = HEAP32[i7 >> 2] | 0;
            HEAP16[i9 >> 1] = i33 >>> ((16 - i5 | 0) >>> 0) & 65535;
            HEAP32[i7 >> 2] = i5 - 13 | 0;
            break;
          } else {
            HEAP32[i7 >> 2] = i44 + 3 | 0;
            break;
          }
        } else {
          i5 = HEAPU16[i12 >> 1] | 0;
          i33 = HEAP32[i7 >> 2] | 0;
          i28 = HEAPU16[i13 >> 1] | 0;
          i27 = HEAPU16[i9 >> 1] | 0 | i28 << i33;
          HEAP16[i9 >> 1] = i27 & 65535;
          if ((i33 | 0) > (16 - i5 | 0)) {
            i29 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i29 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i29 | 0] = i27 & 255;
            i29 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i26 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i26 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i26 | 0] = i29;
            i29 = HEAP32[i7 >> 2] | 0;
            i26 = i28 >>> ((16 - i29 | 0) >>> 0);
            HEAP16[i9 >> 1] = i26 & 65535;
            i46 = (i5 - 16 | 0) + i29 | 0;
            i47 = i26;
          } else {
            i46 = i33 + i5 | 0;
            i47 = i27;
          }
          HEAP32[i7 >> 2] = i46;
          i27 = i20 + 65526 & 65535;
          i5 = i47 & 65535 | i27 << i46;
          HEAP16[i9 >> 1] = i5 & 65535;
          if ((i46 | 0) > 9) {
            i33 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i33 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i33 | 0] = i5 & 255;
            i5 = (HEAPU16[i9 >> 1] | 0) >>> 8 & 255;
            i33 = HEAP32[i10 >> 2] | 0;
            HEAP32[i10 >> 2] = i33 + 1 | 0;
            HEAP8[(HEAP32[i11 >> 2] | 0) + i33 | 0] = i5;
            i5 = HEAP32[i7 >> 2] | 0;
            HEAP16[i9 >> 1] = i27 >>> ((16 - i5 | 0) >>> 0) & 65535;
            HEAP32[i7 >> 2] = i5 - 9 | 0;
            break;
          } else {
            HEAP32[i7 >> 2] = i46 + 7 | 0;
            break;
          }
        }
      }
    } while (0);
    if (i22 << 16 >> 16 == 0) {
      i16 = i21;
      i17 = i18;
      i18 = i23;
      i4 = 138;
      i19 = 3;
      continue;
    }
    i16 = i21;
    i17 = i18;
    i18 = i23;
    i4 = i25 ? 6 : 7;
    i19 = i25 ? 3 : 4;
  }
  return;
}
function _zcalloc(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  return _malloc(Math_imul(i3, i2) & -1) | 0;
}
function _zcfree(i1, i2) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0;
  if ((i2 | 0) == 0) {
    return;
  }
  i1 = i2 - 8 | 0;
  i3 = i1;
  i4 = HEAP32[1314007] | 0;
  if (i1 >>> 0 < i4 >>> 0) {
    _abort();
  }
  i5 = HEAP32[i2 - 4 >> 2] | 0;
  i6 = i5 & 3;
  if ((i6 | 0) == 1) {
    _abort();
  }
  i7 = i5 & -8;
  i8 = i2 + (i7 - 8 | 0) | 0;
  i9 = i8;
  L1494 : do {
    if ((i5 & 1 | 0) == 0) {
      i10 = HEAP32[i1 >> 2] | 0;
      if ((i6 | 0) == 0) {
        return;
      }
      i11 = -8 - i10 | 0;
      i12 = i2 + i11 | 0;
      i13 = i12;
      i14 = i10 + i7 | 0;
      if (i12 >>> 0 < i4 >>> 0) {
        _abort();
      }
      if ((i13 | 0) == (HEAP32[1314008] | 0)) {
        i15 = i2 + (i7 - 4 | 0) | 0;
        if ((HEAP32[i15 >> 2] & 3 | 0) != 3) {
          i16 = i13;
          i17 = i14;
          break;
        }
        HEAP32[1314005] = i14;
        HEAP32[i15 >> 2] = HEAP32[i15 >> 2] & -2;
        HEAP32[i2 + (i11 + 4 | 0) >> 2] = i14 | 1;
        HEAP32[i8 >> 2] = i14;
        return;
      }
      i15 = i10 >>> 3;
      if (i10 >>> 0 < 256) {
        i10 = HEAP32[i2 + (i11 + 8 | 0) >> 2] | 0;
        i18 = HEAP32[i2 + (i11 + 12 | 0) >> 2] | 0;
        if ((i10 | 0) == (i18 | 0)) {
          HEAP32[1314003] = HEAP32[1314003] & (1 << i15 ^ -1);
          i16 = i13;
          i17 = i14;
          break;
        }
        i19 = 5256052 + (i15 << 1 << 2) | 0;
        if ((i10 | 0) != (i19 | 0) & i10 >>> 0 < i4 >>> 0) {
          _abort();
        }
        if ((i18 | 0) == (i19 | 0) | i18 >>> 0 >= i4 >>> 0) {
          HEAP32[i10 + 12 >> 2] = i18;
          HEAP32[i18 + 8 >> 2] = i10;
          i16 = i13;
          i17 = i14;
          break;
        } else {
          _abort();
        }
      }
      i10 = i12;
      i12 = HEAP32[i2 + (i11 + 24 | 0) >> 2] | 0;
      i18 = HEAP32[i2 + (i11 + 12 | 0) >> 2] | 0;
      L1519 : do {
        if ((i18 | 0) == (i10 | 0)) {
          i19 = i2 + (i11 + 20 | 0) | 0;
          i15 = HEAP32[i19 >> 2] | 0;
          do {
            if ((i15 | 0) == 0) {
              i20 = i2 + (i11 + 16 | 0) | 0;
              i21 = HEAP32[i20 >> 2] | 0;
              if ((i21 | 0) == 0) {
                i22 = 0;
                break L1519;
              } else {
                i23 = i21;
                i24 = i20;
                break;
              }
            } else {
              i23 = i15;
              i24 = i19;
            }
          } while (0);
          while (1) {
            i19 = i23 + 20 | 0;
            i15 = HEAP32[i19 >> 2] | 0;
            if ((i15 | 0) != 0) {
              i23 = i15;
              i24 = i19;
              continue;
            }
            i19 = i23 + 16 | 0;
            i15 = HEAP32[i19 >> 2] | 0;
            if ((i15 | 0) == 0) {
              break;
            } else {
              i23 = i15;
              i24 = i19;
            }
          }
          if (i24 >>> 0 < i4 >>> 0) {
            _abort();
          } else {
            HEAP32[i24 >> 2] = 0;
            i22 = i23;
            break;
          }
        } else {
          i19 = HEAP32[i2 + (i11 + 8 | 0) >> 2] | 0;
          if (i19 >>> 0 < i4 >>> 0) {
            _abort();
          } else {
            HEAP32[i19 + 12 >> 2] = i18;
            HEAP32[i18 + 8 >> 2] = i19;
            i22 = i18;
            break;
          }
        }
      } while (0);
      if ((i12 | 0) == 0) {
        i16 = i13;
        i17 = i14;
        break;
      }
      i18 = i2 + (i11 + 28 | 0) | 0;
      i19 = 5256316 + (HEAP32[i18 >> 2] << 2) | 0;
      do {
        if ((i10 | 0) == (HEAP32[i19 >> 2] | 0)) {
          HEAP32[i19 >> 2] = i22;
          if ((i22 | 0) != 0) {
            break;
          }
          HEAP32[1314004] = HEAP32[1314004] & (1 << HEAP32[i18 >> 2] ^ -1);
          i16 = i13;
          i17 = i14;
          break L1494;
        } else {
          if (i12 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
          }
          i15 = i12 + 16 | 0;
          if ((HEAP32[i15 >> 2] | 0) == (i10 | 0)) {
            HEAP32[i15 >> 2] = i22;
          } else {
            HEAP32[i12 + 20 >> 2] = i22;
          }
          if ((i22 | 0) == 0) {
            i16 = i13;
            i17 = i14;
            break L1494;
          }
        }
      } while (0);
      if (i22 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
        _abort();
      }
      HEAP32[i22 + 24 >> 2] = i12;
      i10 = HEAP32[i2 + (i11 + 16 | 0) >> 2] | 0;
      do {
        if ((i10 | 0) != 0) {
          if (i10 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
          } else {
            HEAP32[i22 + 16 >> 2] = i10;
            HEAP32[i10 + 24 >> 2] = i22;
            break;
          }
        }
      } while (0);
      i10 = HEAP32[i2 + (i11 + 20 | 0) >> 2] | 0;
      if ((i10 | 0) == 0) {
        i16 = i13;
        i17 = i14;
        break;
      }
      if (i10 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
        _abort();
      } else {
        HEAP32[i22 + 20 >> 2] = i10;
        HEAP32[i10 + 24 >> 2] = i22;
        i16 = i13;
        i17 = i14;
        break;
      }
    } else {
      i16 = i3;
      i17 = i7;
    }
  } while (0);
  i3 = i16;
  if (i3 >>> 0 >= i8 >>> 0) {
    _abort();
  }
  i22 = i2 + (i7 - 4 | 0) | 0;
  i4 = HEAP32[i22 >> 2] | 0;
  if ((i4 & 1 | 0) == 0) {
    _abort();
  }
  do {
    if ((i4 & 2 | 0) == 0) {
      if ((i9 | 0) == (HEAP32[1314009] | 0)) {
        i23 = (HEAP32[1314006] | 0) + i17 | 0;
        HEAP32[1314006] = i23;
        HEAP32[1314009] = i16;
        HEAP32[i16 + 4 >> 2] = i23 | 1;
        if ((i16 | 0) == (HEAP32[1314008] | 0)) {
          HEAP32[1314008] = 0;
          HEAP32[1314005] = 0;
        }
        if (i23 >>> 0 <= (HEAP32[1314010] | 0) >>> 0) {
          return;
        }
        do {
          if ((HEAP32[1311054] | 0) == 0) {
            if ((HEAP32[1311054] | 0) != 0) {
              break;
            }
            i23 = _sysconf(8) | 0;
            if ((i23 - 1 & i23 | 0) == 0) {
              HEAP32[1311056] = i23;
              HEAP32[1311055] = i23;
              HEAP32[1311057] = -1;
              HEAP32[1311058] = 2097152;
              HEAP32[1311059] = 0;
              HEAP32[1314113] = 0;
              HEAP32[1311054] = _time(0) & -16 ^ 1431655768;
              break;
            } else {
              _abort();
            }
          }
        } while (0);
        i14 = HEAP32[1314009] | 0;
        if ((i14 | 0) == 0) {
          return;
        }
        i13 = HEAP32[1314006] | 0;
        do {
          if (i13 >>> 0 > 40) {
            i11 = HEAP32[1311056] | 0;
            i23 = Math_imul(((((i13 - 41 | 0) + i11 | 0) >>> 0) / (i11 >>> 0) >>> 0) - 1 | 0, i11) & -1;
            i24 = i14;
            i6 = 5256456;
            while (1) {
              i1 = HEAP32[i6 >> 2] | 0;
              if (i1 >>> 0 <= i24 >>> 0) {
                if ((i1 + (HEAP32[i6 + 4 >> 2] | 0) | 0) >>> 0 > i24 >>> 0) {
                  i25 = i6;
                  break;
                }
              }
              i1 = HEAP32[i6 + 8 >> 2] | 0;
              if ((i1 | 0) == 0) {
                i25 = 0;
                break;
              } else {
                i6 = i1;
              }
            }
            if ((HEAP32[i25 + 12 >> 2] & 8 | 0) != 0) {
              break;
            }
            i6 = _sbrk(0) | 0;
            i24 = i25 + 4 | 0;
            if ((i6 | 0) != ((HEAP32[i25 >> 2] | 0) + (HEAP32[i24 >> 2] | 0) | 0)) {
              break;
            }
            i1 = _sbrk(-(i23 >>> 0 > 2147483646 ? -2147483648 - i11 | 0 : i23) | 0) | 0;
            i5 = _sbrk(0) | 0;
            if (!((i1 | 0) != -1 & i5 >>> 0 < i6 >>> 0)) {
              break;
            }
            i1 = i6 - i5 | 0;
            if ((i6 | 0) == (i5 | 0)) {
              break;
            }
            HEAP32[i24 >> 2] = (HEAP32[i24 >> 2] | 0) - i1 | 0;
            HEAP32[1314111] = (HEAP32[1314111] | 0) - i1 | 0;
            i24 = HEAP32[1314009] | 0;
            i5 = (HEAP32[1314006] | 0) - i1 | 0;
            i1 = i24;
            i6 = i24 + 8 | 0;
            if ((i6 & 7 | 0) == 0) {
              i26 = 0;
            } else {
              i26 = -i6 & 7;
            }
            i6 = i5 - i26 | 0;
            HEAP32[1314009] = i1 + i26 | 0;
            HEAP32[1314006] = i6;
            HEAP32[i1 + (i26 + 4 | 0) >> 2] = i6 | 1;
            HEAP32[i1 + (i5 + 4 | 0) >> 2] = 40;
            HEAP32[1314010] = HEAP32[1311058] | 0;
            return;
          }
        } while (0);
        if ((HEAP32[1314006] | 0) >>> 0 <= (HEAP32[1314010] | 0) >>> 0) {
          return;
        }
        HEAP32[1314010] = -1;
        return;
      }
      if ((i9 | 0) == (HEAP32[1314008] | 0)) {
        i14 = (HEAP32[1314005] | 0) + i17 | 0;
        HEAP32[1314005] = i14;
        HEAP32[1314008] = i16;
        HEAP32[i16 + 4 >> 2] = i14 | 1;
        HEAP32[i3 + i14 >> 2] = i14;
        return;
      }
      i14 = (i4 & -8) + i17 | 0;
      i13 = i4 >>> 3;
      L1614 : do {
        if (i4 >>> 0 < 256) {
          i5 = HEAP32[i2 + i7 >> 2] | 0;
          i1 = HEAP32[i2 + (i7 | 4) >> 2] | 0;
          if ((i5 | 0) == (i1 | 0)) {
            HEAP32[1314003] = HEAP32[1314003] & (1 << i13 ^ -1);
            break;
          }
          i6 = 5256052 + (i13 << 1 << 2) | 0;
          do {
            if ((i5 | 0) != (i6 | 0)) {
              if (i5 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                break;
              }
              _abort();
            }
          } while (0);
          do {
            if ((i1 | 0) != (i6 | 0)) {
              if (i1 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                break;
              }
              _abort();
            }
          } while (0);
          HEAP32[i5 + 12 >> 2] = i1;
          HEAP32[i1 + 8 >> 2] = i5;
        } else {
          i6 = i8;
          i23 = HEAP32[i2 + (i7 + 16 | 0) >> 2] | 0;
          i11 = HEAP32[i2 + (i7 | 4) >> 2] | 0;
          L1628 : do {
            if ((i11 | 0) == (i6 | 0)) {
              i24 = i2 + (i7 + 12 | 0) | 0;
              i10 = HEAP32[i24 >> 2] | 0;
              do {
                if ((i10 | 0) == 0) {
                  i12 = i2 + (i7 + 8 | 0) | 0;
                  i18 = HEAP32[i12 >> 2] | 0;
                  if ((i18 | 0) == 0) {
                    i27 = 0;
                    break L1628;
                  } else {
                    i28 = i18;
                    i29 = i12;
                    break;
                  }
                } else {
                  i28 = i10;
                  i29 = i24;
                }
              } while (0);
              while (1) {
                i24 = i28 + 20 | 0;
                i10 = HEAP32[i24 >> 2] | 0;
                if ((i10 | 0) != 0) {
                  i28 = i10;
                  i29 = i24;
                  continue;
                }
                i24 = i28 + 16 | 0;
                i10 = HEAP32[i24 >> 2] | 0;
                if ((i10 | 0) == 0) {
                  break;
                } else {
                  i28 = i10;
                  i29 = i24;
                }
              }
              if (i29 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
              } else {
                HEAP32[i29 >> 2] = 0;
                i27 = i28;
                break;
              }
            } else {
              i24 = HEAP32[i2 + i7 >> 2] | 0;
              if (i24 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
              } else {
                HEAP32[i24 + 12 >> 2] = i11;
                HEAP32[i11 + 8 >> 2] = i24;
                i27 = i11;
                break;
              }
            }
          } while (0);
          if ((i23 | 0) == 0) {
            break;
          }
          i11 = i2 + (i7 + 20 | 0) | 0;
          i5 = 5256316 + (HEAP32[i11 >> 2] << 2) | 0;
          do {
            if ((i6 | 0) == (HEAP32[i5 >> 2] | 0)) {
              HEAP32[i5 >> 2] = i27;
              if ((i27 | 0) != 0) {
                break;
              }
              HEAP32[1314004] = HEAP32[1314004] & (1 << HEAP32[i11 >> 2] ^ -1);
              break L1614;
            } else {
              if (i23 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
              }
              i1 = i23 + 16 | 0;
              if ((HEAP32[i1 >> 2] | 0) == (i6 | 0)) {
                HEAP32[i1 >> 2] = i27;
              } else {
                HEAP32[i23 + 20 >> 2] = i27;
              }
              if ((i27 | 0) == 0) {
                break L1614;
              }
            }
          } while (0);
          if (i27 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
          }
          HEAP32[i27 + 24 >> 2] = i23;
          i6 = HEAP32[i2 + (i7 + 8 | 0) >> 2] | 0;
          do {
            if ((i6 | 0) != 0) {
              if (i6 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
              } else {
                HEAP32[i27 + 16 >> 2] = i6;
                HEAP32[i6 + 24 >> 2] = i27;
                break;
              }
            }
          } while (0);
          i6 = HEAP32[i2 + (i7 + 12 | 0) >> 2] | 0;
          if ((i6 | 0) == 0) {
            break;
          }
          if (i6 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
          } else {
            HEAP32[i27 + 20 >> 2] = i6;
            HEAP32[i6 + 24 >> 2] = i27;
            break;
          }
        }
      } while (0);
      HEAP32[i16 + 4 >> 2] = i14 | 1;
      HEAP32[i3 + i14 >> 2] = i14;
      if ((i16 | 0) != (HEAP32[1314008] | 0)) {
        i30 = i14;
        break;
      }
      HEAP32[1314005] = i14;
      return;
    } else {
      HEAP32[i22 >> 2] = i4 & -2;
      HEAP32[i16 + 4 >> 2] = i17 | 1;
      HEAP32[i3 + i17 >> 2] = i17;
      i30 = i17;
    }
  } while (0);
  i17 = i30 >>> 3;
  if (i30 >>> 0 < 256) {
    i3 = i17 << 1;
    i4 = 5256052 + (i3 << 2) | 0;
    i22 = HEAP32[1314003] | 0;
    i27 = 1 << i17;
    do {
      if ((i22 & i27 | 0) == 0) {
        HEAP32[1314003] = i22 | i27;
        i31 = i4;
        i32 = 5256052 + (i3 + 2 << 2) | 0;
      } else {
        i17 = 5256052 + (i3 + 2 << 2) | 0;
        i7 = HEAP32[i17 >> 2] | 0;
        if (i7 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
          i31 = i7;
          i32 = i17;
          break;
        }
        _abort();
      }
    } while (0);
    HEAP32[i32 >> 2] = i16;
    HEAP32[i31 + 12 >> 2] = i16;
    HEAP32[i16 + 8 >> 2] = i31;
    HEAP32[i16 + 12 >> 2] = i4;
    return;
  }
  i4 = i16;
  i31 = i30 >>> 8;
  do {
    if ((i31 | 0) == 0) {
      i33 = 0;
    } else {
      if (i30 >>> 0 > 16777215) {
        i33 = 31;
        break;
      }
      i32 = (i31 + 1048320 | 0) >>> 16 & 8;
      i3 = i31 << i32;
      i27 = (i3 + 520192 | 0) >>> 16 & 4;
      i22 = i3 << i27;
      i3 = (i22 + 245760 | 0) >>> 16 & 2;
      i17 = (14 - (i27 | i32 | i3) | 0) + (i22 << i3 >>> 15) | 0;
      i33 = i30 >>> ((i17 + 7 | 0) >>> 0) & 1 | i17 << 1;
    }
  } while (0);
  i31 = 5256316 + (i33 << 2) | 0;
  HEAP32[i16 + 28 >> 2] = i33;
  HEAP32[i16 + 20 >> 2] = 0;
  HEAP32[i16 + 16 >> 2] = 0;
  i17 = HEAP32[1314004] | 0;
  i3 = 1 << i33;
  do {
    if ((i17 & i3 | 0) == 0) {
      HEAP32[1314004] = i17 | i3;
      HEAP32[i31 >> 2] = i4;
      HEAP32[i16 + 24 >> 2] = i31;
      HEAP32[i16 + 12 >> 2] = i16;
      HEAP32[i16 + 8 >> 2] = i16;
    } else {
      if ((i33 | 0) == 31) {
        i34 = 0;
      } else {
        i34 = 25 - (i33 >>> 1) | 0;
      }
      i22 = i30 << i34;
      i32 = HEAP32[i31 >> 2] | 0;
      while (1) {
        if ((HEAP32[i32 + 4 >> 2] & -8 | 0) == (i30 | 0)) {
          break;
        }
        i35 = i32 + 16 + (i22 >>> 31 << 2) | 0;
        i27 = HEAP32[i35 >> 2] | 0;
        if ((i27 | 0) == 0) {
          i36 = 1197;
          break;
        } else {
          i22 = i22 << 1;
          i32 = i27;
        }
      }
      if ((i36 | 0) == 1197) {
        if (i35 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
          _abort();
        } else {
          HEAP32[i35 >> 2] = i4;
          HEAP32[i16 + 24 >> 2] = i32;
          HEAP32[i16 + 12 >> 2] = i16;
          HEAP32[i16 + 8 >> 2] = i16;
          break;
        }
      }
      i22 = i32 + 8 | 0;
      i14 = HEAP32[i22 >> 2] | 0;
      i27 = HEAP32[1314007] | 0;
      if (i32 >>> 0 < i27 >>> 0) {
        _abort();
      }
      if (i14 >>> 0 < i27 >>> 0) {
        _abort();
      } else {
        HEAP32[i14 + 12 >> 2] = i4;
        HEAP32[i22 >> 2] = i4;
        HEAP32[i16 + 8 >> 2] = i14;
        HEAP32[i16 + 12 >> 2] = i32;
        HEAP32[i16 + 24 >> 2] = 0;
        break;
      }
    }
  } while (0);
  i16 = (HEAP32[1314011] | 0) - 1 | 0;
  HEAP32[1314011] = i16;
  if ((i16 | 0) == 0) {
    i37 = 5256464;
  } else {
    return;
  }
  while (1) {
    i16 = HEAP32[i37 >> 2] | 0;
    if ((i16 | 0) == 0) {
      break;
    } else {
      i37 = i16 + 8 | 0;
    }
  }
  HEAP32[1314011] = -1;
  return;
}
function _adler32(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0;
  i4 = i1 >>> 16;
  i5 = i1 & 65535;
  if ((i3 | 0) == 1) {
    i1 = (HEAPU8[i2] | 0) + i5 | 0;
    i6 = i1 >>> 0 > 65520 ? i1 - 65521 | 0 : i1;
    i1 = i6 + i4 | 0;
    i7 = (i1 >>> 0 > 65520 ? i1 + 15 | 0 : i1) << 16 | i6;
    return i7 | 0;
  }
  if ((i2 | 0) == 0) {
    i7 = 1;
    return i7 | 0;
  }
  if (i3 >>> 0 < 16) {
    L1726 : do {
      if ((i3 | 0) == 0) {
        i8 = i5;
        i9 = i4;
      } else {
        i6 = i5;
        i1 = i2;
        i10 = i3;
        i11 = i4;
        while (1) {
          i12 = i10 - 1 | 0;
          i13 = (HEAPU8[i1] | 0) + i6 | 0;
          i14 = i13 + i11 | 0;
          if ((i12 | 0) == 0) {
            i8 = i13;
            i9 = i14;
            break L1726;
          } else {
            i6 = i13;
            i1 = i1 + 1 | 0;
            i10 = i12;
            i11 = i14;
          }
        }
      }
    } while (0);
    i7 = (i9 >>> 0) % 65521 << 16 | (i8 >>> 0 > 65520 ? i8 - 65521 | 0 : i8);
    return i7 | 0;
  }
  do {
    if (i3 >>> 0 > 5551) {
      i8 = i5;
      i9 = i2;
      i11 = i3;
      i10 = i4;
      while (1) {
        i15 = i11 - 5552 | 0;
        i1 = 347;
        i6 = i10;
        i14 = i9;
        i12 = i8;
        while (1) {
          i13 = (HEAPU8[i14] | 0) + i12 | 0;
          i16 = i13 + (HEAPU8[i14 + 1 | 0] | 0) | 0;
          i17 = i16 + (HEAPU8[i14 + 2 | 0] | 0) | 0;
          i18 = i17 + (HEAPU8[i14 + 3 | 0] | 0) | 0;
          i19 = i18 + (HEAPU8[i14 + 4 | 0] | 0) | 0;
          i20 = i19 + (HEAPU8[i14 + 5 | 0] | 0) | 0;
          i21 = i20 + (HEAPU8[i14 + 6 | 0] | 0) | 0;
          i22 = i21 + (HEAPU8[i14 + 7 | 0] | 0) | 0;
          i23 = i22 + (HEAPU8[i14 + 8 | 0] | 0) | 0;
          i24 = i23 + (HEAPU8[i14 + 9 | 0] | 0) | 0;
          i25 = i24 + (HEAPU8[i14 + 10 | 0] | 0) | 0;
          i26 = i25 + (HEAPU8[i14 + 11 | 0] | 0) | 0;
          i27 = i26 + (HEAPU8[i14 + 12 | 0] | 0) | 0;
          i28 = i27 + (HEAPU8[i14 + 13 | 0] | 0) | 0;
          i29 = i28 + (HEAPU8[i14 + 14 | 0] | 0) | 0;
          i30 = i29 + (HEAPU8[i14 + 15 | 0] | 0) | 0;
          i31 = (((((((((((((((i13 + i6 | 0) + i16 | 0) + i17 | 0) + i18 | 0) + i19 | 0) + i20 | 0) + i21 | 0) + i22 | 0) + i23 | 0) + i24 | 0) + i25 | 0) + i26 | 0) + i27 | 0) + i28 | 0) + i29 | 0) + i30 | 0;
          i29 = i1 - 1 | 0;
          if ((i29 | 0) == 0) {
            break;
          } else {
            i1 = i29;
            i6 = i31;
            i14 = i14 + 16 | 0;
            i12 = i30;
          }
        }
        i32 = i9 + 5552 | 0;
        i33 = (i30 >>> 0) % 65521;
        i34 = (i31 >>> 0) % 65521;
        if (i15 >>> 0 > 5551) {
          i8 = i33;
          i9 = i32;
          i11 = i15;
          i10 = i34;
        } else {
          break;
        }
      }
      if ((i15 | 0) == 0) {
        i35 = i34;
        i36 = i33;
        break;
      }
      if (i15 >>> 0 > 15) {
        i37 = i33;
        i38 = i32;
        i39 = i15;
        i40 = i34;
        i41 = 1247;
        break;
      } else {
        i42 = i33;
        i43 = i32;
        i44 = i15;
        i45 = i34;
        i41 = 1248;
        break;
      }
    } else {
      i37 = i5;
      i38 = i2;
      i39 = i3;
      i40 = i4;
      i41 = 1247;
    }
  } while (0);
  do {
    if ((i41 | 0) == 1247) {
      while (1) {
        i41 = 0;
        i46 = i39 - 16 | 0;
        i4 = (HEAPU8[i38] | 0) + i37 | 0;
        i3 = i4 + (HEAPU8[i38 + 1 | 0] | 0) | 0;
        i2 = i3 + (HEAPU8[i38 + 2 | 0] | 0) | 0;
        i5 = i2 + (HEAPU8[i38 + 3 | 0] | 0) | 0;
        i34 = i5 + (HEAPU8[i38 + 4 | 0] | 0) | 0;
        i15 = i34 + (HEAPU8[i38 + 5 | 0] | 0) | 0;
        i32 = i15 + (HEAPU8[i38 + 6 | 0] | 0) | 0;
        i33 = i32 + (HEAPU8[i38 + 7 | 0] | 0) | 0;
        i31 = i33 + (HEAPU8[i38 + 8 | 0] | 0) | 0;
        i30 = i31 + (HEAPU8[i38 + 9 | 0] | 0) | 0;
        i10 = i30 + (HEAPU8[i38 + 10 | 0] | 0) | 0;
        i11 = i10 + (HEAPU8[i38 + 11 | 0] | 0) | 0;
        i9 = i11 + (HEAPU8[i38 + 12 | 0] | 0) | 0;
        i8 = i9 + (HEAPU8[i38 + 13 | 0] | 0) | 0;
        i12 = i8 + (HEAPU8[i38 + 14 | 0] | 0) | 0;
        i47 = i12 + (HEAPU8[i38 + 15 | 0] | 0) | 0;
        i48 = (((((((((((((((i4 + i40 | 0) + i3 | 0) + i2 | 0) + i5 | 0) + i34 | 0) + i15 | 0) + i32 | 0) + i33 | 0) + i31 | 0) + i30 | 0) + i10 | 0) + i11 | 0) + i9 | 0) + i8 | 0) + i12 | 0) + i47 | 0;
        i49 = i38 + 16 | 0;
        if (i46 >>> 0 > 15) {
          i37 = i47;
          i38 = i49;
          i39 = i46;
          i40 = i48;
          i41 = 1247;
        } else {
          break;
        }
      }
      if ((i46 | 0) == 0) {
        i50 = i47;
        i51 = i48;
        i41 = 1249;
        break;
      } else {
        i42 = i47;
        i43 = i49;
        i44 = i46;
        i45 = i48;
        i41 = 1248;
        break;
      }
    }
  } while (0);
  L1744 : do {
    if ((i41 | 0) == 1248) {
      while (1) {
        i41 = 0;
        i48 = i44 - 1 | 0;
        i46 = (HEAPU8[i43] | 0) + i42 | 0;
        i49 = i46 + i45 | 0;
        if ((i48 | 0) == 0) {
          i50 = i46;
          i51 = i49;
          i41 = 1249;
          break L1744;
        } else {
          i42 = i46;
          i43 = i43 + 1 | 0;
          i44 = i48;
          i45 = i49;
          i41 = 1248;
        }
      }
    }
  } while (0);
  if ((i41 | 0) == 1249) {
    i35 = (i51 >>> 0) % 65521;
    i36 = (i50 >>> 0) % 65521;
  }
  i7 = i35 << 16 | i36;
  return i7 | 0;
}
function _crc32(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0;
  if ((i2 | 0) == 0) {
    i4 = 0;
    return i4 | 0;
  }
  i5 = i1 ^ -1;
  L1755 : do {
    if ((i3 | 0) == 0) {
      i6 = i5;
    } else {
      i1 = i2;
      i7 = i3;
      i8 = i5;
      while (1) {
        if ((i1 & 3 | 0) == 0) {
          break;
        }
        i9 = HEAP32[5247032 + (((HEAPU8[i1] | 0) ^ i8 & 255) << 2) >> 2] ^ i8 >>> 8;
        i10 = i7 - 1 | 0;
        if ((i10 | 0) == 0) {
          i6 = i9;
          break L1755;
        } else {
          i1 = i1 + 1 | 0;
          i7 = i10;
          i8 = i9;
        }
      }
      i9 = i1;
      L1760 : do {
        if (i7 >>> 0 > 31) {
          i10 = i7;
          i11 = i8;
          i12 = i9;
          while (1) {
            i13 = HEAP32[i12 >> 2] ^ i11;
            i14 = HEAP32[5249080 + ((i13 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i13 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i13 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i13 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 4 >> 2];
            i13 = HEAP32[5249080 + ((i14 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i14 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i14 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i14 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 8 >> 2];
            i14 = HEAP32[5249080 + ((i13 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i13 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i13 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i13 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 12 >> 2];
            i13 = HEAP32[5249080 + ((i14 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i14 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i14 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i14 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 16 >> 2];
            i14 = HEAP32[5249080 + ((i13 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i13 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i13 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i13 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 20 >> 2];
            i13 = HEAP32[5249080 + ((i14 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i14 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i14 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i14 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 24 >> 2];
            i14 = i12 + 32 | 0;
            i15 = HEAP32[5249080 + ((i13 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i13 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i13 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i13 >>> 24 << 2) >> 2] ^ HEAP32[i12 + 28 >> 2];
            i13 = HEAP32[5249080 + ((i15 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i15 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i15 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i15 >>> 24 << 2) >> 2];
            i15 = i10 - 32 | 0;
            if (i15 >>> 0 > 31) {
              i10 = i15;
              i11 = i13;
              i12 = i14;
            } else {
              i16 = i15;
              i17 = i13;
              i18 = i14;
              break L1760;
            }
          }
        } else {
          i16 = i7;
          i17 = i8;
          i18 = i9;
        }
      } while (0);
      L1764 : do {
        if (i16 >>> 0 > 3) {
          i9 = i16;
          i8 = i17;
          i7 = i18;
          while (1) {
            i1 = i7 + 4 | 0;
            i12 = HEAP32[i7 >> 2] ^ i8;
            i11 = HEAP32[5249080 + ((i12 >>> 8 & 255) << 2) >> 2] ^ HEAP32[5250104 + ((i12 & 255) << 2) >> 2] ^ HEAP32[5248056 + ((i12 >>> 16 & 255) << 2) >> 2] ^ HEAP32[5247032 + (i12 >>> 24 << 2) >> 2];
            i12 = i9 - 4 | 0;
            if (i12 >>> 0 > 3) {
              i9 = i12;
              i8 = i11;
              i7 = i1;
            } else {
              i19 = i12;
              i20 = i11;
              i21 = i1;
              break L1764;
            }
          }
        } else {
          i19 = i16;
          i20 = i17;
          i21 = i18;
        }
      } while (0);
      if ((i19 | 0) == 0) {
        i6 = i20;
        break;
      }
      i7 = i20;
      i8 = i19;
      i9 = i21;
      while (1) {
        i1 = HEAP32[5247032 + (((HEAPU8[i9] | 0) ^ i7 & 255) << 2) >> 2] ^ i7 >>> 8;
        i11 = i8 - 1 | 0;
        if ((i11 | 0) == 0) {
          i6 = i1;
          break L1755;
        } else {
          i7 = i1;
          i8 = i11;
          i9 = i9 + 1 | 0;
        }
      }
    }
  } while (0);
  i4 = i6 ^ -1;
  return i4 | 0;
}
function _inflate_table(i1, i2, i3, i4, i5, i6) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  i4 = i4 | 0;
  i5 = i5 | 0;
  i6 = i6 | 0;
  var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0;
  i7 = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  i8 = i7 | 0;
  i9 = STACKTOP;
  STACKTOP = STACKTOP + 32 | 0;
  _memset(i8 | 0, 0, 32);
  i10 = (i3 | 0) == 0;
  L1774 : do {
    if (!i10) {
      i11 = 0;
      while (1) {
        i12 = i8 + ((HEAPU16[i2 + (i11 << 1) >> 1] | 0) << 1) | 0;
        HEAP16[i12 >> 1] = (HEAP16[i12 >> 1] | 0) + 1 & 65535;
        i12 = i11 + 1 | 0;
        if ((i12 | 0) == (i3 | 0)) {
          break L1774;
        } else {
          i11 = i12;
        }
      }
    }
  } while (0);
  i11 = HEAP32[i5 >> 2] | 0;
  i12 = 15;
  while (1) {
    if ((i12 | 0) == 0) {
      i13 = 1277;
      break;
    }
    if (HEAP16[i8 + (i12 << 1) >> 1] << 16 >> 16 == 0) {
      i12 = i12 - 1 | 0;
    } else {
      break;
    }
  }
  if ((i13 | 0) == 1277) {
    i14 = HEAP32[i4 >> 2] | 0;
    HEAP32[i4 >> 2] = i14 + 4 | 0;
    HEAP8[i14 | 0] = 64;
    HEAP8[i14 + 1 | 0] = 1;
    HEAP16[i14 + 2 >> 1] = 0;
    i14 = HEAP32[i4 >> 2] | 0;
    HEAP32[i4 >> 2] = i14 + 4 | 0;
    HEAP8[i14 | 0] = 64;
    HEAP8[i14 + 1 | 0] = 1;
    HEAP16[i14 + 2 >> 1] = 0;
    HEAP32[i5 >> 2] = 1;
    i15 = 0;
    STACKTOP = i7;
    return i15 | 0;
  }
  i14 = i11 >>> 0 > i12 >>> 0 ? i12 : i11;
  i11 = 1;
  while (1) {
    if (i11 >>> 0 >= i12 >>> 0) {
      break;
    }
    if (HEAP16[i8 + (i11 << 1) >> 1] << 16 >> 16 == 0) {
      i11 = i11 + 1 | 0;
    } else {
      break;
    }
  }
  i16 = i14 >>> 0 < i11 >>> 0 ? i11 : i14;
  i14 = 1;
  i17 = 1;
  while (1) {
    if (i17 >>> 0 >= 16) {
      break;
    }
    i18 = (i14 << 1) - (HEAPU16[i8 + (i17 << 1) >> 1] | 0) | 0;
    if ((i18 | 0) < 0) {
      i15 = -1;
      i13 = 1326;
      break;
    } else {
      i14 = i18;
      i17 = i17 + 1 | 0;
    }
  }
  if ((i13 | 0) == 1326) {
    STACKTOP = i7;
    return i15 | 0;
  }
  do {
    if ((i14 | 0) > 0) {
      if ((i1 | 0) != 0 & (i12 | 0) == 1) {
        break;
      } else {
        i15 = -1;
      }
      STACKTOP = i7;
      return i15 | 0;
    }
  } while (0);
  HEAP16[i9 + 2 >> 1] = 0;
  i14 = HEAP16[i8 + 2 >> 1] | 0;
  HEAP16[i9 + 4 >> 1] = i14;
  i17 = (HEAP16[i8 + 4 >> 1] | 0) + i14 & 65535;
  HEAP16[i9 + 6 >> 1] = i17;
  i14 = (HEAP16[i8 + 6 >> 1] | 0) + i17 & 65535;
  HEAP16[i9 + 8 >> 1] = i14;
  i17 = (HEAP16[i8 + 8 >> 1] | 0) + i14 & 65535;
  HEAP16[i9 + 10 >> 1] = i17;
  i14 = (HEAP16[i8 + 10 >> 1] | 0) + i17 & 65535;
  HEAP16[i9 + 12 >> 1] = i14;
  i17 = (HEAP16[i8 + 12 >> 1] | 0) + i14 & 65535;
  HEAP16[i9 + 14 >> 1] = i17;
  i14 = (HEAP16[i8 + 14 >> 1] | 0) + i17 & 65535;
  HEAP16[i9 + 16 >> 1] = i14;
  i17 = (HEAP16[i8 + 16 >> 1] | 0) + i14 & 65535;
  HEAP16[i9 + 18 >> 1] = i17;
  i14 = (HEAP16[i8 + 18 >> 1] | 0) + i17 & 65535;
  HEAP16[i9 + 20 >> 1] = i14;
  i17 = (HEAP16[i8 + 20 >> 1] | 0) + i14 & 65535;
  HEAP16[i9 + 22 >> 1] = i17;
  i14 = (HEAP16[i8 + 22 >> 1] | 0) + i17 & 65535;
  HEAP16[i9 + 24 >> 1] = i14;
  i17 = (HEAP16[i8 + 24 >> 1] | 0) + i14 & 65535;
  HEAP16[i9 + 26 >> 1] = i17;
  i14 = (HEAP16[i8 + 26 >> 1] | 0) + i17 & 65535;
  HEAP16[i9 + 28 >> 1] = i14;
  HEAP16[i9 + 30 >> 1] = (HEAP16[i8 + 28 >> 1] | 0) + i14 & 65535;
  L1799 : do {
    if (!i10) {
      i14 = 0;
      while (1) {
        i17 = HEAP16[i2 + (i14 << 1) >> 1] | 0;
        if (i17 << 16 >> 16 != 0) {
          i18 = i9 + ((i17 & 65535) << 1) | 0;
          i17 = HEAP16[i18 >> 1] | 0;
          HEAP16[i18 >> 1] = i17 + 1 & 65535;
          HEAP16[i6 + ((i17 & 65535) << 1) >> 1] = i14 & 65535;
        }
        i17 = i14 + 1 | 0;
        if ((i17 | 0) == (i3 | 0)) {
          break L1799;
        } else {
          i14 = i17;
        }
      }
    }
  } while (0);
  do {
    if ((i1 | 0) == 0) {
      i19 = 0;
      i20 = 1 << i16;
      i21 = 19;
      i22 = i6;
      i23 = i6;
      i24 = 0;
    } else if ((i1 | 0) == 1) {
      i3 = 1 << i16;
      if (i3 >>> 0 > 851) {
        i15 = 1;
      } else {
        i19 = 1;
        i20 = i3;
        i21 = 256;
        i22 = 5243726;
        i23 = 5243790;
        i24 = 0;
        break;
      }
      STACKTOP = i7;
      return i15 | 0;
    } else {
      i3 = 1 << i16;
      i9 = (i1 | 0) == 2;
      if (i9 & i3 >>> 0 > 591) {
        i15 = 1;
      } else {
        i19 = 0;
        i20 = i3;
        i21 = -1;
        i22 = 5244368;
        i23 = 5244432;
        i24 = i9;
        break;
      }
      STACKTOP = i7;
      return i15 | 0;
    }
  } while (0);
  i1 = i20 - 1 | 0;
  i9 = i16 & 255;
  i3 = HEAP32[i4 >> 2] | 0;
  i10 = -1;
  i14 = 0;
  i17 = i20;
  i20 = 0;
  i18 = i16;
  i25 = 0;
  i26 = i11;
  L1813 : while (1) {
    i11 = 1 << i18;
    i27 = i14;
    i28 = i25;
    i29 = i26;
    while (1) {
      i30 = i29 - i20 | 0;
      i31 = i30 & 255;
      i32 = HEAP16[i6 + (i28 << 1) >> 1] | 0;
      i33 = i32 & 65535;
      do {
        if ((i33 | 0) < (i21 | 0)) {
          i34 = 0;
          i35 = i32;
        } else {
          if ((i33 | 0) <= (i21 | 0)) {
            i34 = 96;
            i35 = 0;
            break;
          }
          i34 = HEAP16[i22 + (i33 << 1) >> 1] & 255;
          i35 = HEAP16[i23 + (i33 << 1) >> 1] | 0;
        }
      } while (0);
      i33 = 1 << i30;
      i32 = i27 >>> (i20 >>> 0);
      i36 = i11;
      while (1) {
        i37 = i36 - i33 | 0;
        i38 = i37 + i32 | 0;
        HEAP8[i3 + (i38 << 2) | 0] = i34;
        HEAP8[i3 + (i38 << 2) + 1 | 0] = i31;
        HEAP16[i3 + (i38 << 2) + 2 >> 1] = i35;
        if ((i36 | 0) == (i33 | 0)) {
          break;
        } else {
          i36 = i37;
        }
      }
      i36 = 1 << i29 - 1;
      while (1) {
        if ((i36 & i27 | 0) == 0) {
          break;
        } else {
          i36 = i36 >>> 1;
        }
      }
      if ((i36 | 0) == 0) {
        i39 = 0;
      } else {
        i39 = (i36 - 1 & i27) + i36 | 0;
      }
      i40 = i28 + 1 | 0;
      i33 = i8 + (i29 << 1) | 0;
      i32 = (HEAP16[i33 >> 1] | 0) - 1 & 65535;
      HEAP16[i33 >> 1] = i32;
      if (i32 << 16 >> 16 == 0) {
        if ((i29 | 0) == (i12 | 0)) {
          break L1813;
        }
        i41 = HEAPU16[i2 + ((HEAPU16[i6 + (i40 << 1) >> 1] | 0) << 1) >> 1] | 0;
      } else {
        i41 = i29;
      }
      if (i41 >>> 0 <= i16 >>> 0) {
        i27 = i39;
        i28 = i40;
        i29 = i41;
        continue;
      }
      i42 = i39 & i1;
      if ((i42 | 0) == (i10 | 0)) {
        i27 = i39;
        i28 = i40;
        i29 = i41;
      } else {
        break;
      }
    }
    i29 = (i20 | 0) == 0 ? i16 : i20;
    i28 = i3 + (i11 << 2) | 0;
    i27 = i41 - i29 | 0;
    L1836 : do {
      if (i41 >>> 0 < i12 >>> 0) {
        i32 = i27;
        i33 = 1 << i27;
        i30 = i41;
        while (1) {
          i37 = i33 - (HEAPU16[i8 + (i30 << 1) >> 1] | 0) | 0;
          if ((i37 | 0) < 1) {
            i43 = i32;
            break L1836;
          }
          i38 = i32 + 1 | 0;
          i44 = i38 + i29 | 0;
          if (i44 >>> 0 < i12 >>> 0) {
            i32 = i38;
            i33 = i37 << 1;
            i30 = i44;
          } else {
            i43 = i38;
            break L1836;
          }
        }
      } else {
        i43 = i27;
      }
    } while (0);
    i27 = (1 << i43) + i17 | 0;
    if (i19 & i27 >>> 0 > 851 | i24 & i27 >>> 0 > 591) {
      i15 = 1;
      i13 = 1330;
      break;
    }
    HEAP8[(HEAP32[i4 >> 2] | 0) + (i42 << 2) | 0] = i43 & 255;
    HEAP8[(HEAP32[i4 >> 2] | 0) + (i42 << 2) + 1 | 0] = i9;
    i11 = HEAP32[i4 >> 2] | 0;
    HEAP16[i11 + (i42 << 2) + 2 >> 1] = (i28 - i11 | 0) >>> 2 & 65535;
    i3 = i28;
    i10 = i42;
    i14 = i39;
    i17 = i27;
    i20 = i29;
    i18 = i43;
    i25 = i40;
    i26 = i41;
  }
  if ((i13 | 0) == 1330) {
    STACKTOP = i7;
    return i15 | 0;
  }
  L1846 : do {
    if ((i39 | 0) != 0) {
      i13 = i12;
      i41 = i20;
      i26 = i39;
      i40 = i31;
      i25 = i3;
      while (1) {
        do {
          if ((i41 | 0) == 0) {
            i45 = i25;
            i46 = i40;
            i47 = 0;
            i48 = i13;
          } else {
            if ((i26 & i1 | 0) == (i10 | 0)) {
              i45 = i25;
              i46 = i40;
              i47 = i41;
              i48 = i13;
              break;
            }
            i45 = HEAP32[i4 >> 2] | 0;
            i46 = i9;
            i47 = 0;
            i48 = i16;
          }
        } while (0);
        i43 = i26 >>> (i47 >>> 0);
        HEAP8[i45 + (i43 << 2) | 0] = 64;
        HEAP8[i45 + (i43 << 2) + 1 | 0] = i46;
        HEAP16[i45 + (i43 << 2) + 2 >> 1] = 0;
        i43 = 1 << i48 - 1;
        while (1) {
          if ((i43 & i26 | 0) == 0) {
            break;
          } else {
            i43 = i43 >>> 1;
          }
        }
        if ((i43 | 0) == 0) {
          break L1846;
        }
        i18 = (i43 - 1 & i26) + i43 | 0;
        if ((i18 | 0) == 0) {
          break L1846;
        } else {
          i13 = i48;
          i41 = i47;
          i26 = i18;
          i40 = i46;
          i25 = i45;
        }
      }
    }
  } while (0);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + (i17 << 2) | 0;
  HEAP32[i5 >> 2] = i16;
  i15 = 0;
  STACKTOP = i7;
  return i15 | 0;
}
function _malloc(i1) {
  i1 = i1 | 0;
  var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i72 = 0, i73 = 0, i74 = 0, i75 = 0, i76 = 0, i77 = 0, i78 = 0, i79 = 0, i80 = 0, i81 = 0, i82 = 0, i83 = 0, i84 = 0, i85 = 0;
  do {
    if (i1 >>> 0 < 245) {
      if (i1 >>> 0 < 11) {
        i2 = 16;
      } else {
        i2 = i1 + 11 & -8;
      }
      i3 = i2 >>> 3;
      i4 = HEAP32[1314003] | 0;
      i5 = i4 >>> (i3 >>> 0);
      if ((i5 & 3 | 0) != 0) {
        i6 = (i5 & 1 ^ 1) + i3 | 0;
        i7 = i6 << 1;
        i8 = 5256052 + (i7 << 2) | 0;
        i9 = 5256052 + (i7 + 2 << 2) | 0;
        i7 = HEAP32[i9 >> 2] | 0;
        i10 = i7 + 8 | 0;
        i11 = HEAP32[i10 >> 2] | 0;
        do {
          if ((i8 | 0) == (i11 | 0)) {
            HEAP32[1314003] = i4 & (1 << i6 ^ -1);
          } else {
            if (i11 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
              _abort();
              return 0;
            } else {
              HEAP32[i9 >> 2] = i11;
              HEAP32[i11 + 12 >> 2] = i8;
              break;
            }
          }
        } while (0);
        i8 = i6 << 3;
        HEAP32[i7 + 4 >> 2] = i8 | 3;
        i11 = i7 + (i8 | 4) | 0;
        HEAP32[i11 >> 2] = HEAP32[i11 >> 2] | 1;
        i12 = i10;
        return i12 | 0;
      }
      if (i2 >>> 0 <= (HEAP32[1314005] | 0) >>> 0) {
        i13 = i2;
        break;
      }
      if ((i5 | 0) != 0) {
        i11 = 2 << i3;
        i8 = i5 << i3 & (i11 | -i11);
        i11 = (i8 & -i8) - 1 | 0;
        i8 = i11 >>> 12 & 16;
        i9 = i11 >>> (i8 >>> 0);
        i11 = i9 >>> 5 & 8;
        i14 = i9 >>> (i11 >>> 0);
        i9 = i14 >>> 2 & 4;
        i15 = i14 >>> (i9 >>> 0);
        i14 = i15 >>> 1 & 2;
        i16 = i15 >>> (i14 >>> 0);
        i15 = i16 >>> 1 & 1;
        i17 = (i11 | i8 | i9 | i14 | i15) + (i16 >>> (i15 >>> 0)) | 0;
        i15 = i17 << 1;
        i16 = 5256052 + (i15 << 2) | 0;
        i14 = 5256052 + (i15 + 2 << 2) | 0;
        i15 = HEAP32[i14 >> 2] | 0;
        i9 = i15 + 8 | 0;
        i8 = HEAP32[i9 >> 2] | 0;
        do {
          if ((i16 | 0) == (i8 | 0)) {
            HEAP32[1314003] = i4 & (1 << i17 ^ -1);
          } else {
            if (i8 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
              _abort();
              return 0;
            } else {
              HEAP32[i14 >> 2] = i8;
              HEAP32[i8 + 12 >> 2] = i16;
              break;
            }
          }
        } while (0);
        i16 = i17 << 3;
        i8 = i16 - i2 | 0;
        HEAP32[i15 + 4 >> 2] = i2 | 3;
        i14 = i15;
        i4 = i14 + i2 | 0;
        HEAP32[i14 + (i2 | 4) >> 2] = i8 | 1;
        HEAP32[i14 + i16 >> 2] = i8;
        i16 = HEAP32[1314005] | 0;
        if ((i16 | 0) != 0) {
          i14 = HEAP32[1314008] | 0;
          i3 = i16 >>> 3;
          i16 = i3 << 1;
          i5 = 5256052 + (i16 << 2) | 0;
          i10 = HEAP32[1314003] | 0;
          i7 = 1 << i3;
          do {
            if ((i10 & i7 | 0) == 0) {
              HEAP32[1314003] = i10 | i7;
              i18 = i5;
              i19 = 5256052 + (i16 + 2 << 2) | 0;
            } else {
              i3 = 5256052 + (i16 + 2 << 2) | 0;
              i6 = HEAP32[i3 >> 2] | 0;
              if (i6 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                i18 = i6;
                i19 = i3;
                break;
              }
              _abort();
              return 0;
            }
          } while (0);
          HEAP32[i19 >> 2] = i14;
          HEAP32[i18 + 12 >> 2] = i14;
          HEAP32[i14 + 8 >> 2] = i18;
          HEAP32[i14 + 12 >> 2] = i5;
        }
        HEAP32[1314005] = i8;
        HEAP32[1314008] = i4;
        i12 = i9;
        return i12 | 0;
      }
      i16 = HEAP32[1314004] | 0;
      if ((i16 | 0) == 0) {
        i13 = i2;
        break;
      }
      i7 = (i16 & -i16) - 1 | 0;
      i16 = i7 >>> 12 & 16;
      i10 = i7 >>> (i16 >>> 0);
      i7 = i10 >>> 5 & 8;
      i15 = i10 >>> (i7 >>> 0);
      i10 = i15 >>> 2 & 4;
      i17 = i15 >>> (i10 >>> 0);
      i15 = i17 >>> 1 & 2;
      i3 = i17 >>> (i15 >>> 0);
      i17 = i3 >>> 1 & 1;
      i6 = HEAP32[5256316 + ((i7 | i16 | i10 | i15 | i17) + (i3 >>> (i17 >>> 0)) << 2) >> 2] | 0;
      i17 = i6;
      i3 = i6;
      i15 = (HEAP32[i6 + 4 >> 2] & -8) - i2 | 0;
      while (1) {
        i6 = HEAP32[i17 + 16 >> 2] | 0;
        if ((i6 | 0) == 0) {
          i10 = HEAP32[i17 + 20 >> 2] | 0;
          if ((i10 | 0) == 0) {
            break;
          } else {
            i20 = i10;
          }
        } else {
          i20 = i6;
        }
        i6 = (HEAP32[i20 + 4 >> 2] & -8) - i2 | 0;
        i10 = i6 >>> 0 < i15 >>> 0;
        i17 = i20;
        i3 = i10 ? i20 : i3;
        i15 = i10 ? i6 : i15;
      }
      i17 = i3;
      i9 = HEAP32[1314007] | 0;
      if (i17 >>> 0 < i9 >>> 0) {
        _abort();
        return 0;
      }
      i4 = i17 + i2 | 0;
      i8 = i4;
      if (i17 >>> 0 >= i4 >>> 0) {
        _abort();
        return 0;
      }
      i4 = HEAP32[i3 + 24 >> 2] | 0;
      i5 = HEAP32[i3 + 12 >> 2] | 0;
      L1909 : do {
        if ((i5 | 0) == (i3 | 0)) {
          i14 = i3 + 20 | 0;
          i6 = HEAP32[i14 >> 2] | 0;
          do {
            if ((i6 | 0) == 0) {
              i10 = i3 + 16 | 0;
              i16 = HEAP32[i10 >> 2] | 0;
              if ((i16 | 0) == 0) {
                i21 = 0;
                break L1909;
              } else {
                i22 = i16;
                i23 = i10;
                break;
              }
            } else {
              i22 = i6;
              i23 = i14;
            }
          } while (0);
          while (1) {
            i14 = i22 + 20 | 0;
            i6 = HEAP32[i14 >> 2] | 0;
            if ((i6 | 0) != 0) {
              i22 = i6;
              i23 = i14;
              continue;
            }
            i14 = i22 + 16 | 0;
            i6 = HEAP32[i14 >> 2] | 0;
            if ((i6 | 0) == 0) {
              break;
            } else {
              i22 = i6;
              i23 = i14;
            }
          }
          if (i23 >>> 0 < i9 >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i23 >> 2] = 0;
            i21 = i22;
            break;
          }
        } else {
          i14 = HEAP32[i3 + 8 >> 2] | 0;
          if (i14 >>> 0 < i9 >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i14 + 12 >> 2] = i5;
            HEAP32[i5 + 8 >> 2] = i14;
            i21 = i5;
            break;
          }
        }
      } while (0);
      L1925 : do {
        if ((i4 | 0) != 0) {
          i5 = i3 + 28 | 0;
          i9 = 5256316 + (HEAP32[i5 >> 2] << 2) | 0;
          do {
            if ((i3 | 0) == (HEAP32[i9 >> 2] | 0)) {
              HEAP32[i9 >> 2] = i21;
              if ((i21 | 0) != 0) {
                break;
              }
              HEAP32[1314004] = HEAP32[1314004] & (1 << HEAP32[i5 >> 2] ^ -1);
              break L1925;
            } else {
              if (i4 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
                return 0;
              }
              i14 = i4 + 16 | 0;
              if ((HEAP32[i14 >> 2] | 0) == (i3 | 0)) {
                HEAP32[i14 >> 2] = i21;
              } else {
                HEAP32[i4 + 20 >> 2] = i21;
              }
              if ((i21 | 0) == 0) {
                break L1925;
              }
            }
          } while (0);
          if (i21 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
            return 0;
          }
          HEAP32[i21 + 24 >> 2] = i4;
          i5 = HEAP32[i3 + 16 >> 2] | 0;
          do {
            if ((i5 | 0) != 0) {
              if (i5 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
                return 0;
              } else {
                HEAP32[i21 + 16 >> 2] = i5;
                HEAP32[i5 + 24 >> 2] = i21;
                break;
              }
            }
          } while (0);
          i5 = HEAP32[i3 + 20 >> 2] | 0;
          if ((i5 | 0) == 0) {
            break;
          }
          if (i5 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i21 + 20 >> 2] = i5;
            HEAP32[i5 + 24 >> 2] = i21;
            break;
          }
        }
      } while (0);
      if (i15 >>> 0 < 16) {
        i4 = i15 + i2 | 0;
        HEAP32[i3 + 4 >> 2] = i4 | 3;
        i5 = i17 + (i4 + 4 | 0) | 0;
        HEAP32[i5 >> 2] = HEAP32[i5 >> 2] | 1;
      } else {
        HEAP32[i3 + 4 >> 2] = i2 | 3;
        HEAP32[i17 + (i2 | 4) >> 2] = i15 | 1;
        HEAP32[i17 + (i15 + i2 | 0) >> 2] = i15;
        i5 = HEAP32[1314005] | 0;
        if ((i5 | 0) != 0) {
          i4 = HEAP32[1314008] | 0;
          i9 = i5 >>> 3;
          i5 = i9 << 1;
          i14 = 5256052 + (i5 << 2) | 0;
          i6 = HEAP32[1314003] | 0;
          i10 = 1 << i9;
          do {
            if ((i6 & i10 | 0) == 0) {
              HEAP32[1314003] = i6 | i10;
              i24 = i14;
              i25 = 5256052 + (i5 + 2 << 2) | 0;
            } else {
              i9 = 5256052 + (i5 + 2 << 2) | 0;
              i16 = HEAP32[i9 >> 2] | 0;
              if (i16 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                i24 = i16;
                i25 = i9;
                break;
              }
              _abort();
              return 0;
            }
          } while (0);
          HEAP32[i25 >> 2] = i4;
          HEAP32[i24 + 12 >> 2] = i4;
          HEAP32[i4 + 8 >> 2] = i24;
          HEAP32[i4 + 12 >> 2] = i14;
        }
        HEAP32[1314005] = i15;
        HEAP32[1314008] = i8;
      }
      i5 = i3 + 8 | 0;
      if ((i5 | 0) == 0) {
        i13 = i2;
        break;
      } else {
        i12 = i5;
      }
      return i12 | 0;
    } else {
      if (i1 >>> 0 > 4294967231) {
        i13 = -1;
        break;
      }
      i5 = i1 + 11 | 0;
      i10 = i5 & -8;
      i6 = HEAP32[1314004] | 0;
      if ((i6 | 0) == 0) {
        i13 = i10;
        break;
      }
      i17 = -i10 | 0;
      i9 = i5 >>> 8;
      do {
        if ((i9 | 0) == 0) {
          i26 = 0;
        } else {
          if (i10 >>> 0 > 16777215) {
            i26 = 31;
            break;
          }
          i5 = (i9 + 1048320 | 0) >>> 16 & 8;
          i16 = i9 << i5;
          i7 = (i16 + 520192 | 0) >>> 16 & 4;
          i11 = i16 << i7;
          i16 = (i11 + 245760 | 0) >>> 16 & 2;
          i27 = (14 - (i7 | i5 | i16) | 0) + (i11 << i16 >>> 15) | 0;
          i26 = i10 >>> ((i27 + 7 | 0) >>> 0) & 1 | i27 << 1;
        }
      } while (0);
      i9 = HEAP32[5256316 + (i26 << 2) >> 2] | 0;
      L1973 : do {
        if ((i9 | 0) == 0) {
          i28 = 0;
          i29 = i17;
          i30 = 0;
        } else {
          if ((i26 | 0) == 31) {
            i31 = 0;
          } else {
            i31 = 25 - (i26 >>> 1) | 0;
          }
          i3 = 0;
          i8 = i17;
          i15 = i9;
          i14 = i10 << i31;
          i4 = 0;
          while (1) {
            i27 = HEAP32[i15 + 4 >> 2] & -8;
            i16 = i27 - i10 | 0;
            if (i16 >>> 0 < i8 >>> 0) {
              if ((i27 | 0) == (i10 | 0)) {
                i28 = i15;
                i29 = i16;
                i30 = i15;
                break L1973;
              } else {
                i32 = i15;
                i33 = i16;
              }
            } else {
              i32 = i3;
              i33 = i8;
            }
            i16 = HEAP32[i15 + 20 >> 2] | 0;
            i27 = HEAP32[i15 + 16 + (i14 >>> 31 << 2) >> 2] | 0;
            i11 = (i16 | 0) == 0 | (i16 | 0) == (i27 | 0) ? i4 : i16;
            if ((i27 | 0) == 0) {
              i28 = i32;
              i29 = i33;
              i30 = i11;
              break L1973;
            } else {
              i3 = i32;
              i8 = i33;
              i15 = i27;
              i14 = i14 << 1;
              i4 = i11;
            }
          }
        }
      } while (0);
      if ((i30 | 0) == 0 & (i28 | 0) == 0) {
        i9 = 2 << i26;
        i17 = i6 & (i9 | -i9);
        if ((i17 | 0) == 0) {
          i13 = i10;
          break;
        }
        i9 = (i17 & -i17) - 1 | 0;
        i17 = i9 >>> 12 & 16;
        i4 = i9 >>> (i17 >>> 0);
        i9 = i4 >>> 5 & 8;
        i14 = i4 >>> (i9 >>> 0);
        i4 = i14 >>> 2 & 4;
        i15 = i14 >>> (i4 >>> 0);
        i14 = i15 >>> 1 & 2;
        i8 = i15 >>> (i14 >>> 0);
        i15 = i8 >>> 1 & 1;
        i34 = HEAP32[5256316 + ((i9 | i17 | i4 | i14 | i15) + (i8 >>> (i15 >>> 0)) << 2) >> 2] | 0;
      } else {
        i34 = i30;
      }
      L1988 : do {
        if ((i34 | 0) == 0) {
          i35 = i29;
          i36 = i28;
        } else {
          i15 = i34;
          i8 = i29;
          i14 = i28;
          while (1) {
            i4 = (HEAP32[i15 + 4 >> 2] & -8) - i10 | 0;
            i17 = i4 >>> 0 < i8 >>> 0;
            i9 = i17 ? i4 : i8;
            i4 = i17 ? i15 : i14;
            i17 = HEAP32[i15 + 16 >> 2] | 0;
            if ((i17 | 0) != 0) {
              i15 = i17;
              i8 = i9;
              i14 = i4;
              continue;
            }
            i17 = HEAP32[i15 + 20 >> 2] | 0;
            if ((i17 | 0) == 0) {
              i35 = i9;
              i36 = i4;
              break L1988;
            } else {
              i15 = i17;
              i8 = i9;
              i14 = i4;
            }
          }
        }
      } while (0);
      if ((i36 | 0) == 0) {
        i13 = i10;
        break;
      }
      if (i35 >>> 0 >= ((HEAP32[1314005] | 0) - i10 | 0) >>> 0) {
        i13 = i10;
        break;
      }
      i6 = i36;
      i14 = HEAP32[1314007] | 0;
      if (i6 >>> 0 < i14 >>> 0) {
        _abort();
        return 0;
      }
      i8 = i6 + i10 | 0;
      i15 = i8;
      if (i6 >>> 0 >= i8 >>> 0) {
        _abort();
        return 0;
      }
      i4 = HEAP32[i36 + 24 >> 2] | 0;
      i9 = HEAP32[i36 + 12 >> 2] | 0;
      L2001 : do {
        if ((i9 | 0) == (i36 | 0)) {
          i17 = i36 + 20 | 0;
          i3 = HEAP32[i17 >> 2] | 0;
          do {
            if ((i3 | 0) == 0) {
              i11 = i36 + 16 | 0;
              i27 = HEAP32[i11 >> 2] | 0;
              if ((i27 | 0) == 0) {
                i37 = 0;
                break L2001;
              } else {
                i38 = i27;
                i39 = i11;
                break;
              }
            } else {
              i38 = i3;
              i39 = i17;
            }
          } while (0);
          while (1) {
            i17 = i38 + 20 | 0;
            i3 = HEAP32[i17 >> 2] | 0;
            if ((i3 | 0) != 0) {
              i38 = i3;
              i39 = i17;
              continue;
            }
            i17 = i38 + 16 | 0;
            i3 = HEAP32[i17 >> 2] | 0;
            if ((i3 | 0) == 0) {
              break;
            } else {
              i38 = i3;
              i39 = i17;
            }
          }
          if (i39 >>> 0 < i14 >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i39 >> 2] = 0;
            i37 = i38;
            break;
          }
        } else {
          i17 = HEAP32[i36 + 8 >> 2] | 0;
          if (i17 >>> 0 < i14 >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i17 + 12 >> 2] = i9;
            HEAP32[i9 + 8 >> 2] = i17;
            i37 = i9;
            break;
          }
        }
      } while (0);
      L2017 : do {
        if ((i4 | 0) != 0) {
          i9 = i36 + 28 | 0;
          i14 = 5256316 + (HEAP32[i9 >> 2] << 2) | 0;
          do {
            if ((i36 | 0) == (HEAP32[i14 >> 2] | 0)) {
              HEAP32[i14 >> 2] = i37;
              if ((i37 | 0) != 0) {
                break;
              }
              HEAP32[1314004] = HEAP32[1314004] & (1 << HEAP32[i9 >> 2] ^ -1);
              break L2017;
            } else {
              if (i4 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
                return 0;
              }
              i17 = i4 + 16 | 0;
              if ((HEAP32[i17 >> 2] | 0) == (i36 | 0)) {
                HEAP32[i17 >> 2] = i37;
              } else {
                HEAP32[i4 + 20 >> 2] = i37;
              }
              if ((i37 | 0) == 0) {
                break L2017;
              }
            }
          } while (0);
          if (i37 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
            return 0;
          }
          HEAP32[i37 + 24 >> 2] = i4;
          i9 = HEAP32[i36 + 16 >> 2] | 0;
          do {
            if ((i9 | 0) != 0) {
              if (i9 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                _abort();
                return 0;
              } else {
                HEAP32[i37 + 16 >> 2] = i9;
                HEAP32[i9 + 24 >> 2] = i37;
                break;
              }
            }
          } while (0);
          i9 = HEAP32[i36 + 20 >> 2] | 0;
          if ((i9 | 0) == 0) {
            break;
          }
          if (i9 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i37 + 20 >> 2] = i9;
            HEAP32[i9 + 24 >> 2] = i37;
            break;
          }
        }
      } while (0);
      do {
        if (i35 >>> 0 < 16) {
          i4 = i35 + i10 | 0;
          HEAP32[i36 + 4 >> 2] = i4 | 3;
          i9 = i6 + (i4 + 4 | 0) | 0;
          HEAP32[i9 >> 2] = HEAP32[i9 >> 2] | 1;
        } else {
          HEAP32[i36 + 4 >> 2] = i10 | 3;
          HEAP32[i6 + (i10 | 4) >> 2] = i35 | 1;
          HEAP32[i6 + (i35 + i10 | 0) >> 2] = i35;
          i9 = i35 >>> 3;
          if (i35 >>> 0 < 256) {
            i4 = i9 << 1;
            i14 = 5256052 + (i4 << 2) | 0;
            i17 = HEAP32[1314003] | 0;
            i3 = 1 << i9;
            do {
              if ((i17 & i3 | 0) == 0) {
                HEAP32[1314003] = i17 | i3;
                i40 = i14;
                i41 = 5256052 + (i4 + 2 << 2) | 0;
              } else {
                i9 = 5256052 + (i4 + 2 << 2) | 0;
                i11 = HEAP32[i9 >> 2] | 0;
                if (i11 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                  i40 = i11;
                  i41 = i9;
                  break;
                }
                _abort();
                return 0;
              }
            } while (0);
            HEAP32[i41 >> 2] = i15;
            HEAP32[i40 + 12 >> 2] = i15;
            HEAP32[i6 + (i10 + 8 | 0) >> 2] = i40;
            HEAP32[i6 + (i10 + 12 | 0) >> 2] = i14;
            break;
          }
          i4 = i8;
          i3 = i35 >>> 8;
          do {
            if ((i3 | 0) == 0) {
              i42 = 0;
            } else {
              if (i35 >>> 0 > 16777215) {
                i42 = 31;
                break;
              }
              i17 = (i3 + 1048320 | 0) >>> 16 & 8;
              i9 = i3 << i17;
              i11 = (i9 + 520192 | 0) >>> 16 & 4;
              i27 = i9 << i11;
              i9 = (i27 + 245760 | 0) >>> 16 & 2;
              i16 = (14 - (i11 | i17 | i9) | 0) + (i27 << i9 >>> 15) | 0;
              i42 = i35 >>> ((i16 + 7 | 0) >>> 0) & 1 | i16 << 1;
            }
          } while (0);
          i3 = 5256316 + (i42 << 2) | 0;
          HEAP32[i6 + (i10 + 28 | 0) >> 2] = i42;
          HEAP32[i6 + (i10 + 20 | 0) >> 2] = 0;
          HEAP32[i6 + (i10 + 16 | 0) >> 2] = 0;
          i14 = HEAP32[1314004] | 0;
          i16 = 1 << i42;
          if ((i14 & i16 | 0) == 0) {
            HEAP32[1314004] = i14 | i16;
            HEAP32[i3 >> 2] = i4;
            HEAP32[i6 + (i10 + 24 | 0) >> 2] = i3;
            HEAP32[i6 + (i10 + 12 | 0) >> 2] = i4;
            HEAP32[i6 + (i10 + 8 | 0) >> 2] = i4;
            break;
          }
          if ((i42 | 0) == 31) {
            i43 = 0;
          } else {
            i43 = 25 - (i42 >>> 1) | 0;
          }
          i16 = i35 << i43;
          i14 = HEAP32[i3 >> 2] | 0;
          while (1) {
            if ((HEAP32[i14 + 4 >> 2] & -8 | 0) == (i35 | 0)) {
              break;
            }
            i44 = i14 + 16 + (i16 >>> 31 << 2) | 0;
            i3 = HEAP32[i44 >> 2] | 0;
            if ((i3 | 0) == 0) {
              i45 = 1476;
              break;
            } else {
              i16 = i16 << 1;
              i14 = i3;
            }
          }
          if ((i45 | 0) == 1476) {
            if (i44 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
              _abort();
              return 0;
            } else {
              HEAP32[i44 >> 2] = i4;
              HEAP32[i6 + (i10 + 24 | 0) >> 2] = i14;
              HEAP32[i6 + (i10 + 12 | 0) >> 2] = i4;
              HEAP32[i6 + (i10 + 8 | 0) >> 2] = i4;
              break;
            }
          }
          i16 = i14 + 8 | 0;
          i3 = HEAP32[i16 >> 2] | 0;
          i9 = HEAP32[1314007] | 0;
          if (i14 >>> 0 < i9 >>> 0) {
            _abort();
            return 0;
          }
          if (i3 >>> 0 < i9 >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i3 + 12 >> 2] = i4;
            HEAP32[i16 >> 2] = i4;
            HEAP32[i6 + (i10 + 8 | 0) >> 2] = i3;
            HEAP32[i6 + (i10 + 12 | 0) >> 2] = i14;
            HEAP32[i6 + (i10 + 24 | 0) >> 2] = 0;
            break;
          }
        }
      } while (0);
      i6 = i36 + 8 | 0;
      if ((i6 | 0) == 0) {
        i13 = i10;
        break;
      } else {
        i12 = i6;
      }
      return i12 | 0;
    }
  } while (0);
  i36 = HEAP32[1314005] | 0;
  if (i13 >>> 0 <= i36 >>> 0) {
    i44 = i36 - i13 | 0;
    i35 = HEAP32[1314008] | 0;
    if (i44 >>> 0 > 15) {
      i43 = i35;
      HEAP32[1314008] = i43 + i13 | 0;
      HEAP32[1314005] = i44;
      HEAP32[i43 + (i13 + 4 | 0) >> 2] = i44 | 1;
      HEAP32[i43 + i36 >> 2] = i44;
      HEAP32[i35 + 4 >> 2] = i13 | 3;
    } else {
      HEAP32[1314005] = 0;
      HEAP32[1314008] = 0;
      HEAP32[i35 + 4 >> 2] = i36 | 3;
      i44 = i35 + (i36 + 4 | 0) | 0;
      HEAP32[i44 >> 2] = HEAP32[i44 >> 2] | 1;
    }
    i12 = i35 + 8 | 0;
    return i12 | 0;
  }
  i35 = HEAP32[1314006] | 0;
  if (i13 >>> 0 < i35 >>> 0) {
    i44 = i35 - i13 | 0;
    HEAP32[1314006] = i44;
    i35 = HEAP32[1314009] | 0;
    i36 = i35;
    HEAP32[1314009] = i36 + i13 | 0;
    HEAP32[i36 + (i13 + 4 | 0) >> 2] = i44 | 1;
    HEAP32[i35 + 4 >> 2] = i13 | 3;
    i12 = i35 + 8 | 0;
    return i12 | 0;
  }
  do {
    if ((HEAP32[1311054] | 0) == 0) {
      if ((HEAP32[1311054] | 0) != 0) {
        break;
      }
      i35 = _sysconf(8) | 0;
      if ((i35 - 1 & i35 | 0) == 0) {
        HEAP32[1311056] = i35;
        HEAP32[1311055] = i35;
        HEAP32[1311057] = -1;
        HEAP32[1311058] = 2097152;
        HEAP32[1311059] = 0;
        HEAP32[1314113] = 0;
        HEAP32[1311054] = _time(0) & -16 ^ 1431655768;
        break;
      } else {
        _abort();
        return 0;
      }
    }
  } while (0);
  L2103 : do {
    if ((HEAP32[1314113] & 4 | 0) == 0) {
      i35 = HEAP32[1314009] | 0;
      L2105 : do {
        if ((i35 | 0) == 0) {
          i45 = 1504;
        } else {
          i44 = i35;
          i36 = 5256456;
          while (1) {
            i46 = i36 | 0;
            i43 = HEAP32[i46 >> 2] | 0;
            if (i43 >>> 0 <= i44 >>> 0) {
              i47 = i36 + 4 | 0;
              if ((i43 + (HEAP32[i47 >> 2] | 0) | 0) >>> 0 > i44 >>> 0) {
                break;
              }
            }
            i43 = HEAP32[i36 + 8 >> 2] | 0;
            if ((i43 | 0) == 0) {
              i45 = 1504;
              break L2105;
            } else {
              i36 = i43;
            }
          }
          if ((i36 | 0) == 0) {
            i45 = 1504;
            break;
          }
          i44 = HEAP32[1311056] | 0;
          i14 = ((i13 + 47 | 0) - (HEAP32[1314006] | 0) | 0) + i44 & -i44;
          if (i14 >>> 0 >= 2147483647) {
            i48 = 0;
            break;
          }
          i44 = _sbrk(i14 | 0) | 0;
          i4 = (i44 | 0) == ((HEAP32[i46 >> 2] | 0) + (HEAP32[i47 >> 2] | 0) | 0);
          i49 = i4 ? i44 : -1;
          i50 = i4 ? i14 : 0;
          i51 = i44;
          i52 = i14;
          i45 = 1511;
          break;
        }
      } while (0);
      do {
        if ((i45 | 0) == 1504) {
          i35 = _sbrk(0) | 0;
          if ((i35 | 0) == -1) {
            i48 = 0;
            break;
          }
          i10 = HEAP32[1311056] | 0;
          i14 = (i13 + 47 | 0) + i10 & -i10;
          i10 = i35;
          i44 = HEAP32[1311055] | 0;
          i4 = i44 - 1 | 0;
          if ((i4 & i10 | 0) == 0) {
            i53 = i14;
          } else {
            i53 = (i14 - i10 | 0) + (i4 + i10 & -i44) | 0;
          }
          if (i53 >>> 0 >= 2147483647) {
            i48 = 0;
            break;
          }
          i44 = _sbrk(i53 | 0) | 0;
          i10 = (i44 | 0) == (i35 | 0);
          i49 = i10 ? i35 : -1;
          i50 = i10 ? i53 : 0;
          i51 = i44;
          i52 = i53;
          i45 = 1511;
          break;
        }
      } while (0);
      L2122 : do {
        if ((i45 | 0) == 1511) {
          i44 = -i52 | 0;
          if ((i49 | 0) != -1) {
            i54 = i50;
            i55 = i49;
            i45 = 1524;
            break L2103;
          }
          do {
            if ((i51 | 0) != -1 & i52 >>> 0 < 2147483647) {
              if (i52 >>> 0 >= (i13 + 48 | 0) >>> 0) {
                i56 = i52;
                break;
              }
              i10 = HEAP32[1311056] | 0;
              i35 = ((i13 + 47 | 0) - i52 | 0) + i10 & -i10;
              if (i35 >>> 0 >= 2147483647) {
                i56 = i52;
                break;
              }
              if ((_sbrk(i35 | 0) | 0) == -1) {
                _sbrk(i44 | 0) | 0;
                i48 = i50;
                break L2122;
              } else {
                i56 = i35 + i52 | 0;
                break;
              }
            } else {
              i56 = i52;
            }
          } while (0);
          if ((i51 | 0) != -1) {
            i54 = i56;
            i55 = i51;
            i45 = 1524;
            break L2103;
          }
          HEAP32[1314113] = HEAP32[1314113] | 4;
          i57 = i50;
          i45 = 1521;
          break L2103;
        }
      } while (0);
      HEAP32[1314113] = HEAP32[1314113] | 4;
      i57 = i48;
      i45 = 1521;
      break;
    } else {
      i57 = 0;
      i45 = 1521;
    }
  } while (0);
  do {
    if ((i45 | 0) == 1521) {
      i48 = HEAP32[1311056] | 0;
      i50 = (i13 + 47 | 0) + i48 & -i48;
      if (i50 >>> 0 >= 2147483647) {
        break;
      }
      i48 = _sbrk(i50 | 0) | 0;
      i50 = _sbrk(0) | 0;
      if (!((i50 | 0) != -1 & (i48 | 0) != -1 & i48 >>> 0 < i50 >>> 0)) {
        break;
      }
      i51 = i50 - i48 | 0;
      i50 = i51 >>> 0 > (i13 + 40 | 0) >>> 0;
      i56 = i50 ? i48 : -1;
      if ((i56 | 0) == -1) {
        break;
      } else {
        i54 = i50 ? i51 : i57;
        i55 = i56;
        i45 = 1524;
        break;
      }
    }
  } while (0);
  do {
    if ((i45 | 0) == 1524) {
      i57 = (HEAP32[1314111] | 0) + i54 | 0;
      HEAP32[1314111] = i57;
      if (i57 >>> 0 > (HEAP32[1314112] | 0) >>> 0) {
        HEAP32[1314112] = i57;
      }
      i57 = HEAP32[1314009] | 0;
      L2144 : do {
        if ((i57 | 0) == 0) {
          i56 = HEAP32[1314007] | 0;
          if ((i56 | 0) == 0 | i55 >>> 0 < i56 >>> 0) {
            HEAP32[1314007] = i55;
          }
          HEAP32[1314114] = i55;
          HEAP32[1314115] = i54;
          HEAP32[1314117] = 0;
          HEAP32[1314012] = HEAP32[1311054] | 0;
          HEAP32[1314011] = -1;
          i56 = 0;
          while (1) {
            i51 = i56 << 1;
            i50 = 5256052 + (i51 << 2) | 0;
            HEAP32[5256052 + (i51 + 3 << 2) >> 2] = i50;
            HEAP32[5256052 + (i51 + 2 << 2) >> 2] = i50;
            i50 = i56 + 1 | 0;
            if ((i50 | 0) == 32) {
              break;
            } else {
              i56 = i50;
            }
          }
          i56 = i55 + 8 | 0;
          if ((i56 & 7 | 0) == 0) {
            i58 = 0;
          } else {
            i58 = -i56 & 7;
          }
          i56 = (i54 - 40 | 0) - i58 | 0;
          HEAP32[1314009] = i55 + i58 | 0;
          HEAP32[1314006] = i56;
          HEAP32[i55 + (i58 + 4 | 0) >> 2] = i56 | 1;
          HEAP32[i55 + (i54 - 36 | 0) >> 2] = 40;
          HEAP32[1314010] = HEAP32[1311058] | 0;
        } else {
          i56 = 5256456;
          while (1) {
            i59 = HEAP32[i56 >> 2] | 0;
            i60 = i56 + 4 | 0;
            i61 = HEAP32[i60 >> 2] | 0;
            if ((i55 | 0) == (i59 + i61 | 0)) {
              i45 = 1536;
              break;
            }
            i50 = HEAP32[i56 + 8 >> 2] | 0;
            if ((i50 | 0) == 0) {
              break;
            } else {
              i56 = i50;
            }
          }
          do {
            if ((i45 | 0) == 1536) {
              if ((HEAP32[i56 + 12 >> 2] & 8 | 0) != 0) {
                break;
              }
              i50 = i57;
              if (!(i50 >>> 0 >= i59 >>> 0 & i50 >>> 0 < i55 >>> 0)) {
                break;
              }
              HEAP32[i60 >> 2] = i61 + i54 | 0;
              i50 = HEAP32[1314009] | 0;
              i51 = (HEAP32[1314006] | 0) + i54 | 0;
              i48 = i50;
              i52 = i50 + 8 | 0;
              if ((i52 & 7 | 0) == 0) {
                i62 = 0;
              } else {
                i62 = -i52 & 7;
              }
              i52 = i51 - i62 | 0;
              HEAP32[1314009] = i48 + i62 | 0;
              HEAP32[1314006] = i52;
              HEAP32[i48 + (i62 + 4 | 0) >> 2] = i52 | 1;
              HEAP32[i48 + (i51 + 4 | 0) >> 2] = 40;
              HEAP32[1314010] = HEAP32[1311058] | 0;
              break L2144;
            }
          } while (0);
          if (i55 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
            HEAP32[1314007] = i55;
          }
          i56 = i55 + i54 | 0;
          i51 = 5256456;
          while (1) {
            i63 = i51 | 0;
            if ((HEAP32[i63 >> 2] | 0) == (i56 | 0)) {
              i45 = 1546;
              break;
            }
            i48 = HEAP32[i51 + 8 >> 2] | 0;
            if ((i48 | 0) == 0) {
              break;
            } else {
              i51 = i48;
            }
          }
          do {
            if ((i45 | 0) == 1546) {
              if ((HEAP32[i51 + 12 >> 2] & 8 | 0) != 0) {
                break;
              }
              HEAP32[i63 >> 2] = i55;
              i56 = i51 + 4 | 0;
              HEAP32[i56 >> 2] = (HEAP32[i56 >> 2] | 0) + i54 | 0;
              i56 = i55 + 8 | 0;
              if ((i56 & 7 | 0) == 0) {
                i64 = 0;
              } else {
                i64 = -i56 & 7;
              }
              i56 = i55 + (i54 + 8 | 0) | 0;
              if ((i56 & 7 | 0) == 0) {
                i65 = 0;
              } else {
                i65 = -i56 & 7;
              }
              i56 = i55 + (i65 + i54 | 0) | 0;
              i48 = i56;
              i52 = i64 + i13 | 0;
              i50 = i55 + i52 | 0;
              i49 = i50;
              i53 = (i56 - (i55 + i64 | 0) | 0) - i13 | 0;
              HEAP32[i55 + (i64 + 4 | 0) >> 2] = i13 | 3;
              do {
                if ((i48 | 0) == (HEAP32[1314009] | 0)) {
                  i47 = (HEAP32[1314006] | 0) + i53 | 0;
                  HEAP32[1314006] = i47;
                  HEAP32[1314009] = i49;
                  HEAP32[i55 + (i52 + 4 | 0) >> 2] = i47 | 1;
                } else {
                  if ((i48 | 0) == (HEAP32[1314008] | 0)) {
                    i47 = (HEAP32[1314005] | 0) + i53 | 0;
                    HEAP32[1314005] = i47;
                    HEAP32[1314008] = i49;
                    HEAP32[i55 + (i52 + 4 | 0) >> 2] = i47 | 1;
                    HEAP32[i55 + (i47 + i52 | 0) >> 2] = i47;
                    break;
                  }
                  i47 = i54 + 4 | 0;
                  i46 = HEAP32[i55 + (i47 + i65 | 0) >> 2] | 0;
                  if ((i46 & 3 | 0) == 1) {
                    i44 = i46 & -8;
                    i36 = i46 >>> 3;
                    L2189 : do {
                      if (i46 >>> 0 < 256) {
                        i35 = HEAP32[i55 + ((i65 | 8) + i54 | 0) >> 2] | 0;
                        i10 = HEAP32[i55 + ((i54 + 12 | 0) + i65 | 0) >> 2] | 0;
                        if ((i35 | 0) == (i10 | 0)) {
                          HEAP32[1314003] = HEAP32[1314003] & (1 << i36 ^ -1);
                          break;
                        }
                        i4 = 5256052 + (i36 << 1 << 2) | 0;
                        do {
                          if ((i35 | 0) != (i4 | 0)) {
                            if (i35 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                              break;
                            }
                            _abort();
                            return 0;
                          }
                        } while (0);
                        do {
                          if ((i10 | 0) != (i4 | 0)) {
                            if (i10 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                              break;
                            }
                            _abort();
                            return 0;
                          }
                        } while (0);
                        HEAP32[i35 + 12 >> 2] = i10;
                        HEAP32[i10 + 8 >> 2] = i35;
                      } else {
                        i4 = i56;
                        i14 = HEAP32[i55 + ((i65 | 24) + i54 | 0) >> 2] | 0;
                        i43 = HEAP32[i55 + ((i54 + 12 | 0) + i65 | 0) >> 2] | 0;
                        L2203 : do {
                          if ((i43 | 0) == (i4 | 0)) {
                            i42 = i65 | 16;
                            i40 = i55 + (i47 + i42 | 0) | 0;
                            i41 = HEAP32[i40 >> 2] | 0;
                            do {
                              if ((i41 | 0) == 0) {
                                i37 = i55 + (i42 + i54 | 0) | 0;
                                i38 = HEAP32[i37 >> 2] | 0;
                                if ((i38 | 0) == 0) {
                                  i66 = 0;
                                  break L2203;
                                } else {
                                  i67 = i38;
                                  i68 = i37;
                                  break;
                                }
                              } else {
                                i67 = i41;
                                i68 = i40;
                              }
                            } while (0);
                            while (1) {
                              i40 = i67 + 20 | 0;
                              i41 = HEAP32[i40 >> 2] | 0;
                              if ((i41 | 0) != 0) {
                                i67 = i41;
                                i68 = i40;
                                continue;
                              }
                              i40 = i67 + 16 | 0;
                              i41 = HEAP32[i40 >> 2] | 0;
                              if ((i41 | 0) == 0) {
                                break;
                              } else {
                                i67 = i41;
                                i68 = i40;
                              }
                            }
                            if (i68 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                              _abort();
                              return 0;
                            } else {
                              HEAP32[i68 >> 2] = 0;
                              i66 = i67;
                              break;
                            }
                          } else {
                            i40 = HEAP32[i55 + ((i65 | 8) + i54 | 0) >> 2] | 0;
                            if (i40 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                              _abort();
                              return 0;
                            } else {
                              HEAP32[i40 + 12 >> 2] = i43;
                              HEAP32[i43 + 8 >> 2] = i40;
                              i66 = i43;
                              break;
                            }
                          }
                        } while (0);
                        if ((i14 | 0) == 0) {
                          break;
                        }
                        i43 = i55 + ((i54 + 28 | 0) + i65 | 0) | 0;
                        i35 = 5256316 + (HEAP32[i43 >> 2] << 2) | 0;
                        do {
                          if ((i4 | 0) == (HEAP32[i35 >> 2] | 0)) {
                            HEAP32[i35 >> 2] = i66;
                            if ((i66 | 0) != 0) {
                              break;
                            }
                            HEAP32[1314004] = HEAP32[1314004] & (1 << HEAP32[i43 >> 2] ^ -1);
                            break L2189;
                          } else {
                            if (i14 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                              _abort();
                              return 0;
                            }
                            i10 = i14 + 16 | 0;
                            if ((HEAP32[i10 >> 2] | 0) == (i4 | 0)) {
                              HEAP32[i10 >> 2] = i66;
                            } else {
                              HEAP32[i14 + 20 >> 2] = i66;
                            }
                            if ((i66 | 0) == 0) {
                              break L2189;
                            }
                          }
                        } while (0);
                        if (i66 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                          _abort();
                          return 0;
                        }
                        HEAP32[i66 + 24 >> 2] = i14;
                        i4 = i65 | 16;
                        i43 = HEAP32[i55 + (i4 + i54 | 0) >> 2] | 0;
                        do {
                          if ((i43 | 0) != 0) {
                            if (i43 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                              _abort();
                              return 0;
                            } else {
                              HEAP32[i66 + 16 >> 2] = i43;
                              HEAP32[i43 + 24 >> 2] = i66;
                              break;
                            }
                          }
                        } while (0);
                        i43 = HEAP32[i55 + (i47 + i4 | 0) >> 2] | 0;
                        if ((i43 | 0) == 0) {
                          break;
                        }
                        if (i43 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                          _abort();
                          return 0;
                        } else {
                          HEAP32[i66 + 20 >> 2] = i43;
                          HEAP32[i43 + 24 >> 2] = i66;
                          break;
                        }
                      }
                    } while (0);
                    i69 = i55 + ((i44 | i65) + i54 | 0) | 0;
                    i70 = i44 + i53 | 0;
                  } else {
                    i69 = i48;
                    i70 = i53;
                  }
                  i47 = i69 + 4 | 0;
                  HEAP32[i47 >> 2] = HEAP32[i47 >> 2] & -2;
                  HEAP32[i55 + (i52 + 4 | 0) >> 2] = i70 | 1;
                  HEAP32[i55 + (i70 + i52 | 0) >> 2] = i70;
                  i47 = i70 >>> 3;
                  if (i70 >>> 0 < 256) {
                    i36 = i47 << 1;
                    i46 = 5256052 + (i36 << 2) | 0;
                    i43 = HEAP32[1314003] | 0;
                    i14 = 1 << i47;
                    do {
                      if ((i43 & i14 | 0) == 0) {
                        HEAP32[1314003] = i43 | i14;
                        i71 = i46;
                        i72 = 5256052 + (i36 + 2 << 2) | 0;
                      } else {
                        i47 = 5256052 + (i36 + 2 << 2) | 0;
                        i35 = HEAP32[i47 >> 2] | 0;
                        if (i35 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                          i71 = i35;
                          i72 = i47;
                          break;
                        }
                        _abort();
                        return 0;
                      }
                    } while (0);
                    HEAP32[i72 >> 2] = i49;
                    HEAP32[i71 + 12 >> 2] = i49;
                    HEAP32[i55 + (i52 + 8 | 0) >> 2] = i71;
                    HEAP32[i55 + (i52 + 12 | 0) >> 2] = i46;
                    break;
                  }
                  i36 = i50;
                  i14 = i70 >>> 8;
                  do {
                    if ((i14 | 0) == 0) {
                      i73 = 0;
                    } else {
                      if (i70 >>> 0 > 16777215) {
                        i73 = 31;
                        break;
                      }
                      i43 = (i14 + 1048320 | 0) >>> 16 & 8;
                      i44 = i14 << i43;
                      i47 = (i44 + 520192 | 0) >>> 16 & 4;
                      i35 = i44 << i47;
                      i44 = (i35 + 245760 | 0) >>> 16 & 2;
                      i10 = (14 - (i47 | i43 | i44) | 0) + (i35 << i44 >>> 15) | 0;
                      i73 = i70 >>> ((i10 + 7 | 0) >>> 0) & 1 | i10 << 1;
                    }
                  } while (0);
                  i14 = 5256316 + (i73 << 2) | 0;
                  HEAP32[i55 + (i52 + 28 | 0) >> 2] = i73;
                  HEAP32[i55 + (i52 + 20 | 0) >> 2] = 0;
                  HEAP32[i55 + (i52 + 16 | 0) >> 2] = 0;
                  i46 = HEAP32[1314004] | 0;
                  i10 = 1 << i73;
                  if ((i46 & i10 | 0) == 0) {
                    HEAP32[1314004] = i46 | i10;
                    HEAP32[i14 >> 2] = i36;
                    HEAP32[i55 + (i52 + 24 | 0) >> 2] = i14;
                    HEAP32[i55 + (i52 + 12 | 0) >> 2] = i36;
                    HEAP32[i55 + (i52 + 8 | 0) >> 2] = i36;
                    break;
                  }
                  if ((i73 | 0) == 31) {
                    i74 = 0;
                  } else {
                    i74 = 25 - (i73 >>> 1) | 0;
                  }
                  i10 = i70 << i74;
                  i46 = HEAP32[i14 >> 2] | 0;
                  while (1) {
                    if ((HEAP32[i46 + 4 >> 2] & -8 | 0) == (i70 | 0)) {
                      break;
                    }
                    i75 = i46 + 16 + (i10 >>> 31 << 2) | 0;
                    i14 = HEAP32[i75 >> 2] | 0;
                    if ((i14 | 0) == 0) {
                      i45 = 1613;
                      break;
                    } else {
                      i10 = i10 << 1;
                      i46 = i14;
                    }
                  }
                  if ((i45 | 0) == 1613) {
                    if (i75 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
                      _abort();
                      return 0;
                    } else {
                      HEAP32[i75 >> 2] = i36;
                      HEAP32[i55 + (i52 + 24 | 0) >> 2] = i46;
                      HEAP32[i55 + (i52 + 12 | 0) >> 2] = i36;
                      HEAP32[i55 + (i52 + 8 | 0) >> 2] = i36;
                      break;
                    }
                  }
                  i10 = i46 + 8 | 0;
                  i14 = HEAP32[i10 >> 2] | 0;
                  i44 = HEAP32[1314007] | 0;
                  if (i46 >>> 0 < i44 >>> 0) {
                    _abort();
                    return 0;
                  }
                  if (i14 >>> 0 < i44 >>> 0) {
                    _abort();
                    return 0;
                  } else {
                    HEAP32[i14 + 12 >> 2] = i36;
                    HEAP32[i10 >> 2] = i36;
                    HEAP32[i55 + (i52 + 8 | 0) >> 2] = i14;
                    HEAP32[i55 + (i52 + 12 | 0) >> 2] = i46;
                    HEAP32[i55 + (i52 + 24 | 0) >> 2] = 0;
                    break;
                  }
                }
              } while (0);
              i12 = i55 + (i64 | 8) | 0;
              return i12 | 0;
            }
          } while (0);
          i51 = i57;
          i52 = 5256456;
          while (1) {
            i76 = HEAP32[i52 >> 2] | 0;
            if (i76 >>> 0 <= i51 >>> 0) {
              i77 = HEAP32[i52 + 4 >> 2] | 0;
              i78 = i76 + i77 | 0;
              if (i78 >>> 0 > i51 >>> 0) {
                break;
              }
            }
            i52 = HEAP32[i52 + 8 >> 2] | 0;
          }
          i52 = i76 + (i77 - 39 | 0) | 0;
          if ((i52 & 7 | 0) == 0) {
            i79 = 0;
          } else {
            i79 = -i52 & 7;
          }
          i52 = i76 + ((i77 - 47 | 0) + i79 | 0) | 0;
          i50 = i52 >>> 0 < (i57 + 16 | 0) >>> 0 ? i51 : i52;
          i52 = i50 + 8 | 0;
          i49 = i55 + 8 | 0;
          if ((i49 & 7 | 0) == 0) {
            i80 = 0;
          } else {
            i80 = -i49 & 7;
          }
          i49 = (i54 - 40 | 0) - i80 | 0;
          HEAP32[1314009] = i55 + i80 | 0;
          HEAP32[1314006] = i49;
          HEAP32[i55 + (i80 + 4 | 0) >> 2] = i49 | 1;
          HEAP32[i55 + (i54 - 36 | 0) >> 2] = 40;
          HEAP32[1314010] = HEAP32[1311058] | 0;
          HEAP32[i50 + 4 >> 2] = 27;
          HEAP32[i52 >> 2] = HEAP32[1314114] | 0;
          HEAP32[i52 + 4 >> 2] = HEAP32[5256460 >> 2] | 0;
          HEAP32[i52 + 8 >> 2] = HEAP32[5256464 >> 2] | 0;
          HEAP32[i52 + 12 >> 2] = HEAP32[5256468 >> 2] | 0;
          HEAP32[1314114] = i55;
          HEAP32[1314115] = i54;
          HEAP32[1314117] = 0;
          HEAP32[1314116] = i52;
          i52 = i50 + 28 | 0;
          HEAP32[i52 >> 2] = 7;
          L2295 : do {
            if ((i50 + 32 | 0) >>> 0 < i78 >>> 0) {
              i49 = i52;
              while (1) {
                i53 = i49 + 4 | 0;
                HEAP32[i53 >> 2] = 7;
                if ((i49 + 8 | 0) >>> 0 < i78 >>> 0) {
                  i49 = i53;
                } else {
                  break L2295;
                }
              }
            }
          } while (0);
          if ((i50 | 0) == (i51 | 0)) {
            break;
          }
          i52 = i50 - i57 | 0;
          i49 = i51 + (i52 + 4 | 0) | 0;
          HEAP32[i49 >> 2] = HEAP32[i49 >> 2] & -2;
          HEAP32[i57 + 4 >> 2] = i52 | 1;
          HEAP32[i51 + i52 >> 2] = i52;
          i49 = i52 >>> 3;
          if (i52 >>> 0 < 256) {
            i53 = i49 << 1;
            i48 = 5256052 + (i53 << 2) | 0;
            i56 = HEAP32[1314003] | 0;
            i14 = 1 << i49;
            do {
              if ((i56 & i14 | 0) == 0) {
                HEAP32[1314003] = i56 | i14;
                i81 = i48;
                i82 = 5256052 + (i53 + 2 << 2) | 0;
              } else {
                i49 = 5256052 + (i53 + 2 << 2) | 0;
                i10 = HEAP32[i49 >> 2] | 0;
                if (i10 >>> 0 >= (HEAP32[1314007] | 0) >>> 0) {
                  i81 = i10;
                  i82 = i49;
                  break;
                }
                _abort();
                return 0;
              }
            } while (0);
            HEAP32[i82 >> 2] = i57;
            HEAP32[i81 + 12 >> 2] = i57;
            HEAP32[i57 + 8 >> 2] = i81;
            HEAP32[i57 + 12 >> 2] = i48;
            break;
          }
          i53 = i57;
          i14 = i52 >>> 8;
          do {
            if ((i14 | 0) == 0) {
              i83 = 0;
            } else {
              if (i52 >>> 0 > 16777215) {
                i83 = 31;
                break;
              }
              i56 = (i14 + 1048320 | 0) >>> 16 & 8;
              i51 = i14 << i56;
              i50 = (i51 + 520192 | 0) >>> 16 & 4;
              i49 = i51 << i50;
              i51 = (i49 + 245760 | 0) >>> 16 & 2;
              i10 = (14 - (i50 | i56 | i51) | 0) + (i49 << i51 >>> 15) | 0;
              i83 = i52 >>> ((i10 + 7 | 0) >>> 0) & 1 | i10 << 1;
            }
          } while (0);
          i14 = 5256316 + (i83 << 2) | 0;
          HEAP32[i57 + 28 >> 2] = i83;
          HEAP32[i57 + 20 >> 2] = 0;
          HEAP32[i57 + 16 >> 2] = 0;
          i48 = HEAP32[1314004] | 0;
          i10 = 1 << i83;
          if ((i48 & i10 | 0) == 0) {
            HEAP32[1314004] = i48 | i10;
            HEAP32[i14 >> 2] = i53;
            HEAP32[i57 + 24 >> 2] = i14;
            HEAP32[i57 + 12 >> 2] = i57;
            HEAP32[i57 + 8 >> 2] = i57;
            break;
          }
          if ((i83 | 0) == 31) {
            i84 = 0;
          } else {
            i84 = 25 - (i83 >>> 1) | 0;
          }
          i10 = i52 << i84;
          i48 = HEAP32[i14 >> 2] | 0;
          while (1) {
            if ((HEAP32[i48 + 4 >> 2] & -8 | 0) == (i52 | 0)) {
              break;
            }
            i85 = i48 + 16 + (i10 >>> 31 << 2) | 0;
            i14 = HEAP32[i85 >> 2] | 0;
            if ((i14 | 0) == 0) {
              i45 = 1648;
              break;
            } else {
              i10 = i10 << 1;
              i48 = i14;
            }
          }
          if ((i45 | 0) == 1648) {
            if (i85 >>> 0 < (HEAP32[1314007] | 0) >>> 0) {
              _abort();
              return 0;
            } else {
              HEAP32[i85 >> 2] = i53;
              HEAP32[i57 + 24 >> 2] = i48;
              HEAP32[i57 + 12 >> 2] = i57;
              HEAP32[i57 + 8 >> 2] = i57;
              break;
            }
          }
          i10 = i48 + 8 | 0;
          i52 = HEAP32[i10 >> 2] | 0;
          i14 = HEAP32[1314007] | 0;
          if (i48 >>> 0 < i14 >>> 0) {
            _abort();
            return 0;
          }
          if (i52 >>> 0 < i14 >>> 0) {
            _abort();
            return 0;
          } else {
            HEAP32[i52 + 12 >> 2] = i53;
            HEAP32[i10 >> 2] = i53;
            HEAP32[i57 + 8 >> 2] = i52;
            HEAP32[i57 + 12 >> 2] = i48;
            HEAP32[i57 + 24 >> 2] = 0;
            break;
          }
        }
      } while (0);
      i57 = HEAP32[1314006] | 0;
      if (i57 >>> 0 <= i13 >>> 0) {
        break;
      }
      i52 = i57 - i13 | 0;
      HEAP32[1314006] = i52;
      i57 = HEAP32[1314009] | 0;
      i10 = i57;
      HEAP32[1314009] = i10 + i13 | 0;
      HEAP32[i10 + (i13 + 4 | 0) >> 2] = i52 | 1;
      HEAP32[i57 + 4 >> 2] = i13 | 3;
      i12 = i57 + 8 | 0;
      return i12 | 0;
    }
  } while (0);
  HEAP32[___errno_location() >> 2] = 12;
  i12 = 0;
  return i12 | 0;
}
function _strlen(i1) {
  i1 = i1 | 0;
  var i2 = 0;
  i2 = i1;
  while (HEAP8[i2] | 0 != 0) {
    i2 = i2 + 1 | 0;
  }
  return i2 - i1 | 0;
}
function _memset(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0, i5 = 0, i6 = 0;
  i4 = i1 + i3 | 0;
  if (i3 | 0 >= 20) {
    i3 = i1 & 3;
    i5 = i2 | i2 << 8 | i2 << 16 | i2 << 24;
    i6 = i4 & ~3;
    if (i3) {
      i3 = i1 + 4 - i3 | 0;
      while ((i1 | 0) < (i3 | 0)) {
        HEAP8[i1] = i2;
        i1 = i1 + 1 | 0;
      }
    }
    while ((i1 | 0) < (i6 | 0)) {
      HEAP32[i1 >> 2] = i5;
      i1 = i1 + 4 | 0;
    }
  }
  while ((i1 | 0) < (i4 | 0)) {
    HEAP8[i1] = i2;
    i1 = i1 + 1 | 0;
  }
}
function _memcpy(i1, i2, i3) {
  i1 = i1 | 0;
  i2 = i2 | 0;
  i3 = i3 | 0;
  var i4 = 0;
  i4 = i1 | 0;
  if ((i1 & 3) == (i2 & 3)) {
    while (i1 & 3) {
      if ((i3 | 0) == 0) return i4 | 0;
      HEAP8[i1] = HEAP8[i2] | 0;
      i1 = i1 + 1 | 0;
      i2 = i2 + 1 | 0;
      i3 = i3 - 1 | 0;
    }
    while ((i3 | 0) >= 4) {
      HEAP32[i1 >> 2] = HEAP32[i2 >> 2] | 0;
      i1 = i1 + 4 | 0;
      i2 = i2 + 4 | 0;
      i3 = i3 - 4 | 0;
    }
  }
  while ((i3 | 0) > 0) {
    HEAP8[i1] = HEAP8[i2] | 0;
    i1 = i1 + 1 | 0;
    i2 = i2 + 1 | 0;
    i3 = i3 - 1 | 0;
  }
  return i4 | 0;
}






  
  function dynCall_iiii(index,a1,a2,a3) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0;
    return FUNCTION_TABLE_iiii[index&15](a1|0,a2|0,a3|0)|0;
  }


  function dynCall_vi(index,a1) {
    index = index|0;
    a1=a1|0;
    FUNCTION_TABLE_vi[index&15](a1|0);
  }


  function dynCall_vii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    FUNCTION_TABLE_vii[index&15](a1|0,a2|0);
  }


  function dynCall_ii(index,a1) {
    index = index|0;
    a1=a1|0;
    return FUNCTION_TABLE_ii[index&15](a1|0)|0;
  }


  function dynCall_v(index) {
    index = index|0;
    
    FUNCTION_TABLE_v[index&15]();
  }


  function dynCall_iii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    return FUNCTION_TABLE_iii[index&15](a1|0,a2|0)|0;
  }

function b0(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(0); return 0 };
  function b1(p0) { p0 = p0|0; abort(1);  };
  function b2(p0,p1) { p0 = p0|0;p1 = p1|0; abort(2);  };
  function b3(p0) { p0 = p0|0; abort(3); return 0 };
  function b4() { ; abort(4);  };
  function b5(p0,p1) { p0 = p0|0;p1 = p1|0; abort(5); return 0 };
  var FUNCTION_TABLE_iiii = [b0,b0,b0,b0,_zcalloc,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0];
  
  var FUNCTION_TABLE_vi = [b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1];
  
  var FUNCTION_TABLE_vii = [b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,_zcfree,b2,b2,b2,b2,b2];
  
  var FUNCTION_TABLE_ii = [b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3];
  
  var FUNCTION_TABLE_v = [b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4];
  
  var FUNCTION_TABLE_iii = [b5,b5,_deflate_fast,b5,b5,b5,_deflate_slow,b5,_deflate_stored,b5,b5,b5,b5,b5,b5,b5];
  

  return { _malloc: _malloc, _strlen: _strlen, _memcpy: _memcpy, _main: _main, _memset: _memset, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, setTempRet1: setTempRet1, setTempRet2: setTempRet2, setTempRet3: setTempRet3, setTempRet4: setTempRet4, setTempRet5: setTempRet5, setTempRet6: setTempRet6, setTempRet7: setTempRet7, setTempRet8: setTempRet8, setTempRet9: setTempRet9, dynCall_iiii: dynCall_iiii, dynCall_vi: dynCall_vi, dynCall_vii: dynCall_vii, dynCall_ii: dynCall_ii, dynCall_v: dynCall_v, dynCall_iii: dynCall_iii };
})({ Math: Math, Int8Array: Int8Array, Int16Array: Int16Array, Int32Array: Int32Array, Uint8Array: Uint8Array, Uint16Array: Uint16Array, Uint32Array: Uint32Array, Float32Array: Float32Array, Float64Array: Float64Array }, { abort: abort, assert: assert, asmPrintInt: asmPrintInt, asmPrintFloat: asmPrintFloat, copyTempDouble: copyTempDouble, copyTempFloat: copyTempFloat, Runtime_bitshift64: Runtime_bitshift64, min: Math_min, _strncmp: _strncmp, _llvm_lifetime_end: _llvm_lifetime_end, _sysconf: _sysconf, _abort: _abort, _fprintf: _fprintf, _printf: _printf, _strtol: _strtol, _fputc: _fputc, _puts: _puts, ___setErrNo: ___setErrNo, _fwrite: _fwrite, _write: _write, _fputs: _fputs, _isspace: _isspace, __formatString: __formatString, _free: _free, _atoi: _atoi, ___assert_func: ___assert_func, _pwrite: _pwrite, _sbrk: _sbrk, ___errno_location: ___errno_location, _llvm_lifetime_start: _llvm_lifetime_start, _llvm_bswap_i32: _llvm_bswap_i32, __parseInt: __parseInt, _time: _time, _strcmp: _strcmp, STACKTOP: STACKTOP, STACK_MAX: STACK_MAX, tempDoublePtr: tempDoublePtr, ABORT: ABORT, NaN: NaN, Infinity: Infinity }, buffer);
var _malloc = Module["_malloc"] = asm._malloc;
var _strlen = Module["_strlen"] = asm._strlen;
var _memcpy = Module["_memcpy"] = asm._memcpy;
var _main = Module["_main"] = asm._main;
var _memset = Module["_memset"] = asm._memset;
var dynCall_iiii = Module["dynCall_iiii"] = asm.dynCall_iiii;
var dynCall_vi = Module["dynCall_vi"] = asm.dynCall_vi;
var dynCall_vii = Module["dynCall_vii"] = asm.dynCall_vii;
var dynCall_ii = Module["dynCall_ii"] = asm.dynCall_ii;
var dynCall_v = Module["dynCall_v"] = asm.dynCall_v;
var dynCall_iii = Module["dynCall_iii"] = asm.dynCall_iii;
Runtime.stackAlloc = function(size) { return asm.stackAlloc(size) };
Runtime.stackSave = function() { return asm.stackSave() };
Runtime.stackRestore = function(top) { asm.stackRestore(top) };
// Warning: printing of i64 values may be slightly rounded! No deep i64 math used, so precise i64 code not included
var i64Math = null;

// === Auto-generated postamble setup entry stuff ===

Module.callMain = function callMain(args) {
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_STATIC) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_STATIC));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_STATIC);


  var ret;

  ret = Module['_main'](argc, argv, 0);


  return ret;
}




function run(args) {
  args = args || Module['arguments'];

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }

  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }

  function doRun() {
    var ret = 0;
    calledRun = true;
    if (Module['_main']) {
      preMain();
      ret = Module.callMain(args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = Module.run = run;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

initRuntime();

var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}

if (shouldRunNow) {
  var ret = run(['100000', '500']);
}

// {{POST_RUN_ADDITIONS}}






  // {{MODULE_ADDITIONS}}


// EMSCRIPTEN_GENERATED_FUNCTIONS: ["_strlen","_main","_adler32","_doit","_inflate_table","_deflate_stored","_send_tree","_longest_match","_memset","_memcpy","_zcalloc","_init_block","__tr_flush_block","_deflate_slow","_deflate_fast","__tr_stored_block","_zcfree","_compress_block","_malloc","_crc32","_fill_window","_build_tree"]



